var Ws = Object.defineProperty;
var Ia = (n) => {
  throw TypeError(n);
};
var js = (n, e, t) => e in n ? Ws(n, e, { enumerable: !0, configurable: !0, writable: !0, value: t }) : n[e] = t;
var ve = (n, e, t) => js(n, typeof e != "symbol" ? e + "" : e, t), Xs = (n, e, t) => e.has(n) || Ia("Cannot " + t);
var La = (n, e, t) => e.has(n) ? Ia("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(n) : e.set(n, t);
var hr = (n, e, t) => (Xs(n, e, "access private method"), t);
const {
  SvelteComponent: Zs,
  append_hydration: Ks,
  attr: Tt,
  children: Oa,
  claim_element: Pa,
  detach: an,
  element: Ha,
  init: Qs,
  insert_hydration: Js,
  noop: Ua,
  safe_not_equal: eo,
  src_url_equal: Va
} = window.__gradio__svelte__internal, { createEventDispatcher: to } = window.__gradio__svelte__internal;
function ro(n) {
  let e, t, r, a;
  return {
    c() {
      e = Ha("div"), t = Ha("iframe"), this.h();
    },
    l(i) {
      e = Pa(i, "DIV", { class: !0 });
      var l = Oa(e);
      t = Pa(l, "IFRAME", {
        id: !0,
        title: !0,
        src: !0,
        allow: !0,
        sandbox: !0,
        allowtransparency: !0,
        class: !0
      }), Oa(t).forEach(an), l.forEach(an), this.h();
    },
    h() {
      Tt(t, "id", "sandboxIframe"), Tt(t, "title", "iframe component"), Va(t.src, r = /*value*/
      n[0]) || Tt(t, "src", r), Tt(t, "allow", "accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share; display-capture"), Tt(t, "sandbox", "allow-forms allow-pointer-lock allow-popups allow-same-origin allow-scripts allow-modals"), Tt(t, "allowtransparency", ""), t.allowFullscreen = !0, Tt(t, "class", "w-full h-full"), Tt(e, "class", a = `relative w-full h-full ${/*min_height*/
      n[2] ? "min" : ""} ${/*visible*/
      n[1] ? "" : "hidden"} bg-white`);
    },
    m(i, l) {
      Js(i, e, l), Ks(e, t);
    },
    p(i, [l]) {
      l & /*value*/
      1 && !Va(t.src, r = /*value*/
      i[0]) && Tt(t, "src", r), l & /*min_height, visible*/
      6 && a !== (a = `relative w-full h-full ${/*min_height*/
      i[2] ? "min" : ""} ${/*visible*/
      i[1] ? "" : "hidden"} bg-white`) && Tt(e, "class", a);
    },
    i: Ua,
    o: Ua,
    d(i) {
      i && an(e);
    }
  };
}
function no(n, e, t) {
  const r = [];
  let { value: a } = e, { visible: i = !0 } = e, { min_height: l = !1 } = e;
  const o = to();
  return n.$$set = (u) => {
    "value" in u && t(0, a = u.value), "visible" in u && t(1, i = u.visible), "min_height" in u && t(2, l = u.min_height);
  }, n.$$.update = () => {
    n.$$.dirty & /*value*/
    1 && o("change");
  }, [a, i, l, r];
}
class ao extends Zs {
  constructor(e) {
    super(), Qs(this, e, no, ro, eo, {
      elem_classes: 3,
      value: 0,
      visible: 1,
      min_height: 2
    });
  }
  get elem_classes() {
    return this.$$.ctx[3];
  }
}
function T0(n) {
  let e = ["", "k", "M", "G", "T", "P", "E", "Z"], t = 0;
  for (; n > 1e3 && t < e.length - 1; )
    n /= 1e3, t++;
  let r = e[t];
  return (Number.isInteger(n) ? n : n.toFixed(1)) + r;
}
function Tr() {
}
function io(n, e) {
  return n != n ? e == e : n !== e || n && typeof n == "object" || typeof n == "function";
}
const _l = typeof window < "u";
let Ga = _l ? () => window.performance.now() : () => Date.now(), bl = _l ? (n) => requestAnimationFrame(n) : Tr;
const $0 = /* @__PURE__ */ new Set();
function yl(n) {
  $0.forEach((e) => {
    e.c(n) || ($0.delete(e), e.f());
  }), $0.size !== 0 && bl(yl);
}
function lo(n) {
  let e;
  return $0.size === 0 && bl(yl), {
    promise: new Promise((t) => {
      $0.add(e = { c: n, f: t });
    }),
    abort() {
      $0.delete(e);
    }
  };
}
const A0 = [];
function so(n, e = Tr) {
  let t;
  const r = /* @__PURE__ */ new Set();
  function a(o) {
    if (io(n, o) && (n = o, t)) {
      const u = !A0.length;
      for (const h of r)
        h[1](), A0.push(h, n);
      if (u) {
        for (let h = 0; h < A0.length; h += 2)
          A0[h][0](A0[h + 1]);
        A0.length = 0;
      }
    }
  }
  function i(o) {
    a(o(n));
  }
  function l(o, u = Tr) {
    const h = [o, u];
    return r.add(h), r.size === 1 && (t = e(a, i) || Tr), o(n), () => {
      r.delete(h), r.size === 0 && t && (t(), t = null);
    };
  }
  return { set: a, update: i, subscribe: l };
}
function Ya(n) {
  return Object.prototype.toString.call(n) === "[object Date]";
}
function Cn(n, e, t, r) {
  if (typeof t == "number" || Ya(t)) {
    const a = r - t, i = (t - e) / (n.dt || 1 / 60), l = n.opts.stiffness * a, o = n.opts.damping * i, u = (l - o) * n.inv_mass, h = (i + u) * n.dt;
    return Math.abs(h) < n.opts.precision && Math.abs(a) < n.opts.precision ? r : (n.settled = !1, Ya(t) ? new Date(t.getTime() + h) : t + h);
  } else {
    if (Array.isArray(t))
      return t.map(
        (a, i) => Cn(n, e[i], t[i], r[i])
      );
    if (typeof t == "object") {
      const a = {};
      for (const i in t)
        a[i] = Cn(n, e[i], t[i], r[i]);
      return a;
    } else
      throw new Error(`Cannot spring ${typeof t} values`);
  }
}
function Wa(n, e = {}) {
  const t = so(n), { stiffness: r = 0.15, damping: a = 0.8, precision: i = 0.01 } = e;
  let l, o, u, h = n, d = n, p = 1, b = 0, y = !1;
  function D(C, T = {}) {
    d = C;
    const w = u = {};
    return n == null || T.hard || A.stiffness >= 1 && A.damping >= 1 ? (y = !0, l = Ga(), h = C, t.set(n = d), Promise.resolve()) : (T.soft && (b = 1 / ((T.soft === !0 ? 0.5 : +T.soft) * 60), p = 0), o || (l = Ga(), y = !1, o = lo((g) => {
      if (y)
        return y = !1, o = null, !1;
      p = Math.min(p + b, 1);
      const S = {
        inv_mass: p,
        opts: A,
        settled: !0,
        dt: (g - l) * 60 / 1e3
      }, E = Cn(S, h, n, d);
      return l = g, h = n, t.set(n = E), S.settled && (o = null), !S.settled;
    })), new Promise((g) => {
      o.promise.then(() => {
        w === u && g();
      });
    }));
  }
  const A = {
    set: D,
    update: (C, T) => D(C(d, n), T),
    subscribe: t.subscribe,
    stiffness: r,
    damping: a,
    precision: i
  };
  return A;
}
const {
  SvelteComponent: oo,
  append_hydration: pt,
  attr: le,
  children: nt,
  claim_element: uo,
  claim_svg_element: gt,
  component_subscribe: ja,
  detach: Ke,
  element: co,
  init: ho,
  insert_hydration: mo,
  noop: Xa,
  safe_not_equal: fo,
  set_style: mr,
  svg_element: vt,
  toggle_class: Za
} = window.__gradio__svelte__internal, { onMount: po } = window.__gradio__svelte__internal;
function go(n) {
  let e, t, r, a, i, l, o, u, h, d, p, b;
  return {
    c() {
      e = co("div"), t = vt("svg"), r = vt("g"), a = vt("path"), i = vt("path"), l = vt("path"), o = vt("path"), u = vt("g"), h = vt("path"), d = vt("path"), p = vt("path"), b = vt("path"), this.h();
    },
    l(y) {
      e = uo(y, "DIV", { class: !0 });
      var D = nt(e);
      t = gt(D, "svg", {
        viewBox: !0,
        fill: !0,
        xmlns: !0,
        class: !0
      });
      var A = nt(t);
      r = gt(A, "g", { style: !0 });
      var C = nt(r);
      a = gt(C, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), nt(a).forEach(Ke), i = gt(C, "path", { d: !0, fill: !0, class: !0 }), nt(i).forEach(Ke), l = gt(C, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), nt(l).forEach(Ke), o = gt(C, "path", { d: !0, fill: !0, class: !0 }), nt(o).forEach(Ke), C.forEach(Ke), u = gt(A, "g", { style: !0 });
      var T = nt(u);
      h = gt(T, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), nt(h).forEach(Ke), d = gt(T, "path", { d: !0, fill: !0, class: !0 }), nt(d).forEach(Ke), p = gt(T, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), nt(p).forEach(Ke), b = gt(T, "path", { d: !0, fill: !0, class: !0 }), nt(b).forEach(Ke), T.forEach(Ke), A.forEach(Ke), D.forEach(Ke), this.h();
    },
    h() {
      le(a, "d", "M255.926 0.754768L509.702 139.936V221.027L255.926 81.8465V0.754768Z"), le(a, "fill", "#FF7C00"), le(a, "fill-opacity", "0.4"), le(a, "class", "svelte-43sxxs"), le(i, "d", "M509.69 139.936L254.981 279.641V361.255L509.69 221.55V139.936Z"), le(i, "fill", "#FF7C00"), le(i, "class", "svelte-43sxxs"), le(l, "d", "M0.250138 139.937L254.981 279.641V361.255L0.250138 221.55V139.937Z"), le(l, "fill", "#FF7C00"), le(l, "fill-opacity", "0.4"), le(l, "class", "svelte-43sxxs"), le(o, "d", "M255.923 0.232622L0.236328 139.936V221.55L255.923 81.8469V0.232622Z"), le(o, "fill", "#FF7C00"), le(o, "class", "svelte-43sxxs"), mr(r, "transform", "translate(" + /*$top*/
      n[1][0] + "px, " + /*$top*/
      n[1][1] + "px)"), le(h, "d", "M255.926 141.5L509.702 280.681V361.773L255.926 222.592V141.5Z"), le(h, "fill", "#FF7C00"), le(h, "fill-opacity", "0.4"), le(h, "class", "svelte-43sxxs"), le(d, "d", "M509.69 280.679L254.981 420.384V501.998L509.69 362.293V280.679Z"), le(d, "fill", "#FF7C00"), le(d, "class", "svelte-43sxxs"), le(p, "d", "M0.250138 280.681L254.981 420.386V502L0.250138 362.295V280.681Z"), le(p, "fill", "#FF7C00"), le(p, "fill-opacity", "0.4"), le(p, "class", "svelte-43sxxs"), le(b, "d", "M255.923 140.977L0.236328 280.68V362.294L255.923 222.591V140.977Z"), le(b, "fill", "#FF7C00"), le(b, "class", "svelte-43sxxs"), mr(u, "transform", "translate(" + /*$bottom*/
      n[2][0] + "px, " + /*$bottom*/
      n[2][1] + "px)"), le(t, "viewBox", "-1200 -1200 3000 3000"), le(t, "fill", "none"), le(t, "xmlns", "http://www.w3.org/2000/svg"), le(t, "class", "svelte-43sxxs"), le(e, "class", "svelte-43sxxs"), Za(
        e,
        "margin",
        /*margin*/
        n[0]
      );
    },
    m(y, D) {
      mo(y, e, D), pt(e, t), pt(t, r), pt(r, a), pt(r, i), pt(r, l), pt(r, o), pt(t, u), pt(u, h), pt(u, d), pt(u, p), pt(u, b);
    },
    p(y, [D]) {
      D & /*$top*/
      2 && mr(r, "transform", "translate(" + /*$top*/
      y[1][0] + "px, " + /*$top*/
      y[1][1] + "px)"), D & /*$bottom*/
      4 && mr(u, "transform", "translate(" + /*$bottom*/
      y[2][0] + "px, " + /*$bottom*/
      y[2][1] + "px)"), D & /*margin*/
      1 && Za(
        e,
        "margin",
        /*margin*/
        y[0]
      );
    },
    i: Xa,
    o: Xa,
    d(y) {
      y && Ke(e);
    }
  };
}
function vo(n, e, t) {
  let r, a, { margin: i = !0 } = e;
  const l = Wa([0, 0]);
  ja(n, l, (b) => t(1, r = b));
  const o = Wa([0, 0]);
  ja(n, o, (b) => t(2, a = b));
  let u;
  async function h() {
    await Promise.all([l.set([125, 140]), o.set([-125, -140])]), await Promise.all([l.set([-125, 140]), o.set([125, -140])]), await Promise.all([l.set([-125, 0]), o.set([125, -0])]), await Promise.all([l.set([125, 0]), o.set([-125, 0])]);
  }
  async function d() {
    await h(), u || d();
  }
  async function p() {
    await Promise.all([l.set([125, 0]), o.set([-125, 0])]), d();
  }
  return po(() => (p(), () => u = !0)), n.$$set = (b) => {
    "margin" in b && t(0, i = b.margin);
  }, [i, r, a, l, o];
}
class _o extends oo {
  constructor(e) {
    super(), ho(this, e, vo, go, fo, { margin: 0 });
  }
}
const {
  SvelteComponent: bo,
  assign: yo,
  children: wo,
  claim_element: ko,
  create_slot: Do,
  detach: Ka,
  element: xo,
  get_all_dirty_from_scope: So,
  get_slot_changes: Ao,
  get_spread_update: Fo,
  init: Co,
  insert_hydration: Eo,
  safe_not_equal: To,
  set_dynamic_element_data: Qa,
  set_style: Be,
  toggle_class: Ye,
  transition_in: wl,
  transition_out: kl,
  update_slot_base: $o
} = window.__gradio__svelte__internal;
function Mo(n) {
  let e, t, r;
  const a = (
    /*#slots*/
    n[22].default
  ), i = Do(
    a,
    n,
    /*$$scope*/
    n[21],
    null
  );
  let l = [
    { "data-testid": (
      /*test_id*/
      n[10]
    ) },
    { id: (
      /*elem_id*/
      n[5]
    ) },
    {
      class: t = "block " + /*elem_classes*/
      n[6].join(" ") + " svelte-dbzldu"
    }
  ], o = {};
  for (let u = 0; u < l.length; u += 1)
    o = yo(o, l[u]);
  return {
    c() {
      e = xo(
        /*tag*/
        n[18]
      ), i && i.c(), this.h();
    },
    l(u) {
      e = ko(
        u,
        /*tag*/
        (n[18] || "null").toUpperCase(),
        {
          "data-testid": !0,
          id: !0,
          class: !0
        }
      );
      var h = wo(e);
      i && i.l(h), h.forEach(Ka), this.h();
    },
    h() {
      Qa(
        /*tag*/
        n[18]
      )(e, o), Ye(
        e,
        "hidden",
        /*visible*/
        n[13] === !1
      ), Ye(
        e,
        "padded",
        /*padding*/
        n[9]
      ), Ye(
        e,
        "flex",
        /*flex*/
        n[0]
      ), Ye(
        e,
        "border_focus",
        /*border_mode*/
        n[8] === "focus"
      ), Ye(
        e,
        "border_contrast",
        /*border_mode*/
        n[8] === "contrast"
      ), Ye(e, "hide-container", !/*explicit_call*/
      n[11] && !/*container*/
      n[12]), Ye(
        e,
        "auto-margin",
        /*scale*/
        n[16] === null
      ), Be(
        e,
        "height",
        /*get_dimension*/
        n[19](
          /*height*/
          n[1]
        )
      ), Be(
        e,
        "min-height",
        /*get_dimension*/
        n[19](
          /*min_height*/
          n[2]
        )
      ), Be(
        e,
        "max-height",
        /*get_dimension*/
        n[19](
          /*max_height*/
          n[3]
        )
      ), Be(e, "width", typeof /*width*/
      n[4] == "number" ? `calc(min(${/*width*/
      n[4]}px, 100%))` : (
        /*get_dimension*/
        n[19](
          /*width*/
          n[4]
        )
      )), Be(
        e,
        "border-style",
        /*variant*/
        n[7]
      ), Be(
        e,
        "overflow",
        /*allow_overflow*/
        n[14] ? (
          /*overflow_behavior*/
          n[15]
        ) : "hidden"
      ), Be(
        e,
        "flex-grow",
        /*scale*/
        n[16]
      ), Be(e, "min-width", `calc(min(${/*min_width*/
      n[17]}px, 100%))`), Be(e, "border-width", "var(--block-border-width)");
    },
    m(u, h) {
      Eo(u, e, h), i && i.m(e, null), r = !0;
    },
    p(u, h) {
      i && i.p && (!r || h & /*$$scope*/
      2097152) && $o(
        i,
        a,
        u,
        /*$$scope*/
        u[21],
        r ? Ao(
          a,
          /*$$scope*/
          u[21],
          h,
          null
        ) : So(
          /*$$scope*/
          u[21]
        ),
        null
      ), Qa(
        /*tag*/
        u[18]
      )(e, o = Fo(l, [
        (!r || h & /*test_id*/
        1024) && { "data-testid": (
          /*test_id*/
          u[10]
        ) },
        (!r || h & /*elem_id*/
        32) && { id: (
          /*elem_id*/
          u[5]
        ) },
        (!r || h & /*elem_classes*/
        64 && t !== (t = "block " + /*elem_classes*/
        u[6].join(" ") + " svelte-dbzldu")) && { class: t }
      ])), Ye(
        e,
        "hidden",
        /*visible*/
        u[13] === !1
      ), Ye(
        e,
        "padded",
        /*padding*/
        u[9]
      ), Ye(
        e,
        "flex",
        /*flex*/
        u[0]
      ), Ye(
        e,
        "border_focus",
        /*border_mode*/
        u[8] === "focus"
      ), Ye(
        e,
        "border_contrast",
        /*border_mode*/
        u[8] === "contrast"
      ), Ye(e, "hide-container", !/*explicit_call*/
      u[11] && !/*container*/
      u[12]), Ye(
        e,
        "auto-margin",
        /*scale*/
        u[16] === null
      ), h & /*height*/
      2 && Be(
        e,
        "height",
        /*get_dimension*/
        u[19](
          /*height*/
          u[1]
        )
      ), h & /*min_height*/
      4 && Be(
        e,
        "min-height",
        /*get_dimension*/
        u[19](
          /*min_height*/
          u[2]
        )
      ), h & /*max_height*/
      8 && Be(
        e,
        "max-height",
        /*get_dimension*/
        u[19](
          /*max_height*/
          u[3]
        )
      ), h & /*width*/
      16 && Be(e, "width", typeof /*width*/
      u[4] == "number" ? `calc(min(${/*width*/
      u[4]}px, 100%))` : (
        /*get_dimension*/
        u[19](
          /*width*/
          u[4]
        )
      )), h & /*variant*/
      128 && Be(
        e,
        "border-style",
        /*variant*/
        u[7]
      ), h & /*allow_overflow, overflow_behavior*/
      49152 && Be(
        e,
        "overflow",
        /*allow_overflow*/
        u[14] ? (
          /*overflow_behavior*/
          u[15]
        ) : "hidden"
      ), h & /*scale*/
      65536 && Be(
        e,
        "flex-grow",
        /*scale*/
        u[16]
      ), h & /*min_width*/
      131072 && Be(e, "min-width", `calc(min(${/*min_width*/
      u[17]}px, 100%))`);
    },
    i(u) {
      r || (wl(i, u), r = !0);
    },
    o(u) {
      kl(i, u), r = !1;
    },
    d(u) {
      u && Ka(e), i && i.d(u);
    }
  };
}
function zo(n) {
  let e, t = (
    /*tag*/
    n[18] && Mo(n)
  );
  return {
    c() {
      t && t.c();
    },
    l(r) {
      t && t.l(r);
    },
    m(r, a) {
      t && t.m(r, a), e = !0;
    },
    p(r, [a]) {
      /*tag*/
      r[18] && t.p(r, a);
    },
    i(r) {
      e || (wl(t, r), e = !0);
    },
    o(r) {
      kl(t, r), e = !1;
    },
    d(r) {
      t && t.d(r);
    }
  };
}
function Bo(n, e, t) {
  let { $$slots: r = {}, $$scope: a } = e, { height: i = void 0 } = e, { min_height: l = void 0 } = e, { max_height: o = void 0 } = e, { width: u = void 0 } = e, { elem_id: h = "" } = e, { elem_classes: d = [] } = e, { variant: p = "solid" } = e, { border_mode: b = "base" } = e, { padding: y = !0 } = e, { type: D = "normal" } = e, { test_id: A = void 0 } = e, { explicit_call: C = !1 } = e, { container: T = !0 } = e, { visible: w = !0 } = e, { allow_overflow: g = !0 } = e, { overflow_behavior: S = "auto" } = e, { scale: E = null } = e, { min_width: $ = 0 } = e, { flex: B = !1 } = e;
  w || (B = !1);
  let O = D === "fieldset" ? "fieldset" : "div";
  const M = (R) => {
    if (R !== void 0) {
      if (typeof R == "number")
        return R + "px";
      if (typeof R == "string")
        return R;
    }
  };
  return n.$$set = (R) => {
    "height" in R && t(1, i = R.height), "min_height" in R && t(2, l = R.min_height), "max_height" in R && t(3, o = R.max_height), "width" in R && t(4, u = R.width), "elem_id" in R && t(5, h = R.elem_id), "elem_classes" in R && t(6, d = R.elem_classes), "variant" in R && t(7, p = R.variant), "border_mode" in R && t(8, b = R.border_mode), "padding" in R && t(9, y = R.padding), "type" in R && t(20, D = R.type), "test_id" in R && t(10, A = R.test_id), "explicit_call" in R && t(11, C = R.explicit_call), "container" in R && t(12, T = R.container), "visible" in R && t(13, w = R.visible), "allow_overflow" in R && t(14, g = R.allow_overflow), "overflow_behavior" in R && t(15, S = R.overflow_behavior), "scale" in R && t(16, E = R.scale), "min_width" in R && t(17, $ = R.min_width), "flex" in R && t(0, B = R.flex), "$$scope" in R && t(21, a = R.$$scope);
  }, [
    B,
    i,
    l,
    o,
    u,
    h,
    d,
    p,
    b,
    y,
    A,
    C,
    T,
    w,
    g,
    S,
    E,
    $,
    O,
    M,
    D,
    a,
    r
  ];
}
class Ro extends bo {
  constructor(e) {
    super(), Co(this, e, Bo, zo, To, {
      height: 1,
      min_height: 2,
      max_height: 3,
      width: 4,
      elem_id: 5,
      elem_classes: 6,
      variant: 7,
      border_mode: 8,
      padding: 9,
      type: 20,
      test_id: 10,
      explicit_call: 11,
      container: 12,
      visible: 13,
      allow_overflow: 14,
      overflow_behavior: 15,
      scale: 16,
      min_width: 17,
      flex: 0
    });
  }
}
class Vn {
  // The + prefix indicates that these fields aren't writeable
  // Lexer holding the input string.
  // Start offset, zero-based inclusive.
  // End offset, zero-based exclusive.
  constructor(e, t, r) {
    this.lexer = void 0, this.start = void 0, this.end = void 0, this.lexer = e, this.start = t, this.end = r;
  }
  /**
   * Merges two `SourceLocation`s from location providers, given they are
   * provided in order of appearance.
   * - Returns the first one's location if only the first is provided.
   * - Returns a merged range of the first and the last if both are provided
   *   and their lexers match.
   * - Otherwise, returns null.
   */
  static range(e, t) {
    return t ? !e || !e.loc || !t.loc || e.loc.lexer !== t.loc.lexer ? null : new Vn(e.loc.lexer, e.loc.start, t.loc.end) : e && e.loc;
  }
}
class Gn {
  // don't expand the token
  // used in \noexpand
  constructor(e, t) {
    this.text = void 0, this.loc = void 0, this.noexpand = void 0, this.treatAsRelax = void 0, this.text = e, this.loc = t;
  }
  /**
   * Given a pair of tokens (this and endToken), compute a `Token` encompassing
   * the whole input range enclosed by these two.
   */
  range(e, t) {
    return new Gn(t, Vn.range(this, e));
  }
}
class X {
  // Error start position based on passed-in Token or ParseNode.
  // Length of affected text based on passed-in Token or ParseNode.
  // The underlying error message without any context added.
  constructor(e, t) {
    this.name = void 0, this.position = void 0, this.length = void 0, this.rawMessage = void 0;
    var r = "KaTeX parse error: " + e, a, i, l = t && t.loc;
    if (l && l.start <= l.end) {
      var o = l.lexer.input;
      a = l.start, i = l.end, a === o.length ? r += " at end of input: " : r += " at position " + (a + 1) + ": ";
      var u = o.slice(a, i).replace(/[^]/g, "$&̲"), h;
      a > 15 ? h = "…" + o.slice(a - 15, a) : h = o.slice(0, a);
      var d;
      i + 15 < o.length ? d = o.slice(i, i + 15) + "…" : d = o.slice(i), r += h + u + d;
    }
    var p = new Error(r);
    return p.name = "ParseError", p.__proto__ = X.prototype, p.position = a, a != null && i != null && (p.length = i - a), p.rawMessage = e, p;
  }
}
X.prototype.__proto__ = Error.prototype;
var qo = function(e, t) {
  return e.indexOf(t) !== -1;
}, No = function(e, t) {
  return e === void 0 ? t : e;
}, Io = /([A-Z])/g, Lo = function(e) {
  return e.replace(Io, "-$1").toLowerCase();
}, Oo = {
  "&": "&amp;",
  ">": "&gt;",
  "<": "&lt;",
  '"': "&quot;",
  "'": "&#x27;"
}, Po = /[&><"']/g;
function Ho(n) {
  return String(n).replace(Po, (e) => Oo[e]);
}
var Dl = function n(e) {
  return e.type === "ordgroup" || e.type === "color" ? e.body.length === 1 ? n(e.body[0]) : e : e.type === "font" ? n(e.body) : e;
}, Uo = function(e) {
  var t = Dl(e);
  return t.type === "mathord" || t.type === "textord" || t.type === "atom";
}, Vo = function(e) {
  if (!e)
    throw new Error("Expected non-null, but got " + String(e));
  return e;
}, Go = function(e) {
  var t = /^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(e);
  return t ? t[2] !== ":" || !/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(t[1]) ? null : t[1].toLowerCase() : "_relative";
}, K = {
  contains: qo,
  deflt: No,
  escape: Ho,
  hyphenate: Lo,
  getBaseElem: Dl,
  isCharacterBox: Uo,
  protocolFromUrl: Go
};
class r0 {
  constructor(e, t, r) {
    this.id = void 0, this.size = void 0, this.cramped = void 0, this.id = e, this.size = t, this.cramped = r;
  }
  /**
   * Get the style of a superscript given a base in the current style.
   */
  sup() {
    return Mt[Yo[this.id]];
  }
  /**
   * Get the style of a subscript given a base in the current style.
   */
  sub() {
    return Mt[Wo[this.id]];
  }
  /**
   * Get the style of a fraction numerator given the fraction in the current
   * style.
   */
  fracNum() {
    return Mt[jo[this.id]];
  }
  /**
   * Get the style of a fraction denominator given the fraction in the current
   * style.
   */
  fracDen() {
    return Mt[Xo[this.id]];
  }
  /**
   * Get the cramped version of a style (in particular, cramping a cramped style
   * doesn't change the style).
   */
  cramp() {
    return Mt[Zo[this.id]];
  }
  /**
   * Get a text or display version of this style.
   */
  text() {
    return Mt[Ko[this.id]];
  }
  /**
   * Return true if this style is tightly spaced (scriptstyle/scriptscriptstyle)
   */
  isTight() {
    return this.size >= 2;
  }
}
var Yn = 0, Br = 1, M0 = 2, Qt = 3, J0 = 4, it = 5, z0 = 6, He = 7, Mt = [new r0(Yn, 0, !1), new r0(Br, 0, !0), new r0(M0, 1, !1), new r0(Qt, 1, !0), new r0(J0, 2, !1), new r0(it, 2, !0), new r0(z0, 3, !1), new r0(He, 3, !0)], Yo = [J0, it, J0, it, z0, He, z0, He], Wo = [it, it, it, it, He, He, He, He], jo = [M0, Qt, J0, it, z0, He, z0, He], Xo = [Qt, Qt, it, it, He, He, He, He], Zo = [Br, Br, Qt, Qt, it, it, He, He], Ko = [Yn, Br, M0, Qt, M0, Qt, M0, Qt], J = {
  DISPLAY: Mt[Yn],
  TEXT: Mt[M0],
  SCRIPT: Mt[J0],
  SCRIPTSCRIPT: Mt[z0]
}, En = [{
  // Latin characters beyond the Latin-1 characters we have metrics for.
  // Needed for Czech, Hungarian and Turkish text, for example.
  name: "latin",
  blocks: [
    [256, 591],
    // Latin Extended-A and Latin Extended-B
    [768, 879]
    // Combining Diacritical marks
  ]
}, {
  // The Cyrillic script used by Russian and related languages.
  // A Cyrillic subset used to be supported as explicitly defined
  // symbols in symbols.js
  name: "cyrillic",
  blocks: [[1024, 1279]]
}, {
  // Armenian
  name: "armenian",
  blocks: [[1328, 1423]]
}, {
  // The Brahmic scripts of South and Southeast Asia
  // Devanagari (0900–097F)
  // Bengali (0980–09FF)
  // Gurmukhi (0A00–0A7F)
  // Gujarati (0A80–0AFF)
  // Oriya (0B00–0B7F)
  // Tamil (0B80–0BFF)
  // Telugu (0C00–0C7F)
  // Kannada (0C80–0CFF)
  // Malayalam (0D00–0D7F)
  // Sinhala (0D80–0DFF)
  // Thai (0E00–0E7F)
  // Lao (0E80–0EFF)
  // Tibetan (0F00–0FFF)
  // Myanmar (1000–109F)
  name: "brahmic",
  blocks: [[2304, 4255]]
}, {
  name: "georgian",
  blocks: [[4256, 4351]]
}, {
  // Chinese and Japanese.
  // The "k" in cjk is for Korean, but we've separated Korean out
  name: "cjk",
  blocks: [
    [12288, 12543],
    // CJK symbols and punctuation, Hiragana, Katakana
    [19968, 40879],
    // CJK ideograms
    [65280, 65376]
    // Fullwidth punctuation
    // TODO: add halfwidth Katakana and Romanji glyphs
  ]
}, {
  // Korean
  name: "hangul",
  blocks: [[44032, 55215]]
}];
function Qo(n) {
  for (var e = 0; e < En.length; e++)
    for (var t = En[e], r = 0; r < t.blocks.length; r++) {
      var a = t.blocks[r];
      if (n >= a[0] && n <= a[1])
        return t.name;
    }
  return null;
}
var $r = [];
En.forEach((n) => n.blocks.forEach((e) => $r.push(...e)));
function Jo(n) {
  for (var e = 0; e < $r.length; e += 2)
    if (n >= $r[e] && n <= $r[e + 1])
      return !0;
  return !1;
}
var F0 = 80, e1 = function(e, t) {
  return "M95," + (622 + e + t) + `
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l` + e / 2.075 + " -" + e + `
c5.3,-9.3,12,-14,20,-14
H400000v` + (40 + e) + `H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M` + (834 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, t1 = function(e, t) {
  return "M263," + (601 + e + t) + `c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l` + e / 2.084 + " -" + e + `
c4.7,-7.3,11,-11,19,-11
H40000v` + (40 + e) + `H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, r1 = function(e, t) {
  return "M983 " + (10 + e + t) + `
l` + e / 3.13 + " -" + e + `
c4,-6.7,10,-10,18,-10 H400000v` + (40 + e) + `
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, n1 = function(e, t) {
  return "M424," + (2398 + e + t) + `
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l` + e / 4.223 + " -" + e + `c4,-6.7,10,-10,18,-10 H400000
v` + (40 + e) + `H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M` + (1001 + e) + " " + t + `
h400000v` + (40 + e) + "h-400000z";
}, a1 = function(e, t) {
  return "M473," + (2713 + e + t) + `
c339.3,-1799.3,509.3,-2700,510,-2702 l` + e / 5.298 + " -" + e + `
c3.3,-7.3,9.3,-11,18,-11 H400000v` + (40 + e) + `H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "H1017.7z";
}, i1 = function(e) {
  var t = e / 2;
  return "M400000 " + e + " H0 L" + t + " 0 l65 45 L145 " + (e - 80) + " H400000z";
}, l1 = function(e, t, r) {
  var a = r - 54 - t - e;
  return "M702 " + (e + t) + "H400000" + (40 + e) + `
H742v` + a + `l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 ` + t + "H400000v" + (40 + e) + "H742z";
}, s1 = function(e, t, r) {
  t = 1e3 * t;
  var a = "";
  switch (e) {
    case "sqrtMain":
      a = e1(t, F0);
      break;
    case "sqrtSize1":
      a = t1(t, F0);
      break;
    case "sqrtSize2":
      a = r1(t, F0);
      break;
    case "sqrtSize3":
      a = n1(t, F0);
      break;
    case "sqrtSize4":
      a = a1(t, F0);
      break;
    case "sqrtTall":
      a = l1(t, F0, r);
  }
  return a;
}, o1 = function(e, t) {
  switch (e) {
    case "⎜":
      return "M291 0 H417 V" + t + " H291z M291 0 H417 V" + t + " H291z";
    case "∣":
      return "M145 0 H188 V" + t + " H145z M145 0 H188 V" + t + " H145z";
    case "∥":
      return "M145 0 H188 V" + t + " H145z M145 0 H188 V" + t + " H145z" + ("M367 0 H410 V" + t + " H367z M367 0 H410 V" + t + " H367z");
    case "⎟":
      return "M457 0 H583 V" + t + " H457z M457 0 H583 V" + t + " H457z";
    case "⎢":
      return "M319 0 H403 V" + t + " H319z M319 0 H403 V" + t + " H319z";
    case "⎥":
      return "M263 0 H347 V" + t + " H263z M263 0 H347 V" + t + " H263z";
    case "⎪":
      return "M384 0 H504 V" + t + " H384z M384 0 H504 V" + t + " H384z";
    case "⏐":
      return "M312 0 H355 V" + t + " H312z M312 0 H355 V" + t + " H312z";
    case "‖":
      return "M257 0 H300 V" + t + " H257z M257 0 H300 V" + t + " H257z" + ("M478 0 H521 V" + t + " H478z M478 0 H521 V" + t + " H478z");
    default:
      return "";
  }
}, Ja = {
  // The doubleleftarrow geometry is from glyph U+21D0 in the font KaTeX Main
  doubleleftarrow: `M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,
  // doublerightarrow is from glyph U+21D2 in font KaTeX Main
  doublerightarrow: `M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,
  // leftarrow is from glyph U+2190 in font KaTeX Main
  leftarrow: `M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,
  // overbrace is from glyphs U+23A9/23A8/23A7 in font KaTeX_Size4-Regular
  leftbrace: `M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,
  leftbraceunder: `M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,
  // overgroup is from the MnSymbol package (public domain)
  leftgroup: `M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,
  leftgroupunder: `M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,
  // Harpoons are from glyph U+21BD in font KaTeX Main
  leftharpoon: `M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,
  leftharpoonplus: `M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,
  leftharpoondown: `M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,
  leftharpoondownplus: `M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,
  // hook is from glyph U+21A9 in font KaTeX Main
  lefthook: `M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,
  leftlinesegment: `M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,
  leftmapsto: `M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,
  // tofrom is from glyph U+21C4 in font KaTeX AMS Regular
  leftToFrom: `M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,
  longequal: `M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,
  midbrace: `M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,
  midbraceunder: `M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,
  oiintSize1: `M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,
  oiintSize2: `M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,
  oiiintSize1: `M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,
  oiiintSize2: `M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,
  rightarrow: `M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,
  rightbrace: `M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,
  rightbraceunder: `M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,
  rightgroup: `M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,
  rightgroupunder: `M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,
  rightharpoon: `M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,
  rightharpoonplus: `M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,
  rightharpoondown: `M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,
  rightharpoondownplus: `M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,
  righthook: `M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,
  rightlinesegment: `M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,
  rightToFrom: `M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,
  // twoheadleftarrow is from glyph U+219E in font KaTeX AMS Regular
  twoheadleftarrow: `M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,
  twoheadrightarrow: `M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,
  // tilde1 is a modified version of a glyph from the MnSymbol package
  tilde1: `M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,
  // ditto tilde2, tilde3, & tilde4
  tilde2: `M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,
  tilde3: `M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,
  tilde4: `M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,
  // vec is from glyph U+20D7 in font KaTeX Main
  vec: `M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,
  // widehat1 is a modified version of a glyph from the MnSymbol package
  widehat1: `M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,
  // ditto widehat2, widehat3, & widehat4
  widehat2: `M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  widehat3: `M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  widehat4: `M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  // widecheck paths are all inverted versions of widehat
  widecheck1: `M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,
  widecheck2: `M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  widecheck3: `M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  widecheck4: `M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  // The next ten paths support reaction arrows from the mhchem package.
  // Arrows for \ce{<-->} are offset from xAxis by 0.22ex, per mhchem in LaTeX
  // baraboveleftarrow is mostly from glyph U+2190 in font KaTeX Main
  baraboveleftarrow: `M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,
  // rightarrowabovebar is mostly from glyph U+2192, KaTeX Main
  rightarrowabovebar: `M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,
  // The short left harpoon has 0.5em (i.e. 500 units) kern on the left end.
  // Ref from mhchem.sty: \rlap{\raisebox{-.22ex}{$\kern0.5em
  baraboveshortleftharpoon: `M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,
  rightharpoonaboveshortbar: `M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,
  shortbaraboveleftharpoon: `M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,
  shortrightharpoonabovebar: `M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`
}, u1 = function(e, t) {
  switch (e) {
    case "lbrack":
      return "M403 1759 V84 H666 V0 H319 V1759 v" + t + ` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v` + t + " v1759 h84z";
    case "rbrack":
      return "M347 1759 V0 H0 V84 H263 V1759 v" + t + ` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v` + t + " v1759 h84z";
    case "vert":
      return "M145 15 v585 v" + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v` + t + " v585 h43z";
    case "doublevert":
      return "M145 15 v585 v" + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v` + t + ` v585 h43z
M367 15 v585 v` + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v` + t + " v585 h43z";
    case "lfloor":
      return "M319 602 V0 H403 V602 v" + t + ` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v` + t + " v1715 H319z";
    case "rfloor":
      return "M319 602 V0 H403 V602 v" + t + ` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v` + t + " v1715 H319z";
    case "lceil":
      return "M403 1759 V84 H666 V0 H319 V1759 v" + t + ` v602 h84z
M403 1759 V0 H319 V1759 v` + t + " v602 h84z";
    case "rceil":
      return "M347 1759 V0 H0 V84 H263 V1759 v" + t + ` v602 h84z
M347 1759 V0 h-84 V1759 v` + t + " v602 h84z";
    case "lparen":
      return `M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,` + (t + 84) + `c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-` + (t + 92) + `c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;
    case "rparen":
      return `M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,` + (t + 9) + `
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-` + (t + 144) + `c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;
    default:
      throw new Error("Unknown stretchy delimiter.");
  }
};
class rr {
  // HtmlDomNode
  // Never used; needed for satisfying interface.
  constructor(e) {
    this.children = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, this.children = e, this.classes = [], this.height = 0, this.depth = 0, this.maxFontSize = 0, this.style = {};
  }
  hasClass(e) {
    return K.contains(this.classes, e);
  }
  /** Convert the fragment into a node. */
  toNode() {
    for (var e = document.createDocumentFragment(), t = 0; t < this.children.length; t++)
      e.appendChild(this.children[t].toNode());
    return e;
  }
  /** Convert the fragment into HTML markup. */
  toMarkup() {
    for (var e = "", t = 0; t < this.children.length; t++)
      e += this.children[t].toMarkup();
    return e;
  }
  /**
   * Converts the math node into a string, similar to innerText. Applies to
   * MathDomNode's only.
   */
  toText() {
    var e = (t) => t.toText();
    return this.children.map(e).join("");
  }
}
var Kt = {
  "AMS-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.68889, 0, 0, 0.72222],
    66: [0, 0.68889, 0, 0, 0.66667],
    67: [0, 0.68889, 0, 0, 0.72222],
    68: [0, 0.68889, 0, 0, 0.72222],
    69: [0, 0.68889, 0, 0, 0.66667],
    70: [0, 0.68889, 0, 0, 0.61111],
    71: [0, 0.68889, 0, 0, 0.77778],
    72: [0, 0.68889, 0, 0, 0.77778],
    73: [0, 0.68889, 0, 0, 0.38889],
    74: [0.16667, 0.68889, 0, 0, 0.5],
    75: [0, 0.68889, 0, 0, 0.77778],
    76: [0, 0.68889, 0, 0, 0.66667],
    77: [0, 0.68889, 0, 0, 0.94445],
    78: [0, 0.68889, 0, 0, 0.72222],
    79: [0.16667, 0.68889, 0, 0, 0.77778],
    80: [0, 0.68889, 0, 0, 0.61111],
    81: [0.16667, 0.68889, 0, 0, 0.77778],
    82: [0, 0.68889, 0, 0, 0.72222],
    83: [0, 0.68889, 0, 0, 0.55556],
    84: [0, 0.68889, 0, 0, 0.66667],
    85: [0, 0.68889, 0, 0, 0.72222],
    86: [0, 0.68889, 0, 0, 0.72222],
    87: [0, 0.68889, 0, 0, 1],
    88: [0, 0.68889, 0, 0, 0.72222],
    89: [0, 0.68889, 0, 0, 0.72222],
    90: [0, 0.68889, 0, 0, 0.66667],
    107: [0, 0.68889, 0, 0, 0.55556],
    160: [0, 0, 0, 0, 0.25],
    165: [0, 0.675, 0.025, 0, 0.75],
    174: [0.15559, 0.69224, 0, 0, 0.94666],
    240: [0, 0.68889, 0, 0, 0.55556],
    295: [0, 0.68889, 0, 0, 0.54028],
    710: [0, 0.825, 0, 0, 2.33334],
    732: [0, 0.9, 0, 0, 2.33334],
    770: [0, 0.825, 0, 0, 2.33334],
    771: [0, 0.9, 0, 0, 2.33334],
    989: [0.08167, 0.58167, 0, 0, 0.77778],
    1008: [0, 0.43056, 0.04028, 0, 0.66667],
    8245: [0, 0.54986, 0, 0, 0.275],
    8463: [0, 0.68889, 0, 0, 0.54028],
    8487: [0, 0.68889, 0, 0, 0.72222],
    8498: [0, 0.68889, 0, 0, 0.55556],
    8502: [0, 0.68889, 0, 0, 0.66667],
    8503: [0, 0.68889, 0, 0, 0.44445],
    8504: [0, 0.68889, 0, 0, 0.66667],
    8513: [0, 0.68889, 0, 0, 0.63889],
    8592: [-0.03598, 0.46402, 0, 0, 0.5],
    8594: [-0.03598, 0.46402, 0, 0, 0.5],
    8602: [-0.13313, 0.36687, 0, 0, 1],
    8603: [-0.13313, 0.36687, 0, 0, 1],
    8606: [0.01354, 0.52239, 0, 0, 1],
    8608: [0.01354, 0.52239, 0, 0, 1],
    8610: [0.01354, 0.52239, 0, 0, 1.11111],
    8611: [0.01354, 0.52239, 0, 0, 1.11111],
    8619: [0, 0.54986, 0, 0, 1],
    8620: [0, 0.54986, 0, 0, 1],
    8621: [-0.13313, 0.37788, 0, 0, 1.38889],
    8622: [-0.13313, 0.36687, 0, 0, 1],
    8624: [0, 0.69224, 0, 0, 0.5],
    8625: [0, 0.69224, 0, 0, 0.5],
    8630: [0, 0.43056, 0, 0, 1],
    8631: [0, 0.43056, 0, 0, 1],
    8634: [0.08198, 0.58198, 0, 0, 0.77778],
    8635: [0.08198, 0.58198, 0, 0, 0.77778],
    8638: [0.19444, 0.69224, 0, 0, 0.41667],
    8639: [0.19444, 0.69224, 0, 0, 0.41667],
    8642: [0.19444, 0.69224, 0, 0, 0.41667],
    8643: [0.19444, 0.69224, 0, 0, 0.41667],
    8644: [0.1808, 0.675, 0, 0, 1],
    8646: [0.1808, 0.675, 0, 0, 1],
    8647: [0.1808, 0.675, 0, 0, 1],
    8648: [0.19444, 0.69224, 0, 0, 0.83334],
    8649: [0.1808, 0.675, 0, 0, 1],
    8650: [0.19444, 0.69224, 0, 0, 0.83334],
    8651: [0.01354, 0.52239, 0, 0, 1],
    8652: [0.01354, 0.52239, 0, 0, 1],
    8653: [-0.13313, 0.36687, 0, 0, 1],
    8654: [-0.13313, 0.36687, 0, 0, 1],
    8655: [-0.13313, 0.36687, 0, 0, 1],
    8666: [0.13667, 0.63667, 0, 0, 1],
    8667: [0.13667, 0.63667, 0, 0, 1],
    8669: [-0.13313, 0.37788, 0, 0, 1],
    8672: [-0.064, 0.437, 0, 0, 1.334],
    8674: [-0.064, 0.437, 0, 0, 1.334],
    8705: [0, 0.825, 0, 0, 0.5],
    8708: [0, 0.68889, 0, 0, 0.55556],
    8709: [0.08167, 0.58167, 0, 0, 0.77778],
    8717: [0, 0.43056, 0, 0, 0.42917],
    8722: [-0.03598, 0.46402, 0, 0, 0.5],
    8724: [0.08198, 0.69224, 0, 0, 0.77778],
    8726: [0.08167, 0.58167, 0, 0, 0.77778],
    8733: [0, 0.69224, 0, 0, 0.77778],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8737: [0, 0.69224, 0, 0, 0.72222],
    8738: [0.03517, 0.52239, 0, 0, 0.72222],
    8739: [0.08167, 0.58167, 0, 0, 0.22222],
    8740: [0.25142, 0.74111, 0, 0, 0.27778],
    8741: [0.08167, 0.58167, 0, 0, 0.38889],
    8742: [0.25142, 0.74111, 0, 0, 0.5],
    8756: [0, 0.69224, 0, 0, 0.66667],
    8757: [0, 0.69224, 0, 0, 0.66667],
    8764: [-0.13313, 0.36687, 0, 0, 0.77778],
    8765: [-0.13313, 0.37788, 0, 0, 0.77778],
    8769: [-0.13313, 0.36687, 0, 0, 0.77778],
    8770: [-0.03625, 0.46375, 0, 0, 0.77778],
    8774: [0.30274, 0.79383, 0, 0, 0.77778],
    8776: [-0.01688, 0.48312, 0, 0, 0.77778],
    8778: [0.08167, 0.58167, 0, 0, 0.77778],
    8782: [0.06062, 0.54986, 0, 0, 0.77778],
    8783: [0.06062, 0.54986, 0, 0, 0.77778],
    8785: [0.08198, 0.58198, 0, 0, 0.77778],
    8786: [0.08198, 0.58198, 0, 0, 0.77778],
    8787: [0.08198, 0.58198, 0, 0, 0.77778],
    8790: [0, 0.69224, 0, 0, 0.77778],
    8791: [0.22958, 0.72958, 0, 0, 0.77778],
    8796: [0.08198, 0.91667, 0, 0, 0.77778],
    8806: [0.25583, 0.75583, 0, 0, 0.77778],
    8807: [0.25583, 0.75583, 0, 0, 0.77778],
    8808: [0.25142, 0.75726, 0, 0, 0.77778],
    8809: [0.25142, 0.75726, 0, 0, 0.77778],
    8812: [0.25583, 0.75583, 0, 0, 0.5],
    8814: [0.20576, 0.70576, 0, 0, 0.77778],
    8815: [0.20576, 0.70576, 0, 0, 0.77778],
    8816: [0.30274, 0.79383, 0, 0, 0.77778],
    8817: [0.30274, 0.79383, 0, 0, 0.77778],
    8818: [0.22958, 0.72958, 0, 0, 0.77778],
    8819: [0.22958, 0.72958, 0, 0, 0.77778],
    8822: [0.1808, 0.675, 0, 0, 0.77778],
    8823: [0.1808, 0.675, 0, 0, 0.77778],
    8828: [0.13667, 0.63667, 0, 0, 0.77778],
    8829: [0.13667, 0.63667, 0, 0, 0.77778],
    8830: [0.22958, 0.72958, 0, 0, 0.77778],
    8831: [0.22958, 0.72958, 0, 0, 0.77778],
    8832: [0.20576, 0.70576, 0, 0, 0.77778],
    8833: [0.20576, 0.70576, 0, 0, 0.77778],
    8840: [0.30274, 0.79383, 0, 0, 0.77778],
    8841: [0.30274, 0.79383, 0, 0, 0.77778],
    8842: [0.13597, 0.63597, 0, 0, 0.77778],
    8843: [0.13597, 0.63597, 0, 0, 0.77778],
    8847: [0.03517, 0.54986, 0, 0, 0.77778],
    8848: [0.03517, 0.54986, 0, 0, 0.77778],
    8858: [0.08198, 0.58198, 0, 0, 0.77778],
    8859: [0.08198, 0.58198, 0, 0, 0.77778],
    8861: [0.08198, 0.58198, 0, 0, 0.77778],
    8862: [0, 0.675, 0, 0, 0.77778],
    8863: [0, 0.675, 0, 0, 0.77778],
    8864: [0, 0.675, 0, 0, 0.77778],
    8865: [0, 0.675, 0, 0, 0.77778],
    8872: [0, 0.69224, 0, 0, 0.61111],
    8873: [0, 0.69224, 0, 0, 0.72222],
    8874: [0, 0.69224, 0, 0, 0.88889],
    8876: [0, 0.68889, 0, 0, 0.61111],
    8877: [0, 0.68889, 0, 0, 0.61111],
    8878: [0, 0.68889, 0, 0, 0.72222],
    8879: [0, 0.68889, 0, 0, 0.72222],
    8882: [0.03517, 0.54986, 0, 0, 0.77778],
    8883: [0.03517, 0.54986, 0, 0, 0.77778],
    8884: [0.13667, 0.63667, 0, 0, 0.77778],
    8885: [0.13667, 0.63667, 0, 0, 0.77778],
    8888: [0, 0.54986, 0, 0, 1.11111],
    8890: [0.19444, 0.43056, 0, 0, 0.55556],
    8891: [0.19444, 0.69224, 0, 0, 0.61111],
    8892: [0.19444, 0.69224, 0, 0, 0.61111],
    8901: [0, 0.54986, 0, 0, 0.27778],
    8903: [0.08167, 0.58167, 0, 0, 0.77778],
    8905: [0.08167, 0.58167, 0, 0, 0.77778],
    8906: [0.08167, 0.58167, 0, 0, 0.77778],
    8907: [0, 0.69224, 0, 0, 0.77778],
    8908: [0, 0.69224, 0, 0, 0.77778],
    8909: [-0.03598, 0.46402, 0, 0, 0.77778],
    8910: [0, 0.54986, 0, 0, 0.76042],
    8911: [0, 0.54986, 0, 0, 0.76042],
    8912: [0.03517, 0.54986, 0, 0, 0.77778],
    8913: [0.03517, 0.54986, 0, 0, 0.77778],
    8914: [0, 0.54986, 0, 0, 0.66667],
    8915: [0, 0.54986, 0, 0, 0.66667],
    8916: [0, 0.69224, 0, 0, 0.66667],
    8918: [0.0391, 0.5391, 0, 0, 0.77778],
    8919: [0.0391, 0.5391, 0, 0, 0.77778],
    8920: [0.03517, 0.54986, 0, 0, 1.33334],
    8921: [0.03517, 0.54986, 0, 0, 1.33334],
    8922: [0.38569, 0.88569, 0, 0, 0.77778],
    8923: [0.38569, 0.88569, 0, 0, 0.77778],
    8926: [0.13667, 0.63667, 0, 0, 0.77778],
    8927: [0.13667, 0.63667, 0, 0, 0.77778],
    8928: [0.30274, 0.79383, 0, 0, 0.77778],
    8929: [0.30274, 0.79383, 0, 0, 0.77778],
    8934: [0.23222, 0.74111, 0, 0, 0.77778],
    8935: [0.23222, 0.74111, 0, 0, 0.77778],
    8936: [0.23222, 0.74111, 0, 0, 0.77778],
    8937: [0.23222, 0.74111, 0, 0, 0.77778],
    8938: [0.20576, 0.70576, 0, 0, 0.77778],
    8939: [0.20576, 0.70576, 0, 0, 0.77778],
    8940: [0.30274, 0.79383, 0, 0, 0.77778],
    8941: [0.30274, 0.79383, 0, 0, 0.77778],
    8994: [0.19444, 0.69224, 0, 0, 0.77778],
    8995: [0.19444, 0.69224, 0, 0, 0.77778],
    9416: [0.15559, 0.69224, 0, 0, 0.90222],
    9484: [0, 0.69224, 0, 0, 0.5],
    9488: [0, 0.69224, 0, 0, 0.5],
    9492: [0, 0.37788, 0, 0, 0.5],
    9496: [0, 0.37788, 0, 0, 0.5],
    9585: [0.19444, 0.68889, 0, 0, 0.88889],
    9586: [0.19444, 0.74111, 0, 0, 0.88889],
    9632: [0, 0.675, 0, 0, 0.77778],
    9633: [0, 0.675, 0, 0, 0.77778],
    9650: [0, 0.54986, 0, 0, 0.72222],
    9651: [0, 0.54986, 0, 0, 0.72222],
    9654: [0.03517, 0.54986, 0, 0, 0.77778],
    9660: [0, 0.54986, 0, 0, 0.72222],
    9661: [0, 0.54986, 0, 0, 0.72222],
    9664: [0.03517, 0.54986, 0, 0, 0.77778],
    9674: [0.11111, 0.69224, 0, 0, 0.66667],
    9733: [0.19444, 0.69224, 0, 0, 0.94445],
    10003: [0, 0.69224, 0, 0, 0.83334],
    10016: [0, 0.69224, 0, 0, 0.83334],
    10731: [0.11111, 0.69224, 0, 0, 0.66667],
    10846: [0.19444, 0.75583, 0, 0, 0.61111],
    10877: [0.13667, 0.63667, 0, 0, 0.77778],
    10878: [0.13667, 0.63667, 0, 0, 0.77778],
    10885: [0.25583, 0.75583, 0, 0, 0.77778],
    10886: [0.25583, 0.75583, 0, 0, 0.77778],
    10887: [0.13597, 0.63597, 0, 0, 0.77778],
    10888: [0.13597, 0.63597, 0, 0, 0.77778],
    10889: [0.26167, 0.75726, 0, 0, 0.77778],
    10890: [0.26167, 0.75726, 0, 0, 0.77778],
    10891: [0.48256, 0.98256, 0, 0, 0.77778],
    10892: [0.48256, 0.98256, 0, 0, 0.77778],
    10901: [0.13667, 0.63667, 0, 0, 0.77778],
    10902: [0.13667, 0.63667, 0, 0, 0.77778],
    10933: [0.25142, 0.75726, 0, 0, 0.77778],
    10934: [0.25142, 0.75726, 0, 0, 0.77778],
    10935: [0.26167, 0.75726, 0, 0, 0.77778],
    10936: [0.26167, 0.75726, 0, 0, 0.77778],
    10937: [0.26167, 0.75726, 0, 0, 0.77778],
    10938: [0.26167, 0.75726, 0, 0, 0.77778],
    10949: [0.25583, 0.75583, 0, 0, 0.77778],
    10950: [0.25583, 0.75583, 0, 0, 0.77778],
    10955: [0.28481, 0.79383, 0, 0, 0.77778],
    10956: [0.28481, 0.79383, 0, 0, 0.77778],
    57350: [0.08167, 0.58167, 0, 0, 0.22222],
    57351: [0.08167, 0.58167, 0, 0, 0.38889],
    57352: [0.08167, 0.58167, 0, 0, 0.77778],
    57353: [0, 0.43056, 0.04028, 0, 0.66667],
    57356: [0.25142, 0.75726, 0, 0, 0.77778],
    57357: [0.25142, 0.75726, 0, 0, 0.77778],
    57358: [0.41951, 0.91951, 0, 0, 0.77778],
    57359: [0.30274, 0.79383, 0, 0, 0.77778],
    57360: [0.30274, 0.79383, 0, 0, 0.77778],
    57361: [0.41951, 0.91951, 0, 0, 0.77778],
    57366: [0.25142, 0.75726, 0, 0, 0.77778],
    57367: [0.25142, 0.75726, 0, 0, 0.77778],
    57368: [0.25142, 0.75726, 0, 0, 0.77778],
    57369: [0.25142, 0.75726, 0, 0, 0.77778],
    57370: [0.13597, 0.63597, 0, 0, 0.77778],
    57371: [0.13597, 0.63597, 0, 0, 0.77778]
  },
  "Caligraphic-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.68333, 0, 0.19445, 0.79847],
    66: [0, 0.68333, 0.03041, 0.13889, 0.65681],
    67: [0, 0.68333, 0.05834, 0.13889, 0.52653],
    68: [0, 0.68333, 0.02778, 0.08334, 0.77139],
    69: [0, 0.68333, 0.08944, 0.11111, 0.52778],
    70: [0, 0.68333, 0.09931, 0.11111, 0.71875],
    71: [0.09722, 0.68333, 0.0593, 0.11111, 0.59487],
    72: [0, 0.68333, 965e-5, 0.11111, 0.84452],
    73: [0, 0.68333, 0.07382, 0, 0.54452],
    74: [0.09722, 0.68333, 0.18472, 0.16667, 0.67778],
    75: [0, 0.68333, 0.01445, 0.05556, 0.76195],
    76: [0, 0.68333, 0, 0.13889, 0.68972],
    77: [0, 0.68333, 0, 0.13889, 1.2009],
    78: [0, 0.68333, 0.14736, 0.08334, 0.82049],
    79: [0, 0.68333, 0.02778, 0.11111, 0.79611],
    80: [0, 0.68333, 0.08222, 0.08334, 0.69556],
    81: [0.09722, 0.68333, 0, 0.11111, 0.81667],
    82: [0, 0.68333, 0, 0.08334, 0.8475],
    83: [0, 0.68333, 0.075, 0.13889, 0.60556],
    84: [0, 0.68333, 0.25417, 0, 0.54464],
    85: [0, 0.68333, 0.09931, 0.08334, 0.62583],
    86: [0, 0.68333, 0.08222, 0, 0.61278],
    87: [0, 0.68333, 0.08222, 0.08334, 0.98778],
    88: [0, 0.68333, 0.14643, 0.13889, 0.7133],
    89: [0.09722, 0.68333, 0.08222, 0.08334, 0.66834],
    90: [0, 0.68333, 0.07944, 0.13889, 0.72473],
    160: [0, 0, 0, 0, 0.25]
  },
  "Fraktur-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69141, 0, 0, 0.29574],
    34: [0, 0.69141, 0, 0, 0.21471],
    38: [0, 0.69141, 0, 0, 0.73786],
    39: [0, 0.69141, 0, 0, 0.21201],
    40: [0.24982, 0.74947, 0, 0, 0.38865],
    41: [0.24982, 0.74947, 0, 0, 0.38865],
    42: [0, 0.62119, 0, 0, 0.27764],
    43: [0.08319, 0.58283, 0, 0, 0.75623],
    44: [0, 0.10803, 0, 0, 0.27764],
    45: [0.08319, 0.58283, 0, 0, 0.75623],
    46: [0, 0.10803, 0, 0, 0.27764],
    47: [0.24982, 0.74947, 0, 0, 0.50181],
    48: [0, 0.47534, 0, 0, 0.50181],
    49: [0, 0.47534, 0, 0, 0.50181],
    50: [0, 0.47534, 0, 0, 0.50181],
    51: [0.18906, 0.47534, 0, 0, 0.50181],
    52: [0.18906, 0.47534, 0, 0, 0.50181],
    53: [0.18906, 0.47534, 0, 0, 0.50181],
    54: [0, 0.69141, 0, 0, 0.50181],
    55: [0.18906, 0.47534, 0, 0, 0.50181],
    56: [0, 0.69141, 0, 0, 0.50181],
    57: [0.18906, 0.47534, 0, 0, 0.50181],
    58: [0, 0.47534, 0, 0, 0.21606],
    59: [0.12604, 0.47534, 0, 0, 0.21606],
    61: [-0.13099, 0.36866, 0, 0, 0.75623],
    63: [0, 0.69141, 0, 0, 0.36245],
    65: [0, 0.69141, 0, 0, 0.7176],
    66: [0, 0.69141, 0, 0, 0.88397],
    67: [0, 0.69141, 0, 0, 0.61254],
    68: [0, 0.69141, 0, 0, 0.83158],
    69: [0, 0.69141, 0, 0, 0.66278],
    70: [0.12604, 0.69141, 0, 0, 0.61119],
    71: [0, 0.69141, 0, 0, 0.78539],
    72: [0.06302, 0.69141, 0, 0, 0.7203],
    73: [0, 0.69141, 0, 0, 0.55448],
    74: [0.12604, 0.69141, 0, 0, 0.55231],
    75: [0, 0.69141, 0, 0, 0.66845],
    76: [0, 0.69141, 0, 0, 0.66602],
    77: [0, 0.69141, 0, 0, 1.04953],
    78: [0, 0.69141, 0, 0, 0.83212],
    79: [0, 0.69141, 0, 0, 0.82699],
    80: [0.18906, 0.69141, 0, 0, 0.82753],
    81: [0.03781, 0.69141, 0, 0, 0.82699],
    82: [0, 0.69141, 0, 0, 0.82807],
    83: [0, 0.69141, 0, 0, 0.82861],
    84: [0, 0.69141, 0, 0, 0.66899],
    85: [0, 0.69141, 0, 0, 0.64576],
    86: [0, 0.69141, 0, 0, 0.83131],
    87: [0, 0.69141, 0, 0, 1.04602],
    88: [0, 0.69141, 0, 0, 0.71922],
    89: [0.18906, 0.69141, 0, 0, 0.83293],
    90: [0.12604, 0.69141, 0, 0, 0.60201],
    91: [0.24982, 0.74947, 0, 0, 0.27764],
    93: [0.24982, 0.74947, 0, 0, 0.27764],
    94: [0, 0.69141, 0, 0, 0.49965],
    97: [0, 0.47534, 0, 0, 0.50046],
    98: [0, 0.69141, 0, 0, 0.51315],
    99: [0, 0.47534, 0, 0, 0.38946],
    100: [0, 0.62119, 0, 0, 0.49857],
    101: [0, 0.47534, 0, 0, 0.40053],
    102: [0.18906, 0.69141, 0, 0, 0.32626],
    103: [0.18906, 0.47534, 0, 0, 0.5037],
    104: [0.18906, 0.69141, 0, 0, 0.52126],
    105: [0, 0.69141, 0, 0, 0.27899],
    106: [0, 0.69141, 0, 0, 0.28088],
    107: [0, 0.69141, 0, 0, 0.38946],
    108: [0, 0.69141, 0, 0, 0.27953],
    109: [0, 0.47534, 0, 0, 0.76676],
    110: [0, 0.47534, 0, 0, 0.52666],
    111: [0, 0.47534, 0, 0, 0.48885],
    112: [0.18906, 0.52396, 0, 0, 0.50046],
    113: [0.18906, 0.47534, 0, 0, 0.48912],
    114: [0, 0.47534, 0, 0, 0.38919],
    115: [0, 0.47534, 0, 0, 0.44266],
    116: [0, 0.62119, 0, 0, 0.33301],
    117: [0, 0.47534, 0, 0, 0.5172],
    118: [0, 0.52396, 0, 0, 0.5118],
    119: [0, 0.52396, 0, 0, 0.77351],
    120: [0.18906, 0.47534, 0, 0, 0.38865],
    121: [0.18906, 0.47534, 0, 0, 0.49884],
    122: [0.18906, 0.47534, 0, 0, 0.39054],
    160: [0, 0, 0, 0, 0.25],
    8216: [0, 0.69141, 0, 0, 0.21471],
    8217: [0, 0.69141, 0, 0, 0.21471],
    58112: [0, 0.62119, 0, 0, 0.49749],
    58113: [0, 0.62119, 0, 0, 0.4983],
    58114: [0.18906, 0.69141, 0, 0, 0.33328],
    58115: [0.18906, 0.69141, 0, 0, 0.32923],
    58116: [0.18906, 0.47534, 0, 0, 0.50343],
    58117: [0, 0.69141, 0, 0, 0.33301],
    58118: [0, 0.62119, 0, 0, 0.33409],
    58119: [0, 0.47534, 0, 0, 0.50073]
  },
  "Main-Bold": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.35],
    34: [0, 0.69444, 0, 0, 0.60278],
    35: [0.19444, 0.69444, 0, 0, 0.95833],
    36: [0.05556, 0.75, 0, 0, 0.575],
    37: [0.05556, 0.75, 0, 0, 0.95833],
    38: [0, 0.69444, 0, 0, 0.89444],
    39: [0, 0.69444, 0, 0, 0.31944],
    40: [0.25, 0.75, 0, 0, 0.44722],
    41: [0.25, 0.75, 0, 0, 0.44722],
    42: [0, 0.75, 0, 0, 0.575],
    43: [0.13333, 0.63333, 0, 0, 0.89444],
    44: [0.19444, 0.15556, 0, 0, 0.31944],
    45: [0, 0.44444, 0, 0, 0.38333],
    46: [0, 0.15556, 0, 0, 0.31944],
    47: [0.25, 0.75, 0, 0, 0.575],
    48: [0, 0.64444, 0, 0, 0.575],
    49: [0, 0.64444, 0, 0, 0.575],
    50: [0, 0.64444, 0, 0, 0.575],
    51: [0, 0.64444, 0, 0, 0.575],
    52: [0, 0.64444, 0, 0, 0.575],
    53: [0, 0.64444, 0, 0, 0.575],
    54: [0, 0.64444, 0, 0, 0.575],
    55: [0, 0.64444, 0, 0, 0.575],
    56: [0, 0.64444, 0, 0, 0.575],
    57: [0, 0.64444, 0, 0, 0.575],
    58: [0, 0.44444, 0, 0, 0.31944],
    59: [0.19444, 0.44444, 0, 0, 0.31944],
    60: [0.08556, 0.58556, 0, 0, 0.89444],
    61: [-0.10889, 0.39111, 0, 0, 0.89444],
    62: [0.08556, 0.58556, 0, 0, 0.89444],
    63: [0, 0.69444, 0, 0, 0.54305],
    64: [0, 0.69444, 0, 0, 0.89444],
    65: [0, 0.68611, 0, 0, 0.86944],
    66: [0, 0.68611, 0, 0, 0.81805],
    67: [0, 0.68611, 0, 0, 0.83055],
    68: [0, 0.68611, 0, 0, 0.88194],
    69: [0, 0.68611, 0, 0, 0.75555],
    70: [0, 0.68611, 0, 0, 0.72361],
    71: [0, 0.68611, 0, 0, 0.90416],
    72: [0, 0.68611, 0, 0, 0.9],
    73: [0, 0.68611, 0, 0, 0.43611],
    74: [0, 0.68611, 0, 0, 0.59444],
    75: [0, 0.68611, 0, 0, 0.90138],
    76: [0, 0.68611, 0, 0, 0.69166],
    77: [0, 0.68611, 0, 0, 1.09166],
    78: [0, 0.68611, 0, 0, 0.9],
    79: [0, 0.68611, 0, 0, 0.86388],
    80: [0, 0.68611, 0, 0, 0.78611],
    81: [0.19444, 0.68611, 0, 0, 0.86388],
    82: [0, 0.68611, 0, 0, 0.8625],
    83: [0, 0.68611, 0, 0, 0.63889],
    84: [0, 0.68611, 0, 0, 0.8],
    85: [0, 0.68611, 0, 0, 0.88472],
    86: [0, 0.68611, 0.01597, 0, 0.86944],
    87: [0, 0.68611, 0.01597, 0, 1.18888],
    88: [0, 0.68611, 0, 0, 0.86944],
    89: [0, 0.68611, 0.02875, 0, 0.86944],
    90: [0, 0.68611, 0, 0, 0.70277],
    91: [0.25, 0.75, 0, 0, 0.31944],
    92: [0.25, 0.75, 0, 0, 0.575],
    93: [0.25, 0.75, 0, 0, 0.31944],
    94: [0, 0.69444, 0, 0, 0.575],
    95: [0.31, 0.13444, 0.03194, 0, 0.575],
    97: [0, 0.44444, 0, 0, 0.55902],
    98: [0, 0.69444, 0, 0, 0.63889],
    99: [0, 0.44444, 0, 0, 0.51111],
    100: [0, 0.69444, 0, 0, 0.63889],
    101: [0, 0.44444, 0, 0, 0.52708],
    102: [0, 0.69444, 0.10903, 0, 0.35139],
    103: [0.19444, 0.44444, 0.01597, 0, 0.575],
    104: [0, 0.69444, 0, 0, 0.63889],
    105: [0, 0.69444, 0, 0, 0.31944],
    106: [0.19444, 0.69444, 0, 0, 0.35139],
    107: [0, 0.69444, 0, 0, 0.60694],
    108: [0, 0.69444, 0, 0, 0.31944],
    109: [0, 0.44444, 0, 0, 0.95833],
    110: [0, 0.44444, 0, 0, 0.63889],
    111: [0, 0.44444, 0, 0, 0.575],
    112: [0.19444, 0.44444, 0, 0, 0.63889],
    113: [0.19444, 0.44444, 0, 0, 0.60694],
    114: [0, 0.44444, 0, 0, 0.47361],
    115: [0, 0.44444, 0, 0, 0.45361],
    116: [0, 0.63492, 0, 0, 0.44722],
    117: [0, 0.44444, 0, 0, 0.63889],
    118: [0, 0.44444, 0.01597, 0, 0.60694],
    119: [0, 0.44444, 0.01597, 0, 0.83055],
    120: [0, 0.44444, 0, 0, 0.60694],
    121: [0.19444, 0.44444, 0.01597, 0, 0.60694],
    122: [0, 0.44444, 0, 0, 0.51111],
    123: [0.25, 0.75, 0, 0, 0.575],
    124: [0.25, 0.75, 0, 0, 0.31944],
    125: [0.25, 0.75, 0, 0, 0.575],
    126: [0.35, 0.34444, 0, 0, 0.575],
    160: [0, 0, 0, 0, 0.25],
    163: [0, 0.69444, 0, 0, 0.86853],
    168: [0, 0.69444, 0, 0, 0.575],
    172: [0, 0.44444, 0, 0, 0.76666],
    176: [0, 0.69444, 0, 0, 0.86944],
    177: [0.13333, 0.63333, 0, 0, 0.89444],
    184: [0.17014, 0, 0, 0, 0.51111],
    198: [0, 0.68611, 0, 0, 1.04166],
    215: [0.13333, 0.63333, 0, 0, 0.89444],
    216: [0.04861, 0.73472, 0, 0, 0.89444],
    223: [0, 0.69444, 0, 0, 0.59722],
    230: [0, 0.44444, 0, 0, 0.83055],
    247: [0.13333, 0.63333, 0, 0, 0.89444],
    248: [0.09722, 0.54167, 0, 0, 0.575],
    305: [0, 0.44444, 0, 0, 0.31944],
    338: [0, 0.68611, 0, 0, 1.16944],
    339: [0, 0.44444, 0, 0, 0.89444],
    567: [0.19444, 0.44444, 0, 0, 0.35139],
    710: [0, 0.69444, 0, 0, 0.575],
    711: [0, 0.63194, 0, 0, 0.575],
    713: [0, 0.59611, 0, 0, 0.575],
    714: [0, 0.69444, 0, 0, 0.575],
    715: [0, 0.69444, 0, 0, 0.575],
    728: [0, 0.69444, 0, 0, 0.575],
    729: [0, 0.69444, 0, 0, 0.31944],
    730: [0, 0.69444, 0, 0, 0.86944],
    732: [0, 0.69444, 0, 0, 0.575],
    733: [0, 0.69444, 0, 0, 0.575],
    915: [0, 0.68611, 0, 0, 0.69166],
    916: [0, 0.68611, 0, 0, 0.95833],
    920: [0, 0.68611, 0, 0, 0.89444],
    923: [0, 0.68611, 0, 0, 0.80555],
    926: [0, 0.68611, 0, 0, 0.76666],
    928: [0, 0.68611, 0, 0, 0.9],
    931: [0, 0.68611, 0, 0, 0.83055],
    933: [0, 0.68611, 0, 0, 0.89444],
    934: [0, 0.68611, 0, 0, 0.83055],
    936: [0, 0.68611, 0, 0, 0.89444],
    937: [0, 0.68611, 0, 0, 0.83055],
    8211: [0, 0.44444, 0.03194, 0, 0.575],
    8212: [0, 0.44444, 0.03194, 0, 1.14999],
    8216: [0, 0.69444, 0, 0, 0.31944],
    8217: [0, 0.69444, 0, 0, 0.31944],
    8220: [0, 0.69444, 0, 0, 0.60278],
    8221: [0, 0.69444, 0, 0, 0.60278],
    8224: [0.19444, 0.69444, 0, 0, 0.51111],
    8225: [0.19444, 0.69444, 0, 0, 0.51111],
    8242: [0, 0.55556, 0, 0, 0.34444],
    8407: [0, 0.72444, 0.15486, 0, 0.575],
    8463: [0, 0.69444, 0, 0, 0.66759],
    8465: [0, 0.69444, 0, 0, 0.83055],
    8467: [0, 0.69444, 0, 0, 0.47361],
    8472: [0.19444, 0.44444, 0, 0, 0.74027],
    8476: [0, 0.69444, 0, 0, 0.83055],
    8501: [0, 0.69444, 0, 0, 0.70277],
    8592: [-0.10889, 0.39111, 0, 0, 1.14999],
    8593: [0.19444, 0.69444, 0, 0, 0.575],
    8594: [-0.10889, 0.39111, 0, 0, 1.14999],
    8595: [0.19444, 0.69444, 0, 0, 0.575],
    8596: [-0.10889, 0.39111, 0, 0, 1.14999],
    8597: [0.25, 0.75, 0, 0, 0.575],
    8598: [0.19444, 0.69444, 0, 0, 1.14999],
    8599: [0.19444, 0.69444, 0, 0, 1.14999],
    8600: [0.19444, 0.69444, 0, 0, 1.14999],
    8601: [0.19444, 0.69444, 0, 0, 1.14999],
    8636: [-0.10889, 0.39111, 0, 0, 1.14999],
    8637: [-0.10889, 0.39111, 0, 0, 1.14999],
    8640: [-0.10889, 0.39111, 0, 0, 1.14999],
    8641: [-0.10889, 0.39111, 0, 0, 1.14999],
    8656: [-0.10889, 0.39111, 0, 0, 1.14999],
    8657: [0.19444, 0.69444, 0, 0, 0.70277],
    8658: [-0.10889, 0.39111, 0, 0, 1.14999],
    8659: [0.19444, 0.69444, 0, 0, 0.70277],
    8660: [-0.10889, 0.39111, 0, 0, 1.14999],
    8661: [0.25, 0.75, 0, 0, 0.70277],
    8704: [0, 0.69444, 0, 0, 0.63889],
    8706: [0, 0.69444, 0.06389, 0, 0.62847],
    8707: [0, 0.69444, 0, 0, 0.63889],
    8709: [0.05556, 0.75, 0, 0, 0.575],
    8711: [0, 0.68611, 0, 0, 0.95833],
    8712: [0.08556, 0.58556, 0, 0, 0.76666],
    8715: [0.08556, 0.58556, 0, 0, 0.76666],
    8722: [0.13333, 0.63333, 0, 0, 0.89444],
    8723: [0.13333, 0.63333, 0, 0, 0.89444],
    8725: [0.25, 0.75, 0, 0, 0.575],
    8726: [0.25, 0.75, 0, 0, 0.575],
    8727: [-0.02778, 0.47222, 0, 0, 0.575],
    8728: [-0.02639, 0.47361, 0, 0, 0.575],
    8729: [-0.02639, 0.47361, 0, 0, 0.575],
    8730: [0.18, 0.82, 0, 0, 0.95833],
    8733: [0, 0.44444, 0, 0, 0.89444],
    8734: [0, 0.44444, 0, 0, 1.14999],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8739: [0.25, 0.75, 0, 0, 0.31944],
    8741: [0.25, 0.75, 0, 0, 0.575],
    8743: [0, 0.55556, 0, 0, 0.76666],
    8744: [0, 0.55556, 0, 0, 0.76666],
    8745: [0, 0.55556, 0, 0, 0.76666],
    8746: [0, 0.55556, 0, 0, 0.76666],
    8747: [0.19444, 0.69444, 0.12778, 0, 0.56875],
    8764: [-0.10889, 0.39111, 0, 0, 0.89444],
    8768: [0.19444, 0.69444, 0, 0, 0.31944],
    8771: [222e-5, 0.50222, 0, 0, 0.89444],
    8773: [0.027, 0.638, 0, 0, 0.894],
    8776: [0.02444, 0.52444, 0, 0, 0.89444],
    8781: [222e-5, 0.50222, 0, 0, 0.89444],
    8801: [222e-5, 0.50222, 0, 0, 0.89444],
    8804: [0.19667, 0.69667, 0, 0, 0.89444],
    8805: [0.19667, 0.69667, 0, 0, 0.89444],
    8810: [0.08556, 0.58556, 0, 0, 1.14999],
    8811: [0.08556, 0.58556, 0, 0, 1.14999],
    8826: [0.08556, 0.58556, 0, 0, 0.89444],
    8827: [0.08556, 0.58556, 0, 0, 0.89444],
    8834: [0.08556, 0.58556, 0, 0, 0.89444],
    8835: [0.08556, 0.58556, 0, 0, 0.89444],
    8838: [0.19667, 0.69667, 0, 0, 0.89444],
    8839: [0.19667, 0.69667, 0, 0, 0.89444],
    8846: [0, 0.55556, 0, 0, 0.76666],
    8849: [0.19667, 0.69667, 0, 0, 0.89444],
    8850: [0.19667, 0.69667, 0, 0, 0.89444],
    8851: [0, 0.55556, 0, 0, 0.76666],
    8852: [0, 0.55556, 0, 0, 0.76666],
    8853: [0.13333, 0.63333, 0, 0, 0.89444],
    8854: [0.13333, 0.63333, 0, 0, 0.89444],
    8855: [0.13333, 0.63333, 0, 0, 0.89444],
    8856: [0.13333, 0.63333, 0, 0, 0.89444],
    8857: [0.13333, 0.63333, 0, 0, 0.89444],
    8866: [0, 0.69444, 0, 0, 0.70277],
    8867: [0, 0.69444, 0, 0, 0.70277],
    8868: [0, 0.69444, 0, 0, 0.89444],
    8869: [0, 0.69444, 0, 0, 0.89444],
    8900: [-0.02639, 0.47361, 0, 0, 0.575],
    8901: [-0.02639, 0.47361, 0, 0, 0.31944],
    8902: [-0.02778, 0.47222, 0, 0, 0.575],
    8968: [0.25, 0.75, 0, 0, 0.51111],
    8969: [0.25, 0.75, 0, 0, 0.51111],
    8970: [0.25, 0.75, 0, 0, 0.51111],
    8971: [0.25, 0.75, 0, 0, 0.51111],
    8994: [-0.13889, 0.36111, 0, 0, 1.14999],
    8995: [-0.13889, 0.36111, 0, 0, 1.14999],
    9651: [0.19444, 0.69444, 0, 0, 1.02222],
    9657: [-0.02778, 0.47222, 0, 0, 0.575],
    9661: [0.19444, 0.69444, 0, 0, 1.02222],
    9667: [-0.02778, 0.47222, 0, 0, 0.575],
    9711: [0.19444, 0.69444, 0, 0, 1.14999],
    9824: [0.12963, 0.69444, 0, 0, 0.89444],
    9825: [0.12963, 0.69444, 0, 0, 0.89444],
    9826: [0.12963, 0.69444, 0, 0, 0.89444],
    9827: [0.12963, 0.69444, 0, 0, 0.89444],
    9837: [0, 0.75, 0, 0, 0.44722],
    9838: [0.19444, 0.69444, 0, 0, 0.44722],
    9839: [0.19444, 0.69444, 0, 0, 0.44722],
    10216: [0.25, 0.75, 0, 0, 0.44722],
    10217: [0.25, 0.75, 0, 0, 0.44722],
    10815: [0, 0.68611, 0, 0, 0.9],
    10927: [0.19667, 0.69667, 0, 0, 0.89444],
    10928: [0.19667, 0.69667, 0, 0, 0.89444],
    57376: [0.19444, 0.69444, 0, 0, 0]
  },
  "Main-BoldItalic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.11417, 0, 0.38611],
    34: [0, 0.69444, 0.07939, 0, 0.62055],
    35: [0.19444, 0.69444, 0.06833, 0, 0.94444],
    37: [0.05556, 0.75, 0.12861, 0, 0.94444],
    38: [0, 0.69444, 0.08528, 0, 0.88555],
    39: [0, 0.69444, 0.12945, 0, 0.35555],
    40: [0.25, 0.75, 0.15806, 0, 0.47333],
    41: [0.25, 0.75, 0.03306, 0, 0.47333],
    42: [0, 0.75, 0.14333, 0, 0.59111],
    43: [0.10333, 0.60333, 0.03306, 0, 0.88555],
    44: [0.19444, 0.14722, 0, 0, 0.35555],
    45: [0, 0.44444, 0.02611, 0, 0.41444],
    46: [0, 0.14722, 0, 0, 0.35555],
    47: [0.25, 0.75, 0.15806, 0, 0.59111],
    48: [0, 0.64444, 0.13167, 0, 0.59111],
    49: [0, 0.64444, 0.13167, 0, 0.59111],
    50: [0, 0.64444, 0.13167, 0, 0.59111],
    51: [0, 0.64444, 0.13167, 0, 0.59111],
    52: [0.19444, 0.64444, 0.13167, 0, 0.59111],
    53: [0, 0.64444, 0.13167, 0, 0.59111],
    54: [0, 0.64444, 0.13167, 0, 0.59111],
    55: [0.19444, 0.64444, 0.13167, 0, 0.59111],
    56: [0, 0.64444, 0.13167, 0, 0.59111],
    57: [0, 0.64444, 0.13167, 0, 0.59111],
    58: [0, 0.44444, 0.06695, 0, 0.35555],
    59: [0.19444, 0.44444, 0.06695, 0, 0.35555],
    61: [-0.10889, 0.39111, 0.06833, 0, 0.88555],
    63: [0, 0.69444, 0.11472, 0, 0.59111],
    64: [0, 0.69444, 0.09208, 0, 0.88555],
    65: [0, 0.68611, 0, 0, 0.86555],
    66: [0, 0.68611, 0.0992, 0, 0.81666],
    67: [0, 0.68611, 0.14208, 0, 0.82666],
    68: [0, 0.68611, 0.09062, 0, 0.87555],
    69: [0, 0.68611, 0.11431, 0, 0.75666],
    70: [0, 0.68611, 0.12903, 0, 0.72722],
    71: [0, 0.68611, 0.07347, 0, 0.89527],
    72: [0, 0.68611, 0.17208, 0, 0.8961],
    73: [0, 0.68611, 0.15681, 0, 0.47166],
    74: [0, 0.68611, 0.145, 0, 0.61055],
    75: [0, 0.68611, 0.14208, 0, 0.89499],
    76: [0, 0.68611, 0, 0, 0.69777],
    77: [0, 0.68611, 0.17208, 0, 1.07277],
    78: [0, 0.68611, 0.17208, 0, 0.8961],
    79: [0, 0.68611, 0.09062, 0, 0.85499],
    80: [0, 0.68611, 0.0992, 0, 0.78721],
    81: [0.19444, 0.68611, 0.09062, 0, 0.85499],
    82: [0, 0.68611, 0.02559, 0, 0.85944],
    83: [0, 0.68611, 0.11264, 0, 0.64999],
    84: [0, 0.68611, 0.12903, 0, 0.7961],
    85: [0, 0.68611, 0.17208, 0, 0.88083],
    86: [0, 0.68611, 0.18625, 0, 0.86555],
    87: [0, 0.68611, 0.18625, 0, 1.15999],
    88: [0, 0.68611, 0.15681, 0, 0.86555],
    89: [0, 0.68611, 0.19803, 0, 0.86555],
    90: [0, 0.68611, 0.14208, 0, 0.70888],
    91: [0.25, 0.75, 0.1875, 0, 0.35611],
    93: [0.25, 0.75, 0.09972, 0, 0.35611],
    94: [0, 0.69444, 0.06709, 0, 0.59111],
    95: [0.31, 0.13444, 0.09811, 0, 0.59111],
    97: [0, 0.44444, 0.09426, 0, 0.59111],
    98: [0, 0.69444, 0.07861, 0, 0.53222],
    99: [0, 0.44444, 0.05222, 0, 0.53222],
    100: [0, 0.69444, 0.10861, 0, 0.59111],
    101: [0, 0.44444, 0.085, 0, 0.53222],
    102: [0.19444, 0.69444, 0.21778, 0, 0.4],
    103: [0.19444, 0.44444, 0.105, 0, 0.53222],
    104: [0, 0.69444, 0.09426, 0, 0.59111],
    105: [0, 0.69326, 0.11387, 0, 0.35555],
    106: [0.19444, 0.69326, 0.1672, 0, 0.35555],
    107: [0, 0.69444, 0.11111, 0, 0.53222],
    108: [0, 0.69444, 0.10861, 0, 0.29666],
    109: [0, 0.44444, 0.09426, 0, 0.94444],
    110: [0, 0.44444, 0.09426, 0, 0.64999],
    111: [0, 0.44444, 0.07861, 0, 0.59111],
    112: [0.19444, 0.44444, 0.07861, 0, 0.59111],
    113: [0.19444, 0.44444, 0.105, 0, 0.53222],
    114: [0, 0.44444, 0.11111, 0, 0.50167],
    115: [0, 0.44444, 0.08167, 0, 0.48694],
    116: [0, 0.63492, 0.09639, 0, 0.385],
    117: [0, 0.44444, 0.09426, 0, 0.62055],
    118: [0, 0.44444, 0.11111, 0, 0.53222],
    119: [0, 0.44444, 0.11111, 0, 0.76777],
    120: [0, 0.44444, 0.12583, 0, 0.56055],
    121: [0.19444, 0.44444, 0.105, 0, 0.56166],
    122: [0, 0.44444, 0.13889, 0, 0.49055],
    126: [0.35, 0.34444, 0.11472, 0, 0.59111],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.69444, 0.11473, 0, 0.59111],
    176: [0, 0.69444, 0, 0, 0.94888],
    184: [0.17014, 0, 0, 0, 0.53222],
    198: [0, 0.68611, 0.11431, 0, 1.02277],
    216: [0.04861, 0.73472, 0.09062, 0, 0.88555],
    223: [0.19444, 0.69444, 0.09736, 0, 0.665],
    230: [0, 0.44444, 0.085, 0, 0.82666],
    248: [0.09722, 0.54167, 0.09458, 0, 0.59111],
    305: [0, 0.44444, 0.09426, 0, 0.35555],
    338: [0, 0.68611, 0.11431, 0, 1.14054],
    339: [0, 0.44444, 0.085, 0, 0.82666],
    567: [0.19444, 0.44444, 0.04611, 0, 0.385],
    710: [0, 0.69444, 0.06709, 0, 0.59111],
    711: [0, 0.63194, 0.08271, 0, 0.59111],
    713: [0, 0.59444, 0.10444, 0, 0.59111],
    714: [0, 0.69444, 0.08528, 0, 0.59111],
    715: [0, 0.69444, 0, 0, 0.59111],
    728: [0, 0.69444, 0.10333, 0, 0.59111],
    729: [0, 0.69444, 0.12945, 0, 0.35555],
    730: [0, 0.69444, 0, 0, 0.94888],
    732: [0, 0.69444, 0.11472, 0, 0.59111],
    733: [0, 0.69444, 0.11472, 0, 0.59111],
    915: [0, 0.68611, 0.12903, 0, 0.69777],
    916: [0, 0.68611, 0, 0, 0.94444],
    920: [0, 0.68611, 0.09062, 0, 0.88555],
    923: [0, 0.68611, 0, 0, 0.80666],
    926: [0, 0.68611, 0.15092, 0, 0.76777],
    928: [0, 0.68611, 0.17208, 0, 0.8961],
    931: [0, 0.68611, 0.11431, 0, 0.82666],
    933: [0, 0.68611, 0.10778, 0, 0.88555],
    934: [0, 0.68611, 0.05632, 0, 0.82666],
    936: [0, 0.68611, 0.10778, 0, 0.88555],
    937: [0, 0.68611, 0.0992, 0, 0.82666],
    8211: [0, 0.44444, 0.09811, 0, 0.59111],
    8212: [0, 0.44444, 0.09811, 0, 1.18221],
    8216: [0, 0.69444, 0.12945, 0, 0.35555],
    8217: [0, 0.69444, 0.12945, 0, 0.35555],
    8220: [0, 0.69444, 0.16772, 0, 0.62055],
    8221: [0, 0.69444, 0.07939, 0, 0.62055]
  },
  "Main-Italic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.12417, 0, 0.30667],
    34: [0, 0.69444, 0.06961, 0, 0.51444],
    35: [0.19444, 0.69444, 0.06616, 0, 0.81777],
    37: [0.05556, 0.75, 0.13639, 0, 0.81777],
    38: [0, 0.69444, 0.09694, 0, 0.76666],
    39: [0, 0.69444, 0.12417, 0, 0.30667],
    40: [0.25, 0.75, 0.16194, 0, 0.40889],
    41: [0.25, 0.75, 0.03694, 0, 0.40889],
    42: [0, 0.75, 0.14917, 0, 0.51111],
    43: [0.05667, 0.56167, 0.03694, 0, 0.76666],
    44: [0.19444, 0.10556, 0, 0, 0.30667],
    45: [0, 0.43056, 0.02826, 0, 0.35778],
    46: [0, 0.10556, 0, 0, 0.30667],
    47: [0.25, 0.75, 0.16194, 0, 0.51111],
    48: [0, 0.64444, 0.13556, 0, 0.51111],
    49: [0, 0.64444, 0.13556, 0, 0.51111],
    50: [0, 0.64444, 0.13556, 0, 0.51111],
    51: [0, 0.64444, 0.13556, 0, 0.51111],
    52: [0.19444, 0.64444, 0.13556, 0, 0.51111],
    53: [0, 0.64444, 0.13556, 0, 0.51111],
    54: [0, 0.64444, 0.13556, 0, 0.51111],
    55: [0.19444, 0.64444, 0.13556, 0, 0.51111],
    56: [0, 0.64444, 0.13556, 0, 0.51111],
    57: [0, 0.64444, 0.13556, 0, 0.51111],
    58: [0, 0.43056, 0.0582, 0, 0.30667],
    59: [0.19444, 0.43056, 0.0582, 0, 0.30667],
    61: [-0.13313, 0.36687, 0.06616, 0, 0.76666],
    63: [0, 0.69444, 0.1225, 0, 0.51111],
    64: [0, 0.69444, 0.09597, 0, 0.76666],
    65: [0, 0.68333, 0, 0, 0.74333],
    66: [0, 0.68333, 0.10257, 0, 0.70389],
    67: [0, 0.68333, 0.14528, 0, 0.71555],
    68: [0, 0.68333, 0.09403, 0, 0.755],
    69: [0, 0.68333, 0.12028, 0, 0.67833],
    70: [0, 0.68333, 0.13305, 0, 0.65277],
    71: [0, 0.68333, 0.08722, 0, 0.77361],
    72: [0, 0.68333, 0.16389, 0, 0.74333],
    73: [0, 0.68333, 0.15806, 0, 0.38555],
    74: [0, 0.68333, 0.14028, 0, 0.525],
    75: [0, 0.68333, 0.14528, 0, 0.76888],
    76: [0, 0.68333, 0, 0, 0.62722],
    77: [0, 0.68333, 0.16389, 0, 0.89666],
    78: [0, 0.68333, 0.16389, 0, 0.74333],
    79: [0, 0.68333, 0.09403, 0, 0.76666],
    80: [0, 0.68333, 0.10257, 0, 0.67833],
    81: [0.19444, 0.68333, 0.09403, 0, 0.76666],
    82: [0, 0.68333, 0.03868, 0, 0.72944],
    83: [0, 0.68333, 0.11972, 0, 0.56222],
    84: [0, 0.68333, 0.13305, 0, 0.71555],
    85: [0, 0.68333, 0.16389, 0, 0.74333],
    86: [0, 0.68333, 0.18361, 0, 0.74333],
    87: [0, 0.68333, 0.18361, 0, 0.99888],
    88: [0, 0.68333, 0.15806, 0, 0.74333],
    89: [0, 0.68333, 0.19383, 0, 0.74333],
    90: [0, 0.68333, 0.14528, 0, 0.61333],
    91: [0.25, 0.75, 0.1875, 0, 0.30667],
    93: [0.25, 0.75, 0.10528, 0, 0.30667],
    94: [0, 0.69444, 0.06646, 0, 0.51111],
    95: [0.31, 0.12056, 0.09208, 0, 0.51111],
    97: [0, 0.43056, 0.07671, 0, 0.51111],
    98: [0, 0.69444, 0.06312, 0, 0.46],
    99: [0, 0.43056, 0.05653, 0, 0.46],
    100: [0, 0.69444, 0.10333, 0, 0.51111],
    101: [0, 0.43056, 0.07514, 0, 0.46],
    102: [0.19444, 0.69444, 0.21194, 0, 0.30667],
    103: [0.19444, 0.43056, 0.08847, 0, 0.46],
    104: [0, 0.69444, 0.07671, 0, 0.51111],
    105: [0, 0.65536, 0.1019, 0, 0.30667],
    106: [0.19444, 0.65536, 0.14467, 0, 0.30667],
    107: [0, 0.69444, 0.10764, 0, 0.46],
    108: [0, 0.69444, 0.10333, 0, 0.25555],
    109: [0, 0.43056, 0.07671, 0, 0.81777],
    110: [0, 0.43056, 0.07671, 0, 0.56222],
    111: [0, 0.43056, 0.06312, 0, 0.51111],
    112: [0.19444, 0.43056, 0.06312, 0, 0.51111],
    113: [0.19444, 0.43056, 0.08847, 0, 0.46],
    114: [0, 0.43056, 0.10764, 0, 0.42166],
    115: [0, 0.43056, 0.08208, 0, 0.40889],
    116: [0, 0.61508, 0.09486, 0, 0.33222],
    117: [0, 0.43056, 0.07671, 0, 0.53666],
    118: [0, 0.43056, 0.10764, 0, 0.46],
    119: [0, 0.43056, 0.10764, 0, 0.66444],
    120: [0, 0.43056, 0.12042, 0, 0.46389],
    121: [0.19444, 0.43056, 0.08847, 0, 0.48555],
    122: [0, 0.43056, 0.12292, 0, 0.40889],
    126: [0.35, 0.31786, 0.11585, 0, 0.51111],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.66786, 0.10474, 0, 0.51111],
    176: [0, 0.69444, 0, 0, 0.83129],
    184: [0.17014, 0, 0, 0, 0.46],
    198: [0, 0.68333, 0.12028, 0, 0.88277],
    216: [0.04861, 0.73194, 0.09403, 0, 0.76666],
    223: [0.19444, 0.69444, 0.10514, 0, 0.53666],
    230: [0, 0.43056, 0.07514, 0, 0.71555],
    248: [0.09722, 0.52778, 0.09194, 0, 0.51111],
    338: [0, 0.68333, 0.12028, 0, 0.98499],
    339: [0, 0.43056, 0.07514, 0, 0.71555],
    710: [0, 0.69444, 0.06646, 0, 0.51111],
    711: [0, 0.62847, 0.08295, 0, 0.51111],
    713: [0, 0.56167, 0.10333, 0, 0.51111],
    714: [0, 0.69444, 0.09694, 0, 0.51111],
    715: [0, 0.69444, 0, 0, 0.51111],
    728: [0, 0.69444, 0.10806, 0, 0.51111],
    729: [0, 0.66786, 0.11752, 0, 0.30667],
    730: [0, 0.69444, 0, 0, 0.83129],
    732: [0, 0.66786, 0.11585, 0, 0.51111],
    733: [0, 0.69444, 0.1225, 0, 0.51111],
    915: [0, 0.68333, 0.13305, 0, 0.62722],
    916: [0, 0.68333, 0, 0, 0.81777],
    920: [0, 0.68333, 0.09403, 0, 0.76666],
    923: [0, 0.68333, 0, 0, 0.69222],
    926: [0, 0.68333, 0.15294, 0, 0.66444],
    928: [0, 0.68333, 0.16389, 0, 0.74333],
    931: [0, 0.68333, 0.12028, 0, 0.71555],
    933: [0, 0.68333, 0.11111, 0, 0.76666],
    934: [0, 0.68333, 0.05986, 0, 0.71555],
    936: [0, 0.68333, 0.11111, 0, 0.76666],
    937: [0, 0.68333, 0.10257, 0, 0.71555],
    8211: [0, 0.43056, 0.09208, 0, 0.51111],
    8212: [0, 0.43056, 0.09208, 0, 1.02222],
    8216: [0, 0.69444, 0.12417, 0, 0.30667],
    8217: [0, 0.69444, 0.12417, 0, 0.30667],
    8220: [0, 0.69444, 0.1685, 0, 0.51444],
    8221: [0, 0.69444, 0.06961, 0, 0.51444],
    8463: [0, 0.68889, 0, 0, 0.54028]
  },
  "Main-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.27778],
    34: [0, 0.69444, 0, 0, 0.5],
    35: [0.19444, 0.69444, 0, 0, 0.83334],
    36: [0.05556, 0.75, 0, 0, 0.5],
    37: [0.05556, 0.75, 0, 0, 0.83334],
    38: [0, 0.69444, 0, 0, 0.77778],
    39: [0, 0.69444, 0, 0, 0.27778],
    40: [0.25, 0.75, 0, 0, 0.38889],
    41: [0.25, 0.75, 0, 0, 0.38889],
    42: [0, 0.75, 0, 0, 0.5],
    43: [0.08333, 0.58333, 0, 0, 0.77778],
    44: [0.19444, 0.10556, 0, 0, 0.27778],
    45: [0, 0.43056, 0, 0, 0.33333],
    46: [0, 0.10556, 0, 0, 0.27778],
    47: [0.25, 0.75, 0, 0, 0.5],
    48: [0, 0.64444, 0, 0, 0.5],
    49: [0, 0.64444, 0, 0, 0.5],
    50: [0, 0.64444, 0, 0, 0.5],
    51: [0, 0.64444, 0, 0, 0.5],
    52: [0, 0.64444, 0, 0, 0.5],
    53: [0, 0.64444, 0, 0, 0.5],
    54: [0, 0.64444, 0, 0, 0.5],
    55: [0, 0.64444, 0, 0, 0.5],
    56: [0, 0.64444, 0, 0, 0.5],
    57: [0, 0.64444, 0, 0, 0.5],
    58: [0, 0.43056, 0, 0, 0.27778],
    59: [0.19444, 0.43056, 0, 0, 0.27778],
    60: [0.0391, 0.5391, 0, 0, 0.77778],
    61: [-0.13313, 0.36687, 0, 0, 0.77778],
    62: [0.0391, 0.5391, 0, 0, 0.77778],
    63: [0, 0.69444, 0, 0, 0.47222],
    64: [0, 0.69444, 0, 0, 0.77778],
    65: [0, 0.68333, 0, 0, 0.75],
    66: [0, 0.68333, 0, 0, 0.70834],
    67: [0, 0.68333, 0, 0, 0.72222],
    68: [0, 0.68333, 0, 0, 0.76389],
    69: [0, 0.68333, 0, 0, 0.68056],
    70: [0, 0.68333, 0, 0, 0.65278],
    71: [0, 0.68333, 0, 0, 0.78472],
    72: [0, 0.68333, 0, 0, 0.75],
    73: [0, 0.68333, 0, 0, 0.36111],
    74: [0, 0.68333, 0, 0, 0.51389],
    75: [0, 0.68333, 0, 0, 0.77778],
    76: [0, 0.68333, 0, 0, 0.625],
    77: [0, 0.68333, 0, 0, 0.91667],
    78: [0, 0.68333, 0, 0, 0.75],
    79: [0, 0.68333, 0, 0, 0.77778],
    80: [0, 0.68333, 0, 0, 0.68056],
    81: [0.19444, 0.68333, 0, 0, 0.77778],
    82: [0, 0.68333, 0, 0, 0.73611],
    83: [0, 0.68333, 0, 0, 0.55556],
    84: [0, 0.68333, 0, 0, 0.72222],
    85: [0, 0.68333, 0, 0, 0.75],
    86: [0, 0.68333, 0.01389, 0, 0.75],
    87: [0, 0.68333, 0.01389, 0, 1.02778],
    88: [0, 0.68333, 0, 0, 0.75],
    89: [0, 0.68333, 0.025, 0, 0.75],
    90: [0, 0.68333, 0, 0, 0.61111],
    91: [0.25, 0.75, 0, 0, 0.27778],
    92: [0.25, 0.75, 0, 0, 0.5],
    93: [0.25, 0.75, 0, 0, 0.27778],
    94: [0, 0.69444, 0, 0, 0.5],
    95: [0.31, 0.12056, 0.02778, 0, 0.5],
    97: [0, 0.43056, 0, 0, 0.5],
    98: [0, 0.69444, 0, 0, 0.55556],
    99: [0, 0.43056, 0, 0, 0.44445],
    100: [0, 0.69444, 0, 0, 0.55556],
    101: [0, 0.43056, 0, 0, 0.44445],
    102: [0, 0.69444, 0.07778, 0, 0.30556],
    103: [0.19444, 0.43056, 0.01389, 0, 0.5],
    104: [0, 0.69444, 0, 0, 0.55556],
    105: [0, 0.66786, 0, 0, 0.27778],
    106: [0.19444, 0.66786, 0, 0, 0.30556],
    107: [0, 0.69444, 0, 0, 0.52778],
    108: [0, 0.69444, 0, 0, 0.27778],
    109: [0, 0.43056, 0, 0, 0.83334],
    110: [0, 0.43056, 0, 0, 0.55556],
    111: [0, 0.43056, 0, 0, 0.5],
    112: [0.19444, 0.43056, 0, 0, 0.55556],
    113: [0.19444, 0.43056, 0, 0, 0.52778],
    114: [0, 0.43056, 0, 0, 0.39167],
    115: [0, 0.43056, 0, 0, 0.39445],
    116: [0, 0.61508, 0, 0, 0.38889],
    117: [0, 0.43056, 0, 0, 0.55556],
    118: [0, 0.43056, 0.01389, 0, 0.52778],
    119: [0, 0.43056, 0.01389, 0, 0.72222],
    120: [0, 0.43056, 0, 0, 0.52778],
    121: [0.19444, 0.43056, 0.01389, 0, 0.52778],
    122: [0, 0.43056, 0, 0, 0.44445],
    123: [0.25, 0.75, 0, 0, 0.5],
    124: [0.25, 0.75, 0, 0, 0.27778],
    125: [0.25, 0.75, 0, 0, 0.5],
    126: [0.35, 0.31786, 0, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    163: [0, 0.69444, 0, 0, 0.76909],
    167: [0.19444, 0.69444, 0, 0, 0.44445],
    168: [0, 0.66786, 0, 0, 0.5],
    172: [0, 0.43056, 0, 0, 0.66667],
    176: [0, 0.69444, 0, 0, 0.75],
    177: [0.08333, 0.58333, 0, 0, 0.77778],
    182: [0.19444, 0.69444, 0, 0, 0.61111],
    184: [0.17014, 0, 0, 0, 0.44445],
    198: [0, 0.68333, 0, 0, 0.90278],
    215: [0.08333, 0.58333, 0, 0, 0.77778],
    216: [0.04861, 0.73194, 0, 0, 0.77778],
    223: [0, 0.69444, 0, 0, 0.5],
    230: [0, 0.43056, 0, 0, 0.72222],
    247: [0.08333, 0.58333, 0, 0, 0.77778],
    248: [0.09722, 0.52778, 0, 0, 0.5],
    305: [0, 0.43056, 0, 0, 0.27778],
    338: [0, 0.68333, 0, 0, 1.01389],
    339: [0, 0.43056, 0, 0, 0.77778],
    567: [0.19444, 0.43056, 0, 0, 0.30556],
    710: [0, 0.69444, 0, 0, 0.5],
    711: [0, 0.62847, 0, 0, 0.5],
    713: [0, 0.56778, 0, 0, 0.5],
    714: [0, 0.69444, 0, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0, 0, 0.5],
    729: [0, 0.66786, 0, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.75],
    732: [0, 0.66786, 0, 0, 0.5],
    733: [0, 0.69444, 0, 0, 0.5],
    915: [0, 0.68333, 0, 0, 0.625],
    916: [0, 0.68333, 0, 0, 0.83334],
    920: [0, 0.68333, 0, 0, 0.77778],
    923: [0, 0.68333, 0, 0, 0.69445],
    926: [0, 0.68333, 0, 0, 0.66667],
    928: [0, 0.68333, 0, 0, 0.75],
    931: [0, 0.68333, 0, 0, 0.72222],
    933: [0, 0.68333, 0, 0, 0.77778],
    934: [0, 0.68333, 0, 0, 0.72222],
    936: [0, 0.68333, 0, 0, 0.77778],
    937: [0, 0.68333, 0, 0, 0.72222],
    8211: [0, 0.43056, 0.02778, 0, 0.5],
    8212: [0, 0.43056, 0.02778, 0, 1],
    8216: [0, 0.69444, 0, 0, 0.27778],
    8217: [0, 0.69444, 0, 0, 0.27778],
    8220: [0, 0.69444, 0, 0, 0.5],
    8221: [0, 0.69444, 0, 0, 0.5],
    8224: [0.19444, 0.69444, 0, 0, 0.44445],
    8225: [0.19444, 0.69444, 0, 0, 0.44445],
    8230: [0, 0.123, 0, 0, 1.172],
    8242: [0, 0.55556, 0, 0, 0.275],
    8407: [0, 0.71444, 0.15382, 0, 0.5],
    8463: [0, 0.68889, 0, 0, 0.54028],
    8465: [0, 0.69444, 0, 0, 0.72222],
    8467: [0, 0.69444, 0, 0.11111, 0.41667],
    8472: [0.19444, 0.43056, 0, 0.11111, 0.63646],
    8476: [0, 0.69444, 0, 0, 0.72222],
    8501: [0, 0.69444, 0, 0, 0.61111],
    8592: [-0.13313, 0.36687, 0, 0, 1],
    8593: [0.19444, 0.69444, 0, 0, 0.5],
    8594: [-0.13313, 0.36687, 0, 0, 1],
    8595: [0.19444, 0.69444, 0, 0, 0.5],
    8596: [-0.13313, 0.36687, 0, 0, 1],
    8597: [0.25, 0.75, 0, 0, 0.5],
    8598: [0.19444, 0.69444, 0, 0, 1],
    8599: [0.19444, 0.69444, 0, 0, 1],
    8600: [0.19444, 0.69444, 0, 0, 1],
    8601: [0.19444, 0.69444, 0, 0, 1],
    8614: [0.011, 0.511, 0, 0, 1],
    8617: [0.011, 0.511, 0, 0, 1.126],
    8618: [0.011, 0.511, 0, 0, 1.126],
    8636: [-0.13313, 0.36687, 0, 0, 1],
    8637: [-0.13313, 0.36687, 0, 0, 1],
    8640: [-0.13313, 0.36687, 0, 0, 1],
    8641: [-0.13313, 0.36687, 0, 0, 1],
    8652: [0.011, 0.671, 0, 0, 1],
    8656: [-0.13313, 0.36687, 0, 0, 1],
    8657: [0.19444, 0.69444, 0, 0, 0.61111],
    8658: [-0.13313, 0.36687, 0, 0, 1],
    8659: [0.19444, 0.69444, 0, 0, 0.61111],
    8660: [-0.13313, 0.36687, 0, 0, 1],
    8661: [0.25, 0.75, 0, 0, 0.61111],
    8704: [0, 0.69444, 0, 0, 0.55556],
    8706: [0, 0.69444, 0.05556, 0.08334, 0.5309],
    8707: [0, 0.69444, 0, 0, 0.55556],
    8709: [0.05556, 0.75, 0, 0, 0.5],
    8711: [0, 0.68333, 0, 0, 0.83334],
    8712: [0.0391, 0.5391, 0, 0, 0.66667],
    8715: [0.0391, 0.5391, 0, 0, 0.66667],
    8722: [0.08333, 0.58333, 0, 0, 0.77778],
    8723: [0.08333, 0.58333, 0, 0, 0.77778],
    8725: [0.25, 0.75, 0, 0, 0.5],
    8726: [0.25, 0.75, 0, 0, 0.5],
    8727: [-0.03472, 0.46528, 0, 0, 0.5],
    8728: [-0.05555, 0.44445, 0, 0, 0.5],
    8729: [-0.05555, 0.44445, 0, 0, 0.5],
    8730: [0.2, 0.8, 0, 0, 0.83334],
    8733: [0, 0.43056, 0, 0, 0.77778],
    8734: [0, 0.43056, 0, 0, 1],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8739: [0.25, 0.75, 0, 0, 0.27778],
    8741: [0.25, 0.75, 0, 0, 0.5],
    8743: [0, 0.55556, 0, 0, 0.66667],
    8744: [0, 0.55556, 0, 0, 0.66667],
    8745: [0, 0.55556, 0, 0, 0.66667],
    8746: [0, 0.55556, 0, 0, 0.66667],
    8747: [0.19444, 0.69444, 0.11111, 0, 0.41667],
    8764: [-0.13313, 0.36687, 0, 0, 0.77778],
    8768: [0.19444, 0.69444, 0, 0, 0.27778],
    8771: [-0.03625, 0.46375, 0, 0, 0.77778],
    8773: [-0.022, 0.589, 0, 0, 0.778],
    8776: [-0.01688, 0.48312, 0, 0, 0.77778],
    8781: [-0.03625, 0.46375, 0, 0, 0.77778],
    8784: [-0.133, 0.673, 0, 0, 0.778],
    8801: [-0.03625, 0.46375, 0, 0, 0.77778],
    8804: [0.13597, 0.63597, 0, 0, 0.77778],
    8805: [0.13597, 0.63597, 0, 0, 0.77778],
    8810: [0.0391, 0.5391, 0, 0, 1],
    8811: [0.0391, 0.5391, 0, 0, 1],
    8826: [0.0391, 0.5391, 0, 0, 0.77778],
    8827: [0.0391, 0.5391, 0, 0, 0.77778],
    8834: [0.0391, 0.5391, 0, 0, 0.77778],
    8835: [0.0391, 0.5391, 0, 0, 0.77778],
    8838: [0.13597, 0.63597, 0, 0, 0.77778],
    8839: [0.13597, 0.63597, 0, 0, 0.77778],
    8846: [0, 0.55556, 0, 0, 0.66667],
    8849: [0.13597, 0.63597, 0, 0, 0.77778],
    8850: [0.13597, 0.63597, 0, 0, 0.77778],
    8851: [0, 0.55556, 0, 0, 0.66667],
    8852: [0, 0.55556, 0, 0, 0.66667],
    8853: [0.08333, 0.58333, 0, 0, 0.77778],
    8854: [0.08333, 0.58333, 0, 0, 0.77778],
    8855: [0.08333, 0.58333, 0, 0, 0.77778],
    8856: [0.08333, 0.58333, 0, 0, 0.77778],
    8857: [0.08333, 0.58333, 0, 0, 0.77778],
    8866: [0, 0.69444, 0, 0, 0.61111],
    8867: [0, 0.69444, 0, 0, 0.61111],
    8868: [0, 0.69444, 0, 0, 0.77778],
    8869: [0, 0.69444, 0, 0, 0.77778],
    8872: [0.249, 0.75, 0, 0, 0.867],
    8900: [-0.05555, 0.44445, 0, 0, 0.5],
    8901: [-0.05555, 0.44445, 0, 0, 0.27778],
    8902: [-0.03472, 0.46528, 0, 0, 0.5],
    8904: [5e-3, 0.505, 0, 0, 0.9],
    8942: [0.03, 0.903, 0, 0, 0.278],
    8943: [-0.19, 0.313, 0, 0, 1.172],
    8945: [-0.1, 0.823, 0, 0, 1.282],
    8968: [0.25, 0.75, 0, 0, 0.44445],
    8969: [0.25, 0.75, 0, 0, 0.44445],
    8970: [0.25, 0.75, 0, 0, 0.44445],
    8971: [0.25, 0.75, 0, 0, 0.44445],
    8994: [-0.14236, 0.35764, 0, 0, 1],
    8995: [-0.14236, 0.35764, 0, 0, 1],
    9136: [0.244, 0.744, 0, 0, 0.412],
    9137: [0.244, 0.745, 0, 0, 0.412],
    9651: [0.19444, 0.69444, 0, 0, 0.88889],
    9657: [-0.03472, 0.46528, 0, 0, 0.5],
    9661: [0.19444, 0.69444, 0, 0, 0.88889],
    9667: [-0.03472, 0.46528, 0, 0, 0.5],
    9711: [0.19444, 0.69444, 0, 0, 1],
    9824: [0.12963, 0.69444, 0, 0, 0.77778],
    9825: [0.12963, 0.69444, 0, 0, 0.77778],
    9826: [0.12963, 0.69444, 0, 0, 0.77778],
    9827: [0.12963, 0.69444, 0, 0, 0.77778],
    9837: [0, 0.75, 0, 0, 0.38889],
    9838: [0.19444, 0.69444, 0, 0, 0.38889],
    9839: [0.19444, 0.69444, 0, 0, 0.38889],
    10216: [0.25, 0.75, 0, 0, 0.38889],
    10217: [0.25, 0.75, 0, 0, 0.38889],
    10222: [0.244, 0.744, 0, 0, 0.412],
    10223: [0.244, 0.745, 0, 0, 0.412],
    10229: [0.011, 0.511, 0, 0, 1.609],
    10230: [0.011, 0.511, 0, 0, 1.638],
    10231: [0.011, 0.511, 0, 0, 1.859],
    10232: [0.024, 0.525, 0, 0, 1.609],
    10233: [0.024, 0.525, 0, 0, 1.638],
    10234: [0.024, 0.525, 0, 0, 1.858],
    10236: [0.011, 0.511, 0, 0, 1.638],
    10815: [0, 0.68333, 0, 0, 0.75],
    10927: [0.13597, 0.63597, 0, 0, 0.77778],
    10928: [0.13597, 0.63597, 0, 0, 0.77778],
    57376: [0.19444, 0.69444, 0, 0, 0]
  },
  "Math-BoldItalic": {
    32: [0, 0, 0, 0, 0.25],
    48: [0, 0.44444, 0, 0, 0.575],
    49: [0, 0.44444, 0, 0, 0.575],
    50: [0, 0.44444, 0, 0, 0.575],
    51: [0.19444, 0.44444, 0, 0, 0.575],
    52: [0.19444, 0.44444, 0, 0, 0.575],
    53: [0.19444, 0.44444, 0, 0, 0.575],
    54: [0, 0.64444, 0, 0, 0.575],
    55: [0.19444, 0.44444, 0, 0, 0.575],
    56: [0, 0.64444, 0, 0, 0.575],
    57: [0.19444, 0.44444, 0, 0, 0.575],
    65: [0, 0.68611, 0, 0, 0.86944],
    66: [0, 0.68611, 0.04835, 0, 0.8664],
    67: [0, 0.68611, 0.06979, 0, 0.81694],
    68: [0, 0.68611, 0.03194, 0, 0.93812],
    69: [0, 0.68611, 0.05451, 0, 0.81007],
    70: [0, 0.68611, 0.15972, 0, 0.68889],
    71: [0, 0.68611, 0, 0, 0.88673],
    72: [0, 0.68611, 0.08229, 0, 0.98229],
    73: [0, 0.68611, 0.07778, 0, 0.51111],
    74: [0, 0.68611, 0.10069, 0, 0.63125],
    75: [0, 0.68611, 0.06979, 0, 0.97118],
    76: [0, 0.68611, 0, 0, 0.75555],
    77: [0, 0.68611, 0.11424, 0, 1.14201],
    78: [0, 0.68611, 0.11424, 0, 0.95034],
    79: [0, 0.68611, 0.03194, 0, 0.83666],
    80: [0, 0.68611, 0.15972, 0, 0.72309],
    81: [0.19444, 0.68611, 0, 0, 0.86861],
    82: [0, 0.68611, 421e-5, 0, 0.87235],
    83: [0, 0.68611, 0.05382, 0, 0.69271],
    84: [0, 0.68611, 0.15972, 0, 0.63663],
    85: [0, 0.68611, 0.11424, 0, 0.80027],
    86: [0, 0.68611, 0.25555, 0, 0.67778],
    87: [0, 0.68611, 0.15972, 0, 1.09305],
    88: [0, 0.68611, 0.07778, 0, 0.94722],
    89: [0, 0.68611, 0.25555, 0, 0.67458],
    90: [0, 0.68611, 0.06979, 0, 0.77257],
    97: [0, 0.44444, 0, 0, 0.63287],
    98: [0, 0.69444, 0, 0, 0.52083],
    99: [0, 0.44444, 0, 0, 0.51342],
    100: [0, 0.69444, 0, 0, 0.60972],
    101: [0, 0.44444, 0, 0, 0.55361],
    102: [0.19444, 0.69444, 0.11042, 0, 0.56806],
    103: [0.19444, 0.44444, 0.03704, 0, 0.5449],
    104: [0, 0.69444, 0, 0, 0.66759],
    105: [0, 0.69326, 0, 0, 0.4048],
    106: [0.19444, 0.69326, 0.0622, 0, 0.47083],
    107: [0, 0.69444, 0.01852, 0, 0.6037],
    108: [0, 0.69444, 88e-4, 0, 0.34815],
    109: [0, 0.44444, 0, 0, 1.0324],
    110: [0, 0.44444, 0, 0, 0.71296],
    111: [0, 0.44444, 0, 0, 0.58472],
    112: [0.19444, 0.44444, 0, 0, 0.60092],
    113: [0.19444, 0.44444, 0.03704, 0, 0.54213],
    114: [0, 0.44444, 0.03194, 0, 0.5287],
    115: [0, 0.44444, 0, 0, 0.53125],
    116: [0, 0.63492, 0, 0, 0.41528],
    117: [0, 0.44444, 0, 0, 0.68102],
    118: [0, 0.44444, 0.03704, 0, 0.56666],
    119: [0, 0.44444, 0.02778, 0, 0.83148],
    120: [0, 0.44444, 0, 0, 0.65903],
    121: [0.19444, 0.44444, 0.03704, 0, 0.59028],
    122: [0, 0.44444, 0.04213, 0, 0.55509],
    160: [0, 0, 0, 0, 0.25],
    915: [0, 0.68611, 0.15972, 0, 0.65694],
    916: [0, 0.68611, 0, 0, 0.95833],
    920: [0, 0.68611, 0.03194, 0, 0.86722],
    923: [0, 0.68611, 0, 0, 0.80555],
    926: [0, 0.68611, 0.07458, 0, 0.84125],
    928: [0, 0.68611, 0.08229, 0, 0.98229],
    931: [0, 0.68611, 0.05451, 0, 0.88507],
    933: [0, 0.68611, 0.15972, 0, 0.67083],
    934: [0, 0.68611, 0, 0, 0.76666],
    936: [0, 0.68611, 0.11653, 0, 0.71402],
    937: [0, 0.68611, 0.04835, 0, 0.8789],
    945: [0, 0.44444, 0, 0, 0.76064],
    946: [0.19444, 0.69444, 0.03403, 0, 0.65972],
    947: [0.19444, 0.44444, 0.06389, 0, 0.59003],
    948: [0, 0.69444, 0.03819, 0, 0.52222],
    949: [0, 0.44444, 0, 0, 0.52882],
    950: [0.19444, 0.69444, 0.06215, 0, 0.50833],
    951: [0.19444, 0.44444, 0.03704, 0, 0.6],
    952: [0, 0.69444, 0.03194, 0, 0.5618],
    953: [0, 0.44444, 0, 0, 0.41204],
    954: [0, 0.44444, 0, 0, 0.66759],
    955: [0, 0.69444, 0, 0, 0.67083],
    956: [0.19444, 0.44444, 0, 0, 0.70787],
    957: [0, 0.44444, 0.06898, 0, 0.57685],
    958: [0.19444, 0.69444, 0.03021, 0, 0.50833],
    959: [0, 0.44444, 0, 0, 0.58472],
    960: [0, 0.44444, 0.03704, 0, 0.68241],
    961: [0.19444, 0.44444, 0, 0, 0.6118],
    962: [0.09722, 0.44444, 0.07917, 0, 0.42361],
    963: [0, 0.44444, 0.03704, 0, 0.68588],
    964: [0, 0.44444, 0.13472, 0, 0.52083],
    965: [0, 0.44444, 0.03704, 0, 0.63055],
    966: [0.19444, 0.44444, 0, 0, 0.74722],
    967: [0.19444, 0.44444, 0, 0, 0.71805],
    968: [0.19444, 0.69444, 0.03704, 0, 0.75833],
    969: [0, 0.44444, 0.03704, 0, 0.71782],
    977: [0, 0.69444, 0, 0, 0.69155],
    981: [0.19444, 0.69444, 0, 0, 0.7125],
    982: [0, 0.44444, 0.03194, 0, 0.975],
    1009: [0.19444, 0.44444, 0, 0, 0.6118],
    1013: [0, 0.44444, 0, 0, 0.48333],
    57649: [0, 0.44444, 0, 0, 0.39352],
    57911: [0.19444, 0.44444, 0, 0, 0.43889]
  },
  "Math-Italic": {
    32: [0, 0, 0, 0, 0.25],
    48: [0, 0.43056, 0, 0, 0.5],
    49: [0, 0.43056, 0, 0, 0.5],
    50: [0, 0.43056, 0, 0, 0.5],
    51: [0.19444, 0.43056, 0, 0, 0.5],
    52: [0.19444, 0.43056, 0, 0, 0.5],
    53: [0.19444, 0.43056, 0, 0, 0.5],
    54: [0, 0.64444, 0, 0, 0.5],
    55: [0.19444, 0.43056, 0, 0, 0.5],
    56: [0, 0.64444, 0, 0, 0.5],
    57: [0.19444, 0.43056, 0, 0, 0.5],
    65: [0, 0.68333, 0, 0.13889, 0.75],
    66: [0, 0.68333, 0.05017, 0.08334, 0.75851],
    67: [0, 0.68333, 0.07153, 0.08334, 0.71472],
    68: [0, 0.68333, 0.02778, 0.05556, 0.82792],
    69: [0, 0.68333, 0.05764, 0.08334, 0.7382],
    70: [0, 0.68333, 0.13889, 0.08334, 0.64306],
    71: [0, 0.68333, 0, 0.08334, 0.78625],
    72: [0, 0.68333, 0.08125, 0.05556, 0.83125],
    73: [0, 0.68333, 0.07847, 0.11111, 0.43958],
    74: [0, 0.68333, 0.09618, 0.16667, 0.55451],
    75: [0, 0.68333, 0.07153, 0.05556, 0.84931],
    76: [0, 0.68333, 0, 0.02778, 0.68056],
    77: [0, 0.68333, 0.10903, 0.08334, 0.97014],
    78: [0, 0.68333, 0.10903, 0.08334, 0.80347],
    79: [0, 0.68333, 0.02778, 0.08334, 0.76278],
    80: [0, 0.68333, 0.13889, 0.08334, 0.64201],
    81: [0.19444, 0.68333, 0, 0.08334, 0.79056],
    82: [0, 0.68333, 773e-5, 0.08334, 0.75929],
    83: [0, 0.68333, 0.05764, 0.08334, 0.6132],
    84: [0, 0.68333, 0.13889, 0.08334, 0.58438],
    85: [0, 0.68333, 0.10903, 0.02778, 0.68278],
    86: [0, 0.68333, 0.22222, 0, 0.58333],
    87: [0, 0.68333, 0.13889, 0, 0.94445],
    88: [0, 0.68333, 0.07847, 0.08334, 0.82847],
    89: [0, 0.68333, 0.22222, 0, 0.58056],
    90: [0, 0.68333, 0.07153, 0.08334, 0.68264],
    97: [0, 0.43056, 0, 0, 0.52859],
    98: [0, 0.69444, 0, 0, 0.42917],
    99: [0, 0.43056, 0, 0.05556, 0.43276],
    100: [0, 0.69444, 0, 0.16667, 0.52049],
    101: [0, 0.43056, 0, 0.05556, 0.46563],
    102: [0.19444, 0.69444, 0.10764, 0.16667, 0.48959],
    103: [0.19444, 0.43056, 0.03588, 0.02778, 0.47697],
    104: [0, 0.69444, 0, 0, 0.57616],
    105: [0, 0.65952, 0, 0, 0.34451],
    106: [0.19444, 0.65952, 0.05724, 0, 0.41181],
    107: [0, 0.69444, 0.03148, 0, 0.5206],
    108: [0, 0.69444, 0.01968, 0.08334, 0.29838],
    109: [0, 0.43056, 0, 0, 0.87801],
    110: [0, 0.43056, 0, 0, 0.60023],
    111: [0, 0.43056, 0, 0.05556, 0.48472],
    112: [0.19444, 0.43056, 0, 0.08334, 0.50313],
    113: [0.19444, 0.43056, 0.03588, 0.08334, 0.44641],
    114: [0, 0.43056, 0.02778, 0.05556, 0.45116],
    115: [0, 0.43056, 0, 0.05556, 0.46875],
    116: [0, 0.61508, 0, 0.08334, 0.36111],
    117: [0, 0.43056, 0, 0.02778, 0.57246],
    118: [0, 0.43056, 0.03588, 0.02778, 0.48472],
    119: [0, 0.43056, 0.02691, 0.08334, 0.71592],
    120: [0, 0.43056, 0, 0.02778, 0.57153],
    121: [0.19444, 0.43056, 0.03588, 0.05556, 0.49028],
    122: [0, 0.43056, 0.04398, 0.05556, 0.46505],
    160: [0, 0, 0, 0, 0.25],
    915: [0, 0.68333, 0.13889, 0.08334, 0.61528],
    916: [0, 0.68333, 0, 0.16667, 0.83334],
    920: [0, 0.68333, 0.02778, 0.08334, 0.76278],
    923: [0, 0.68333, 0, 0.16667, 0.69445],
    926: [0, 0.68333, 0.07569, 0.08334, 0.74236],
    928: [0, 0.68333, 0.08125, 0.05556, 0.83125],
    931: [0, 0.68333, 0.05764, 0.08334, 0.77986],
    933: [0, 0.68333, 0.13889, 0.05556, 0.58333],
    934: [0, 0.68333, 0, 0.08334, 0.66667],
    936: [0, 0.68333, 0.11, 0.05556, 0.61222],
    937: [0, 0.68333, 0.05017, 0.08334, 0.7724],
    945: [0, 0.43056, 37e-4, 0.02778, 0.6397],
    946: [0.19444, 0.69444, 0.05278, 0.08334, 0.56563],
    947: [0.19444, 0.43056, 0.05556, 0, 0.51773],
    948: [0, 0.69444, 0.03785, 0.05556, 0.44444],
    949: [0, 0.43056, 0, 0.08334, 0.46632],
    950: [0.19444, 0.69444, 0.07378, 0.08334, 0.4375],
    951: [0.19444, 0.43056, 0.03588, 0.05556, 0.49653],
    952: [0, 0.69444, 0.02778, 0.08334, 0.46944],
    953: [0, 0.43056, 0, 0.05556, 0.35394],
    954: [0, 0.43056, 0, 0, 0.57616],
    955: [0, 0.69444, 0, 0, 0.58334],
    956: [0.19444, 0.43056, 0, 0.02778, 0.60255],
    957: [0, 0.43056, 0.06366, 0.02778, 0.49398],
    958: [0.19444, 0.69444, 0.04601, 0.11111, 0.4375],
    959: [0, 0.43056, 0, 0.05556, 0.48472],
    960: [0, 0.43056, 0.03588, 0, 0.57003],
    961: [0.19444, 0.43056, 0, 0.08334, 0.51702],
    962: [0.09722, 0.43056, 0.07986, 0.08334, 0.36285],
    963: [0, 0.43056, 0.03588, 0, 0.57141],
    964: [0, 0.43056, 0.1132, 0.02778, 0.43715],
    965: [0, 0.43056, 0.03588, 0.02778, 0.54028],
    966: [0.19444, 0.43056, 0, 0.08334, 0.65417],
    967: [0.19444, 0.43056, 0, 0.05556, 0.62569],
    968: [0.19444, 0.69444, 0.03588, 0.11111, 0.65139],
    969: [0, 0.43056, 0.03588, 0, 0.62245],
    977: [0, 0.69444, 0, 0.08334, 0.59144],
    981: [0.19444, 0.69444, 0, 0.08334, 0.59583],
    982: [0, 0.43056, 0.02778, 0, 0.82813],
    1009: [0.19444, 0.43056, 0, 0.08334, 0.51702],
    1013: [0, 0.43056, 0, 0.05556, 0.4059],
    57649: [0, 0.43056, 0, 0.02778, 0.32246],
    57911: [0.19444, 0.43056, 0, 0.08334, 0.38403]
  },
  "SansSerif-Bold": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.36667],
    34: [0, 0.69444, 0, 0, 0.55834],
    35: [0.19444, 0.69444, 0, 0, 0.91667],
    36: [0.05556, 0.75, 0, 0, 0.55],
    37: [0.05556, 0.75, 0, 0, 1.02912],
    38: [0, 0.69444, 0, 0, 0.83056],
    39: [0, 0.69444, 0, 0, 0.30556],
    40: [0.25, 0.75, 0, 0, 0.42778],
    41: [0.25, 0.75, 0, 0, 0.42778],
    42: [0, 0.75, 0, 0, 0.55],
    43: [0.11667, 0.61667, 0, 0, 0.85556],
    44: [0.10556, 0.13056, 0, 0, 0.30556],
    45: [0, 0.45833, 0, 0, 0.36667],
    46: [0, 0.13056, 0, 0, 0.30556],
    47: [0.25, 0.75, 0, 0, 0.55],
    48: [0, 0.69444, 0, 0, 0.55],
    49: [0, 0.69444, 0, 0, 0.55],
    50: [0, 0.69444, 0, 0, 0.55],
    51: [0, 0.69444, 0, 0, 0.55],
    52: [0, 0.69444, 0, 0, 0.55],
    53: [0, 0.69444, 0, 0, 0.55],
    54: [0, 0.69444, 0, 0, 0.55],
    55: [0, 0.69444, 0, 0, 0.55],
    56: [0, 0.69444, 0, 0, 0.55],
    57: [0, 0.69444, 0, 0, 0.55],
    58: [0, 0.45833, 0, 0, 0.30556],
    59: [0.10556, 0.45833, 0, 0, 0.30556],
    61: [-0.09375, 0.40625, 0, 0, 0.85556],
    63: [0, 0.69444, 0, 0, 0.51945],
    64: [0, 0.69444, 0, 0, 0.73334],
    65: [0, 0.69444, 0, 0, 0.73334],
    66: [0, 0.69444, 0, 0, 0.73334],
    67: [0, 0.69444, 0, 0, 0.70278],
    68: [0, 0.69444, 0, 0, 0.79445],
    69: [0, 0.69444, 0, 0, 0.64167],
    70: [0, 0.69444, 0, 0, 0.61111],
    71: [0, 0.69444, 0, 0, 0.73334],
    72: [0, 0.69444, 0, 0, 0.79445],
    73: [0, 0.69444, 0, 0, 0.33056],
    74: [0, 0.69444, 0, 0, 0.51945],
    75: [0, 0.69444, 0, 0, 0.76389],
    76: [0, 0.69444, 0, 0, 0.58056],
    77: [0, 0.69444, 0, 0, 0.97778],
    78: [0, 0.69444, 0, 0, 0.79445],
    79: [0, 0.69444, 0, 0, 0.79445],
    80: [0, 0.69444, 0, 0, 0.70278],
    81: [0.10556, 0.69444, 0, 0, 0.79445],
    82: [0, 0.69444, 0, 0, 0.70278],
    83: [0, 0.69444, 0, 0, 0.61111],
    84: [0, 0.69444, 0, 0, 0.73334],
    85: [0, 0.69444, 0, 0, 0.76389],
    86: [0, 0.69444, 0.01528, 0, 0.73334],
    87: [0, 0.69444, 0.01528, 0, 1.03889],
    88: [0, 0.69444, 0, 0, 0.73334],
    89: [0, 0.69444, 0.0275, 0, 0.73334],
    90: [0, 0.69444, 0, 0, 0.67223],
    91: [0.25, 0.75, 0, 0, 0.34306],
    93: [0.25, 0.75, 0, 0, 0.34306],
    94: [0, 0.69444, 0, 0, 0.55],
    95: [0.35, 0.10833, 0.03056, 0, 0.55],
    97: [0, 0.45833, 0, 0, 0.525],
    98: [0, 0.69444, 0, 0, 0.56111],
    99: [0, 0.45833, 0, 0, 0.48889],
    100: [0, 0.69444, 0, 0, 0.56111],
    101: [0, 0.45833, 0, 0, 0.51111],
    102: [0, 0.69444, 0.07639, 0, 0.33611],
    103: [0.19444, 0.45833, 0.01528, 0, 0.55],
    104: [0, 0.69444, 0, 0, 0.56111],
    105: [0, 0.69444, 0, 0, 0.25556],
    106: [0.19444, 0.69444, 0, 0, 0.28611],
    107: [0, 0.69444, 0, 0, 0.53056],
    108: [0, 0.69444, 0, 0, 0.25556],
    109: [0, 0.45833, 0, 0, 0.86667],
    110: [0, 0.45833, 0, 0, 0.56111],
    111: [0, 0.45833, 0, 0, 0.55],
    112: [0.19444, 0.45833, 0, 0, 0.56111],
    113: [0.19444, 0.45833, 0, 0, 0.56111],
    114: [0, 0.45833, 0.01528, 0, 0.37222],
    115: [0, 0.45833, 0, 0, 0.42167],
    116: [0, 0.58929, 0, 0, 0.40417],
    117: [0, 0.45833, 0, 0, 0.56111],
    118: [0, 0.45833, 0.01528, 0, 0.5],
    119: [0, 0.45833, 0.01528, 0, 0.74445],
    120: [0, 0.45833, 0, 0, 0.5],
    121: [0.19444, 0.45833, 0.01528, 0, 0.5],
    122: [0, 0.45833, 0, 0, 0.47639],
    126: [0.35, 0.34444, 0, 0, 0.55],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.69444, 0, 0, 0.55],
    176: [0, 0.69444, 0, 0, 0.73334],
    180: [0, 0.69444, 0, 0, 0.55],
    184: [0.17014, 0, 0, 0, 0.48889],
    305: [0, 0.45833, 0, 0, 0.25556],
    567: [0.19444, 0.45833, 0, 0, 0.28611],
    710: [0, 0.69444, 0, 0, 0.55],
    711: [0, 0.63542, 0, 0, 0.55],
    713: [0, 0.63778, 0, 0, 0.55],
    728: [0, 0.69444, 0, 0, 0.55],
    729: [0, 0.69444, 0, 0, 0.30556],
    730: [0, 0.69444, 0, 0, 0.73334],
    732: [0, 0.69444, 0, 0, 0.55],
    733: [0, 0.69444, 0, 0, 0.55],
    915: [0, 0.69444, 0, 0, 0.58056],
    916: [0, 0.69444, 0, 0, 0.91667],
    920: [0, 0.69444, 0, 0, 0.85556],
    923: [0, 0.69444, 0, 0, 0.67223],
    926: [0, 0.69444, 0, 0, 0.73334],
    928: [0, 0.69444, 0, 0, 0.79445],
    931: [0, 0.69444, 0, 0, 0.79445],
    933: [0, 0.69444, 0, 0, 0.85556],
    934: [0, 0.69444, 0, 0, 0.79445],
    936: [0, 0.69444, 0, 0, 0.85556],
    937: [0, 0.69444, 0, 0, 0.79445],
    8211: [0, 0.45833, 0.03056, 0, 0.55],
    8212: [0, 0.45833, 0.03056, 0, 1.10001],
    8216: [0, 0.69444, 0, 0, 0.30556],
    8217: [0, 0.69444, 0, 0, 0.30556],
    8220: [0, 0.69444, 0, 0, 0.55834],
    8221: [0, 0.69444, 0, 0, 0.55834]
  },
  "SansSerif-Italic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.05733, 0, 0.31945],
    34: [0, 0.69444, 316e-5, 0, 0.5],
    35: [0.19444, 0.69444, 0.05087, 0, 0.83334],
    36: [0.05556, 0.75, 0.11156, 0, 0.5],
    37: [0.05556, 0.75, 0.03126, 0, 0.83334],
    38: [0, 0.69444, 0.03058, 0, 0.75834],
    39: [0, 0.69444, 0.07816, 0, 0.27778],
    40: [0.25, 0.75, 0.13164, 0, 0.38889],
    41: [0.25, 0.75, 0.02536, 0, 0.38889],
    42: [0, 0.75, 0.11775, 0, 0.5],
    43: [0.08333, 0.58333, 0.02536, 0, 0.77778],
    44: [0.125, 0.08333, 0, 0, 0.27778],
    45: [0, 0.44444, 0.01946, 0, 0.33333],
    46: [0, 0.08333, 0, 0, 0.27778],
    47: [0.25, 0.75, 0.13164, 0, 0.5],
    48: [0, 0.65556, 0.11156, 0, 0.5],
    49: [0, 0.65556, 0.11156, 0, 0.5],
    50: [0, 0.65556, 0.11156, 0, 0.5],
    51: [0, 0.65556, 0.11156, 0, 0.5],
    52: [0, 0.65556, 0.11156, 0, 0.5],
    53: [0, 0.65556, 0.11156, 0, 0.5],
    54: [0, 0.65556, 0.11156, 0, 0.5],
    55: [0, 0.65556, 0.11156, 0, 0.5],
    56: [0, 0.65556, 0.11156, 0, 0.5],
    57: [0, 0.65556, 0.11156, 0, 0.5],
    58: [0, 0.44444, 0.02502, 0, 0.27778],
    59: [0.125, 0.44444, 0.02502, 0, 0.27778],
    61: [-0.13, 0.37, 0.05087, 0, 0.77778],
    63: [0, 0.69444, 0.11809, 0, 0.47222],
    64: [0, 0.69444, 0.07555, 0, 0.66667],
    65: [0, 0.69444, 0, 0, 0.66667],
    66: [0, 0.69444, 0.08293, 0, 0.66667],
    67: [0, 0.69444, 0.11983, 0, 0.63889],
    68: [0, 0.69444, 0.07555, 0, 0.72223],
    69: [0, 0.69444, 0.11983, 0, 0.59722],
    70: [0, 0.69444, 0.13372, 0, 0.56945],
    71: [0, 0.69444, 0.11983, 0, 0.66667],
    72: [0, 0.69444, 0.08094, 0, 0.70834],
    73: [0, 0.69444, 0.13372, 0, 0.27778],
    74: [0, 0.69444, 0.08094, 0, 0.47222],
    75: [0, 0.69444, 0.11983, 0, 0.69445],
    76: [0, 0.69444, 0, 0, 0.54167],
    77: [0, 0.69444, 0.08094, 0, 0.875],
    78: [0, 0.69444, 0.08094, 0, 0.70834],
    79: [0, 0.69444, 0.07555, 0, 0.73611],
    80: [0, 0.69444, 0.08293, 0, 0.63889],
    81: [0.125, 0.69444, 0.07555, 0, 0.73611],
    82: [0, 0.69444, 0.08293, 0, 0.64584],
    83: [0, 0.69444, 0.09205, 0, 0.55556],
    84: [0, 0.69444, 0.13372, 0, 0.68056],
    85: [0, 0.69444, 0.08094, 0, 0.6875],
    86: [0, 0.69444, 0.1615, 0, 0.66667],
    87: [0, 0.69444, 0.1615, 0, 0.94445],
    88: [0, 0.69444, 0.13372, 0, 0.66667],
    89: [0, 0.69444, 0.17261, 0, 0.66667],
    90: [0, 0.69444, 0.11983, 0, 0.61111],
    91: [0.25, 0.75, 0.15942, 0, 0.28889],
    93: [0.25, 0.75, 0.08719, 0, 0.28889],
    94: [0, 0.69444, 0.0799, 0, 0.5],
    95: [0.35, 0.09444, 0.08616, 0, 0.5],
    97: [0, 0.44444, 981e-5, 0, 0.48056],
    98: [0, 0.69444, 0.03057, 0, 0.51667],
    99: [0, 0.44444, 0.08336, 0, 0.44445],
    100: [0, 0.69444, 0.09483, 0, 0.51667],
    101: [0, 0.44444, 0.06778, 0, 0.44445],
    102: [0, 0.69444, 0.21705, 0, 0.30556],
    103: [0.19444, 0.44444, 0.10836, 0, 0.5],
    104: [0, 0.69444, 0.01778, 0, 0.51667],
    105: [0, 0.67937, 0.09718, 0, 0.23889],
    106: [0.19444, 0.67937, 0.09162, 0, 0.26667],
    107: [0, 0.69444, 0.08336, 0, 0.48889],
    108: [0, 0.69444, 0.09483, 0, 0.23889],
    109: [0, 0.44444, 0.01778, 0, 0.79445],
    110: [0, 0.44444, 0.01778, 0, 0.51667],
    111: [0, 0.44444, 0.06613, 0, 0.5],
    112: [0.19444, 0.44444, 0.0389, 0, 0.51667],
    113: [0.19444, 0.44444, 0.04169, 0, 0.51667],
    114: [0, 0.44444, 0.10836, 0, 0.34167],
    115: [0, 0.44444, 0.0778, 0, 0.38333],
    116: [0, 0.57143, 0.07225, 0, 0.36111],
    117: [0, 0.44444, 0.04169, 0, 0.51667],
    118: [0, 0.44444, 0.10836, 0, 0.46111],
    119: [0, 0.44444, 0.10836, 0, 0.68334],
    120: [0, 0.44444, 0.09169, 0, 0.46111],
    121: [0.19444, 0.44444, 0.10836, 0, 0.46111],
    122: [0, 0.44444, 0.08752, 0, 0.43472],
    126: [0.35, 0.32659, 0.08826, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.67937, 0.06385, 0, 0.5],
    176: [0, 0.69444, 0, 0, 0.73752],
    184: [0.17014, 0, 0, 0, 0.44445],
    305: [0, 0.44444, 0.04169, 0, 0.23889],
    567: [0.19444, 0.44444, 0.04169, 0, 0.26667],
    710: [0, 0.69444, 0.0799, 0, 0.5],
    711: [0, 0.63194, 0.08432, 0, 0.5],
    713: [0, 0.60889, 0.08776, 0, 0.5],
    714: [0, 0.69444, 0.09205, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0.09483, 0, 0.5],
    729: [0, 0.67937, 0.07774, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.73752],
    732: [0, 0.67659, 0.08826, 0, 0.5],
    733: [0, 0.69444, 0.09205, 0, 0.5],
    915: [0, 0.69444, 0.13372, 0, 0.54167],
    916: [0, 0.69444, 0, 0, 0.83334],
    920: [0, 0.69444, 0.07555, 0, 0.77778],
    923: [0, 0.69444, 0, 0, 0.61111],
    926: [0, 0.69444, 0.12816, 0, 0.66667],
    928: [0, 0.69444, 0.08094, 0, 0.70834],
    931: [0, 0.69444, 0.11983, 0, 0.72222],
    933: [0, 0.69444, 0.09031, 0, 0.77778],
    934: [0, 0.69444, 0.04603, 0, 0.72222],
    936: [0, 0.69444, 0.09031, 0, 0.77778],
    937: [0, 0.69444, 0.08293, 0, 0.72222],
    8211: [0, 0.44444, 0.08616, 0, 0.5],
    8212: [0, 0.44444, 0.08616, 0, 1],
    8216: [0, 0.69444, 0.07816, 0, 0.27778],
    8217: [0, 0.69444, 0.07816, 0, 0.27778],
    8220: [0, 0.69444, 0.14205, 0, 0.5],
    8221: [0, 0.69444, 316e-5, 0, 0.5]
  },
  "SansSerif-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.31945],
    34: [0, 0.69444, 0, 0, 0.5],
    35: [0.19444, 0.69444, 0, 0, 0.83334],
    36: [0.05556, 0.75, 0, 0, 0.5],
    37: [0.05556, 0.75, 0, 0, 0.83334],
    38: [0, 0.69444, 0, 0, 0.75834],
    39: [0, 0.69444, 0, 0, 0.27778],
    40: [0.25, 0.75, 0, 0, 0.38889],
    41: [0.25, 0.75, 0, 0, 0.38889],
    42: [0, 0.75, 0, 0, 0.5],
    43: [0.08333, 0.58333, 0, 0, 0.77778],
    44: [0.125, 0.08333, 0, 0, 0.27778],
    45: [0, 0.44444, 0, 0, 0.33333],
    46: [0, 0.08333, 0, 0, 0.27778],
    47: [0.25, 0.75, 0, 0, 0.5],
    48: [0, 0.65556, 0, 0, 0.5],
    49: [0, 0.65556, 0, 0, 0.5],
    50: [0, 0.65556, 0, 0, 0.5],
    51: [0, 0.65556, 0, 0, 0.5],
    52: [0, 0.65556, 0, 0, 0.5],
    53: [0, 0.65556, 0, 0, 0.5],
    54: [0, 0.65556, 0, 0, 0.5],
    55: [0, 0.65556, 0, 0, 0.5],
    56: [0, 0.65556, 0, 0, 0.5],
    57: [0, 0.65556, 0, 0, 0.5],
    58: [0, 0.44444, 0, 0, 0.27778],
    59: [0.125, 0.44444, 0, 0, 0.27778],
    61: [-0.13, 0.37, 0, 0, 0.77778],
    63: [0, 0.69444, 0, 0, 0.47222],
    64: [0, 0.69444, 0, 0, 0.66667],
    65: [0, 0.69444, 0, 0, 0.66667],
    66: [0, 0.69444, 0, 0, 0.66667],
    67: [0, 0.69444, 0, 0, 0.63889],
    68: [0, 0.69444, 0, 0, 0.72223],
    69: [0, 0.69444, 0, 0, 0.59722],
    70: [0, 0.69444, 0, 0, 0.56945],
    71: [0, 0.69444, 0, 0, 0.66667],
    72: [0, 0.69444, 0, 0, 0.70834],
    73: [0, 0.69444, 0, 0, 0.27778],
    74: [0, 0.69444, 0, 0, 0.47222],
    75: [0, 0.69444, 0, 0, 0.69445],
    76: [0, 0.69444, 0, 0, 0.54167],
    77: [0, 0.69444, 0, 0, 0.875],
    78: [0, 0.69444, 0, 0, 0.70834],
    79: [0, 0.69444, 0, 0, 0.73611],
    80: [0, 0.69444, 0, 0, 0.63889],
    81: [0.125, 0.69444, 0, 0, 0.73611],
    82: [0, 0.69444, 0, 0, 0.64584],
    83: [0, 0.69444, 0, 0, 0.55556],
    84: [0, 0.69444, 0, 0, 0.68056],
    85: [0, 0.69444, 0, 0, 0.6875],
    86: [0, 0.69444, 0.01389, 0, 0.66667],
    87: [0, 0.69444, 0.01389, 0, 0.94445],
    88: [0, 0.69444, 0, 0, 0.66667],
    89: [0, 0.69444, 0.025, 0, 0.66667],
    90: [0, 0.69444, 0, 0, 0.61111],
    91: [0.25, 0.75, 0, 0, 0.28889],
    93: [0.25, 0.75, 0, 0, 0.28889],
    94: [0, 0.69444, 0, 0, 0.5],
    95: [0.35, 0.09444, 0.02778, 0, 0.5],
    97: [0, 0.44444, 0, 0, 0.48056],
    98: [0, 0.69444, 0, 0, 0.51667],
    99: [0, 0.44444, 0, 0, 0.44445],
    100: [0, 0.69444, 0, 0, 0.51667],
    101: [0, 0.44444, 0, 0, 0.44445],
    102: [0, 0.69444, 0.06944, 0, 0.30556],
    103: [0.19444, 0.44444, 0.01389, 0, 0.5],
    104: [0, 0.69444, 0, 0, 0.51667],
    105: [0, 0.67937, 0, 0, 0.23889],
    106: [0.19444, 0.67937, 0, 0, 0.26667],
    107: [0, 0.69444, 0, 0, 0.48889],
    108: [0, 0.69444, 0, 0, 0.23889],
    109: [0, 0.44444, 0, 0, 0.79445],
    110: [0, 0.44444, 0, 0, 0.51667],
    111: [0, 0.44444, 0, 0, 0.5],
    112: [0.19444, 0.44444, 0, 0, 0.51667],
    113: [0.19444, 0.44444, 0, 0, 0.51667],
    114: [0, 0.44444, 0.01389, 0, 0.34167],
    115: [0, 0.44444, 0, 0, 0.38333],
    116: [0, 0.57143, 0, 0, 0.36111],
    117: [0, 0.44444, 0, 0, 0.51667],
    118: [0, 0.44444, 0.01389, 0, 0.46111],
    119: [0, 0.44444, 0.01389, 0, 0.68334],
    120: [0, 0.44444, 0, 0, 0.46111],
    121: [0.19444, 0.44444, 0.01389, 0, 0.46111],
    122: [0, 0.44444, 0, 0, 0.43472],
    126: [0.35, 0.32659, 0, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.67937, 0, 0, 0.5],
    176: [0, 0.69444, 0, 0, 0.66667],
    184: [0.17014, 0, 0, 0, 0.44445],
    305: [0, 0.44444, 0, 0, 0.23889],
    567: [0.19444, 0.44444, 0, 0, 0.26667],
    710: [0, 0.69444, 0, 0, 0.5],
    711: [0, 0.63194, 0, 0, 0.5],
    713: [0, 0.60889, 0, 0, 0.5],
    714: [0, 0.69444, 0, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0, 0, 0.5],
    729: [0, 0.67937, 0, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.66667],
    732: [0, 0.67659, 0, 0, 0.5],
    733: [0, 0.69444, 0, 0, 0.5],
    915: [0, 0.69444, 0, 0, 0.54167],
    916: [0, 0.69444, 0, 0, 0.83334],
    920: [0, 0.69444, 0, 0, 0.77778],
    923: [0, 0.69444, 0, 0, 0.61111],
    926: [0, 0.69444, 0, 0, 0.66667],
    928: [0, 0.69444, 0, 0, 0.70834],
    931: [0, 0.69444, 0, 0, 0.72222],
    933: [0, 0.69444, 0, 0, 0.77778],
    934: [0, 0.69444, 0, 0, 0.72222],
    936: [0, 0.69444, 0, 0, 0.77778],
    937: [0, 0.69444, 0, 0, 0.72222],
    8211: [0, 0.44444, 0.02778, 0, 0.5],
    8212: [0, 0.44444, 0.02778, 0, 1],
    8216: [0, 0.69444, 0, 0, 0.27778],
    8217: [0, 0.69444, 0, 0, 0.27778],
    8220: [0, 0.69444, 0, 0, 0.5],
    8221: [0, 0.69444, 0, 0, 0.5]
  },
  "Script-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.7, 0.22925, 0, 0.80253],
    66: [0, 0.7, 0.04087, 0, 0.90757],
    67: [0, 0.7, 0.1689, 0, 0.66619],
    68: [0, 0.7, 0.09371, 0, 0.77443],
    69: [0, 0.7, 0.18583, 0, 0.56162],
    70: [0, 0.7, 0.13634, 0, 0.89544],
    71: [0, 0.7, 0.17322, 0, 0.60961],
    72: [0, 0.7, 0.29694, 0, 0.96919],
    73: [0, 0.7, 0.19189, 0, 0.80907],
    74: [0.27778, 0.7, 0.19189, 0, 1.05159],
    75: [0, 0.7, 0.31259, 0, 0.91364],
    76: [0, 0.7, 0.19189, 0, 0.87373],
    77: [0, 0.7, 0.15981, 0, 1.08031],
    78: [0, 0.7, 0.3525, 0, 0.9015],
    79: [0, 0.7, 0.08078, 0, 0.73787],
    80: [0, 0.7, 0.08078, 0, 1.01262],
    81: [0, 0.7, 0.03305, 0, 0.88282],
    82: [0, 0.7, 0.06259, 0, 0.85],
    83: [0, 0.7, 0.19189, 0, 0.86767],
    84: [0, 0.7, 0.29087, 0, 0.74697],
    85: [0, 0.7, 0.25815, 0, 0.79996],
    86: [0, 0.7, 0.27523, 0, 0.62204],
    87: [0, 0.7, 0.27523, 0, 0.80532],
    88: [0, 0.7, 0.26006, 0, 0.94445],
    89: [0, 0.7, 0.2939, 0, 0.70961],
    90: [0, 0.7, 0.24037, 0, 0.8212],
    160: [0, 0, 0, 0, 0.25]
  },
  "Size1-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.35001, 0.85, 0, 0, 0.45834],
    41: [0.35001, 0.85, 0, 0, 0.45834],
    47: [0.35001, 0.85, 0, 0, 0.57778],
    91: [0.35001, 0.85, 0, 0, 0.41667],
    92: [0.35001, 0.85, 0, 0, 0.57778],
    93: [0.35001, 0.85, 0, 0, 0.41667],
    123: [0.35001, 0.85, 0, 0, 0.58334],
    125: [0.35001, 0.85, 0, 0, 0.58334],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.72222, 0, 0, 0.55556],
    732: [0, 0.72222, 0, 0, 0.55556],
    770: [0, 0.72222, 0, 0, 0.55556],
    771: [0, 0.72222, 0, 0, 0.55556],
    8214: [-99e-5, 0.601, 0, 0, 0.77778],
    8593: [1e-5, 0.6, 0, 0, 0.66667],
    8595: [1e-5, 0.6, 0, 0, 0.66667],
    8657: [1e-5, 0.6, 0, 0, 0.77778],
    8659: [1e-5, 0.6, 0, 0, 0.77778],
    8719: [0.25001, 0.75, 0, 0, 0.94445],
    8720: [0.25001, 0.75, 0, 0, 0.94445],
    8721: [0.25001, 0.75, 0, 0, 1.05556],
    8730: [0.35001, 0.85, 0, 0, 1],
    8739: [-599e-5, 0.606, 0, 0, 0.33333],
    8741: [-599e-5, 0.606, 0, 0, 0.55556],
    8747: [0.30612, 0.805, 0.19445, 0, 0.47222],
    8748: [0.306, 0.805, 0.19445, 0, 0.47222],
    8749: [0.306, 0.805, 0.19445, 0, 0.47222],
    8750: [0.30612, 0.805, 0.19445, 0, 0.47222],
    8896: [0.25001, 0.75, 0, 0, 0.83334],
    8897: [0.25001, 0.75, 0, 0, 0.83334],
    8898: [0.25001, 0.75, 0, 0, 0.83334],
    8899: [0.25001, 0.75, 0, 0, 0.83334],
    8968: [0.35001, 0.85, 0, 0, 0.47222],
    8969: [0.35001, 0.85, 0, 0, 0.47222],
    8970: [0.35001, 0.85, 0, 0, 0.47222],
    8971: [0.35001, 0.85, 0, 0, 0.47222],
    9168: [-99e-5, 0.601, 0, 0, 0.66667],
    10216: [0.35001, 0.85, 0, 0, 0.47222],
    10217: [0.35001, 0.85, 0, 0, 0.47222],
    10752: [0.25001, 0.75, 0, 0, 1.11111],
    10753: [0.25001, 0.75, 0, 0, 1.11111],
    10754: [0.25001, 0.75, 0, 0, 1.11111],
    10756: [0.25001, 0.75, 0, 0, 0.83334],
    10758: [0.25001, 0.75, 0, 0, 0.83334]
  },
  "Size2-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.65002, 1.15, 0, 0, 0.59722],
    41: [0.65002, 1.15, 0, 0, 0.59722],
    47: [0.65002, 1.15, 0, 0, 0.81111],
    91: [0.65002, 1.15, 0, 0, 0.47222],
    92: [0.65002, 1.15, 0, 0, 0.81111],
    93: [0.65002, 1.15, 0, 0, 0.47222],
    123: [0.65002, 1.15, 0, 0, 0.66667],
    125: [0.65002, 1.15, 0, 0, 0.66667],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.75, 0, 0, 1],
    732: [0, 0.75, 0, 0, 1],
    770: [0, 0.75, 0, 0, 1],
    771: [0, 0.75, 0, 0, 1],
    8719: [0.55001, 1.05, 0, 0, 1.27778],
    8720: [0.55001, 1.05, 0, 0, 1.27778],
    8721: [0.55001, 1.05, 0, 0, 1.44445],
    8730: [0.65002, 1.15, 0, 0, 1],
    8747: [0.86225, 1.36, 0.44445, 0, 0.55556],
    8748: [0.862, 1.36, 0.44445, 0, 0.55556],
    8749: [0.862, 1.36, 0.44445, 0, 0.55556],
    8750: [0.86225, 1.36, 0.44445, 0, 0.55556],
    8896: [0.55001, 1.05, 0, 0, 1.11111],
    8897: [0.55001, 1.05, 0, 0, 1.11111],
    8898: [0.55001, 1.05, 0, 0, 1.11111],
    8899: [0.55001, 1.05, 0, 0, 1.11111],
    8968: [0.65002, 1.15, 0, 0, 0.52778],
    8969: [0.65002, 1.15, 0, 0, 0.52778],
    8970: [0.65002, 1.15, 0, 0, 0.52778],
    8971: [0.65002, 1.15, 0, 0, 0.52778],
    10216: [0.65002, 1.15, 0, 0, 0.61111],
    10217: [0.65002, 1.15, 0, 0, 0.61111],
    10752: [0.55001, 1.05, 0, 0, 1.51112],
    10753: [0.55001, 1.05, 0, 0, 1.51112],
    10754: [0.55001, 1.05, 0, 0, 1.51112],
    10756: [0.55001, 1.05, 0, 0, 1.11111],
    10758: [0.55001, 1.05, 0, 0, 1.11111]
  },
  "Size3-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.95003, 1.45, 0, 0, 0.73611],
    41: [0.95003, 1.45, 0, 0, 0.73611],
    47: [0.95003, 1.45, 0, 0, 1.04445],
    91: [0.95003, 1.45, 0, 0, 0.52778],
    92: [0.95003, 1.45, 0, 0, 1.04445],
    93: [0.95003, 1.45, 0, 0, 0.52778],
    123: [0.95003, 1.45, 0, 0, 0.75],
    125: [0.95003, 1.45, 0, 0, 0.75],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.75, 0, 0, 1.44445],
    732: [0, 0.75, 0, 0, 1.44445],
    770: [0, 0.75, 0, 0, 1.44445],
    771: [0, 0.75, 0, 0, 1.44445],
    8730: [0.95003, 1.45, 0, 0, 1],
    8968: [0.95003, 1.45, 0, 0, 0.58334],
    8969: [0.95003, 1.45, 0, 0, 0.58334],
    8970: [0.95003, 1.45, 0, 0, 0.58334],
    8971: [0.95003, 1.45, 0, 0, 0.58334],
    10216: [0.95003, 1.45, 0, 0, 0.75],
    10217: [0.95003, 1.45, 0, 0, 0.75]
  },
  "Size4-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [1.25003, 1.75, 0, 0, 0.79167],
    41: [1.25003, 1.75, 0, 0, 0.79167],
    47: [1.25003, 1.75, 0, 0, 1.27778],
    91: [1.25003, 1.75, 0, 0, 0.58334],
    92: [1.25003, 1.75, 0, 0, 1.27778],
    93: [1.25003, 1.75, 0, 0, 0.58334],
    123: [1.25003, 1.75, 0, 0, 0.80556],
    125: [1.25003, 1.75, 0, 0, 0.80556],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.825, 0, 0, 1.8889],
    732: [0, 0.825, 0, 0, 1.8889],
    770: [0, 0.825, 0, 0, 1.8889],
    771: [0, 0.825, 0, 0, 1.8889],
    8730: [1.25003, 1.75, 0, 0, 1],
    8968: [1.25003, 1.75, 0, 0, 0.63889],
    8969: [1.25003, 1.75, 0, 0, 0.63889],
    8970: [1.25003, 1.75, 0, 0, 0.63889],
    8971: [1.25003, 1.75, 0, 0, 0.63889],
    9115: [0.64502, 1.155, 0, 0, 0.875],
    9116: [1e-5, 0.6, 0, 0, 0.875],
    9117: [0.64502, 1.155, 0, 0, 0.875],
    9118: [0.64502, 1.155, 0, 0, 0.875],
    9119: [1e-5, 0.6, 0, 0, 0.875],
    9120: [0.64502, 1.155, 0, 0, 0.875],
    9121: [0.64502, 1.155, 0, 0, 0.66667],
    9122: [-99e-5, 0.601, 0, 0, 0.66667],
    9123: [0.64502, 1.155, 0, 0, 0.66667],
    9124: [0.64502, 1.155, 0, 0, 0.66667],
    9125: [-99e-5, 0.601, 0, 0, 0.66667],
    9126: [0.64502, 1.155, 0, 0, 0.66667],
    9127: [1e-5, 0.9, 0, 0, 0.88889],
    9128: [0.65002, 1.15, 0, 0, 0.88889],
    9129: [0.90001, 0, 0, 0, 0.88889],
    9130: [0, 0.3, 0, 0, 0.88889],
    9131: [1e-5, 0.9, 0, 0, 0.88889],
    9132: [0.65002, 1.15, 0, 0, 0.88889],
    9133: [0.90001, 0, 0, 0, 0.88889],
    9143: [0.88502, 0.915, 0, 0, 1.05556],
    10216: [1.25003, 1.75, 0, 0, 0.80556],
    10217: [1.25003, 1.75, 0, 0, 0.80556],
    57344: [-499e-5, 0.605, 0, 0, 1.05556],
    57345: [-499e-5, 0.605, 0, 0, 1.05556],
    57680: [0, 0.12, 0, 0, 0.45],
    57681: [0, 0.12, 0, 0, 0.45],
    57682: [0, 0.12, 0, 0, 0.45],
    57683: [0, 0.12, 0, 0, 0.45]
  },
  "Typewriter-Regular": {
    32: [0, 0, 0, 0, 0.525],
    33: [0, 0.61111, 0, 0, 0.525],
    34: [0, 0.61111, 0, 0, 0.525],
    35: [0, 0.61111, 0, 0, 0.525],
    36: [0.08333, 0.69444, 0, 0, 0.525],
    37: [0.08333, 0.69444, 0, 0, 0.525],
    38: [0, 0.61111, 0, 0, 0.525],
    39: [0, 0.61111, 0, 0, 0.525],
    40: [0.08333, 0.69444, 0, 0, 0.525],
    41: [0.08333, 0.69444, 0, 0, 0.525],
    42: [0, 0.52083, 0, 0, 0.525],
    43: [-0.08056, 0.53055, 0, 0, 0.525],
    44: [0.13889, 0.125, 0, 0, 0.525],
    45: [-0.08056, 0.53055, 0, 0, 0.525],
    46: [0, 0.125, 0, 0, 0.525],
    47: [0.08333, 0.69444, 0, 0, 0.525],
    48: [0, 0.61111, 0, 0, 0.525],
    49: [0, 0.61111, 0, 0, 0.525],
    50: [0, 0.61111, 0, 0, 0.525],
    51: [0, 0.61111, 0, 0, 0.525],
    52: [0, 0.61111, 0, 0, 0.525],
    53: [0, 0.61111, 0, 0, 0.525],
    54: [0, 0.61111, 0, 0, 0.525],
    55: [0, 0.61111, 0, 0, 0.525],
    56: [0, 0.61111, 0, 0, 0.525],
    57: [0, 0.61111, 0, 0, 0.525],
    58: [0, 0.43056, 0, 0, 0.525],
    59: [0.13889, 0.43056, 0, 0, 0.525],
    60: [-0.05556, 0.55556, 0, 0, 0.525],
    61: [-0.19549, 0.41562, 0, 0, 0.525],
    62: [-0.05556, 0.55556, 0, 0, 0.525],
    63: [0, 0.61111, 0, 0, 0.525],
    64: [0, 0.61111, 0, 0, 0.525],
    65: [0, 0.61111, 0, 0, 0.525],
    66: [0, 0.61111, 0, 0, 0.525],
    67: [0, 0.61111, 0, 0, 0.525],
    68: [0, 0.61111, 0, 0, 0.525],
    69: [0, 0.61111, 0, 0, 0.525],
    70: [0, 0.61111, 0, 0, 0.525],
    71: [0, 0.61111, 0, 0, 0.525],
    72: [0, 0.61111, 0, 0, 0.525],
    73: [0, 0.61111, 0, 0, 0.525],
    74: [0, 0.61111, 0, 0, 0.525],
    75: [0, 0.61111, 0, 0, 0.525],
    76: [0, 0.61111, 0, 0, 0.525],
    77: [0, 0.61111, 0, 0, 0.525],
    78: [0, 0.61111, 0, 0, 0.525],
    79: [0, 0.61111, 0, 0, 0.525],
    80: [0, 0.61111, 0, 0, 0.525],
    81: [0.13889, 0.61111, 0, 0, 0.525],
    82: [0, 0.61111, 0, 0, 0.525],
    83: [0, 0.61111, 0, 0, 0.525],
    84: [0, 0.61111, 0, 0, 0.525],
    85: [0, 0.61111, 0, 0, 0.525],
    86: [0, 0.61111, 0, 0, 0.525],
    87: [0, 0.61111, 0, 0, 0.525],
    88: [0, 0.61111, 0, 0, 0.525],
    89: [0, 0.61111, 0, 0, 0.525],
    90: [0, 0.61111, 0, 0, 0.525],
    91: [0.08333, 0.69444, 0, 0, 0.525],
    92: [0.08333, 0.69444, 0, 0, 0.525],
    93: [0.08333, 0.69444, 0, 0, 0.525],
    94: [0, 0.61111, 0, 0, 0.525],
    95: [0.09514, 0, 0, 0, 0.525],
    96: [0, 0.61111, 0, 0, 0.525],
    97: [0, 0.43056, 0, 0, 0.525],
    98: [0, 0.61111, 0, 0, 0.525],
    99: [0, 0.43056, 0, 0, 0.525],
    100: [0, 0.61111, 0, 0, 0.525],
    101: [0, 0.43056, 0, 0, 0.525],
    102: [0, 0.61111, 0, 0, 0.525],
    103: [0.22222, 0.43056, 0, 0, 0.525],
    104: [0, 0.61111, 0, 0, 0.525],
    105: [0, 0.61111, 0, 0, 0.525],
    106: [0.22222, 0.61111, 0, 0, 0.525],
    107: [0, 0.61111, 0, 0, 0.525],
    108: [0, 0.61111, 0, 0, 0.525],
    109: [0, 0.43056, 0, 0, 0.525],
    110: [0, 0.43056, 0, 0, 0.525],
    111: [0, 0.43056, 0, 0, 0.525],
    112: [0.22222, 0.43056, 0, 0, 0.525],
    113: [0.22222, 0.43056, 0, 0, 0.525],
    114: [0, 0.43056, 0, 0, 0.525],
    115: [0, 0.43056, 0, 0, 0.525],
    116: [0, 0.55358, 0, 0, 0.525],
    117: [0, 0.43056, 0, 0, 0.525],
    118: [0, 0.43056, 0, 0, 0.525],
    119: [0, 0.43056, 0, 0, 0.525],
    120: [0, 0.43056, 0, 0, 0.525],
    121: [0.22222, 0.43056, 0, 0, 0.525],
    122: [0, 0.43056, 0, 0, 0.525],
    123: [0.08333, 0.69444, 0, 0, 0.525],
    124: [0.08333, 0.69444, 0, 0, 0.525],
    125: [0.08333, 0.69444, 0, 0, 0.525],
    126: [0, 0.61111, 0, 0, 0.525],
    127: [0, 0.61111, 0, 0, 0.525],
    160: [0, 0, 0, 0, 0.525],
    176: [0, 0.61111, 0, 0, 0.525],
    184: [0.19445, 0, 0, 0, 0.525],
    305: [0, 0.43056, 0, 0, 0.525],
    567: [0.22222, 0.43056, 0, 0, 0.525],
    711: [0, 0.56597, 0, 0, 0.525],
    713: [0, 0.56555, 0, 0, 0.525],
    714: [0, 0.61111, 0, 0, 0.525],
    715: [0, 0.61111, 0, 0, 0.525],
    728: [0, 0.61111, 0, 0, 0.525],
    730: [0, 0.61111, 0, 0, 0.525],
    770: [0, 0.61111, 0, 0, 0.525],
    771: [0, 0.61111, 0, 0, 0.525],
    776: [0, 0.61111, 0, 0, 0.525],
    915: [0, 0.61111, 0, 0, 0.525],
    916: [0, 0.61111, 0, 0, 0.525],
    920: [0, 0.61111, 0, 0, 0.525],
    923: [0, 0.61111, 0, 0, 0.525],
    926: [0, 0.61111, 0, 0, 0.525],
    928: [0, 0.61111, 0, 0, 0.525],
    931: [0, 0.61111, 0, 0, 0.525],
    933: [0, 0.61111, 0, 0, 0.525],
    934: [0, 0.61111, 0, 0, 0.525],
    936: [0, 0.61111, 0, 0, 0.525],
    937: [0, 0.61111, 0, 0, 0.525],
    8216: [0, 0.61111, 0, 0, 0.525],
    8217: [0, 0.61111, 0, 0, 0.525],
    8242: [0, 0.61111, 0, 0, 0.525],
    9251: [0.11111, 0.21944, 0, 0, 0.525]
  }
}, ei = {
  // Latin-1
  Å: "A",
  Ð: "D",
  Þ: "o",
  å: "a",
  ð: "d",
  þ: "o",
  // Cyrillic
  А: "A",
  Б: "B",
  В: "B",
  Г: "F",
  Д: "A",
  Е: "E",
  Ж: "K",
  З: "3",
  И: "N",
  Й: "N",
  К: "K",
  Л: "N",
  М: "M",
  Н: "H",
  О: "O",
  П: "N",
  Р: "P",
  С: "C",
  Т: "T",
  У: "y",
  Ф: "O",
  Х: "X",
  Ц: "U",
  Ч: "h",
  Ш: "W",
  Щ: "W",
  Ъ: "B",
  Ы: "X",
  Ь: "B",
  Э: "3",
  Ю: "X",
  Я: "R",
  а: "a",
  б: "b",
  в: "a",
  г: "r",
  д: "y",
  е: "e",
  ж: "m",
  з: "e",
  и: "n",
  й: "n",
  к: "n",
  л: "n",
  м: "m",
  н: "n",
  о: "o",
  п: "n",
  р: "p",
  с: "c",
  т: "o",
  у: "y",
  ф: "b",
  х: "x",
  ц: "n",
  ч: "n",
  ш: "w",
  щ: "w",
  ъ: "a",
  ы: "m",
  ь: "a",
  э: "e",
  ю: "m",
  я: "r"
};
function Wn(n, e, t) {
  if (!Kt[e])
    throw new Error("Font metrics not found for font: " + e + ".");
  var r = n.charCodeAt(0), a = Kt[e][r];
  if (!a && n[0] in ei && (r = ei[n[0]].charCodeAt(0), a = Kt[e][r]), !a && t === "text" && Jo(r) && (a = Kt[e][77]), a)
    return {
      depth: a[0],
      height: a[1],
      italic: a[2],
      skew: a[3],
      width: a[4]
    };
}
var Tn = {
  // https://en.wikibooks.org/wiki/LaTeX/Lengths and
  // https://tex.stackexchange.com/a/8263
  pt: 1,
  // TeX point
  mm: 7227 / 2540,
  // millimeter
  cm: 7227 / 254,
  // centimeter
  in: 72.27,
  // inch
  bp: 803 / 800,
  // big (PostScript) points
  pc: 12,
  // pica
  dd: 1238 / 1157,
  // didot
  cc: 14856 / 1157,
  // cicero (12 didot)
  nd: 685 / 642,
  // new didot
  nc: 1370 / 107,
  // new cicero (12 new didot)
  sp: 1 / 65536,
  // scaled point (TeX's internal smallest unit)
  // https://tex.stackexchange.com/a/41371
  px: 803 / 800
  // \pdfpxdimen defaults to 1 bp in pdfTeX and LuaTeX
}, c1 = {
  ex: !0,
  em: !0,
  mu: !0
}, h1 = function(e) {
  return typeof e != "string" && (e = e.unit), e in Tn || e in c1 || e === "ex";
}, ke = function(e, t) {
  var r;
  if (e.unit in Tn)
    r = Tn[e.unit] / t.fontMetrics().ptPerEm / t.sizeMultiplier;
  else if (e.unit === "mu")
    r = t.fontMetrics().cssEmPerMu;
  else {
    var a;
    if (t.style.isTight() ? a = t.havingStyle(t.style.text()) : a = t, e.unit === "ex")
      r = a.fontMetrics().xHeight;
    else if (e.unit === "em")
      r = a.fontMetrics().quad;
    else
      throw new X("Invalid unit: '" + e.unit + "'");
    a !== t && (r *= a.sizeMultiplier / t.sizeMultiplier);
  }
  return Math.min(e.number * r, t.maxSize);
}, L = function(e) {
  return +e.toFixed(4) + "em";
}, l0 = function(e) {
  return e.filter((t) => t).join(" ");
}, xl = function(e, t, r) {
  if (this.classes = e || [], this.attributes = {}, this.height = 0, this.depth = 0, this.maxFontSize = 0, this.style = r || {}, t) {
    t.style.isTight() && this.classes.push("mtight");
    var a = t.getColor();
    a && (this.style.color = a);
  }
}, Sl = function(e) {
  var t = document.createElement(e);
  t.className = l0(this.classes);
  for (var r in this.style)
    this.style.hasOwnProperty(r) && (t.style[r] = this.style[r]);
  for (var a in this.attributes)
    this.attributes.hasOwnProperty(a) && t.setAttribute(a, this.attributes[a]);
  for (var i = 0; i < this.children.length; i++)
    t.appendChild(this.children[i].toNode());
  return t;
}, Al = function(e) {
  var t = "<" + e;
  this.classes.length && (t += ' class="' + K.escape(l0(this.classes)) + '"');
  var r = "";
  for (var a in this.style)
    this.style.hasOwnProperty(a) && (r += K.hyphenate(a) + ":" + this.style[a] + ";");
  r && (t += ' style="' + K.escape(r) + '"');
  for (var i in this.attributes)
    this.attributes.hasOwnProperty(i) && (t += " " + i + '="' + K.escape(this.attributes[i]) + '"');
  t += ">";
  for (var l = 0; l < this.children.length; l++)
    t += this.children[l].toMarkup();
  return t += "</" + e + ">", t;
};
class Gr {
  constructor(e, t, r, a) {
    this.children = void 0, this.attributes = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.width = void 0, this.maxFontSize = void 0, this.style = void 0, xl.call(this, e, r, a), this.children = t || [];
  }
  /**
   * Sets an arbitrary attribute on the span. Warning: use this wisely. Not
   * all browsers support attributes the same, and having too many custom
   * attributes is probably bad.
   */
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  hasClass(e) {
    return K.contains(this.classes, e);
  }
  toNode() {
    return Sl.call(this, "span");
  }
  toMarkup() {
    return Al.call(this, "span");
  }
}
class Fl {
  constructor(e, t, r, a) {
    this.children = void 0, this.attributes = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, xl.call(this, t, a), this.children = r || [], this.setAttribute("href", e);
  }
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  hasClass(e) {
    return K.contains(this.classes, e);
  }
  toNode() {
    return Sl.call(this, "a");
  }
  toMarkup() {
    return Al.call(this, "a");
  }
}
class m1 {
  constructor(e, t, r) {
    this.src = void 0, this.alt = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, this.alt = t, this.src = e, this.classes = ["mord"], this.style = r;
  }
  hasClass(e) {
    return K.contains(this.classes, e);
  }
  toNode() {
    var e = document.createElement("img");
    e.src = this.src, e.alt = this.alt, e.className = "mord";
    for (var t in this.style)
      this.style.hasOwnProperty(t) && (e.style[t] = this.style[t]);
    return e;
  }
  toMarkup() {
    var e = '<img src="' + K.escape(this.src) + '"' + (' alt="' + K.escape(this.alt) + '"'), t = "";
    for (var r in this.style)
      this.style.hasOwnProperty(r) && (t += K.hyphenate(r) + ":" + this.style[r] + ";");
    return t && (e += ' style="' + K.escape(t) + '"'), e += "'/>", e;
  }
}
var d1 = {
  î: "ı̂",
  ï: "ı̈",
  í: "ı́",
  // 'ī': '\u0131\u0304', // enable when we add Extended Latin
  ì: "ı̀"
};
class Lt {
  constructor(e, t, r, a, i, l, o, u) {
    this.text = void 0, this.height = void 0, this.depth = void 0, this.italic = void 0, this.skew = void 0, this.width = void 0, this.maxFontSize = void 0, this.classes = void 0, this.style = void 0, this.text = e, this.height = t || 0, this.depth = r || 0, this.italic = a || 0, this.skew = i || 0, this.width = l || 0, this.classes = o || [], this.style = u || {}, this.maxFontSize = 0;
    var h = Qo(this.text.charCodeAt(0));
    h && this.classes.push(h + "_fallback"), /[îïíì]/.test(this.text) && (this.text = d1[this.text]);
  }
  hasClass(e) {
    return K.contains(this.classes, e);
  }
  /**
   * Creates a text node or span from a symbol node. Note that a span is only
   * created if it is needed.
   */
  toNode() {
    var e = document.createTextNode(this.text), t = null;
    this.italic > 0 && (t = document.createElement("span"), t.style.marginRight = L(this.italic)), this.classes.length > 0 && (t = t || document.createElement("span"), t.className = l0(this.classes));
    for (var r in this.style)
      this.style.hasOwnProperty(r) && (t = t || document.createElement("span"), t.style[r] = this.style[r]);
    return t ? (t.appendChild(e), t) : e;
  }
  /**
   * Creates markup for a symbol node.
   */
  toMarkup() {
    var e = !1, t = "<span";
    this.classes.length && (e = !0, t += ' class="', t += K.escape(l0(this.classes)), t += '"');
    var r = "";
    this.italic > 0 && (r += "margin-right:" + this.italic + "em;");
    for (var a in this.style)
      this.style.hasOwnProperty(a) && (r += K.hyphenate(a) + ":" + this.style[a] + ";");
    r && (e = !0, t += ' style="' + K.escape(r) + '"');
    var i = K.escape(this.text);
    return e ? (t += ">", t += i, t += "</span>", t) : i;
  }
}
class s0 {
  constructor(e, t) {
    this.children = void 0, this.attributes = void 0, this.children = e || [], this.attributes = t || {};
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "svg");
    for (var r in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, r) && t.setAttribute(r, this.attributes[r]);
    for (var a = 0; a < this.children.length; a++)
      t.appendChild(this.children[a].toNode());
    return t;
  }
  toMarkup() {
    var e = '<svg xmlns="http://www.w3.org/2000/svg"';
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="' + K.escape(this.attributes[t]) + '"');
    e += ">";
    for (var r = 0; r < this.children.length; r++)
      e += this.children[r].toMarkup();
    return e += "</svg>", e;
  }
}
class p0 {
  constructor(e, t) {
    this.pathName = void 0, this.alternate = void 0, this.pathName = e, this.alternate = t;
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "path");
    return this.alternate ? t.setAttribute("d", this.alternate) : t.setAttribute("d", Ja[this.pathName]), t;
  }
  toMarkup() {
    return this.alternate ? '<path d="' + K.escape(this.alternate) + '"/>' : '<path d="' + K.escape(Ja[this.pathName]) + '"/>';
  }
}
class ti {
  constructor(e) {
    this.attributes = void 0, this.attributes = e || {};
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "line");
    for (var r in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, r) && t.setAttribute(r, this.attributes[r]);
    return t;
  }
  toMarkup() {
    var e = "<line";
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="' + K.escape(this.attributes[t]) + '"');
    return e += "/>", e;
  }
}
function ri(n) {
  if (n instanceof Lt)
    return n;
  throw new Error("Expected symbolNode but got " + String(n) + ".");
}
function f1(n) {
  if (n instanceof Gr)
    return n;
  throw new Error("Expected span<HtmlDomNode> but got " + String(n) + ".");
}
var p1 = {
  "accent-token": 1,
  mathord: 1,
  "op-token": 1,
  spacing: 1,
  textord: 1
}, Fe = {
  math: {},
  text: {}
};
function s(n, e, t, r, a, i) {
  Fe[n][a] = {
    font: e,
    group: t,
    replace: r
  }, i && r && (Fe[n][r] = Fe[n][a]);
}
var c = "math", z = "text", m = "main", v = "ams", ye = "accent-token", H = "bin", Ve = "close", R0 = "inner", Z = "mathord", Ce = "op-token", tt = "open", Yr = "punct", _ = "rel", t0 = "spacing", k = "textord";
s(c, m, _, "≡", "\\equiv", !0);
s(c, m, _, "≺", "\\prec", !0);
s(c, m, _, "≻", "\\succ", !0);
s(c, m, _, "∼", "\\sim", !0);
s(c, m, _, "⊥", "\\perp");
s(c, m, _, "⪯", "\\preceq", !0);
s(c, m, _, "⪰", "\\succeq", !0);
s(c, m, _, "≃", "\\simeq", !0);
s(c, m, _, "∣", "\\mid", !0);
s(c, m, _, "≪", "\\ll", !0);
s(c, m, _, "≫", "\\gg", !0);
s(c, m, _, "≍", "\\asymp", !0);
s(c, m, _, "∥", "\\parallel");
s(c, m, _, "⋈", "\\bowtie", !0);
s(c, m, _, "⌣", "\\smile", !0);
s(c, m, _, "⊑", "\\sqsubseteq", !0);
s(c, m, _, "⊒", "\\sqsupseteq", !0);
s(c, m, _, "≐", "\\doteq", !0);
s(c, m, _, "⌢", "\\frown", !0);
s(c, m, _, "∋", "\\ni", !0);
s(c, m, _, "∝", "\\propto", !0);
s(c, m, _, "⊢", "\\vdash", !0);
s(c, m, _, "⊣", "\\dashv", !0);
s(c, m, _, "∋", "\\owns");
s(c, m, Yr, ".", "\\ldotp");
s(c, m, Yr, "⋅", "\\cdotp");
s(c, m, k, "#", "\\#");
s(z, m, k, "#", "\\#");
s(c, m, k, "&", "\\&");
s(z, m, k, "&", "\\&");
s(c, m, k, "ℵ", "\\aleph", !0);
s(c, m, k, "∀", "\\forall", !0);
s(c, m, k, "ℏ", "\\hbar", !0);
s(c, m, k, "∃", "\\exists", !0);
s(c, m, k, "∇", "\\nabla", !0);
s(c, m, k, "♭", "\\flat", !0);
s(c, m, k, "ℓ", "\\ell", !0);
s(c, m, k, "♮", "\\natural", !0);
s(c, m, k, "♣", "\\clubsuit", !0);
s(c, m, k, "℘", "\\wp", !0);
s(c, m, k, "♯", "\\sharp", !0);
s(c, m, k, "♢", "\\diamondsuit", !0);
s(c, m, k, "ℜ", "\\Re", !0);
s(c, m, k, "♡", "\\heartsuit", !0);
s(c, m, k, "ℑ", "\\Im", !0);
s(c, m, k, "♠", "\\spadesuit", !0);
s(c, m, k, "§", "\\S", !0);
s(z, m, k, "§", "\\S");
s(c, m, k, "¶", "\\P", !0);
s(z, m, k, "¶", "\\P");
s(c, m, k, "†", "\\dag");
s(z, m, k, "†", "\\dag");
s(z, m, k, "†", "\\textdagger");
s(c, m, k, "‡", "\\ddag");
s(z, m, k, "‡", "\\ddag");
s(z, m, k, "‡", "\\textdaggerdbl");
s(c, m, Ve, "⎱", "\\rmoustache", !0);
s(c, m, tt, "⎰", "\\lmoustache", !0);
s(c, m, Ve, "⟯", "\\rgroup", !0);
s(c, m, tt, "⟮", "\\lgroup", !0);
s(c, m, H, "∓", "\\mp", !0);
s(c, m, H, "⊖", "\\ominus", !0);
s(c, m, H, "⊎", "\\uplus", !0);
s(c, m, H, "⊓", "\\sqcap", !0);
s(c, m, H, "∗", "\\ast");
s(c, m, H, "⊔", "\\sqcup", !0);
s(c, m, H, "◯", "\\bigcirc", !0);
s(c, m, H, "∙", "\\bullet", !0);
s(c, m, H, "‡", "\\ddagger");
s(c, m, H, "≀", "\\wr", !0);
s(c, m, H, "⨿", "\\amalg");
s(c, m, H, "&", "\\And");
s(c, m, _, "⟵", "\\longleftarrow", !0);
s(c, m, _, "⇐", "\\Leftarrow", !0);
s(c, m, _, "⟸", "\\Longleftarrow", !0);
s(c, m, _, "⟶", "\\longrightarrow", !0);
s(c, m, _, "⇒", "\\Rightarrow", !0);
s(c, m, _, "⟹", "\\Longrightarrow", !0);
s(c, m, _, "↔", "\\leftrightarrow", !0);
s(c, m, _, "⟷", "\\longleftrightarrow", !0);
s(c, m, _, "⇔", "\\Leftrightarrow", !0);
s(c, m, _, "⟺", "\\Longleftrightarrow", !0);
s(c, m, _, "↦", "\\mapsto", !0);
s(c, m, _, "⟼", "\\longmapsto", !0);
s(c, m, _, "↗", "\\nearrow", !0);
s(c, m, _, "↩", "\\hookleftarrow", !0);
s(c, m, _, "↪", "\\hookrightarrow", !0);
s(c, m, _, "↘", "\\searrow", !0);
s(c, m, _, "↼", "\\leftharpoonup", !0);
s(c, m, _, "⇀", "\\rightharpoonup", !0);
s(c, m, _, "↙", "\\swarrow", !0);
s(c, m, _, "↽", "\\leftharpoondown", !0);
s(c, m, _, "⇁", "\\rightharpoondown", !0);
s(c, m, _, "↖", "\\nwarrow", !0);
s(c, m, _, "⇌", "\\rightleftharpoons", !0);
s(c, v, _, "≮", "\\nless", !0);
s(c, v, _, "", "\\@nleqslant");
s(c, v, _, "", "\\@nleqq");
s(c, v, _, "⪇", "\\lneq", !0);
s(c, v, _, "≨", "\\lneqq", !0);
s(c, v, _, "", "\\@lvertneqq");
s(c, v, _, "⋦", "\\lnsim", !0);
s(c, v, _, "⪉", "\\lnapprox", !0);
s(c, v, _, "⊀", "\\nprec", !0);
s(c, v, _, "⋠", "\\npreceq", !0);
s(c, v, _, "⋨", "\\precnsim", !0);
s(c, v, _, "⪹", "\\precnapprox", !0);
s(c, v, _, "≁", "\\nsim", !0);
s(c, v, _, "", "\\@nshortmid");
s(c, v, _, "∤", "\\nmid", !0);
s(c, v, _, "⊬", "\\nvdash", !0);
s(c, v, _, "⊭", "\\nvDash", !0);
s(c, v, _, "⋪", "\\ntriangleleft");
s(c, v, _, "⋬", "\\ntrianglelefteq", !0);
s(c, v, _, "⊊", "\\subsetneq", !0);
s(c, v, _, "", "\\@varsubsetneq");
s(c, v, _, "⫋", "\\subsetneqq", !0);
s(c, v, _, "", "\\@varsubsetneqq");
s(c, v, _, "≯", "\\ngtr", !0);
s(c, v, _, "", "\\@ngeqslant");
s(c, v, _, "", "\\@ngeqq");
s(c, v, _, "⪈", "\\gneq", !0);
s(c, v, _, "≩", "\\gneqq", !0);
s(c, v, _, "", "\\@gvertneqq");
s(c, v, _, "⋧", "\\gnsim", !0);
s(c, v, _, "⪊", "\\gnapprox", !0);
s(c, v, _, "⊁", "\\nsucc", !0);
s(c, v, _, "⋡", "\\nsucceq", !0);
s(c, v, _, "⋩", "\\succnsim", !0);
s(c, v, _, "⪺", "\\succnapprox", !0);
s(c, v, _, "≆", "\\ncong", !0);
s(c, v, _, "", "\\@nshortparallel");
s(c, v, _, "∦", "\\nparallel", !0);
s(c, v, _, "⊯", "\\nVDash", !0);
s(c, v, _, "⋫", "\\ntriangleright");
s(c, v, _, "⋭", "\\ntrianglerighteq", !0);
s(c, v, _, "", "\\@nsupseteqq");
s(c, v, _, "⊋", "\\supsetneq", !0);
s(c, v, _, "", "\\@varsupsetneq");
s(c, v, _, "⫌", "\\supsetneqq", !0);
s(c, v, _, "", "\\@varsupsetneqq");
s(c, v, _, "⊮", "\\nVdash", !0);
s(c, v, _, "⪵", "\\precneqq", !0);
s(c, v, _, "⪶", "\\succneqq", !0);
s(c, v, _, "", "\\@nsubseteqq");
s(c, v, H, "⊴", "\\unlhd");
s(c, v, H, "⊵", "\\unrhd");
s(c, v, _, "↚", "\\nleftarrow", !0);
s(c, v, _, "↛", "\\nrightarrow", !0);
s(c, v, _, "⇍", "\\nLeftarrow", !0);
s(c, v, _, "⇏", "\\nRightarrow", !0);
s(c, v, _, "↮", "\\nleftrightarrow", !0);
s(c, v, _, "⇎", "\\nLeftrightarrow", !0);
s(c, v, _, "△", "\\vartriangle");
s(c, v, k, "ℏ", "\\hslash");
s(c, v, k, "▽", "\\triangledown");
s(c, v, k, "◊", "\\lozenge");
s(c, v, k, "Ⓢ", "\\circledS");
s(c, v, k, "®", "\\circledR");
s(z, v, k, "®", "\\circledR");
s(c, v, k, "∡", "\\measuredangle", !0);
s(c, v, k, "∄", "\\nexists");
s(c, v, k, "℧", "\\mho");
s(c, v, k, "Ⅎ", "\\Finv", !0);
s(c, v, k, "⅁", "\\Game", !0);
s(c, v, k, "‵", "\\backprime");
s(c, v, k, "▲", "\\blacktriangle");
s(c, v, k, "▼", "\\blacktriangledown");
s(c, v, k, "■", "\\blacksquare");
s(c, v, k, "⧫", "\\blacklozenge");
s(c, v, k, "★", "\\bigstar");
s(c, v, k, "∢", "\\sphericalangle", !0);
s(c, v, k, "∁", "\\complement", !0);
s(c, v, k, "ð", "\\eth", !0);
s(z, m, k, "ð", "ð");
s(c, v, k, "╱", "\\diagup");
s(c, v, k, "╲", "\\diagdown");
s(c, v, k, "□", "\\square");
s(c, v, k, "□", "\\Box");
s(c, v, k, "◊", "\\Diamond");
s(c, v, k, "¥", "\\yen", !0);
s(z, v, k, "¥", "\\yen", !0);
s(c, v, k, "✓", "\\checkmark", !0);
s(z, v, k, "✓", "\\checkmark");
s(c, v, k, "ℶ", "\\beth", !0);
s(c, v, k, "ℸ", "\\daleth", !0);
s(c, v, k, "ℷ", "\\gimel", !0);
s(c, v, k, "ϝ", "\\digamma", !0);
s(c, v, k, "ϰ", "\\varkappa");
s(c, v, tt, "┌", "\\@ulcorner", !0);
s(c, v, Ve, "┐", "\\@urcorner", !0);
s(c, v, tt, "└", "\\@llcorner", !0);
s(c, v, Ve, "┘", "\\@lrcorner", !0);
s(c, v, _, "≦", "\\leqq", !0);
s(c, v, _, "⩽", "\\leqslant", !0);
s(c, v, _, "⪕", "\\eqslantless", !0);
s(c, v, _, "≲", "\\lesssim", !0);
s(c, v, _, "⪅", "\\lessapprox", !0);
s(c, v, _, "≊", "\\approxeq", !0);
s(c, v, H, "⋖", "\\lessdot");
s(c, v, _, "⋘", "\\lll", !0);
s(c, v, _, "≶", "\\lessgtr", !0);
s(c, v, _, "⋚", "\\lesseqgtr", !0);
s(c, v, _, "⪋", "\\lesseqqgtr", !0);
s(c, v, _, "≑", "\\doteqdot");
s(c, v, _, "≓", "\\risingdotseq", !0);
s(c, v, _, "≒", "\\fallingdotseq", !0);
s(c, v, _, "∽", "\\backsim", !0);
s(c, v, _, "⋍", "\\backsimeq", !0);
s(c, v, _, "⫅", "\\subseteqq", !0);
s(c, v, _, "⋐", "\\Subset", !0);
s(c, v, _, "⊏", "\\sqsubset", !0);
s(c, v, _, "≼", "\\preccurlyeq", !0);
s(c, v, _, "⋞", "\\curlyeqprec", !0);
s(c, v, _, "≾", "\\precsim", !0);
s(c, v, _, "⪷", "\\precapprox", !0);
s(c, v, _, "⊲", "\\vartriangleleft");
s(c, v, _, "⊴", "\\trianglelefteq");
s(c, v, _, "⊨", "\\vDash", !0);
s(c, v, _, "⊪", "\\Vvdash", !0);
s(c, v, _, "⌣", "\\smallsmile");
s(c, v, _, "⌢", "\\smallfrown");
s(c, v, _, "≏", "\\bumpeq", !0);
s(c, v, _, "≎", "\\Bumpeq", !0);
s(c, v, _, "≧", "\\geqq", !0);
s(c, v, _, "⩾", "\\geqslant", !0);
s(c, v, _, "⪖", "\\eqslantgtr", !0);
s(c, v, _, "≳", "\\gtrsim", !0);
s(c, v, _, "⪆", "\\gtrapprox", !0);
s(c, v, H, "⋗", "\\gtrdot");
s(c, v, _, "⋙", "\\ggg", !0);
s(c, v, _, "≷", "\\gtrless", !0);
s(c, v, _, "⋛", "\\gtreqless", !0);
s(c, v, _, "⪌", "\\gtreqqless", !0);
s(c, v, _, "≖", "\\eqcirc", !0);
s(c, v, _, "≗", "\\circeq", !0);
s(c, v, _, "≜", "\\triangleq", !0);
s(c, v, _, "∼", "\\thicksim");
s(c, v, _, "≈", "\\thickapprox");
s(c, v, _, "⫆", "\\supseteqq", !0);
s(c, v, _, "⋑", "\\Supset", !0);
s(c, v, _, "⊐", "\\sqsupset", !0);
s(c, v, _, "≽", "\\succcurlyeq", !0);
s(c, v, _, "⋟", "\\curlyeqsucc", !0);
s(c, v, _, "≿", "\\succsim", !0);
s(c, v, _, "⪸", "\\succapprox", !0);
s(c, v, _, "⊳", "\\vartriangleright");
s(c, v, _, "⊵", "\\trianglerighteq");
s(c, v, _, "⊩", "\\Vdash", !0);
s(c, v, _, "∣", "\\shortmid");
s(c, v, _, "∥", "\\shortparallel");
s(c, v, _, "≬", "\\between", !0);
s(c, v, _, "⋔", "\\pitchfork", !0);
s(c, v, _, "∝", "\\varpropto");
s(c, v, _, "◀", "\\blacktriangleleft");
s(c, v, _, "∴", "\\therefore", !0);
s(c, v, _, "∍", "\\backepsilon");
s(c, v, _, "▶", "\\blacktriangleright");
s(c, v, _, "∵", "\\because", !0);
s(c, v, _, "⋘", "\\llless");
s(c, v, _, "⋙", "\\gggtr");
s(c, v, H, "⊲", "\\lhd");
s(c, v, H, "⊳", "\\rhd");
s(c, v, _, "≂", "\\eqsim", !0);
s(c, m, _, "⋈", "\\Join");
s(c, v, _, "≑", "\\Doteq", !0);
s(c, v, H, "∔", "\\dotplus", !0);
s(c, v, H, "∖", "\\smallsetminus");
s(c, v, H, "⋒", "\\Cap", !0);
s(c, v, H, "⋓", "\\Cup", !0);
s(c, v, H, "⩞", "\\doublebarwedge", !0);
s(c, v, H, "⊟", "\\boxminus", !0);
s(c, v, H, "⊞", "\\boxplus", !0);
s(c, v, H, "⋇", "\\divideontimes", !0);
s(c, v, H, "⋉", "\\ltimes", !0);
s(c, v, H, "⋊", "\\rtimes", !0);
s(c, v, H, "⋋", "\\leftthreetimes", !0);
s(c, v, H, "⋌", "\\rightthreetimes", !0);
s(c, v, H, "⋏", "\\curlywedge", !0);
s(c, v, H, "⋎", "\\curlyvee", !0);
s(c, v, H, "⊝", "\\circleddash", !0);
s(c, v, H, "⊛", "\\circledast", !0);
s(c, v, H, "⋅", "\\centerdot");
s(c, v, H, "⊺", "\\intercal", !0);
s(c, v, H, "⋒", "\\doublecap");
s(c, v, H, "⋓", "\\doublecup");
s(c, v, H, "⊠", "\\boxtimes", !0);
s(c, v, _, "⇢", "\\dashrightarrow", !0);
s(c, v, _, "⇠", "\\dashleftarrow", !0);
s(c, v, _, "⇇", "\\leftleftarrows", !0);
s(c, v, _, "⇆", "\\leftrightarrows", !0);
s(c, v, _, "⇚", "\\Lleftarrow", !0);
s(c, v, _, "↞", "\\twoheadleftarrow", !0);
s(c, v, _, "↢", "\\leftarrowtail", !0);
s(c, v, _, "↫", "\\looparrowleft", !0);
s(c, v, _, "⇋", "\\leftrightharpoons", !0);
s(c, v, _, "↶", "\\curvearrowleft", !0);
s(c, v, _, "↺", "\\circlearrowleft", !0);
s(c, v, _, "↰", "\\Lsh", !0);
s(c, v, _, "⇈", "\\upuparrows", !0);
s(c, v, _, "↿", "\\upharpoonleft", !0);
s(c, v, _, "⇃", "\\downharpoonleft", !0);
s(c, m, _, "⊶", "\\origof", !0);
s(c, m, _, "⊷", "\\imageof", !0);
s(c, v, _, "⊸", "\\multimap", !0);
s(c, v, _, "↭", "\\leftrightsquigarrow", !0);
s(c, v, _, "⇉", "\\rightrightarrows", !0);
s(c, v, _, "⇄", "\\rightleftarrows", !0);
s(c, v, _, "↠", "\\twoheadrightarrow", !0);
s(c, v, _, "↣", "\\rightarrowtail", !0);
s(c, v, _, "↬", "\\looparrowright", !0);
s(c, v, _, "↷", "\\curvearrowright", !0);
s(c, v, _, "↻", "\\circlearrowright", !0);
s(c, v, _, "↱", "\\Rsh", !0);
s(c, v, _, "⇊", "\\downdownarrows", !0);
s(c, v, _, "↾", "\\upharpoonright", !0);
s(c, v, _, "⇂", "\\downharpoonright", !0);
s(c, v, _, "⇝", "\\rightsquigarrow", !0);
s(c, v, _, "⇝", "\\leadsto");
s(c, v, _, "⇛", "\\Rrightarrow", !0);
s(c, v, _, "↾", "\\restriction");
s(c, m, k, "‘", "`");
s(c, m, k, "$", "\\$");
s(z, m, k, "$", "\\$");
s(z, m, k, "$", "\\textdollar");
s(c, m, k, "%", "\\%");
s(z, m, k, "%", "\\%");
s(c, m, k, "_", "\\_");
s(z, m, k, "_", "\\_");
s(z, m, k, "_", "\\textunderscore");
s(c, m, k, "∠", "\\angle", !0);
s(c, m, k, "∞", "\\infty", !0);
s(c, m, k, "′", "\\prime");
s(c, m, k, "△", "\\triangle");
s(c, m, k, "Γ", "\\Gamma", !0);
s(c, m, k, "Δ", "\\Delta", !0);
s(c, m, k, "Θ", "\\Theta", !0);
s(c, m, k, "Λ", "\\Lambda", !0);
s(c, m, k, "Ξ", "\\Xi", !0);
s(c, m, k, "Π", "\\Pi", !0);
s(c, m, k, "Σ", "\\Sigma", !0);
s(c, m, k, "Υ", "\\Upsilon", !0);
s(c, m, k, "Φ", "\\Phi", !0);
s(c, m, k, "Ψ", "\\Psi", !0);
s(c, m, k, "Ω", "\\Omega", !0);
s(c, m, k, "A", "Α");
s(c, m, k, "B", "Β");
s(c, m, k, "E", "Ε");
s(c, m, k, "Z", "Ζ");
s(c, m, k, "H", "Η");
s(c, m, k, "I", "Ι");
s(c, m, k, "K", "Κ");
s(c, m, k, "M", "Μ");
s(c, m, k, "N", "Ν");
s(c, m, k, "O", "Ο");
s(c, m, k, "P", "Ρ");
s(c, m, k, "T", "Τ");
s(c, m, k, "X", "Χ");
s(c, m, k, "¬", "\\neg", !0);
s(c, m, k, "¬", "\\lnot");
s(c, m, k, "⊤", "\\top");
s(c, m, k, "⊥", "\\bot");
s(c, m, k, "∅", "\\emptyset");
s(c, v, k, "∅", "\\varnothing");
s(c, m, Z, "α", "\\alpha", !0);
s(c, m, Z, "β", "\\beta", !0);
s(c, m, Z, "γ", "\\gamma", !0);
s(c, m, Z, "δ", "\\delta", !0);
s(c, m, Z, "ϵ", "\\epsilon", !0);
s(c, m, Z, "ζ", "\\zeta", !0);
s(c, m, Z, "η", "\\eta", !0);
s(c, m, Z, "θ", "\\theta", !0);
s(c, m, Z, "ι", "\\iota", !0);
s(c, m, Z, "κ", "\\kappa", !0);
s(c, m, Z, "λ", "\\lambda", !0);
s(c, m, Z, "μ", "\\mu", !0);
s(c, m, Z, "ν", "\\nu", !0);
s(c, m, Z, "ξ", "\\xi", !0);
s(c, m, Z, "ο", "\\omicron", !0);
s(c, m, Z, "π", "\\pi", !0);
s(c, m, Z, "ρ", "\\rho", !0);
s(c, m, Z, "σ", "\\sigma", !0);
s(c, m, Z, "τ", "\\tau", !0);
s(c, m, Z, "υ", "\\upsilon", !0);
s(c, m, Z, "ϕ", "\\phi", !0);
s(c, m, Z, "χ", "\\chi", !0);
s(c, m, Z, "ψ", "\\psi", !0);
s(c, m, Z, "ω", "\\omega", !0);
s(c, m, Z, "ε", "\\varepsilon", !0);
s(c, m, Z, "ϑ", "\\vartheta", !0);
s(c, m, Z, "ϖ", "\\varpi", !0);
s(c, m, Z, "ϱ", "\\varrho", !0);
s(c, m, Z, "ς", "\\varsigma", !0);
s(c, m, Z, "φ", "\\varphi", !0);
s(c, m, H, "∗", "*", !0);
s(c, m, H, "+", "+");
s(c, m, H, "−", "-", !0);
s(c, m, H, "⋅", "\\cdot", !0);
s(c, m, H, "∘", "\\circ", !0);
s(c, m, H, "÷", "\\div", !0);
s(c, m, H, "±", "\\pm", !0);
s(c, m, H, "×", "\\times", !0);
s(c, m, H, "∩", "\\cap", !0);
s(c, m, H, "∪", "\\cup", !0);
s(c, m, H, "∖", "\\setminus", !0);
s(c, m, H, "∧", "\\land");
s(c, m, H, "∨", "\\lor");
s(c, m, H, "∧", "\\wedge", !0);
s(c, m, H, "∨", "\\vee", !0);
s(c, m, k, "√", "\\surd");
s(c, m, tt, "⟨", "\\langle", !0);
s(c, m, tt, "∣", "\\lvert");
s(c, m, tt, "∥", "\\lVert");
s(c, m, Ve, "?", "?");
s(c, m, Ve, "!", "!");
s(c, m, Ve, "⟩", "\\rangle", !0);
s(c, m, Ve, "∣", "\\rvert");
s(c, m, Ve, "∥", "\\rVert");
s(c, m, _, "=", "=");
s(c, m, _, ":", ":");
s(c, m, _, "≈", "\\approx", !0);
s(c, m, _, "≅", "\\cong", !0);
s(c, m, _, "≥", "\\ge");
s(c, m, _, "≥", "\\geq", !0);
s(c, m, _, "←", "\\gets");
s(c, m, _, ">", "\\gt", !0);
s(c, m, _, "∈", "\\in", !0);
s(c, m, _, "", "\\@not");
s(c, m, _, "⊂", "\\subset", !0);
s(c, m, _, "⊃", "\\supset", !0);
s(c, m, _, "⊆", "\\subseteq", !0);
s(c, m, _, "⊇", "\\supseteq", !0);
s(c, v, _, "⊈", "\\nsubseteq", !0);
s(c, v, _, "⊉", "\\nsupseteq", !0);
s(c, m, _, "⊨", "\\models");
s(c, m, _, "←", "\\leftarrow", !0);
s(c, m, _, "≤", "\\le");
s(c, m, _, "≤", "\\leq", !0);
s(c, m, _, "<", "\\lt", !0);
s(c, m, _, "→", "\\rightarrow", !0);
s(c, m, _, "→", "\\to");
s(c, v, _, "≱", "\\ngeq", !0);
s(c, v, _, "≰", "\\nleq", !0);
s(c, m, t0, " ", "\\ ");
s(c, m, t0, " ", "\\space");
s(c, m, t0, " ", "\\nobreakspace");
s(z, m, t0, " ", "\\ ");
s(z, m, t0, " ", " ");
s(z, m, t0, " ", "\\space");
s(z, m, t0, " ", "\\nobreakspace");
s(c, m, t0, null, "\\nobreak");
s(c, m, t0, null, "\\allowbreak");
s(c, m, Yr, ",", ",");
s(c, m, Yr, ";", ";");
s(c, v, H, "⊼", "\\barwedge", !0);
s(c, v, H, "⊻", "\\veebar", !0);
s(c, m, H, "⊙", "\\odot", !0);
s(c, m, H, "⊕", "\\oplus", !0);
s(c, m, H, "⊗", "\\otimes", !0);
s(c, m, k, "∂", "\\partial", !0);
s(c, m, H, "⊘", "\\oslash", !0);
s(c, v, H, "⊚", "\\circledcirc", !0);
s(c, v, H, "⊡", "\\boxdot", !0);
s(c, m, H, "△", "\\bigtriangleup");
s(c, m, H, "▽", "\\bigtriangledown");
s(c, m, H, "†", "\\dagger");
s(c, m, H, "⋄", "\\diamond");
s(c, m, H, "⋆", "\\star");
s(c, m, H, "◃", "\\triangleleft");
s(c, m, H, "▹", "\\triangleright");
s(c, m, tt, "{", "\\{");
s(z, m, k, "{", "\\{");
s(z, m, k, "{", "\\textbraceleft");
s(c, m, Ve, "}", "\\}");
s(z, m, k, "}", "\\}");
s(z, m, k, "}", "\\textbraceright");
s(c, m, tt, "{", "\\lbrace");
s(c, m, Ve, "}", "\\rbrace");
s(c, m, tt, "[", "\\lbrack", !0);
s(z, m, k, "[", "\\lbrack", !0);
s(c, m, Ve, "]", "\\rbrack", !0);
s(z, m, k, "]", "\\rbrack", !0);
s(c, m, tt, "(", "\\lparen", !0);
s(c, m, Ve, ")", "\\rparen", !0);
s(z, m, k, "<", "\\textless", !0);
s(z, m, k, ">", "\\textgreater", !0);
s(c, m, tt, "⌊", "\\lfloor", !0);
s(c, m, Ve, "⌋", "\\rfloor", !0);
s(c, m, tt, "⌈", "\\lceil", !0);
s(c, m, Ve, "⌉", "\\rceil", !0);
s(c, m, k, "\\", "\\backslash");
s(c, m, k, "∣", "|");
s(c, m, k, "∣", "\\vert");
s(z, m, k, "|", "\\textbar", !0);
s(c, m, k, "∥", "\\|");
s(c, m, k, "∥", "\\Vert");
s(z, m, k, "∥", "\\textbardbl");
s(z, m, k, "~", "\\textasciitilde");
s(z, m, k, "\\", "\\textbackslash");
s(z, m, k, "^", "\\textasciicircum");
s(c, m, _, "↑", "\\uparrow", !0);
s(c, m, _, "⇑", "\\Uparrow", !0);
s(c, m, _, "↓", "\\downarrow", !0);
s(c, m, _, "⇓", "\\Downarrow", !0);
s(c, m, _, "↕", "\\updownarrow", !0);
s(c, m, _, "⇕", "\\Updownarrow", !0);
s(c, m, Ce, "∐", "\\coprod");
s(c, m, Ce, "⋁", "\\bigvee");
s(c, m, Ce, "⋀", "\\bigwedge");
s(c, m, Ce, "⨄", "\\biguplus");
s(c, m, Ce, "⋂", "\\bigcap");
s(c, m, Ce, "⋃", "\\bigcup");
s(c, m, Ce, "∫", "\\int");
s(c, m, Ce, "∫", "\\intop");
s(c, m, Ce, "∬", "\\iint");
s(c, m, Ce, "∭", "\\iiint");
s(c, m, Ce, "∏", "\\prod");
s(c, m, Ce, "∑", "\\sum");
s(c, m, Ce, "⨂", "\\bigotimes");
s(c, m, Ce, "⨁", "\\bigoplus");
s(c, m, Ce, "⨀", "\\bigodot");
s(c, m, Ce, "∮", "\\oint");
s(c, m, Ce, "∯", "\\oiint");
s(c, m, Ce, "∰", "\\oiiint");
s(c, m, Ce, "⨆", "\\bigsqcup");
s(c, m, Ce, "∫", "\\smallint");
s(z, m, R0, "…", "\\textellipsis");
s(c, m, R0, "…", "\\mathellipsis");
s(z, m, R0, "…", "\\ldots", !0);
s(c, m, R0, "…", "\\ldots", !0);
s(c, m, R0, "⋯", "\\@cdots", !0);
s(c, m, R0, "⋱", "\\ddots", !0);
s(c, m, k, "⋮", "\\varvdots");
s(c, m, ye, "ˊ", "\\acute");
s(c, m, ye, "ˋ", "\\grave");
s(c, m, ye, "¨", "\\ddot");
s(c, m, ye, "~", "\\tilde");
s(c, m, ye, "ˉ", "\\bar");
s(c, m, ye, "˘", "\\breve");
s(c, m, ye, "ˇ", "\\check");
s(c, m, ye, "^", "\\hat");
s(c, m, ye, "⃗", "\\vec");
s(c, m, ye, "˙", "\\dot");
s(c, m, ye, "˚", "\\mathring");
s(c, m, Z, "", "\\@imath");
s(c, m, Z, "", "\\@jmath");
s(c, m, k, "ı", "ı");
s(c, m, k, "ȷ", "ȷ");
s(z, m, k, "ı", "\\i", !0);
s(z, m, k, "ȷ", "\\j", !0);
s(z, m, k, "ß", "\\ss", !0);
s(z, m, k, "æ", "\\ae", !0);
s(z, m, k, "œ", "\\oe", !0);
s(z, m, k, "ø", "\\o", !0);
s(z, m, k, "Æ", "\\AE", !0);
s(z, m, k, "Œ", "\\OE", !0);
s(z, m, k, "Ø", "\\O", !0);
s(z, m, ye, "ˊ", "\\'");
s(z, m, ye, "ˋ", "\\`");
s(z, m, ye, "ˆ", "\\^");
s(z, m, ye, "˜", "\\~");
s(z, m, ye, "ˉ", "\\=");
s(z, m, ye, "˘", "\\u");
s(z, m, ye, "˙", "\\.");
s(z, m, ye, "¸", "\\c");
s(z, m, ye, "˚", "\\r");
s(z, m, ye, "ˇ", "\\v");
s(z, m, ye, "¨", '\\"');
s(z, m, ye, "˝", "\\H");
s(z, m, ye, "◯", "\\textcircled");
var Cl = {
  "--": !0,
  "---": !0,
  "``": !0,
  "''": !0
};
s(z, m, k, "–", "--", !0);
s(z, m, k, "–", "\\textendash");
s(z, m, k, "—", "---", !0);
s(z, m, k, "—", "\\textemdash");
s(z, m, k, "‘", "`", !0);
s(z, m, k, "‘", "\\textquoteleft");
s(z, m, k, "’", "'", !0);
s(z, m, k, "’", "\\textquoteright");
s(z, m, k, "“", "``", !0);
s(z, m, k, "“", "\\textquotedblleft");
s(z, m, k, "”", "''", !0);
s(z, m, k, "”", "\\textquotedblright");
s(c, m, k, "°", "\\degree", !0);
s(z, m, k, "°", "\\degree");
s(z, m, k, "°", "\\textdegree", !0);
s(c, m, k, "£", "\\pounds");
s(c, m, k, "£", "\\mathsterling", !0);
s(z, m, k, "£", "\\pounds");
s(z, m, k, "£", "\\textsterling", !0);
s(c, v, k, "✠", "\\maltese");
s(z, v, k, "✠", "\\maltese");
var ni = '0123456789/@."';
for (var ln = 0; ln < ni.length; ln++) {
  var ai = ni.charAt(ln);
  s(c, m, k, ai, ai);
}
var ii = '0123456789!@*()-=+";:?/.,';
for (var sn = 0; sn < ii.length; sn++) {
  var li = ii.charAt(sn);
  s(z, m, k, li, li);
}
var Rr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
for (var on = 0; on < Rr.length; on++) {
  var dr = Rr.charAt(on);
  s(c, m, Z, dr, dr), s(z, m, k, dr, dr);
}
s(c, v, k, "C", "ℂ");
s(z, v, k, "C", "ℂ");
s(c, v, k, "H", "ℍ");
s(z, v, k, "H", "ℍ");
s(c, v, k, "N", "ℕ");
s(z, v, k, "N", "ℕ");
s(c, v, k, "P", "ℙ");
s(z, v, k, "P", "ℙ");
s(c, v, k, "Q", "ℚ");
s(z, v, k, "Q", "ℚ");
s(c, v, k, "R", "ℝ");
s(z, v, k, "R", "ℝ");
s(c, v, k, "Z", "ℤ");
s(z, v, k, "Z", "ℤ");
s(c, m, Z, "h", "ℎ");
s(z, m, Z, "h", "ℎ");
var ee = "";
for (var Oe = 0; Oe < Rr.length; Oe++) {
  var Se = Rr.charAt(Oe);
  ee = String.fromCharCode(55349, 56320 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56372 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56424 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56580 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56684 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56736 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56788 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56840 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56944 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), Oe < 26 && (ee = String.fromCharCode(55349, 56632 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee), ee = String.fromCharCode(55349, 56476 + Oe), s(c, m, Z, Se, ee), s(z, m, k, Se, ee));
}
ee = "𝕜";
s(c, m, Z, "k", ee);
s(z, m, k, "k", ee);
for (var c0 = 0; c0 < 10; c0++) {
  var n0 = c0.toString();
  ee = String.fromCharCode(55349, 57294 + c0), s(c, m, Z, n0, ee), s(z, m, k, n0, ee), ee = String.fromCharCode(55349, 57314 + c0), s(c, m, Z, n0, ee), s(z, m, k, n0, ee), ee = String.fromCharCode(55349, 57324 + c0), s(c, m, Z, n0, ee), s(z, m, k, n0, ee), ee = String.fromCharCode(55349, 57334 + c0), s(c, m, Z, n0, ee), s(z, m, k, n0, ee);
}
var si = "ÐÞþ";
for (var un = 0; un < si.length; un++) {
  var fr = si.charAt(un);
  s(c, m, Z, fr, fr), s(z, m, k, fr, fr);
}
var pr = [
  ["mathbf", "textbf", "Main-Bold"],
  // A-Z bold upright
  ["mathbf", "textbf", "Main-Bold"],
  // a-z bold upright
  ["mathnormal", "textit", "Math-Italic"],
  // A-Z italic
  ["mathnormal", "textit", "Math-Italic"],
  // a-z italic
  ["boldsymbol", "boldsymbol", "Main-BoldItalic"],
  // A-Z bold italic
  ["boldsymbol", "boldsymbol", "Main-BoldItalic"],
  // a-z bold italic
  // Map fancy A-Z letters to script, not calligraphic.
  // This aligns with unicode-math and math fonts (except Cambria Math).
  ["mathscr", "textscr", "Script-Regular"],
  // A-Z script
  ["", "", ""],
  // a-z script.  No font
  ["", "", ""],
  // A-Z bold script. No font
  ["", "", ""],
  // a-z bold script. No font
  ["mathfrak", "textfrak", "Fraktur-Regular"],
  // A-Z Fraktur
  ["mathfrak", "textfrak", "Fraktur-Regular"],
  // a-z Fraktur
  ["mathbb", "textbb", "AMS-Regular"],
  // A-Z double-struck
  ["mathbb", "textbb", "AMS-Regular"],
  // k double-struck
  // Note that we are using a bold font, but font metrics for regular Fraktur.
  ["mathboldfrak", "textboldfrak", "Fraktur-Regular"],
  // A-Z bold Fraktur
  ["mathboldfrak", "textboldfrak", "Fraktur-Regular"],
  // a-z bold Fraktur
  ["mathsf", "textsf", "SansSerif-Regular"],
  // A-Z sans-serif
  ["mathsf", "textsf", "SansSerif-Regular"],
  // a-z sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // A-Z bold sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // a-z bold sans-serif
  ["mathitsf", "textitsf", "SansSerif-Italic"],
  // A-Z italic sans-serif
  ["mathitsf", "textitsf", "SansSerif-Italic"],
  // a-z italic sans-serif
  ["", "", ""],
  // A-Z bold italic sans. No font
  ["", "", ""],
  // a-z bold italic sans. No font
  ["mathtt", "texttt", "Typewriter-Regular"],
  // A-Z monospace
  ["mathtt", "texttt", "Typewriter-Regular"]
  // a-z monospace
], oi = [
  ["mathbf", "textbf", "Main-Bold"],
  // 0-9 bold
  ["", "", ""],
  // 0-9 double-struck. No KaTeX font.
  ["mathsf", "textsf", "SansSerif-Regular"],
  // 0-9 sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // 0-9 bold sans-serif
  ["mathtt", "texttt", "Typewriter-Regular"]
  // 0-9 monospace
], g1 = function(e, t) {
  var r = e.charCodeAt(0), a = e.charCodeAt(1), i = (r - 55296) * 1024 + (a - 56320) + 65536, l = t === "math" ? 0 : 1;
  if (119808 <= i && i < 120484) {
    var o = Math.floor((i - 119808) / 26);
    return [pr[o][2], pr[o][l]];
  } else if (120782 <= i && i <= 120831) {
    var u = Math.floor((i - 120782) / 10);
    return [oi[u][2], oi[u][l]];
  } else {
    if (i === 120485 || i === 120486)
      return [pr[0][2], pr[0][l]];
    if (120486 < i && i < 120782)
      return ["", ""];
    throw new X("Unsupported character: " + e);
  }
}, Wr = function(e, t, r) {
  return Fe[r][e] && Fe[r][e].replace && (e = Fe[r][e].replace), {
    value: e,
    metrics: Wn(e, t, r)
  };
}, kt = function(e, t, r, a, i) {
  var l = Wr(e, t, r), o = l.metrics;
  e = l.value;
  var u;
  if (o) {
    var h = o.italic;
    (r === "text" || a && a.font === "mathit") && (h = 0), u = new Lt(e, o.height, o.depth, h, o.skew, o.width, i);
  } else
    typeof console < "u" && console.warn("No character metrics " + ("for '" + e + "' in style '" + t + "' and mode '" + r + "'")), u = new Lt(e, 0, 0, 0, 0, 0, i);
  if (a) {
    u.maxFontSize = a.sizeMultiplier, a.style.isTight() && u.classes.push("mtight");
    var d = a.getColor();
    d && (u.style.color = d);
  }
  return u;
}, v1 = function(e, t, r, a) {
  return a === void 0 && (a = []), r.font === "boldsymbol" && Wr(e, "Main-Bold", t).metrics ? kt(e, "Main-Bold", t, r, a.concat(["mathbf"])) : e === "\\" || Fe[t][e].font === "main" ? kt(e, "Main-Regular", t, r, a) : kt(e, "AMS-Regular", t, r, a.concat(["amsrm"]));
}, _1 = function(e, t, r, a, i) {
  return i !== "textord" && Wr(e, "Math-BoldItalic", t).metrics ? {
    fontName: "Math-BoldItalic",
    fontClass: "boldsymbol"
  } : {
    fontName: "Main-Bold",
    fontClass: "mathbf"
  };
}, b1 = function(e, t, r) {
  var a = e.mode, i = e.text, l = ["mord"], o = a === "math" || a === "text" && t.font, u = o ? t.font : t.fontFamily, h = "", d = "";
  if (i.charCodeAt(0) === 55349 && ([h, d] = g1(i, a)), h.length > 0)
    return kt(i, h, a, t, l.concat(d));
  if (u) {
    var p, b;
    if (u === "boldsymbol") {
      var y = _1(i, a, t, l, r);
      p = y.fontName, b = [y.fontClass];
    } else o ? (p = $l[u].fontName, b = [u]) : (p = gr(u, t.fontWeight, t.fontShape), b = [u, t.fontWeight, t.fontShape]);
    if (Wr(i, p, a).metrics)
      return kt(i, p, a, t, l.concat(b));
    if (Cl.hasOwnProperty(i) && p.slice(0, 10) === "Typewriter") {
      for (var D = [], A = 0; A < i.length; A++)
        D.push(kt(i[A], p, a, t, l.concat(b)));
      return Tl(D);
    }
  }
  if (r === "mathord")
    return kt(i, "Math-Italic", a, t, l.concat(["mathnormal"]));
  if (r === "textord") {
    var C = Fe[a][i] && Fe[a][i].font;
    if (C === "ams") {
      var T = gr("amsrm", t.fontWeight, t.fontShape);
      return kt(i, T, a, t, l.concat("amsrm", t.fontWeight, t.fontShape));
    } else if (C === "main" || !C) {
      var w = gr("textrm", t.fontWeight, t.fontShape);
      return kt(i, w, a, t, l.concat(t.fontWeight, t.fontShape));
    } else {
      var g = gr(C, t.fontWeight, t.fontShape);
      return kt(i, g, a, t, l.concat(g, t.fontWeight, t.fontShape));
    }
  } else
    throw new Error("unexpected type: " + r + " in makeOrd");
}, y1 = (n, e) => {
  if (l0(n.classes) !== l0(e.classes) || n.skew !== e.skew || n.maxFontSize !== e.maxFontSize)
    return !1;
  if (n.classes.length === 1) {
    var t = n.classes[0];
    if (t === "mbin" || t === "mord")
      return !1;
  }
  for (var r in n.style)
    if (n.style.hasOwnProperty(r) && n.style[r] !== e.style[r])
      return !1;
  for (var a in e.style)
    if (e.style.hasOwnProperty(a) && n.style[a] !== e.style[a])
      return !1;
  return !0;
}, w1 = (n) => {
  for (var e = 0; e < n.length - 1; e++) {
    var t = n[e], r = n[e + 1];
    t instanceof Lt && r instanceof Lt && y1(t, r) && (t.text += r.text, t.height = Math.max(t.height, r.height), t.depth = Math.max(t.depth, r.depth), t.italic = r.italic, n.splice(e + 1, 1), e--);
  }
  return n;
}, jn = function(e) {
  for (var t = 0, r = 0, a = 0, i = 0; i < e.children.length; i++) {
    var l = e.children[i];
    l.height > t && (t = l.height), l.depth > r && (r = l.depth), l.maxFontSize > a && (a = l.maxFontSize);
  }
  e.height = t, e.depth = r, e.maxFontSize = a;
}, je = function(e, t, r, a) {
  var i = new Gr(e, t, r, a);
  return jn(i), i;
}, El = (n, e, t, r) => new Gr(n, e, t, r), k1 = function(e, t, r) {
  var a = je([e], [], t);
  return a.height = Math.max(r || t.fontMetrics().defaultRuleThickness, t.minRuleThickness), a.style.borderBottomWidth = L(a.height), a.maxFontSize = 1, a;
}, D1 = function(e, t, r, a) {
  var i = new Fl(e, t, r, a);
  return jn(i), i;
}, Tl = function(e) {
  var t = new rr(e);
  return jn(t), t;
}, x1 = function(e, t) {
  return e instanceof rr ? je([], [e], t) : e;
}, S1 = function(e) {
  if (e.positionType === "individualShift") {
    for (var t = e.children, r = [t[0]], a = -t[0].shift - t[0].elem.depth, i = a, l = 1; l < t.length; l++) {
      var o = -t[l].shift - i - t[l].elem.depth, u = o - (t[l - 1].elem.height + t[l - 1].elem.depth);
      i = i + o, r.push({
        type: "kern",
        size: u
      }), r.push(t[l]);
    }
    return {
      children: r,
      depth: a
    };
  }
  var h;
  if (e.positionType === "top") {
    for (var d = e.positionData, p = 0; p < e.children.length; p++) {
      var b = e.children[p];
      d -= b.type === "kern" ? b.size : b.elem.height + b.elem.depth;
    }
    h = d;
  } else if (e.positionType === "bottom")
    h = -e.positionData;
  else {
    var y = e.children[0];
    if (y.type !== "elem")
      throw new Error('First child must have type "elem".');
    if (e.positionType === "shift")
      h = -y.elem.depth - e.positionData;
    else if (e.positionType === "firstBaseline")
      h = -y.elem.depth;
    else
      throw new Error("Invalid positionType " + e.positionType + ".");
  }
  return {
    children: e.children,
    depth: h
  };
}, A1 = function(e, t) {
  for (var {
    children: r,
    depth: a
  } = S1(e), i = 0, l = 0; l < r.length; l++) {
    var o = r[l];
    if (o.type === "elem") {
      var u = o.elem;
      i = Math.max(i, u.maxFontSize, u.height);
    }
  }
  i += 2;
  var h = je(["pstrut"], []);
  h.style.height = L(i);
  for (var d = [], p = a, b = a, y = a, D = 0; D < r.length; D++) {
    var A = r[D];
    if (A.type === "kern")
      y += A.size;
    else {
      var C = A.elem, T = A.wrapperClasses || [], w = A.wrapperStyle || {}, g = je(T, [h, C], void 0, w);
      g.style.top = L(-i - y - C.depth), A.marginLeft && (g.style.marginLeft = A.marginLeft), A.marginRight && (g.style.marginRight = A.marginRight), d.push(g), y += C.height + C.depth;
    }
    p = Math.min(p, y), b = Math.max(b, y);
  }
  var S = je(["vlist"], d);
  S.style.height = L(b);
  var E;
  if (p < 0) {
    var $ = je([], []), B = je(["vlist"], [$]);
    B.style.height = L(-p);
    var O = je(["vlist-s"], [new Lt("​")]);
    E = [je(["vlist-r"], [S, O]), je(["vlist-r"], [B])];
  } else
    E = [je(["vlist-r"], [S])];
  var M = je(["vlist-t"], E);
  return E.length === 2 && M.classes.push("vlist-t2"), M.height = b, M.depth = -p, M;
}, F1 = (n, e) => {
  var t = je(["mspace"], [], e), r = ke(n, e);
  return t.style.marginRight = L(r), t;
}, gr = function(e, t, r) {
  var a = "";
  switch (e) {
    case "amsrm":
      a = "AMS";
      break;
    case "textrm":
      a = "Main";
      break;
    case "textsf":
      a = "SansSerif";
      break;
    case "texttt":
      a = "Typewriter";
      break;
    default:
      a = e;
  }
  var i;
  return t === "textbf" && r === "textit" ? i = "BoldItalic" : t === "textbf" ? i = "Bold" : t === "textit" ? i = "Italic" : i = "Regular", a + "-" + i;
}, $l = {
  // styles
  mathbf: {
    variant: "bold",
    fontName: "Main-Bold"
  },
  mathrm: {
    variant: "normal",
    fontName: "Main-Regular"
  },
  textit: {
    variant: "italic",
    fontName: "Main-Italic"
  },
  mathit: {
    variant: "italic",
    fontName: "Main-Italic"
  },
  mathnormal: {
    variant: "italic",
    fontName: "Math-Italic"
  },
  // "boldsymbol" is missing because they require the use of multiple fonts:
  // Math-BoldItalic and Main-Bold.  This is handled by a special case in
  // makeOrd which ends up calling boldsymbol.
  // families
  mathbb: {
    variant: "double-struck",
    fontName: "AMS-Regular"
  },
  mathcal: {
    variant: "script",
    fontName: "Caligraphic-Regular"
  },
  mathfrak: {
    variant: "fraktur",
    fontName: "Fraktur-Regular"
  },
  mathscr: {
    variant: "script",
    fontName: "Script-Regular"
  },
  mathsf: {
    variant: "sans-serif",
    fontName: "SansSerif-Regular"
  },
  mathtt: {
    variant: "monospace",
    fontName: "Typewriter-Regular"
  }
}, Ml = {
  //   path, width, height
  vec: ["vec", 0.471, 0.714],
  // values from the font glyph
  oiintSize1: ["oiintSize1", 0.957, 0.499],
  // oval to overlay the integrand
  oiintSize2: ["oiintSize2", 1.472, 0.659],
  oiiintSize1: ["oiiintSize1", 1.304, 0.499],
  oiiintSize2: ["oiiintSize2", 1.98, 0.659]
}, C1 = function(e, t) {
  var [r, a, i] = Ml[e], l = new p0(r), o = new s0([l], {
    width: L(a),
    height: L(i),
    // Override CSS rule `.katex svg { width: 100% }`
    style: "width:" + L(a),
    viewBox: "0 0 " + 1e3 * a + " " + 1e3 * i,
    preserveAspectRatio: "xMinYMin"
  }), u = El(["overlay"], [o], t);
  return u.height = i, u.style.height = L(i), u.style.width = L(a), u;
}, F = {
  fontMap: $l,
  makeSymbol: kt,
  mathsym: v1,
  makeSpan: je,
  makeSvgSpan: El,
  makeLineSpan: k1,
  makeAnchor: D1,
  makeFragment: Tl,
  wrapFragment: x1,
  makeVList: A1,
  makeOrd: b1,
  makeGlue: F1,
  staticSvg: C1,
  svgData: Ml,
  tryCombineChars: w1
}, we = {
  number: 3,
  unit: "mu"
}, h0 = {
  number: 4,
  unit: "mu"
}, Xt = {
  number: 5,
  unit: "mu"
}, E1 = {
  mord: {
    mop: we,
    mbin: h0,
    mrel: Xt,
    minner: we
  },
  mop: {
    mord: we,
    mop: we,
    mrel: Xt,
    minner: we
  },
  mbin: {
    mord: h0,
    mop: h0,
    mopen: h0,
    minner: h0
  },
  mrel: {
    mord: Xt,
    mop: Xt,
    mopen: Xt,
    minner: Xt
  },
  mopen: {},
  mclose: {
    mop: we,
    mbin: h0,
    mrel: Xt,
    minner: we
  },
  mpunct: {
    mord: we,
    mop: we,
    mrel: Xt,
    mopen: we,
    mclose: we,
    mpunct: we,
    minner: we
  },
  minner: {
    mord: we,
    mop: we,
    mbin: h0,
    mrel: Xt,
    mopen: we,
    mpunct: we,
    minner: we
  }
}, T1 = {
  mord: {
    mop: we
  },
  mop: {
    mord: we,
    mop: we
  },
  mbin: {},
  mrel: {},
  mopen: {},
  mclose: {
    mop: we
  },
  mpunct: {},
  minner: {
    mop: we
  }
}, zl = {}, qr = {}, Nr = {};
function P(n) {
  for (var {
    type: e,
    names: t,
    props: r,
    handler: a,
    htmlBuilder: i,
    mathmlBuilder: l
  } = n, o = {
    type: e,
    numArgs: r.numArgs,
    argTypes: r.argTypes,
    allowedInArgument: !!r.allowedInArgument,
    allowedInText: !!r.allowedInText,
    allowedInMath: r.allowedInMath === void 0 ? !0 : r.allowedInMath,
    numOptionalArgs: r.numOptionalArgs || 0,
    infix: !!r.infix,
    primitive: !!r.primitive,
    handler: a
  }, u = 0; u < t.length; ++u)
    zl[t[u]] = o;
  e && (i && (qr[e] = i), l && (Nr[e] = l));
}
function _0(n) {
  var {
    type: e,
    htmlBuilder: t,
    mathmlBuilder: r
  } = n;
  P({
    type: e,
    names: [],
    props: {
      numArgs: 0
    },
    handler() {
      throw new Error("Should never be called.");
    },
    htmlBuilder: t,
    mathmlBuilder: r
  });
}
var Ir = function(e) {
  return e.type === "ordgroup" && e.body.length === 1 ? e.body[0] : e;
}, Ae = function(e) {
  return e.type === "ordgroup" ? e.body : [e];
}, B0 = F.makeSpan, $1 = ["leftmost", "mbin", "mopen", "mrel", "mop", "mpunct"], M1 = ["rightmost", "mrel", "mclose", "mpunct"], z1 = {
  display: J.DISPLAY,
  text: J.TEXT,
  script: J.SCRIPT,
  scriptscript: J.SCRIPTSCRIPT
}, B1 = {
  mord: "mord",
  mop: "mop",
  mbin: "mbin",
  mrel: "mrel",
  mopen: "mopen",
  mclose: "mclose",
  mpunct: "mpunct",
  minner: "minner"
}, qe = function(e, t, r, a) {
  a === void 0 && (a = [null, null]);
  for (var i = [], l = 0; l < e.length; l++) {
    var o = se(e[l], t);
    if (o instanceof rr) {
      var u = o.children;
      i.push(...u);
    } else
      i.push(o);
  }
  if (F.tryCombineChars(i), !r)
    return i;
  var h = t;
  if (e.length === 1) {
    var d = e[0];
    d.type === "sizing" ? h = t.havingSize(d.size) : d.type === "styling" && (h = t.havingStyle(z1[d.style]));
  }
  var p = B0([a[0] || "leftmost"], [], t), b = B0([a[1] || "rightmost"], [], t), y = r === "root";
  return ui(i, (D, A) => {
    var C = A.classes[0], T = D.classes[0];
    C === "mbin" && K.contains(M1, T) ? A.classes[0] = "mord" : T === "mbin" && K.contains($1, C) && (D.classes[0] = "mord");
  }, {
    node: p
  }, b, y), ui(i, (D, A) => {
    var C = $n(A), T = $n(D), w = C && T ? D.hasClass("mtight") ? T1[C][T] : E1[C][T] : null;
    if (w)
      return F.makeGlue(w, h);
  }, {
    node: p
  }, b, y), i;
}, ui = function n(e, t, r, a, i) {
  a && e.push(a);
  for (var l = 0; l < e.length; l++) {
    var o = e[l], u = Bl(o);
    if (u) {
      n(u.children, t, r, null, i);
      continue;
    }
    var h = !o.hasClass("mspace");
    if (h) {
      var d = t(o, r.node);
      d && (r.insertAfter ? r.insertAfter(d) : (e.unshift(d), l++));
    }
    h ? r.node = o : i && o.hasClass("newline") && (r.node = B0(["leftmost"])), r.insertAfter = /* @__PURE__ */ ((p) => (b) => {
      e.splice(p + 1, 0, b), l++;
    })(l);
  }
  a && e.pop();
}, Bl = function(e) {
  return e instanceof rr || e instanceof Fl || e instanceof Gr && e.hasClass("enclosing") ? e : null;
}, R1 = function n(e, t) {
  var r = Bl(e);
  if (r) {
    var a = r.children;
    if (a.length) {
      if (t === "right")
        return n(a[a.length - 1], "right");
      if (t === "left")
        return n(a[0], "left");
    }
  }
  return e;
}, $n = function(e, t) {
  return e ? (t && (e = R1(e, t)), B1[e.classes[0]] || null) : null;
}, er = function(e, t) {
  var r = ["nulldelimiter"].concat(e.baseSizingClasses());
  return B0(t.concat(r));
}, se = function(e, t, r) {
  if (!e)
    return B0();
  if (qr[e.type]) {
    var a = qr[e.type](e, t);
    if (r && t.size !== r.size) {
      a = B0(t.sizingClasses(r), [a], t);
      var i = t.sizeMultiplier / r.sizeMultiplier;
      a.height *= i, a.depth *= i;
    }
    return a;
  } else
    throw new X("Got group of unknown type: '" + e.type + "'");
};
function Rl(n) {
  return new rr(n);
}
class Dt {
  constructor(e, t, r) {
    this.type = void 0, this.attributes = void 0, this.children = void 0, this.classes = void 0, this.type = e, this.attributes = {}, this.children = t || [], this.classes = r || [];
  }
  /**
   * Sets an attribute on a MathML node. MathML depends on attributes to convey a
   * semantic content, so this is used heavily.
   */
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  /**
   * Gets an attribute on a MathML node.
   */
  getAttribute(e) {
    return this.attributes[e];
  }
  /**
   * Converts the math node into a MathML-namespaced DOM element.
   */
  toNode() {
    var e = document.createElementNS("http://www.w3.org/1998/Math/MathML", this.type);
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && e.setAttribute(t, this.attributes[t]);
    this.classes.length > 0 && (e.className = l0(this.classes));
    for (var r = 0; r < this.children.length; r++)
      e.appendChild(this.children[r].toNode());
    return e;
  }
  /**
   * Converts the math node into an HTML markup string.
   */
  toMarkup() {
    var e = "<" + this.type;
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="', e += K.escape(this.attributes[t]), e += '"');
    this.classes.length > 0 && (e += ' class ="' + K.escape(l0(this.classes)) + '"'), e += ">";
    for (var r = 0; r < this.children.length; r++)
      e += this.children[r].toMarkup();
    return e += "</" + this.type + ">", e;
  }
  /**
   * Converts the math node into a string, similar to innerText, but escaped.
   */
  toText() {
    return this.children.map((e) => e.toText()).join("");
  }
}
class j0 {
  constructor(e) {
    this.text = void 0, this.text = e;
  }
  /**
   * Converts the text node into a DOM text node.
   */
  toNode() {
    return document.createTextNode(this.text);
  }
  /**
   * Converts the text node into escaped HTML markup
   * (representing the text itself).
   */
  toMarkup() {
    return K.escape(this.toText());
  }
  /**
   * Converts the text node into a string
   * (representing the text itself).
   */
  toText() {
    return this.text;
  }
}
class q1 {
  /**
   * Create a Space node with width given in CSS ems.
   */
  constructor(e) {
    this.width = void 0, this.character = void 0, this.width = e, e >= 0.05555 && e <= 0.05556 ? this.character = " " : e >= 0.1666 && e <= 0.1667 ? this.character = " " : e >= 0.2222 && e <= 0.2223 ? this.character = " " : e >= 0.2777 && e <= 0.2778 ? this.character = "  " : e >= -0.05556 && e <= -0.05555 ? this.character = " ⁣" : e >= -0.1667 && e <= -0.1666 ? this.character = " ⁣" : e >= -0.2223 && e <= -0.2222 ? this.character = " ⁣" : e >= -0.2778 && e <= -0.2777 ? this.character = " ⁣" : this.character = null;
  }
  /**
   * Converts the math node into a MathML-namespaced DOM element.
   */
  toNode() {
    if (this.character)
      return document.createTextNode(this.character);
    var e = document.createElementNS("http://www.w3.org/1998/Math/MathML", "mspace");
    return e.setAttribute("width", L(this.width)), e;
  }
  /**
   * Converts the math node into an HTML markup string.
   */
  toMarkup() {
    return this.character ? "<mtext>" + this.character + "</mtext>" : '<mspace width="' + L(this.width) + '"/>';
  }
  /**
   * Converts the math node into a string, similar to innerText.
   */
  toText() {
    return this.character ? this.character : " ";
  }
}
var q = {
  MathNode: Dt,
  TextNode: j0,
  SpaceNode: q1,
  newDocumentFragment: Rl
}, ot = function(e, t, r) {
  return Fe[t][e] && Fe[t][e].replace && e.charCodeAt(0) !== 55349 && !(Cl.hasOwnProperty(e) && r && (r.fontFamily && r.fontFamily.slice(4, 6) === "tt" || r.font && r.font.slice(4, 6) === "tt")) && (e = Fe[t][e].replace), new q.TextNode(e);
}, Xn = function(e) {
  return e.length === 1 ? e[0] : new q.MathNode("mrow", e);
}, Zn = function(e, t) {
  if (t.fontFamily === "texttt")
    return "monospace";
  if (t.fontFamily === "textsf")
    return t.fontShape === "textit" && t.fontWeight === "textbf" ? "sans-serif-bold-italic" : t.fontShape === "textit" ? "sans-serif-italic" : t.fontWeight === "textbf" ? "bold-sans-serif" : "sans-serif";
  if (t.fontShape === "textit" && t.fontWeight === "textbf")
    return "bold-italic";
  if (t.fontShape === "textit")
    return "italic";
  if (t.fontWeight === "textbf")
    return "bold";
  var r = t.font;
  if (!r || r === "mathnormal")
    return null;
  var a = e.mode;
  if (r === "mathit")
    return "italic";
  if (r === "boldsymbol")
    return e.type === "textord" ? "bold" : "bold-italic";
  if (r === "mathbf")
    return "bold";
  if (r === "mathbb")
    return "double-struck";
  if (r === "mathfrak")
    return "fraktur";
  if (r === "mathscr" || r === "mathcal")
    return "script";
  if (r === "mathsf")
    return "sans-serif";
  if (r === "mathtt")
    return "monospace";
  var i = e.text;
  if (K.contains(["\\imath", "\\jmath"], i))
    return null;
  Fe[a][i] && Fe[a][i].replace && (i = Fe[a][i].replace);
  var l = F.fontMap[r].fontName;
  return Wn(i, l, a) ? F.fontMap[r].variant : null;
}, rt = function(e, t, r) {
  if (e.length === 1) {
    var a = pe(e[0], t);
    return r && a instanceof Dt && a.type === "mo" && (a.setAttribute("lspace", "0em"), a.setAttribute("rspace", "0em")), [a];
  }
  for (var i = [], l, o = 0; o < e.length; o++) {
    var u = pe(e[o], t);
    if (u instanceof Dt && l instanceof Dt) {
      if (u.type === "mtext" && l.type === "mtext" && u.getAttribute("mathvariant") === l.getAttribute("mathvariant")) {
        l.children.push(...u.children);
        continue;
      } else if (u.type === "mn" && l.type === "mn") {
        l.children.push(...u.children);
        continue;
      } else if (u.type === "mi" && u.children.length === 1 && l.type === "mn") {
        var h = u.children[0];
        if (h instanceof j0 && h.text === ".") {
          l.children.push(...u.children);
          continue;
        }
      } else if (l.type === "mi" && l.children.length === 1) {
        var d = l.children[0];
        if (d instanceof j0 && d.text === "̸" && (u.type === "mo" || u.type === "mi" || u.type === "mn")) {
          var p = u.children[0];
          p instanceof j0 && p.text.length > 0 && (p.text = p.text.slice(0, 1) + "̸" + p.text.slice(1), i.pop());
        }
      }
    }
    i.push(u), l = u;
  }
  return i;
}, o0 = function(e, t, r) {
  return Xn(rt(e, t, r));
}, pe = function(e, t) {
  if (!e)
    return new q.MathNode("mrow");
  if (Nr[e.type]) {
    var r = Nr[e.type](e, t);
    return r;
  } else
    throw new X("Got group of unknown type: '" + e.type + "'");
}, N1 = {
  widehat: "^",
  widecheck: "ˇ",
  widetilde: "~",
  utilde: "~",
  overleftarrow: "←",
  underleftarrow: "←",
  xleftarrow: "←",
  overrightarrow: "→",
  underrightarrow: "→",
  xrightarrow: "→",
  underbrace: "⏟",
  overbrace: "⏞",
  overgroup: "⏠",
  undergroup: "⏡",
  overleftrightarrow: "↔",
  underleftrightarrow: "↔",
  xleftrightarrow: "↔",
  Overrightarrow: "⇒",
  xRightarrow: "⇒",
  overleftharpoon: "↼",
  xleftharpoonup: "↼",
  overrightharpoon: "⇀",
  xrightharpoonup: "⇀",
  xLeftarrow: "⇐",
  xLeftrightarrow: "⇔",
  xhookleftarrow: "↩",
  xhookrightarrow: "↪",
  xmapsto: "↦",
  xrightharpoondown: "⇁",
  xleftharpoondown: "↽",
  xrightleftharpoons: "⇌",
  xleftrightharpoons: "⇋",
  xtwoheadleftarrow: "↞",
  xtwoheadrightarrow: "↠",
  xlongequal: "=",
  xtofrom: "⇄",
  xrightleftarrows: "⇄",
  xrightequilibrium: "⇌",
  // Not a perfect match.
  xleftequilibrium: "⇋",
  // None better available.
  "\\cdrightarrow": "→",
  "\\cdleftarrow": "←",
  "\\cdlongequal": "="
}, I1 = function(e) {
  var t = new q.MathNode("mo", [new q.TextNode(N1[e.replace(/^\\/, "")])]);
  return t.setAttribute("stretchy", "true"), t;
}, L1 = {
  //   path(s), minWidth, height, align
  overrightarrow: [["rightarrow"], 0.888, 522, "xMaxYMin"],
  overleftarrow: [["leftarrow"], 0.888, 522, "xMinYMin"],
  underrightarrow: [["rightarrow"], 0.888, 522, "xMaxYMin"],
  underleftarrow: [["leftarrow"], 0.888, 522, "xMinYMin"],
  xrightarrow: [["rightarrow"], 1.469, 522, "xMaxYMin"],
  "\\cdrightarrow": [["rightarrow"], 3, 522, "xMaxYMin"],
  // CD minwwidth2.5pc
  xleftarrow: [["leftarrow"], 1.469, 522, "xMinYMin"],
  "\\cdleftarrow": [["leftarrow"], 3, 522, "xMinYMin"],
  Overrightarrow: [["doublerightarrow"], 0.888, 560, "xMaxYMin"],
  xRightarrow: [["doublerightarrow"], 1.526, 560, "xMaxYMin"],
  xLeftarrow: [["doubleleftarrow"], 1.526, 560, "xMinYMin"],
  overleftharpoon: [["leftharpoon"], 0.888, 522, "xMinYMin"],
  xleftharpoonup: [["leftharpoon"], 0.888, 522, "xMinYMin"],
  xleftharpoondown: [["leftharpoondown"], 0.888, 522, "xMinYMin"],
  overrightharpoon: [["rightharpoon"], 0.888, 522, "xMaxYMin"],
  xrightharpoonup: [["rightharpoon"], 0.888, 522, "xMaxYMin"],
  xrightharpoondown: [["rightharpoondown"], 0.888, 522, "xMaxYMin"],
  xlongequal: [["longequal"], 0.888, 334, "xMinYMin"],
  "\\cdlongequal": [["longequal"], 3, 334, "xMinYMin"],
  xtwoheadleftarrow: [["twoheadleftarrow"], 0.888, 334, "xMinYMin"],
  xtwoheadrightarrow: [["twoheadrightarrow"], 0.888, 334, "xMaxYMin"],
  overleftrightarrow: [["leftarrow", "rightarrow"], 0.888, 522],
  overbrace: [["leftbrace", "midbrace", "rightbrace"], 1.6, 548],
  underbrace: [["leftbraceunder", "midbraceunder", "rightbraceunder"], 1.6, 548],
  underleftrightarrow: [["leftarrow", "rightarrow"], 0.888, 522],
  xleftrightarrow: [["leftarrow", "rightarrow"], 1.75, 522],
  xLeftrightarrow: [["doubleleftarrow", "doublerightarrow"], 1.75, 560],
  xrightleftharpoons: [["leftharpoondownplus", "rightharpoonplus"], 1.75, 716],
  xleftrightharpoons: [["leftharpoonplus", "rightharpoondownplus"], 1.75, 716],
  xhookleftarrow: [["leftarrow", "righthook"], 1.08, 522],
  xhookrightarrow: [["lefthook", "rightarrow"], 1.08, 522],
  overlinesegment: [["leftlinesegment", "rightlinesegment"], 0.888, 522],
  underlinesegment: [["leftlinesegment", "rightlinesegment"], 0.888, 522],
  overgroup: [["leftgroup", "rightgroup"], 0.888, 342],
  undergroup: [["leftgroupunder", "rightgroupunder"], 0.888, 342],
  xmapsto: [["leftmapsto", "rightarrow"], 1.5, 522],
  xtofrom: [["leftToFrom", "rightToFrom"], 1.75, 528],
  // The next three arrows are from the mhchem package.
  // In mhchem.sty, min-length is 2.0em. But these arrows might appear in the
  // document as \xrightarrow or \xrightleftharpoons. Those have
  // min-length = 1.75em, so we set min-length on these next three to match.
  xrightleftarrows: [["baraboveleftarrow", "rightarrowabovebar"], 1.75, 901],
  xrightequilibrium: [["baraboveshortleftharpoon", "rightharpoonaboveshortbar"], 1.75, 716],
  xleftequilibrium: [["shortbaraboveleftharpoon", "shortrightharpoonabovebar"], 1.75, 716]
}, O1 = function(e) {
  return e.type === "ordgroup" ? e.body.length : 1;
}, P1 = function(e, t) {
  function r() {
    var o = 4e5, u = e.label.slice(1);
    if (K.contains(["widehat", "widecheck", "widetilde", "utilde"], u)) {
      var h = e, d = O1(h.base), p, b, y;
      if (d > 5)
        u === "widehat" || u === "widecheck" ? (p = 420, o = 2364, y = 0.42, b = u + "4") : (p = 312, o = 2340, y = 0.34, b = "tilde4");
      else {
        var D = [1, 1, 2, 2, 3, 3][d];
        u === "widehat" || u === "widecheck" ? (o = [0, 1062, 2364, 2364, 2364][D], p = [0, 239, 300, 360, 420][D], y = [0, 0.24, 0.3, 0.3, 0.36, 0.42][D], b = u + D) : (o = [0, 600, 1033, 2339, 2340][D], p = [0, 260, 286, 306, 312][D], y = [0, 0.26, 0.286, 0.3, 0.306, 0.34][D], b = "tilde" + D);
      }
      var A = new p0(b), C = new s0([A], {
        width: "100%",
        height: L(y),
        viewBox: "0 0 " + o + " " + p,
        preserveAspectRatio: "none"
      });
      return {
        span: F.makeSvgSpan([], [C], t),
        minWidth: 0,
        height: y
      };
    } else {
      var T = [], w = L1[u], [g, S, E] = w, $ = E / 1e3, B = g.length, O, M;
      if (B === 1) {
        var R = w[3];
        O = ["hide-tail"], M = [R];
      } else if (B === 2)
        O = ["halfarrow-left", "halfarrow-right"], M = ["xMinYMin", "xMaxYMin"];
      else if (B === 3)
        O = ["brace-left", "brace-center", "brace-right"], M = ["xMinYMin", "xMidYMin", "xMaxYMin"];
      else
        throw new Error(`Correct katexImagesData or update code here to support
                    ` + B + " children.");
      for (var W = 0; W < B; W++) {
        var Q = new p0(g[W]), G = new s0([Q], {
          width: "400em",
          height: L($),
          viewBox: "0 0 " + o + " " + E,
          preserveAspectRatio: M[W] + " slice"
        }), U = F.makeSvgSpan([O[W]], [G], t);
        if (B === 1)
          return {
            span: U,
            minWidth: S,
            height: $
          };
        U.style.height = L($), T.push(U);
      }
      return {
        span: F.makeSpan(["stretchy"], T, t),
        minWidth: S,
        height: $
      };
    }
  }
  var {
    span: a,
    minWidth: i,
    height: l
  } = r();
  return a.height = l, a.style.height = L(l), i > 0 && (a.style.minWidth = L(i)), a;
}, H1 = function(e, t, r, a, i) {
  var l, o = e.height + e.depth + r + a;
  if (/fbox|color|angl/.test(t)) {
    if (l = F.makeSpan(["stretchy", t], [], i), t === "fbox") {
      var u = i.color && i.getColor();
      u && (l.style.borderColor = u);
    }
  } else {
    var h = [];
    /^[bx]cancel$/.test(t) && h.push(new ti({
      x1: "0",
      y1: "0",
      x2: "100%",
      y2: "100%",
      "stroke-width": "0.046em"
    })), /^x?cancel$/.test(t) && h.push(new ti({
      x1: "0",
      y1: "100%",
      x2: "100%",
      y2: "0",
      "stroke-width": "0.046em"
    }));
    var d = new s0(h, {
      width: "100%",
      height: L(o)
    });
    l = F.makeSvgSpan([], [d], i);
  }
  return l.height = o, l.style.height = L(o), l;
}, e0 = {
  encloseSpan: H1,
  mathMLnode: I1,
  svgSpan: P1
};
function ne(n, e) {
  if (!n || n.type !== e)
    throw new Error("Expected node of type " + e + ", but got " + (n ? "node of type " + n.type : String(n)));
  return n;
}
function Kn(n) {
  var e = jr(n);
  if (!e)
    throw new Error("Expected node of symbol group type, but got " + (n ? "node of type " + n.type : String(n)));
  return e;
}
function jr(n) {
  return n && (n.type === "atom" || p1.hasOwnProperty(n.type)) ? n : null;
}
var Qn = (n, e) => {
  var t, r, a;
  n && n.type === "supsub" ? (r = ne(n.base, "accent"), t = r.base, n.base = t, a = f1(se(n, e)), n.base = r) : (r = ne(n, "accent"), t = r.base);
  var i = se(t, e.havingCrampedStyle()), l = r.isShifty && K.isCharacterBox(t), o = 0;
  if (l) {
    var u = K.getBaseElem(t), h = se(u, e.havingCrampedStyle());
    o = ri(h).skew;
  }
  var d = r.label === "\\c", p = d ? i.height + i.depth : Math.min(i.height, e.fontMetrics().xHeight), b;
  if (r.isStretchy)
    b = e0.svgSpan(r, e), b = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: i
      }, {
        type: "elem",
        elem: b,
        wrapperClasses: ["svg-align"],
        wrapperStyle: o > 0 ? {
          width: "calc(100% - " + L(2 * o) + ")",
          marginLeft: L(2 * o)
        } : void 0
      }]
    }, e);
  else {
    var y, D;
    r.label === "\\vec" ? (y = F.staticSvg("vec", e), D = F.svgData.vec[1]) : (y = F.makeOrd({
      mode: r.mode,
      text: r.label
    }, e, "textord"), y = ri(y), y.italic = 0, D = y.width, d && (p += y.depth)), b = F.makeSpan(["accent-body"], [y]);
    var A = r.label === "\\textcircled";
    A && (b.classes.push("accent-full"), p = i.height);
    var C = o;
    A || (C -= D / 2), b.style.left = L(C), r.label === "\\textcircled" && (b.style.top = ".2em"), b = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: i
      }, {
        type: "kern",
        size: -p
      }, {
        type: "elem",
        elem: b
      }]
    }, e);
  }
  var T = F.makeSpan(["mord", "accent"], [b], e);
  return a ? (a.children[0] = T, a.height = Math.max(T.height, a.height), a.classes[0] = "mord", a) : T;
}, ql = (n, e) => {
  var t = n.isStretchy ? e0.mathMLnode(n.label) : new q.MathNode("mo", [ot(n.label, n.mode)]), r = new q.MathNode("mover", [pe(n.base, e), t]);
  return r.setAttribute("accent", "true"), r;
}, U1 = new RegExp(["\\acute", "\\grave", "\\ddot", "\\tilde", "\\bar", "\\breve", "\\check", "\\hat", "\\vec", "\\dot", "\\mathring"].map((n) => "\\" + n).join("|"));
P({
  type: "accent",
  names: ["\\acute", "\\grave", "\\ddot", "\\tilde", "\\bar", "\\breve", "\\check", "\\hat", "\\vec", "\\dot", "\\mathring", "\\widecheck", "\\widehat", "\\widetilde", "\\overrightarrow", "\\overleftarrow", "\\Overrightarrow", "\\overleftrightarrow", "\\overgroup", "\\overlinesegment", "\\overleftharpoon", "\\overrightharpoon"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var t = Ir(e[0]), r = !U1.test(n.funcName), a = !r || n.funcName === "\\widehat" || n.funcName === "\\widetilde" || n.funcName === "\\widecheck";
    return {
      type: "accent",
      mode: n.parser.mode,
      label: n.funcName,
      isStretchy: r,
      isShifty: a,
      base: t
    };
  },
  htmlBuilder: Qn,
  mathmlBuilder: ql
});
P({
  type: "accent",
  names: ["\\'", "\\`", "\\^", "\\~", "\\=", "\\u", "\\.", '\\"', "\\c", "\\r", "\\H", "\\v", "\\textcircled"],
  props: {
    numArgs: 1,
    allowedInText: !0,
    allowedInMath: !0,
    // unless in strict mode
    argTypes: ["primitive"]
  },
  handler: (n, e) => {
    var t = e[0], r = n.parser.mode;
    return r === "math" && (n.parser.settings.reportNonstrict("mathVsTextAccents", "LaTeX's accent " + n.funcName + " works only in text mode"), r = "text"), {
      type: "accent",
      mode: r,
      label: n.funcName,
      isStretchy: !1,
      isShifty: !0,
      base: t
    };
  },
  htmlBuilder: Qn,
  mathmlBuilder: ql
});
P({
  type: "accentUnder",
  names: ["\\underleftarrow", "\\underrightarrow", "\\underleftrightarrow", "\\undergroup", "\\underlinesegment", "\\utilde"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "accentUnder",
      mode: t.mode,
      label: r,
      base: a
    };
  },
  htmlBuilder: (n, e) => {
    var t = se(n.base, e), r = e0.svgSpan(n, e), a = n.label === "\\utilde" ? 0.12 : 0, i = F.makeVList({
      positionType: "top",
      positionData: t.height,
      children: [{
        type: "elem",
        elem: r,
        wrapperClasses: ["svg-align"]
      }, {
        type: "kern",
        size: a
      }, {
        type: "elem",
        elem: t
      }]
    }, e);
    return F.makeSpan(["mord", "accentunder"], [i], e);
  },
  mathmlBuilder: (n, e) => {
    var t = e0.mathMLnode(n.label), r = new q.MathNode("munder", [pe(n.base, e), t]);
    return r.setAttribute("accentunder", "true"), r;
  }
});
var vr = (n) => {
  var e = new q.MathNode("mpadded", n ? [n] : []);
  return e.setAttribute("width", "+0.6em"), e.setAttribute("lspace", "0.3em"), e;
};
P({
  type: "xArrow",
  names: [
    "\\xleftarrow",
    "\\xrightarrow",
    "\\xLeftarrow",
    "\\xRightarrow",
    "\\xleftrightarrow",
    "\\xLeftrightarrow",
    "\\xhookleftarrow",
    "\\xhookrightarrow",
    "\\xmapsto",
    "\\xrightharpoondown",
    "\\xrightharpoonup",
    "\\xleftharpoondown",
    "\\xleftharpoonup",
    "\\xrightleftharpoons",
    "\\xleftrightharpoons",
    "\\xlongequal",
    "\\xtwoheadrightarrow",
    "\\xtwoheadleftarrow",
    "\\xtofrom",
    // The next 3 functions are here to support the mhchem extension.
    // Direct use of these functions is discouraged and may break someday.
    "\\xrightleftarrows",
    "\\xrightequilibrium",
    "\\xleftequilibrium",
    // The next 3 functions are here only to support the {CD} environment.
    "\\\\cdrightarrow",
    "\\\\cdleftarrow",
    "\\\\cdlongequal"
  ],
  props: {
    numArgs: 1,
    numOptionalArgs: 1
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n;
    return {
      type: "xArrow",
      mode: r.mode,
      label: a,
      body: e[0],
      below: t[0]
    };
  },
  // Flow is unable to correctly infer the type of `group`, even though it's
  // unambiguously determined from the passed-in `type` above.
  htmlBuilder(n, e) {
    var t = e.style, r = e.havingStyle(t.sup()), a = F.wrapFragment(se(n.body, r, e), e), i = n.label.slice(0, 2) === "\\x" ? "x" : "cd";
    a.classes.push(i + "-arrow-pad");
    var l;
    n.below && (r = e.havingStyle(t.sub()), l = F.wrapFragment(se(n.below, r, e), e), l.classes.push(i + "-arrow-pad"));
    var o = e0.svgSpan(n, e), u = -e.fontMetrics().axisHeight + 0.5 * o.height, h = -e.fontMetrics().axisHeight - 0.5 * o.height - 0.111;
    (a.depth > 0.25 || n.label === "\\xleftequilibrium") && (h -= a.depth);
    var d;
    if (l) {
      var p = -e.fontMetrics().axisHeight + l.height + 0.5 * o.height + 0.111;
      d = F.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: a,
          shift: h
        }, {
          type: "elem",
          elem: o,
          shift: u
        }, {
          type: "elem",
          elem: l,
          shift: p
        }]
      }, e);
    } else
      d = F.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: a,
          shift: h
        }, {
          type: "elem",
          elem: o,
          shift: u
        }]
      }, e);
    return d.children[0].children[0].children[1].classes.push("svg-align"), F.makeSpan(["mrel", "x-arrow"], [d], e);
  },
  mathmlBuilder(n, e) {
    var t = e0.mathMLnode(n.label);
    t.setAttribute("minsize", n.label.charAt(0) === "x" ? "1.75em" : "3.0em");
    var r;
    if (n.body) {
      var a = vr(pe(n.body, e));
      if (n.below) {
        var i = vr(pe(n.below, e));
        r = new q.MathNode("munderover", [t, i, a]);
      } else
        r = new q.MathNode("mover", [t, a]);
    } else if (n.below) {
      var l = vr(pe(n.below, e));
      r = new q.MathNode("munder", [t, l]);
    } else
      r = vr(), r = new q.MathNode("mover", [t, r]);
    return r;
  }
});
var V1 = F.makeSpan;
function Nl(n, e) {
  var t = qe(n.body, e, !0);
  return V1([n.mclass], t, e);
}
function Il(n, e) {
  var t, r = rt(n.body, e);
  return n.mclass === "minner" ? t = new q.MathNode("mpadded", r) : n.mclass === "mord" ? n.isCharacterBox ? (t = r[0], t.type = "mi") : t = new q.MathNode("mi", r) : (n.isCharacterBox ? (t = r[0], t.type = "mo") : t = new q.MathNode("mo", r), n.mclass === "mbin" ? (t.attributes.lspace = "0.22em", t.attributes.rspace = "0.22em") : n.mclass === "mpunct" ? (t.attributes.lspace = "0em", t.attributes.rspace = "0.17em") : n.mclass === "mopen" || n.mclass === "mclose" ? (t.attributes.lspace = "0em", t.attributes.rspace = "0em") : n.mclass === "minner" && (t.attributes.lspace = "0.0556em", t.attributes.width = "+0.1111em")), t;
}
P({
  type: "mclass",
  names: ["\\mathord", "\\mathbin", "\\mathrel", "\\mathopen", "\\mathclose", "\\mathpunct", "\\mathinner"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "mclass",
      mode: t.mode,
      mclass: "m" + r.slice(5),
      // TODO(kevinb): don't prefix with 'm'
      body: Ae(a),
      isCharacterBox: K.isCharacterBox(a)
    };
  },
  htmlBuilder: Nl,
  mathmlBuilder: Il
});
var Xr = (n) => {
  var e = n.type === "ordgroup" && n.body.length ? n.body[0] : n;
  return e.type === "atom" && (e.family === "bin" || e.family === "rel") ? "m" + e.family : "mord";
};
P({
  type: "mclass",
  names: ["\\@binrel"],
  props: {
    numArgs: 2
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "mclass",
      mode: t.mode,
      mclass: Xr(e[0]),
      body: Ae(e[1]),
      isCharacterBox: K.isCharacterBox(e[1])
    };
  }
});
P({
  type: "mclass",
  names: ["\\stackrel", "\\overset", "\\underset"],
  props: {
    numArgs: 2
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[1], i = e[0], l;
    r !== "\\stackrel" ? l = Xr(a) : l = "mrel";
    var o = {
      type: "op",
      mode: a.mode,
      limits: !0,
      alwaysHandleSupSub: !0,
      parentIsSupSub: !1,
      symbol: !1,
      suppressBaseShift: r !== "\\stackrel",
      body: Ae(a)
    }, u = {
      type: "supsub",
      mode: i.mode,
      base: o,
      sup: r === "\\underset" ? null : i,
      sub: r === "\\underset" ? i : null
    };
    return {
      type: "mclass",
      mode: t.mode,
      mclass: l,
      body: [u],
      isCharacterBox: K.isCharacterBox(u)
    };
  },
  htmlBuilder: Nl,
  mathmlBuilder: Il
});
P({
  type: "pmb",
  names: ["\\pmb"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "pmb",
      mode: t.mode,
      mclass: Xr(e[0]),
      body: Ae(e[0])
    };
  },
  htmlBuilder(n, e) {
    var t = qe(n.body, e, !0), r = F.makeSpan([n.mclass], t, e);
    return r.style.textShadow = "0.02em 0.01em 0.04px", r;
  },
  mathmlBuilder(n, e) {
    var t = rt(n.body, e), r = new q.MathNode("mstyle", t);
    return r.setAttribute("style", "text-shadow: 0.02em 0.01em 0.04px"), r;
  }
});
var G1 = {
  ">": "\\\\cdrightarrow",
  "<": "\\\\cdleftarrow",
  "=": "\\\\cdlongequal",
  A: "\\uparrow",
  V: "\\downarrow",
  "|": "\\Vert",
  ".": "no arrow"
}, ci = () => ({
  type: "styling",
  body: [],
  mode: "math",
  style: "display"
}), hi = (n) => n.type === "textord" && n.text === "@", Y1 = (n, e) => (n.type === "mathord" || n.type === "atom") && n.text === e;
function W1(n, e, t) {
  var r = G1[n];
  switch (r) {
    case "\\\\cdrightarrow":
    case "\\\\cdleftarrow":
      return t.callFunction(r, [e[0]], [e[1]]);
    case "\\uparrow":
    case "\\downarrow": {
      var a = t.callFunction("\\\\cdleft", [e[0]], []), i = {
        type: "atom",
        text: r,
        mode: "math",
        family: "rel"
      }, l = t.callFunction("\\Big", [i], []), o = t.callFunction("\\\\cdright", [e[1]], []), u = {
        type: "ordgroup",
        mode: "math",
        body: [a, l, o]
      };
      return t.callFunction("\\\\cdparent", [u], []);
    }
    case "\\\\cdlongequal":
      return t.callFunction("\\\\cdlongequal", [], []);
    case "\\Vert": {
      var h = {
        type: "textord",
        text: "\\Vert",
        mode: "math"
      };
      return t.callFunction("\\Big", [h], []);
    }
    default:
      return {
        type: "textord",
        text: " ",
        mode: "math"
      };
  }
}
function j1(n) {
  var e = [];
  for (n.gullet.beginGroup(), n.gullet.macros.set("\\cr", "\\\\\\relax"), n.gullet.beginGroup(); ; ) {
    e.push(n.parseExpression(!1, "\\\\")), n.gullet.endGroup(), n.gullet.beginGroup();
    var t = n.fetch().text;
    if (t === "&" || t === "\\\\")
      n.consume();
    else if (t === "\\end") {
      e[e.length - 1].length === 0 && e.pop();
      break;
    } else
      throw new X("Expected \\\\ or \\cr or \\end", n.nextToken);
  }
  for (var r = [], a = [r], i = 0; i < e.length; i++) {
    for (var l = e[i], o = ci(), u = 0; u < l.length; u++)
      if (!hi(l[u]))
        o.body.push(l[u]);
      else {
        r.push(o), u += 1;
        var h = Kn(l[u]).text, d = new Array(2);
        if (d[0] = {
          type: "ordgroup",
          mode: "math",
          body: []
        }, d[1] = {
          type: "ordgroup",
          mode: "math",
          body: []
        }, !("=|.".indexOf(h) > -1)) if ("<>AV".indexOf(h) > -1)
          for (var p = 0; p < 2; p++) {
            for (var b = !0, y = u + 1; y < l.length; y++) {
              if (Y1(l[y], h)) {
                b = !1, u = y;
                break;
              }
              if (hi(l[y]))
                throw new X("Missing a " + h + " character to complete a CD arrow.", l[y]);
              d[p].body.push(l[y]);
            }
            if (b)
              throw new X("Missing a " + h + " character to complete a CD arrow.", l[u]);
          }
        else
          throw new X('Expected one of "<>AV=|." after @', l[u]);
        var D = W1(h, d, n), A = {
          type: "styling",
          body: [D],
          mode: "math",
          style: "display"
          // CD is always displaystyle.
        };
        r.push(A), o = ci();
      }
    i % 2 === 0 ? r.push(o) : r.shift(), r = [], a.push(r);
  }
  n.gullet.endGroup(), n.gullet.endGroup();
  var C = new Array(a[0].length).fill({
    type: "align",
    align: "c",
    pregap: 0.25,
    // CD package sets \enskip between columns.
    postgap: 0.25
    // So pre and post each get half an \enskip, i.e. 0.25em.
  });
  return {
    type: "array",
    mode: "math",
    body: a,
    arraystretch: 1,
    addJot: !0,
    rowGaps: [null],
    cols: C,
    colSeparationType: "CD",
    hLinesBeforeRow: new Array(a.length + 1).fill([])
  };
}
P({
  type: "cdlabel",
  names: ["\\\\cdleft", "\\\\cdright"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n;
    return {
      type: "cdlabel",
      mode: t.mode,
      side: r.slice(4),
      label: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = e.havingStyle(e.style.sup()), r = F.wrapFragment(se(n.label, t, e), e);
    return r.classes.push("cd-label-" + n.side), r.style.bottom = L(0.8 - r.depth), r.height = 0, r.depth = 0, r;
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mrow", [pe(n.label, e)]);
    return t = new q.MathNode("mpadded", [t]), t.setAttribute("width", "0"), n.side === "left" && t.setAttribute("lspace", "-1width"), t.setAttribute("voffset", "0.7em"), t = new q.MathNode("mstyle", [t]), t.setAttribute("displaystyle", "false"), t.setAttribute("scriptlevel", "1"), t;
  }
});
P({
  type: "cdlabelparent",
  names: ["\\\\cdparent"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "cdlabelparent",
      mode: t.mode,
      fragment: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = F.wrapFragment(se(n.fragment, e), e);
    return t.classes.push("cd-vert-arrow"), t;
  },
  mathmlBuilder(n, e) {
    return new q.MathNode("mrow", [pe(n.fragment, e)]);
  }
});
P({
  type: "textord",
  names: ["\\@char"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    for (var {
      parser: t
    } = n, r = ne(e[0], "ordgroup"), a = r.body, i = "", l = 0; l < a.length; l++) {
      var o = ne(a[l], "textord");
      i += o.text;
    }
    var u = parseInt(i), h;
    if (isNaN(u))
      throw new X("\\@char has non-numeric argument " + i);
    if (u < 0 || u >= 1114111)
      throw new X("\\@char with invalid code point " + i);
    return u <= 65535 ? h = String.fromCharCode(u) : (u -= 65536, h = String.fromCharCode((u >> 10) + 55296, (u & 1023) + 56320)), {
      type: "textord",
      mode: t.mode,
      text: h
    };
  }
});
var Ll = (n, e) => {
  var t = qe(n.body, e.withColor(n.color), !1);
  return F.makeFragment(t);
}, Ol = (n, e) => {
  var t = rt(n.body, e.withColor(n.color)), r = new q.MathNode("mstyle", t);
  return r.setAttribute("mathcolor", n.color), r;
};
P({
  type: "color",
  names: ["\\textcolor"],
  props: {
    numArgs: 2,
    allowedInText: !0,
    argTypes: ["color", "original"]
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = ne(e[0], "color-token").color, a = e[1];
    return {
      type: "color",
      mode: t.mode,
      color: r,
      body: Ae(a)
    };
  },
  htmlBuilder: Ll,
  mathmlBuilder: Ol
});
P({
  type: "color",
  names: ["\\color"],
  props: {
    numArgs: 1,
    allowedInText: !0,
    argTypes: ["color"]
  },
  handler(n, e) {
    var {
      parser: t,
      breakOnTokenText: r
    } = n, a = ne(e[0], "color-token").color;
    t.gullet.macros.set("\\current@color", a);
    var i = t.parseExpression(!0, r);
    return {
      type: "color",
      mode: t.mode,
      color: a,
      body: i
    };
  },
  htmlBuilder: Ll,
  mathmlBuilder: Ol
});
P({
  type: "cr",
  names: ["\\\\"],
  props: {
    numArgs: 0,
    numOptionalArgs: 0,
    allowedInText: !0
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = r.gullet.future().text === "[" ? r.parseSizeGroup(!0) : null, i = !r.settings.displayMode || !r.settings.useStrictBehavior("newLineInDisplayMode", "In LaTeX, \\\\ or \\newline does nothing in display mode");
    return {
      type: "cr",
      mode: r.mode,
      newLine: i,
      size: a && ne(a, "size").value
    };
  },
  // The following builders are called only at the top level,
  // not within tabular/array environments.
  htmlBuilder(n, e) {
    var t = F.makeSpan(["mspace"], [], e);
    return n.newLine && (t.classes.push("newline"), n.size && (t.style.marginTop = L(ke(n.size, e)))), t;
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mspace");
    return n.newLine && (t.setAttribute("linebreak", "newline"), n.size && t.setAttribute("height", L(ke(n.size, e)))), t;
  }
});
var Mn = {
  "\\global": "\\global",
  "\\long": "\\\\globallong",
  "\\\\globallong": "\\\\globallong",
  "\\def": "\\gdef",
  "\\gdef": "\\gdef",
  "\\edef": "\\xdef",
  "\\xdef": "\\xdef",
  "\\let": "\\\\globallet",
  "\\futurelet": "\\\\globalfuture"
}, Pl = (n) => {
  var e = n.text;
  if (/^(?:[\\{}$&#^_]|EOF)$/.test(e))
    throw new X("Expected a control sequence", n);
  return e;
}, X1 = (n) => {
  var e = n.gullet.popToken();
  return e.text === "=" && (e = n.gullet.popToken(), e.text === " " && (e = n.gullet.popToken())), e;
}, Hl = (n, e, t, r) => {
  var a = n.gullet.macros.get(t.text);
  a == null && (t.noexpand = !0, a = {
    tokens: [t],
    numArgs: 0,
    // reproduce the same behavior in expansion
    unexpandable: !n.gullet.isExpandable(t.text)
  }), n.gullet.macros.set(e, a, r);
};
P({
  type: "internal",
  names: [
    "\\global",
    "\\long",
    "\\\\globallong"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    e.consumeSpaces();
    var r = e.fetch();
    if (Mn[r.text])
      return (t === "\\global" || t === "\\\\globallong") && (r.text = Mn[r.text]), ne(e.parseFunction(), "internal");
    throw new X("Invalid token after macro prefix", r);
  }
});
P({
  type: "internal",
  names: ["\\def", "\\gdef", "\\edef", "\\xdef"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = e.gullet.popToken(), a = r.text;
    if (/^(?:[\\{}$&#^_]|EOF)$/.test(a))
      throw new X("Expected a control sequence", r);
    for (var i = 0, l, o = [[]]; e.gullet.future().text !== "{"; )
      if (r = e.gullet.popToken(), r.text === "#") {
        if (e.gullet.future().text === "{") {
          l = e.gullet.future(), o[i].push("{");
          break;
        }
        if (r = e.gullet.popToken(), !/^[1-9]$/.test(r.text))
          throw new X('Invalid argument number "' + r.text + '"');
        if (parseInt(r.text) !== i + 1)
          throw new X('Argument number "' + r.text + '" out of order');
        i++, o.push([]);
      } else {
        if (r.text === "EOF")
          throw new X("Expected a macro definition");
        o[i].push(r.text);
      }
    var {
      tokens: u
    } = e.gullet.consumeArg();
    return l && u.unshift(l), (t === "\\edef" || t === "\\xdef") && (u = e.gullet.expandTokens(u), u.reverse()), e.gullet.macros.set(a, {
      tokens: u,
      numArgs: i,
      delimiters: o
    }, t === Mn[t]), {
      type: "internal",
      mode: e.mode
    };
  }
});
P({
  type: "internal",
  names: [
    "\\let",
    "\\\\globallet"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = Pl(e.gullet.popToken());
    e.gullet.consumeSpaces();
    var a = X1(e);
    return Hl(e, r, a, t === "\\\\globallet"), {
      type: "internal",
      mode: e.mode
    };
  }
});
P({
  type: "internal",
  names: [
    "\\futurelet",
    "\\\\globalfuture"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = Pl(e.gullet.popToken()), a = e.gullet.popToken(), i = e.gullet.popToken();
    return Hl(e, r, i, t === "\\\\globalfuture"), e.gullet.pushToken(i), e.gullet.pushToken(a), {
      type: "internal",
      mode: e.mode
    };
  }
});
var W0 = function(e, t, r) {
  var a = Fe.math[e] && Fe.math[e].replace, i = Wn(a || e, t, r);
  if (!i)
    throw new Error("Unsupported symbol " + e + " and font size " + t + ".");
  return i;
}, Jn = function(e, t, r, a) {
  var i = r.havingBaseStyle(t), l = F.makeSpan(a.concat(i.sizingClasses(r)), [e], r), o = i.sizeMultiplier / r.sizeMultiplier;
  return l.height *= o, l.depth *= o, l.maxFontSize = i.sizeMultiplier, l;
}, Ul = function(e, t, r) {
  var a = t.havingBaseStyle(r), i = (1 - t.sizeMultiplier / a.sizeMultiplier) * t.fontMetrics().axisHeight;
  e.classes.push("delimcenter"), e.style.top = L(i), e.height -= i, e.depth += i;
}, Z1 = function(e, t, r, a, i, l) {
  var o = F.makeSymbol(e, "Main-Regular", i, a), u = Jn(o, t, a, l);
  return r && Ul(u, a, t), u;
}, K1 = function(e, t, r, a) {
  return F.makeSymbol(e, "Size" + t + "-Regular", r, a);
}, Vl = function(e, t, r, a, i, l) {
  var o = K1(e, t, i, a), u = Jn(F.makeSpan(["delimsizing", "size" + t], [o], a), J.TEXT, a, l);
  return r && Ul(u, a, J.TEXT), u;
}, cn = function(e, t, r) {
  var a;
  t === "Size1-Regular" ? a = "delim-size1" : a = "delim-size4";
  var i = F.makeSpan(["delimsizinginner", a], [F.makeSpan([], [F.makeSymbol(e, t, r)])]);
  return {
    type: "elem",
    elem: i
  };
}, hn = function(e, t, r) {
  var a = Kt["Size4-Regular"][e.charCodeAt(0)] ? Kt["Size4-Regular"][e.charCodeAt(0)][4] : Kt["Size1-Regular"][e.charCodeAt(0)][4], i = new p0("inner", o1(e, Math.round(1e3 * t))), l = new s0([i], {
    width: L(a),
    height: L(t),
    // Override CSS rule `.katex svg { width: 100% }`
    style: "width:" + L(a),
    viewBox: "0 0 " + 1e3 * a + " " + Math.round(1e3 * t),
    preserveAspectRatio: "xMinYMin"
  }), o = F.makeSvgSpan([], [l], r);
  return o.height = t, o.style.height = L(t), o.style.width = L(a), {
    type: "elem",
    elem: o
  };
}, zn = 8e-3, _r = {
  type: "kern",
  size: -1 * zn
}, Q1 = ["|", "\\lvert", "\\rvert", "\\vert"], J1 = ["\\|", "\\lVert", "\\rVert", "\\Vert"], Gl = function(e, t, r, a, i, l) {
  var o, u, h, d, p = "", b = 0;
  o = h = d = e, u = null;
  var y = "Size1-Regular";
  e === "\\uparrow" ? h = d = "⏐" : e === "\\Uparrow" ? h = d = "‖" : e === "\\downarrow" ? o = h = "⏐" : e === "\\Downarrow" ? o = h = "‖" : e === "\\updownarrow" ? (o = "\\uparrow", h = "⏐", d = "\\downarrow") : e === "\\Updownarrow" ? (o = "\\Uparrow", h = "‖", d = "\\Downarrow") : K.contains(Q1, e) ? (h = "∣", p = "vert", b = 333) : K.contains(J1, e) ? (h = "∥", p = "doublevert", b = 556) : e === "[" || e === "\\lbrack" ? (o = "⎡", h = "⎢", d = "⎣", y = "Size4-Regular", p = "lbrack", b = 667) : e === "]" || e === "\\rbrack" ? (o = "⎤", h = "⎥", d = "⎦", y = "Size4-Regular", p = "rbrack", b = 667) : e === "\\lfloor" || e === "⌊" ? (h = o = "⎢", d = "⎣", y = "Size4-Regular", p = "lfloor", b = 667) : e === "\\lceil" || e === "⌈" ? (o = "⎡", h = d = "⎢", y = "Size4-Regular", p = "lceil", b = 667) : e === "\\rfloor" || e === "⌋" ? (h = o = "⎥", d = "⎦", y = "Size4-Regular", p = "rfloor", b = 667) : e === "\\rceil" || e === "⌉" ? (o = "⎤", h = d = "⎥", y = "Size4-Regular", p = "rceil", b = 667) : e === "(" || e === "\\lparen" ? (o = "⎛", h = "⎜", d = "⎝", y = "Size4-Regular", p = "lparen", b = 875) : e === ")" || e === "\\rparen" ? (o = "⎞", h = "⎟", d = "⎠", y = "Size4-Regular", p = "rparen", b = 875) : e === "\\{" || e === "\\lbrace" ? (o = "⎧", u = "⎨", d = "⎩", h = "⎪", y = "Size4-Regular") : e === "\\}" || e === "\\rbrace" ? (o = "⎫", u = "⎬", d = "⎭", h = "⎪", y = "Size4-Regular") : e === "\\lgroup" || e === "⟮" ? (o = "⎧", d = "⎩", h = "⎪", y = "Size4-Regular") : e === "\\rgroup" || e === "⟯" ? (o = "⎫", d = "⎭", h = "⎪", y = "Size4-Regular") : e === "\\lmoustache" || e === "⎰" ? (o = "⎧", d = "⎭", h = "⎪", y = "Size4-Regular") : (e === "\\rmoustache" || e === "⎱") && (o = "⎫", d = "⎩", h = "⎪", y = "Size4-Regular");
  var D = W0(o, y, i), A = D.height + D.depth, C = W0(h, y, i), T = C.height + C.depth, w = W0(d, y, i), g = w.height + w.depth, S = 0, E = 1;
  if (u !== null) {
    var $ = W0(u, y, i);
    S = $.height + $.depth, E = 2;
  }
  var B = A + g + S, O = Math.max(0, Math.ceil((t - B) / (E * T))), M = B + O * E * T, R = a.fontMetrics().axisHeight;
  r && (R *= a.sizeMultiplier);
  var W = M / 2 - R, Q = [];
  if (p.length > 0) {
    var G = M - A - g, U = Math.round(M * 1e3), ae = u1(p, Math.round(G * 1e3)), ce = new p0(p, ae), $e = (b / 1e3).toFixed(3) + "em", ue = (U / 1e3).toFixed(3) + "em", ge = new s0([ce], {
      width: $e,
      height: ue,
      viewBox: "0 0 " + b + " " + U
    }), _e = F.makeSvgSpan([], [ge], a);
    _e.height = U / 1e3, _e.style.width = $e, _e.style.height = ue, Q.push({
      type: "elem",
      elem: _e
    });
  } else {
    if (Q.push(cn(d, y, i)), Q.push(_r), u === null) {
      var re = M - A - g + 2 * zn;
      Q.push(hn(h, re, a));
    } else {
      var he = (M - A - g - S) / 2 + 2 * zn;
      Q.push(hn(h, he, a)), Q.push(_r), Q.push(cn(u, y, i)), Q.push(_r), Q.push(hn(h, he, a));
    }
    Q.push(_r), Q.push(cn(o, y, i));
  }
  var me = a.havingBaseStyle(J.TEXT), Me = F.makeVList({
    positionType: "bottom",
    positionData: W,
    children: Q
  }, me);
  return Jn(F.makeSpan(["delimsizing", "mult"], [Me], me), J.TEXT, a, l);
}, mn = 80, dn = 0.08, fn = function(e, t, r, a, i) {
  var l = s1(e, a, r), o = new p0(e, l), u = new s0([o], {
    // Note: 1000:1 ratio of viewBox to document em width.
    width: "400em",
    height: L(t),
    viewBox: "0 0 400000 " + r,
    preserveAspectRatio: "xMinYMin slice"
  });
  return F.makeSvgSpan(["hide-tail"], [u], i);
}, eu = function(e, t) {
  var r = t.havingBaseSizing(), a = Xl("\\surd", e * r.sizeMultiplier, jl, r), i = r.sizeMultiplier, l = Math.max(0, t.minRuleThickness - t.fontMetrics().sqrtRuleThickness), o, u = 0, h = 0, d = 0, p;
  return a.type === "small" ? (d = 1e3 + 1e3 * l + mn, e < 1 ? i = 1 : e < 1.4 && (i = 0.7), u = (1 + l + dn) / i, h = (1 + l) / i, o = fn("sqrtMain", u, d, l, t), o.style.minWidth = "0.853em", p = 0.833 / i) : a.type === "large" ? (d = (1e3 + mn) * X0[a.size], h = (X0[a.size] + l) / i, u = (X0[a.size] + l + dn) / i, o = fn("sqrtSize" + a.size, u, d, l, t), o.style.minWidth = "1.02em", p = 1 / i) : (u = e + l + dn, h = e + l, d = Math.floor(1e3 * e + l) + mn, o = fn("sqrtTall", u, d, l, t), o.style.minWidth = "0.742em", p = 1.056), o.height = h, o.style.height = L(u), {
    span: o,
    advanceWidth: p,
    // Calculate the actual line width.
    // This actually should depend on the chosen font -- e.g. \boldmath
    // should use the thicker surd symbols from e.g. KaTeX_Main-Bold, and
    // have thicker rules.
    ruleWidth: (t.fontMetrics().sqrtRuleThickness + l) * i
  };
}, Yl = ["(", "\\lparen", ")", "\\rparen", "[", "\\lbrack", "]", "\\rbrack", "\\{", "\\lbrace", "\\}", "\\rbrace", "\\lfloor", "\\rfloor", "⌊", "⌋", "\\lceil", "\\rceil", "⌈", "⌉", "\\surd"], tu = ["\\uparrow", "\\downarrow", "\\updownarrow", "\\Uparrow", "\\Downarrow", "\\Updownarrow", "|", "\\|", "\\vert", "\\Vert", "\\lvert", "\\rvert", "\\lVert", "\\rVert", "\\lgroup", "\\rgroup", "⟮", "⟯", "\\lmoustache", "\\rmoustache", "⎰", "⎱"], Wl = ["<", ">", "\\langle", "\\rangle", "/", "\\backslash", "\\lt", "\\gt"], X0 = [0, 1.2, 1.8, 2.4, 3], ru = function(e, t, r, a, i) {
  if (e === "<" || e === "\\lt" || e === "⟨" ? e = "\\langle" : (e === ">" || e === "\\gt" || e === "⟩") && (e = "\\rangle"), K.contains(Yl, e) || K.contains(Wl, e))
    return Vl(e, t, !1, r, a, i);
  if (K.contains(tu, e))
    return Gl(e, X0[t], !1, r, a, i);
  throw new X("Illegal delimiter: '" + e + "'");
}, nu = [{
  type: "small",
  style: J.SCRIPTSCRIPT
}, {
  type: "small",
  style: J.SCRIPT
}, {
  type: "small",
  style: J.TEXT
}, {
  type: "large",
  size: 1
}, {
  type: "large",
  size: 2
}, {
  type: "large",
  size: 3
}, {
  type: "large",
  size: 4
}], au = [{
  type: "small",
  style: J.SCRIPTSCRIPT
}, {
  type: "small",
  style: J.SCRIPT
}, {
  type: "small",
  style: J.TEXT
}, {
  type: "stack"
}], jl = [{
  type: "small",
  style: J.SCRIPTSCRIPT
}, {
  type: "small",
  style: J.SCRIPT
}, {
  type: "small",
  style: J.TEXT
}, {
  type: "large",
  size: 1
}, {
  type: "large",
  size: 2
}, {
  type: "large",
  size: 3
}, {
  type: "large",
  size: 4
}, {
  type: "stack"
}], iu = function(e) {
  if (e.type === "small")
    return "Main-Regular";
  if (e.type === "large")
    return "Size" + e.size + "-Regular";
  if (e.type === "stack")
    return "Size4-Regular";
  throw new Error("Add support for delim type '" + e.type + "' here.");
}, Xl = function(e, t, r, a) {
  for (var i = Math.min(2, 3 - a.style.size), l = i; l < r.length && r[l].type !== "stack"; l++) {
    var o = W0(e, iu(r[l]), "math"), u = o.height + o.depth;
    if (r[l].type === "small") {
      var h = a.havingBaseStyle(r[l].style);
      u *= h.sizeMultiplier;
    }
    if (u > t)
      return r[l];
  }
  return r[r.length - 1];
}, Zl = function(e, t, r, a, i, l) {
  e === "<" || e === "\\lt" || e === "⟨" ? e = "\\langle" : (e === ">" || e === "\\gt" || e === "⟩") && (e = "\\rangle");
  var o;
  K.contains(Wl, e) ? o = nu : K.contains(Yl, e) ? o = jl : o = au;
  var u = Xl(e, t, o, a);
  return u.type === "small" ? Z1(e, u.style, r, a, i, l) : u.type === "large" ? Vl(e, u.size, r, a, i, l) : Gl(e, t, r, a, i, l);
}, lu = function(e, t, r, a, i, l) {
  var o = a.fontMetrics().axisHeight * a.sizeMultiplier, u = 901, h = 5 / a.fontMetrics().ptPerEm, d = Math.max(t - o, r + o), p = Math.max(
    // In real TeX, calculations are done using integral values which are
    // 65536 per pt, or 655360 per em. So, the division here truncates in
    // TeX but doesn't here, producing different results. If we wanted to
    // exactly match TeX's calculation, we could do
    //   Math.floor(655360 * maxDistFromAxis / 500) *
    //    delimiterFactor / 655360
    // (To see the difference, compare
    //    x^{x^{\left(\rule{0.1em}{0.68em}\right)}}
    // in TeX and KaTeX)
    d / 500 * u,
    2 * d - h
  );
  return Zl(e, p, !0, a, i, l);
}, Jt = {
  sqrtImage: eu,
  sizedDelim: ru,
  sizeToMaxHeight: X0,
  customSizedDelim: Zl,
  leftRightDelim: lu
}, mi = {
  "\\bigl": {
    mclass: "mopen",
    size: 1
  },
  "\\Bigl": {
    mclass: "mopen",
    size: 2
  },
  "\\biggl": {
    mclass: "mopen",
    size: 3
  },
  "\\Biggl": {
    mclass: "mopen",
    size: 4
  },
  "\\bigr": {
    mclass: "mclose",
    size: 1
  },
  "\\Bigr": {
    mclass: "mclose",
    size: 2
  },
  "\\biggr": {
    mclass: "mclose",
    size: 3
  },
  "\\Biggr": {
    mclass: "mclose",
    size: 4
  },
  "\\bigm": {
    mclass: "mrel",
    size: 1
  },
  "\\Bigm": {
    mclass: "mrel",
    size: 2
  },
  "\\biggm": {
    mclass: "mrel",
    size: 3
  },
  "\\Biggm": {
    mclass: "mrel",
    size: 4
  },
  "\\big": {
    mclass: "mord",
    size: 1
  },
  "\\Big": {
    mclass: "mord",
    size: 2
  },
  "\\bigg": {
    mclass: "mord",
    size: 3
  },
  "\\Bigg": {
    mclass: "mord",
    size: 4
  }
}, su = ["(", "\\lparen", ")", "\\rparen", "[", "\\lbrack", "]", "\\rbrack", "\\{", "\\lbrace", "\\}", "\\rbrace", "\\lfloor", "\\rfloor", "⌊", "⌋", "\\lceil", "\\rceil", "⌈", "⌉", "<", ">", "\\langle", "⟨", "\\rangle", "⟩", "\\lt", "\\gt", "\\lvert", "\\rvert", "\\lVert", "\\rVert", "\\lgroup", "\\rgroup", "⟮", "⟯", "\\lmoustache", "\\rmoustache", "⎰", "⎱", "/", "\\backslash", "|", "\\vert", "\\|", "\\Vert", "\\uparrow", "\\Uparrow", "\\downarrow", "\\Downarrow", "\\updownarrow", "\\Updownarrow", "."];
function Zr(n, e) {
  var t = jr(n);
  if (t && K.contains(su, t.text))
    return t;
  throw t ? new X("Invalid delimiter '" + t.text + "' after '" + e.funcName + "'", n) : new X("Invalid delimiter type '" + n.type + "'", n);
}
P({
  type: "delimsizing",
  names: ["\\bigl", "\\Bigl", "\\biggl", "\\Biggl", "\\bigr", "\\Bigr", "\\biggr", "\\Biggr", "\\bigm", "\\Bigm", "\\biggm", "\\Biggm", "\\big", "\\Big", "\\bigg", "\\Bigg"],
  props: {
    numArgs: 1,
    argTypes: ["primitive"]
  },
  handler: (n, e) => {
    var t = Zr(e[0], n);
    return {
      type: "delimsizing",
      mode: n.parser.mode,
      size: mi[n.funcName].size,
      mclass: mi[n.funcName].mclass,
      delim: t.text
    };
  },
  htmlBuilder: (n, e) => n.delim === "." ? F.makeSpan([n.mclass]) : Jt.sizedDelim(n.delim, n.size, e, n.mode, [n.mclass]),
  mathmlBuilder: (n) => {
    var e = [];
    n.delim !== "." && e.push(ot(n.delim, n.mode));
    var t = new q.MathNode("mo", e);
    n.mclass === "mopen" || n.mclass === "mclose" ? t.setAttribute("fence", "true") : t.setAttribute("fence", "false"), t.setAttribute("stretchy", "true");
    var r = L(Jt.sizeToMaxHeight[n.size]);
    return t.setAttribute("minsize", r), t.setAttribute("maxsize", r), t;
  }
});
function di(n) {
  if (!n.body)
    throw new Error("Bug: The leftright ParseNode wasn't fully parsed.");
}
P({
  type: "leftright-right",
  names: ["\\right"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = n.parser.gullet.macros.get("\\current@color");
    if (t && typeof t != "string")
      throw new X("\\current@color set to non-string in \\right");
    return {
      type: "leftright-right",
      mode: n.parser.mode,
      delim: Zr(e[0], n).text,
      color: t
      // undefined if not set via \color
    };
  }
});
P({
  type: "leftright",
  names: ["\\left"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = Zr(e[0], n), r = n.parser;
    ++r.leftrightDepth;
    var a = r.parseExpression(!1);
    --r.leftrightDepth, r.expect("\\right", !1);
    var i = ne(r.parseFunction(), "leftright-right");
    return {
      type: "leftright",
      mode: r.mode,
      body: a,
      left: t.text,
      right: i.delim,
      rightColor: i.color
    };
  },
  htmlBuilder: (n, e) => {
    di(n);
    for (var t = qe(n.body, e, !0, ["mopen", "mclose"]), r = 0, a = 0, i = !1, l = 0; l < t.length; l++)
      t[l].isMiddle ? i = !0 : (r = Math.max(t[l].height, r), a = Math.max(t[l].depth, a));
    r *= e.sizeMultiplier, a *= e.sizeMultiplier;
    var o;
    if (n.left === "." ? o = er(e, ["mopen"]) : o = Jt.leftRightDelim(n.left, r, a, e, n.mode, ["mopen"]), t.unshift(o), i)
      for (var u = 1; u < t.length; u++) {
        var h = t[u], d = h.isMiddle;
        d && (t[u] = Jt.leftRightDelim(d.delim, r, a, d.options, n.mode, []));
      }
    var p;
    if (n.right === ".")
      p = er(e, ["mclose"]);
    else {
      var b = n.rightColor ? e.withColor(n.rightColor) : e;
      p = Jt.leftRightDelim(n.right, r, a, b, n.mode, ["mclose"]);
    }
    return t.push(p), F.makeSpan(["minner"], t, e);
  },
  mathmlBuilder: (n, e) => {
    di(n);
    var t = rt(n.body, e);
    if (n.left !== ".") {
      var r = new q.MathNode("mo", [ot(n.left, n.mode)]);
      r.setAttribute("fence", "true"), t.unshift(r);
    }
    if (n.right !== ".") {
      var a = new q.MathNode("mo", [ot(n.right, n.mode)]);
      a.setAttribute("fence", "true"), n.rightColor && a.setAttribute("mathcolor", n.rightColor), t.push(a);
    }
    return Xn(t);
  }
});
P({
  type: "middle",
  names: ["\\middle"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = Zr(e[0], n);
    if (!n.parser.leftrightDepth)
      throw new X("\\middle without preceding \\left", t);
    return {
      type: "middle",
      mode: n.parser.mode,
      delim: t.text
    };
  },
  htmlBuilder: (n, e) => {
    var t;
    if (n.delim === ".")
      t = er(e, []);
    else {
      t = Jt.sizedDelim(n.delim, 1, e, n.mode, []);
      var r = {
        delim: n.delim,
        options: e
      };
      t.isMiddle = r;
    }
    return t;
  },
  mathmlBuilder: (n, e) => {
    var t = n.delim === "\\vert" || n.delim === "|" ? ot("|", "text") : ot(n.delim, n.mode), r = new q.MathNode("mo", [t]);
    return r.setAttribute("fence", "true"), r.setAttribute("lspace", "0.05em"), r.setAttribute("rspace", "0.05em"), r;
  }
});
var ea = (n, e) => {
  var t = F.wrapFragment(se(n.body, e), e), r = n.label.slice(1), a = e.sizeMultiplier, i, l = 0, o = K.isCharacterBox(n.body);
  if (r === "sout")
    i = F.makeSpan(["stretchy", "sout"]), i.height = e.fontMetrics().defaultRuleThickness / a, l = -0.5 * e.fontMetrics().xHeight;
  else if (r === "phase") {
    var u = ke({
      number: 0.6,
      unit: "pt"
    }, e), h = ke({
      number: 0.35,
      unit: "ex"
    }, e), d = e.havingBaseSizing();
    a = a / d.sizeMultiplier;
    var p = t.height + t.depth + u + h;
    t.style.paddingLeft = L(p / 2 + u);
    var b = Math.floor(1e3 * p * a), y = i1(b), D = new s0([new p0("phase", y)], {
      width: "400em",
      height: L(b / 1e3),
      viewBox: "0 0 400000 " + b,
      preserveAspectRatio: "xMinYMin slice"
    });
    i = F.makeSvgSpan(["hide-tail"], [D], e), i.style.height = L(p), l = t.depth + u + h;
  } else {
    /cancel/.test(r) ? o || t.classes.push("cancel-pad") : r === "angl" ? t.classes.push("anglpad") : t.classes.push("boxpad");
    var A = 0, C = 0, T = 0;
    /box/.test(r) ? (T = Math.max(
      e.fontMetrics().fboxrule,
      // default
      e.minRuleThickness
      // User override.
    ), A = e.fontMetrics().fboxsep + (r === "colorbox" ? 0 : T), C = A) : r === "angl" ? (T = Math.max(e.fontMetrics().defaultRuleThickness, e.minRuleThickness), A = 4 * T, C = Math.max(0, 0.25 - t.depth)) : (A = o ? 0.2 : 0, C = A), i = e0.encloseSpan(t, r, A, C, e), /fbox|boxed|fcolorbox/.test(r) ? (i.style.borderStyle = "solid", i.style.borderWidth = L(T)) : r === "angl" && T !== 0.049 && (i.style.borderTopWidth = L(T), i.style.borderRightWidth = L(T)), l = t.depth + C, n.backgroundColor && (i.style.backgroundColor = n.backgroundColor, n.borderColor && (i.style.borderColor = n.borderColor));
  }
  var w;
  if (n.backgroundColor)
    w = F.makeVList({
      positionType: "individualShift",
      children: [
        // Put the color background behind inner;
        {
          type: "elem",
          elem: i,
          shift: l
        },
        {
          type: "elem",
          elem: t,
          shift: 0
        }
      ]
    }, e);
  else {
    var g = /cancel|phase/.test(r) ? ["svg-align"] : [];
    w = F.makeVList({
      positionType: "individualShift",
      children: [
        // Write the \cancel stroke on top of inner.
        {
          type: "elem",
          elem: t,
          shift: 0
        },
        {
          type: "elem",
          elem: i,
          shift: l,
          wrapperClasses: g
        }
      ]
    }, e);
  }
  return /cancel/.test(r) && (w.height = t.height, w.depth = t.depth), /cancel/.test(r) && !o ? F.makeSpan(["mord", "cancel-lap"], [w], e) : F.makeSpan(["mord"], [w], e);
}, ta = (n, e) => {
  var t = 0, r = new q.MathNode(n.label.indexOf("colorbox") > -1 ? "mpadded" : "menclose", [pe(n.body, e)]);
  switch (n.label) {
    case "\\cancel":
      r.setAttribute("notation", "updiagonalstrike");
      break;
    case "\\bcancel":
      r.setAttribute("notation", "downdiagonalstrike");
      break;
    case "\\phase":
      r.setAttribute("notation", "phasorangle");
      break;
    case "\\sout":
      r.setAttribute("notation", "horizontalstrike");
      break;
    case "\\fbox":
      r.setAttribute("notation", "box");
      break;
    case "\\angl":
      r.setAttribute("notation", "actuarial");
      break;
    case "\\fcolorbox":
    case "\\colorbox":
      if (t = e.fontMetrics().fboxsep * e.fontMetrics().ptPerEm, r.setAttribute("width", "+" + 2 * t + "pt"), r.setAttribute("height", "+" + 2 * t + "pt"), r.setAttribute("lspace", t + "pt"), r.setAttribute("voffset", t + "pt"), n.label === "\\fcolorbox") {
        var a = Math.max(
          e.fontMetrics().fboxrule,
          // default
          e.minRuleThickness
          // user override
        );
        r.setAttribute("style", "border: " + a + "em solid " + String(n.borderColor));
      }
      break;
    case "\\xcancel":
      r.setAttribute("notation", "updiagonalstrike downdiagonalstrike");
      break;
  }
  return n.backgroundColor && r.setAttribute("mathbackground", n.backgroundColor), r;
};
P({
  type: "enclose",
  names: ["\\colorbox"],
  props: {
    numArgs: 2,
    allowedInText: !0,
    argTypes: ["color", "text"]
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n, i = ne(e[0], "color-token").color, l = e[1];
    return {
      type: "enclose",
      mode: r.mode,
      label: a,
      backgroundColor: i,
      body: l
    };
  },
  htmlBuilder: ea,
  mathmlBuilder: ta
});
P({
  type: "enclose",
  names: ["\\fcolorbox"],
  props: {
    numArgs: 3,
    allowedInText: !0,
    argTypes: ["color", "color", "text"]
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n, i = ne(e[0], "color-token").color, l = ne(e[1], "color-token").color, o = e[2];
    return {
      type: "enclose",
      mode: r.mode,
      label: a,
      backgroundColor: l,
      borderColor: i,
      body: o
    };
  },
  htmlBuilder: ea,
  mathmlBuilder: ta
});
P({
  type: "enclose",
  names: ["\\fbox"],
  props: {
    numArgs: 1,
    argTypes: ["hbox"],
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "enclose",
      mode: t.mode,
      label: "\\fbox",
      body: e[0]
    };
  }
});
P({
  type: "enclose",
  names: ["\\cancel", "\\bcancel", "\\xcancel", "\\sout", "\\phase"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "enclose",
      mode: t.mode,
      label: r,
      body: a
    };
  },
  htmlBuilder: ea,
  mathmlBuilder: ta
});
P({
  type: "enclose",
  names: ["\\angl"],
  props: {
    numArgs: 1,
    argTypes: ["hbox"],
    allowedInText: !1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "enclose",
      mode: t.mode,
      label: "\\angl",
      body: e[0]
    };
  }
});
var Kl = {};
function Ot(n) {
  for (var {
    type: e,
    names: t,
    props: r,
    handler: a,
    htmlBuilder: i,
    mathmlBuilder: l
  } = n, o = {
    type: e,
    numArgs: r.numArgs || 0,
    allowedInText: !1,
    numOptionalArgs: 0,
    handler: a
  }, u = 0; u < t.length; ++u)
    Kl[t[u]] = o;
  i && (qr[e] = i), l && (Nr[e] = l);
}
var ou = {};
function f(n, e) {
  ou[n] = e;
}
function fi(n) {
  var e = [];
  n.consumeSpaces();
  var t = n.fetch().text;
  for (t === "\\relax" && (n.consume(), n.consumeSpaces(), t = n.fetch().text); t === "\\hline" || t === "\\hdashline"; )
    n.consume(), e.push(t === "\\hdashline"), n.consumeSpaces(), t = n.fetch().text;
  return e;
}
var Kr = (n) => {
  var e = n.parser.settings;
  if (!e.displayMode)
    throw new X("{" + n.envName + "} can be used only in display mode.");
};
function ra(n) {
  if (n.indexOf("ed") === -1)
    return n.indexOf("*") === -1;
}
function u0(n, e, t) {
  var {
    hskipBeforeAndAfter: r,
    addJot: a,
    cols: i,
    arraystretch: l,
    colSeparationType: o,
    autoTag: u,
    singleRow: h,
    emptySingleRow: d,
    maxNumCols: p,
    leqno: b
  } = e;
  if (n.gullet.beginGroup(), h || n.gullet.macros.set("\\cr", "\\\\\\relax"), !l) {
    var y = n.gullet.expandMacroAsText("\\arraystretch");
    if (y == null)
      l = 1;
    else if (l = parseFloat(y), !l || l < 0)
      throw new X("Invalid \\arraystretch: " + y);
  }
  n.gullet.beginGroup();
  var D = [], A = [D], C = [], T = [], w = u != null ? [] : void 0;
  function g() {
    u && n.gullet.macros.set("\\@eqnsw", "1", !0);
  }
  function S() {
    w && (n.gullet.macros.get("\\df@tag") ? (w.push(n.subparse([new Gn("\\df@tag")])), n.gullet.macros.set("\\df@tag", void 0, !0)) : w.push(!!u && n.gullet.macros.get("\\@eqnsw") === "1"));
  }
  for (g(), T.push(fi(n)); ; ) {
    var E = n.parseExpression(!1, h ? "\\end" : "\\\\");
    n.gullet.endGroup(), n.gullet.beginGroup(), E = {
      type: "ordgroup",
      mode: n.mode,
      body: E
    }, t && (E = {
      type: "styling",
      mode: n.mode,
      style: t,
      body: [E]
    }), D.push(E);
    var $ = n.fetch().text;
    if ($ === "&") {
      if (p && D.length === p) {
        if (h || o)
          throw new X("Too many tab characters: &", n.nextToken);
        n.settings.reportNonstrict("textEnv", "Too few columns specified in the {array} column argument.");
      }
      n.consume();
    } else if ($ === "\\end") {
      S(), D.length === 1 && E.type === "styling" && E.body[0].body.length === 0 && (A.length > 1 || !d) && A.pop(), T.length < A.length + 1 && T.push([]);
      break;
    } else if ($ === "\\\\") {
      n.consume();
      var B = void 0;
      n.gullet.future().text !== " " && (B = n.parseSizeGroup(!0)), C.push(B ? B.value : null), S(), T.push(fi(n)), D = [], A.push(D), g();
    } else
      throw new X("Expected & or \\\\ or \\cr or \\end", n.nextToken);
  }
  return n.gullet.endGroup(), n.gullet.endGroup(), {
    type: "array",
    mode: n.mode,
    addJot: a,
    arraystretch: l,
    body: A,
    cols: i,
    rowGaps: C,
    hskipBeforeAndAfter: r,
    hLinesBeforeRow: T,
    colSeparationType: o,
    tags: w,
    leqno: b
  };
}
function na(n) {
  return n.slice(0, 1) === "d" ? "display" : "text";
}
var Pt = function(e, t) {
  var r, a, i = e.body.length, l = e.hLinesBeforeRow, o = 0, u = new Array(i), h = [], d = Math.max(
    // From LaTeX \showthe\arrayrulewidth. Equals 0.04 em.
    t.fontMetrics().arrayRuleWidth,
    t.minRuleThickness
    // User override.
  ), p = 1 / t.fontMetrics().ptPerEm, b = 5 * p;
  if (e.colSeparationType && e.colSeparationType === "small") {
    var y = t.havingStyle(J.SCRIPT).sizeMultiplier;
    b = 0.2778 * (y / t.sizeMultiplier);
  }
  var D = e.colSeparationType === "CD" ? ke({
    number: 3,
    unit: "ex"
  }, t) : 12 * p, A = 3 * p, C = e.arraystretch * D, T = 0.7 * C, w = 0.3 * C, g = 0;
  function S(Gt) {
    for (var Yt = 0; Yt < Gt.length; ++Yt)
      Yt > 0 && (g += 0.25), h.push({
        pos: g,
        isDashed: Gt[Yt]
      });
  }
  for (S(l[0]), r = 0; r < e.body.length; ++r) {
    var E = e.body[r], $ = T, B = w;
    o < E.length && (o = E.length);
    var O = new Array(E.length);
    for (a = 0; a < E.length; ++a) {
      var M = se(E[a], t);
      B < M.depth && (B = M.depth), $ < M.height && ($ = M.height), O[a] = M;
    }
    var R = e.rowGaps[r], W = 0;
    R && (W = ke(R, t), W > 0 && (W += w, B < W && (B = W), W = 0)), e.addJot && (B += A), O.height = $, O.depth = B, g += $, O.pos = g, g += B + W, u[r] = O, S(l[r + 1]);
  }
  var Q = g / 2 + t.fontMetrics().axisHeight, G = e.cols || [], U = [], ae, ce, $e = [];
  if (e.tags && e.tags.some((Gt) => Gt))
    for (r = 0; r < i; ++r) {
      var ue = u[r], ge = ue.pos - Q, _e = e.tags[r], re = void 0;
      _e === !0 ? re = F.makeSpan(["eqn-num"], [], t) : _e === !1 ? re = F.makeSpan([], [], t) : re = F.makeSpan([], qe(_e, t, !0), t), re.depth = ue.depth, re.height = ue.height, $e.push({
        type: "elem",
        elem: re,
        shift: ge
      });
    }
  for (
    a = 0, ce = 0;
    // Continue while either there are more columns or more column
    // descriptions, so trailing separators don't get lost.
    a < o || ce < G.length;
    ++a, ++ce
  ) {
    for (var he = G[ce] || {}, me = !0; he.type === "separator"; ) {
      if (me || (ae = F.makeSpan(["arraycolsep"], []), ae.style.width = L(t.fontMetrics().doubleRuleSep), U.push(ae)), he.separator === "|" || he.separator === ":") {
        var Me = he.separator === "|" ? "solid" : "dashed", I = F.makeSpan(["vertical-separator"], [], t);
        I.style.height = L(g), I.style.borderRightWidth = L(d), I.style.borderRightStyle = Me, I.style.margin = "0 " + L(-d / 2);
        var Xe = g - Q;
        Xe && (I.style.verticalAlign = L(-Xe)), U.push(I);
      } else
        throw new X("Invalid separator type: " + he.separator);
      ce++, he = G[ce] || {}, me = !1;
    }
    if (!(a >= o)) {
      var Ie = void 0;
      (a > 0 || e.hskipBeforeAndAfter) && (Ie = K.deflt(he.pregap, b), Ie !== 0 && (ae = F.makeSpan(["arraycolsep"], []), ae.style.width = L(Ie), U.push(ae)));
      var Ze = [];
      for (r = 0; r < i; ++r) {
        var mt = u[r], dt = mt[a];
        if (dt) {
          var Ut = mt.pos - Q;
          dt.depth = mt.depth, dt.height = mt.height, Ze.push({
            type: "elem",
            elem: dt,
            shift: Ut
          });
        }
      }
      Ze = F.makeVList({
        positionType: "individualShift",
        children: Ze
      }, t), Ze = F.makeSpan(["col-align-" + (he.align || "c")], [Ze]), U.push(Ze), (a < o - 1 || e.hskipBeforeAndAfter) && (Ie = K.deflt(he.postgap, b), Ie !== 0 && (ae = F.makeSpan(["arraycolsep"], []), ae.style.width = L(Ie), U.push(ae)));
    }
  }
  if (u = F.makeSpan(["mtable"], U), h.length > 0) {
    for (var At = F.makeLineSpan("hline", t, d), Vt = F.makeLineSpan("hdashline", t, d), ft = [{
      type: "elem",
      elem: u,
      shift: 0
    }]; h.length > 0; ) {
      var y0 = h.pop(), w0 = y0.pos - Q;
      y0.isDashed ? ft.push({
        type: "elem",
        elem: Vt,
        shift: w0
      }) : ft.push({
        type: "elem",
        elem: At,
        shift: w0
      });
    }
    u = F.makeVList({
      positionType: "individualShift",
      children: ft
    }, t);
  }
  if ($e.length === 0)
    return F.makeSpan(["mord"], [u], t);
  var Ft = F.makeVList({
    positionType: "individualShift",
    children: $e
  }, t);
  return Ft = F.makeSpan(["tag"], [Ft], t), F.makeFragment([u, Ft]);
}, uu = {
  c: "center ",
  l: "left ",
  r: "right "
}, Ht = function(e, t) {
  for (var r = [], a = new q.MathNode("mtd", [], ["mtr-glue"]), i = new q.MathNode("mtd", [], ["mml-eqn-num"]), l = 0; l < e.body.length; l++) {
    for (var o = e.body[l], u = [], h = 0; h < o.length; h++)
      u.push(new q.MathNode("mtd", [pe(o[h], t)]));
    e.tags && e.tags[l] && (u.unshift(a), u.push(a), e.leqno ? u.unshift(i) : u.push(i)), r.push(new q.MathNode("mtr", u));
  }
  var d = new q.MathNode("mtable", r), p = e.arraystretch === 0.5 ? 0.1 : 0.16 + e.arraystretch - 1 + (e.addJot ? 0.09 : 0);
  d.setAttribute("rowspacing", L(p));
  var b = "", y = "";
  if (e.cols && e.cols.length > 0) {
    var D = e.cols, A = "", C = !1, T = 0, w = D.length;
    D[0].type === "separator" && (b += "top ", T = 1), D[D.length - 1].type === "separator" && (b += "bottom ", w -= 1);
    for (var g = T; g < w; g++)
      D[g].type === "align" ? (y += uu[D[g].align], C && (A += "none "), C = !0) : D[g].type === "separator" && C && (A += D[g].separator === "|" ? "solid " : "dashed ", C = !1);
    d.setAttribute("columnalign", y.trim()), /[sd]/.test(A) && d.setAttribute("columnlines", A.trim());
  }
  if (e.colSeparationType === "align") {
    for (var S = e.cols || [], E = "", $ = 1; $ < S.length; $++)
      E += $ % 2 ? "0em " : "1em ";
    d.setAttribute("columnspacing", E.trim());
  } else e.colSeparationType === "alignat" || e.colSeparationType === "gather" ? d.setAttribute("columnspacing", "0em") : e.colSeparationType === "small" ? d.setAttribute("columnspacing", "0.2778em") : e.colSeparationType === "CD" ? d.setAttribute("columnspacing", "0.5em") : d.setAttribute("columnspacing", "1em");
  var B = "", O = e.hLinesBeforeRow;
  b += O[0].length > 0 ? "left " : "", b += O[O.length - 1].length > 0 ? "right " : "";
  for (var M = 1; M < O.length - 1; M++)
    B += O[M].length === 0 ? "none " : O[M][0] ? "dashed " : "solid ";
  return /[sd]/.test(B) && d.setAttribute("rowlines", B.trim()), b !== "" && (d = new q.MathNode("menclose", [d]), d.setAttribute("notation", b.trim())), e.arraystretch && e.arraystretch < 1 && (d = new q.MathNode("mstyle", [d]), d.setAttribute("scriptlevel", "1")), d;
}, Ql = function(e, t) {
  e.envName.indexOf("ed") === -1 && Kr(e);
  var r = [], a = e.envName.indexOf("at") > -1 ? "alignat" : "align", i = e.envName === "split", l = u0(e.parser, {
    cols: r,
    addJot: !0,
    autoTag: i ? void 0 : ra(e.envName),
    emptySingleRow: !0,
    colSeparationType: a,
    maxNumCols: i ? 2 : void 0,
    leqno: e.parser.settings.leqno
  }, "display"), o, u = 0, h = {
    type: "ordgroup",
    mode: e.mode,
    body: []
  };
  if (t[0] && t[0].type === "ordgroup") {
    for (var d = "", p = 0; p < t[0].body.length; p++) {
      var b = ne(t[0].body[p], "textord");
      d += b.text;
    }
    o = Number(d), u = o * 2;
  }
  var y = !u;
  l.body.forEach(function(T) {
    for (var w = 1; w < T.length; w += 2) {
      var g = ne(T[w], "styling"), S = ne(g.body[0], "ordgroup");
      S.body.unshift(h);
    }
    if (y)
      u < T.length && (u = T.length);
    else {
      var E = T.length / 2;
      if (o < E)
        throw new X("Too many math in a row: " + ("expected " + o + ", but got " + E), T[0]);
    }
  });
  for (var D = 0; D < u; ++D) {
    var A = "r", C = 0;
    D % 2 === 1 ? A = "l" : D > 0 && y && (C = 1), r[D] = {
      type: "align",
      align: A,
      pregap: C,
      postgap: 0
    };
  }
  return l.colSeparationType = y ? "align" : "alignat", l;
};
Ot({
  type: "array",
  names: ["array", "darray"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var t = jr(e[0]), r = t ? [e[0]] : ne(e[0], "ordgroup").body, a = r.map(function(l) {
      var o = Kn(l), u = o.text;
      if ("lcr".indexOf(u) !== -1)
        return {
          type: "align",
          align: u
        };
      if (u === "|")
        return {
          type: "separator",
          separator: "|"
        };
      if (u === ":")
        return {
          type: "separator",
          separator: ":"
        };
      throw new X("Unknown column alignment: " + u, l);
    }), i = {
      cols: a,
      hskipBeforeAndAfter: !0,
      // \@preamble in lttab.dtx
      maxNumCols: a.length
    };
    return u0(n.parser, i, na(n.envName));
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["matrix", "pmatrix", "bmatrix", "Bmatrix", "vmatrix", "Vmatrix", "matrix*", "pmatrix*", "bmatrix*", "Bmatrix*", "vmatrix*", "Vmatrix*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      matrix: null,
      pmatrix: ["(", ")"],
      bmatrix: ["[", "]"],
      Bmatrix: ["\\{", "\\}"],
      vmatrix: ["|", "|"],
      Vmatrix: ["\\Vert", "\\Vert"]
    }[n.envName.replace("*", "")], t = "c", r = {
      hskipBeforeAndAfter: !1,
      cols: [{
        type: "align",
        align: t
      }]
    };
    if (n.envName.charAt(n.envName.length - 1) === "*") {
      var a = n.parser;
      if (a.consumeSpaces(), a.fetch().text === "[") {
        if (a.consume(), a.consumeSpaces(), t = a.fetch().text, "lcr".indexOf(t) === -1)
          throw new X("Expected l or c or r", a.nextToken);
        a.consume(), a.consumeSpaces(), a.expect("]"), a.consume(), r.cols = [{
          type: "align",
          align: t
        }];
      }
    }
    var i = u0(n.parser, r, na(n.envName)), l = Math.max(0, ...i.body.map((o) => o.length));
    return i.cols = new Array(l).fill({
      type: "align",
      align: t
    }), e ? {
      type: "leftright",
      mode: n.mode,
      body: [i],
      left: e[0],
      right: e[1],
      rightColor: void 0
      // \right uninfluenced by \color in array
    } : i;
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["smallmatrix"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      arraystretch: 0.5
    }, t = u0(n.parser, e, "script");
    return t.colSeparationType = "small", t;
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["subarray"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var t = jr(e[0]), r = t ? [e[0]] : ne(e[0], "ordgroup").body, a = r.map(function(l) {
      var o = Kn(l), u = o.text;
      if ("lc".indexOf(u) !== -1)
        return {
          type: "align",
          align: u
        };
      throw new X("Unknown column alignment: " + u, l);
    });
    if (a.length > 1)
      throw new X("{subarray} can contain only one column");
    var i = {
      cols: a,
      hskipBeforeAndAfter: !1,
      arraystretch: 0.5
    };
    if (i = u0(n.parser, i, "script"), i.body.length > 0 && i.body[0].length > 1)
      throw new X("{subarray} can contain only one column");
    return i;
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["cases", "dcases", "rcases", "drcases"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      arraystretch: 1.2,
      cols: [{
        type: "align",
        align: "l",
        pregap: 0,
        // TODO(kevinb) get the current style.
        // For now we use the metrics for TEXT style which is what we were
        // doing before.  Before attempting to get the current style we
        // should look at TeX's behavior especially for \over and matrices.
        postgap: 1
        /* 1em quad */
      }, {
        type: "align",
        align: "l",
        pregap: 0,
        postgap: 0
      }]
    }, t = u0(n.parser, e, na(n.envName));
    return {
      type: "leftright",
      mode: n.mode,
      body: [t],
      left: n.envName.indexOf("r") > -1 ? "." : "\\{",
      right: n.envName.indexOf("r") > -1 ? "\\}" : ".",
      rightColor: void 0
    };
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["align", "align*", "aligned", "split"],
  props: {
    numArgs: 0
  },
  handler: Ql,
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["gathered", "gather", "gather*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    K.contains(["gather", "gather*"], n.envName) && Kr(n);
    var e = {
      cols: [{
        type: "align",
        align: "c"
      }],
      addJot: !0,
      colSeparationType: "gather",
      autoTag: ra(n.envName),
      emptySingleRow: !0,
      leqno: n.parser.settings.leqno
    };
    return u0(n.parser, e, "display");
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["alignat", "alignat*", "alignedat"],
  props: {
    numArgs: 1
  },
  handler: Ql,
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["equation", "equation*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    Kr(n);
    var e = {
      autoTag: ra(n.envName),
      emptySingleRow: !0,
      singleRow: !0,
      maxNumCols: 1,
      leqno: n.parser.settings.leqno
    };
    return u0(n.parser, e, "display");
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
Ot({
  type: "array",
  names: ["CD"],
  props: {
    numArgs: 0
  },
  handler(n) {
    return Kr(n), j1(n.parser);
  },
  htmlBuilder: Pt,
  mathmlBuilder: Ht
});
f("\\nonumber", "\\gdef\\@eqnsw{0}");
f("\\notag", "\\nonumber");
P({
  type: "text",
  // Doesn't matter what this is.
  names: ["\\hline", "\\hdashline"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !0
  },
  handler(n, e) {
    throw new X(n.funcName + " valid only within array environment");
  }
});
var pi = Kl;
P({
  type: "environment",
  names: ["\\begin", "\\end"],
  props: {
    numArgs: 1,
    argTypes: ["text"]
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    if (a.type !== "ordgroup")
      throw new X("Invalid environment name", a);
    for (var i = "", l = 0; l < a.body.length; ++l)
      i += ne(a.body[l], "textord").text;
    if (r === "\\begin") {
      if (!pi.hasOwnProperty(i))
        throw new X("No such environment: " + i, a);
      var o = pi[i], {
        args: u,
        optArgs: h
      } = t.parseArguments("\\begin{" + i + "}", o), d = {
        mode: t.mode,
        envName: i,
        parser: t
      }, p = o.handler(d, u, h);
      t.expect("\\end", !1);
      var b = t.nextToken, y = ne(t.parseFunction(), "environment");
      if (y.name !== i)
        throw new X("Mismatch: \\begin{" + i + "} matched by \\end{" + y.name + "}", b);
      return p;
    }
    return {
      type: "environment",
      mode: t.mode,
      name: i,
      nameGroup: a
    };
  }
});
var Jl = (n, e) => {
  var t = n.font, r = e.withFont(t);
  return se(n.body, r);
}, es = (n, e) => {
  var t = n.font, r = e.withFont(t);
  return pe(n.body, r);
}, gi = {
  "\\Bbb": "\\mathbb",
  "\\bold": "\\mathbf",
  "\\frak": "\\mathfrak",
  "\\bm": "\\boldsymbol"
};
P({
  type: "font",
  names: [
    // styles, except \boldsymbol defined below
    "\\mathrm",
    "\\mathit",
    "\\mathbf",
    "\\mathnormal",
    // families
    "\\mathbb",
    "\\mathcal",
    "\\mathfrak",
    "\\mathscr",
    "\\mathsf",
    "\\mathtt",
    // aliases, except \bm defined below
    "\\Bbb",
    "\\bold",
    "\\frak"
  ],
  props: {
    numArgs: 1,
    allowedInArgument: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = Ir(e[0]), i = r;
    return i in gi && (i = gi[i]), {
      type: "font",
      mode: t.mode,
      font: i.slice(1),
      body: a
    };
  },
  htmlBuilder: Jl,
  mathmlBuilder: es
});
P({
  type: "mclass",
  names: ["\\boldsymbol", "\\bm"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0], a = K.isCharacterBox(r);
    return {
      type: "mclass",
      mode: t.mode,
      mclass: Xr(r),
      body: [{
        type: "font",
        mode: t.mode,
        font: "boldsymbol",
        body: r
      }],
      isCharacterBox: a
    };
  }
});
P({
  type: "font",
  names: ["\\rm", "\\sf", "\\tt", "\\bf", "\\it", "\\cal"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r,
      breakOnTokenText: a
    } = n, {
      mode: i
    } = t, l = t.parseExpression(!0, a), o = "math" + r.slice(1);
    return {
      type: "font",
      mode: i,
      font: o,
      body: {
        type: "ordgroup",
        mode: t.mode,
        body: l
      }
    };
  },
  htmlBuilder: Jl,
  mathmlBuilder: es
});
var ts = (n, e) => {
  var t = e;
  return n === "display" ? t = t.id >= J.SCRIPT.id ? t.text() : J.DISPLAY : n === "text" && t.size === J.DISPLAY.size ? t = J.TEXT : n === "script" ? t = J.SCRIPT : n === "scriptscript" && (t = J.SCRIPTSCRIPT), t;
}, aa = (n, e) => {
  var t = ts(n.size, e.style), r = t.fracNum(), a = t.fracDen(), i;
  i = e.havingStyle(r);
  var l = se(n.numer, i, e);
  if (n.continued) {
    var o = 8.5 / e.fontMetrics().ptPerEm, u = 3.5 / e.fontMetrics().ptPerEm;
    l.height = l.height < o ? o : l.height, l.depth = l.depth < u ? u : l.depth;
  }
  i = e.havingStyle(a);
  var h = se(n.denom, i, e), d, p, b;
  n.hasBarLine ? (n.barSize ? (p = ke(n.barSize, e), d = F.makeLineSpan("frac-line", e, p)) : d = F.makeLineSpan("frac-line", e), p = d.height, b = d.height) : (d = null, p = 0, b = e.fontMetrics().defaultRuleThickness);
  var y, D, A;
  t.size === J.DISPLAY.size || n.size === "display" ? (y = e.fontMetrics().num1, p > 0 ? D = 3 * b : D = 7 * b, A = e.fontMetrics().denom1) : (p > 0 ? (y = e.fontMetrics().num2, D = b) : (y = e.fontMetrics().num3, D = 3 * b), A = e.fontMetrics().denom2);
  var C;
  if (d) {
    var w = e.fontMetrics().axisHeight;
    y - l.depth - (w + 0.5 * p) < D && (y += D - (y - l.depth - (w + 0.5 * p))), w - 0.5 * p - (h.height - A) < D && (A += D - (w - 0.5 * p - (h.height - A)));
    var g = -(w - 0.5 * p);
    C = F.makeVList({
      positionType: "individualShift",
      children: [{
        type: "elem",
        elem: h,
        shift: A
      }, {
        type: "elem",
        elem: d,
        shift: g
      }, {
        type: "elem",
        elem: l,
        shift: -y
      }]
    }, e);
  } else {
    var T = y - l.depth - (h.height - A);
    T < D && (y += 0.5 * (D - T), A += 0.5 * (D - T)), C = F.makeVList({
      positionType: "individualShift",
      children: [{
        type: "elem",
        elem: h,
        shift: A
      }, {
        type: "elem",
        elem: l,
        shift: -y
      }]
    }, e);
  }
  i = e.havingStyle(t), C.height *= i.sizeMultiplier / e.sizeMultiplier, C.depth *= i.sizeMultiplier / e.sizeMultiplier;
  var S;
  t.size === J.DISPLAY.size ? S = e.fontMetrics().delim1 : t.size === J.SCRIPTSCRIPT.size ? S = e.havingStyle(J.SCRIPT).fontMetrics().delim2 : S = e.fontMetrics().delim2;
  var E, $;
  return n.leftDelim == null ? E = er(e, ["mopen"]) : E = Jt.customSizedDelim(n.leftDelim, S, !0, e.havingStyle(t), n.mode, ["mopen"]), n.continued ? $ = F.makeSpan([]) : n.rightDelim == null ? $ = er(e, ["mclose"]) : $ = Jt.customSizedDelim(n.rightDelim, S, !0, e.havingStyle(t), n.mode, ["mclose"]), F.makeSpan(["mord"].concat(i.sizingClasses(e)), [E, F.makeSpan(["mfrac"], [C]), $], e);
}, ia = (n, e) => {
  var t = new q.MathNode("mfrac", [pe(n.numer, e), pe(n.denom, e)]);
  if (!n.hasBarLine)
    t.setAttribute("linethickness", "0px");
  else if (n.barSize) {
    var r = ke(n.barSize, e);
    t.setAttribute("linethickness", L(r));
  }
  var a = ts(n.size, e.style);
  if (a.size !== e.style.size) {
    t = new q.MathNode("mstyle", [t]);
    var i = a.size === J.DISPLAY.size ? "true" : "false";
    t.setAttribute("displaystyle", i), t.setAttribute("scriptlevel", "0");
  }
  if (n.leftDelim != null || n.rightDelim != null) {
    var l = [];
    if (n.leftDelim != null) {
      var o = new q.MathNode("mo", [new q.TextNode(n.leftDelim.replace("\\", ""))]);
      o.setAttribute("fence", "true"), l.push(o);
    }
    if (l.push(t), n.rightDelim != null) {
      var u = new q.MathNode("mo", [new q.TextNode(n.rightDelim.replace("\\", ""))]);
      u.setAttribute("fence", "true"), l.push(u);
    }
    return Xn(l);
  }
  return t;
};
P({
  type: "genfrac",
  names: [
    "\\dfrac",
    "\\frac",
    "\\tfrac",
    "\\dbinom",
    "\\binom",
    "\\tbinom",
    "\\\\atopfrac",
    // can’t be entered directly
    "\\\\bracefrac",
    "\\\\brackfrac"
    // ditto
  ],
  props: {
    numArgs: 2,
    allowedInArgument: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = e[1], l, o = null, u = null, h = "auto";
    switch (r) {
      case "\\dfrac":
      case "\\frac":
      case "\\tfrac":
        l = !0;
        break;
      case "\\\\atopfrac":
        l = !1;
        break;
      case "\\dbinom":
      case "\\binom":
      case "\\tbinom":
        l = !1, o = "(", u = ")";
        break;
      case "\\\\bracefrac":
        l = !1, o = "\\{", u = "\\}";
        break;
      case "\\\\brackfrac":
        l = !1, o = "[", u = "]";
        break;
      default:
        throw new Error("Unrecognized genfrac command");
    }
    switch (r) {
      case "\\dfrac":
      case "\\dbinom":
        h = "display";
        break;
      case "\\tfrac":
      case "\\tbinom":
        h = "text";
        break;
    }
    return {
      type: "genfrac",
      mode: t.mode,
      continued: !1,
      numer: a,
      denom: i,
      hasBarLine: l,
      leftDelim: o,
      rightDelim: u,
      size: h,
      barSize: null
    };
  },
  htmlBuilder: aa,
  mathmlBuilder: ia
});
P({
  type: "genfrac",
  names: ["\\cfrac"],
  props: {
    numArgs: 2
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = e[1];
    return {
      type: "genfrac",
      mode: t.mode,
      continued: !0,
      numer: a,
      denom: i,
      hasBarLine: !0,
      leftDelim: null,
      rightDelim: null,
      size: "display",
      barSize: null
    };
  }
});
P({
  type: "infix",
  names: ["\\over", "\\choose", "\\atop", "\\brace", "\\brack"],
  props: {
    numArgs: 0,
    infix: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t,
      token: r
    } = n, a;
    switch (t) {
      case "\\over":
        a = "\\frac";
        break;
      case "\\choose":
        a = "\\binom";
        break;
      case "\\atop":
        a = "\\\\atopfrac";
        break;
      case "\\brace":
        a = "\\\\bracefrac";
        break;
      case "\\brack":
        a = "\\\\brackfrac";
        break;
      default:
        throw new Error("Unrecognized infix genfrac command");
    }
    return {
      type: "infix",
      mode: e.mode,
      replaceWith: a,
      token: r
    };
  }
});
var vi = ["display", "text", "script", "scriptscript"], _i = function(e) {
  var t = null;
  return e.length > 0 && (t = e, t = t === "." ? null : t), t;
};
P({
  type: "genfrac",
  names: ["\\genfrac"],
  props: {
    numArgs: 6,
    allowedInArgument: !0,
    argTypes: ["math", "math", "size", "text", "math", "math"]
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = e[4], a = e[5], i = Ir(e[0]), l = i.type === "atom" && i.family === "open" ? _i(i.text) : null, o = Ir(e[1]), u = o.type === "atom" && o.family === "close" ? _i(o.text) : null, h = ne(e[2], "size"), d, p = null;
    h.isBlank ? d = !0 : (p = h.value, d = p.number > 0);
    var b = "auto", y = e[3];
    if (y.type === "ordgroup") {
      if (y.body.length > 0) {
        var D = ne(y.body[0], "textord");
        b = vi[Number(D.text)];
      }
    } else
      y = ne(y, "textord"), b = vi[Number(y.text)];
    return {
      type: "genfrac",
      mode: t.mode,
      numer: r,
      denom: a,
      continued: !1,
      hasBarLine: d,
      barSize: p,
      leftDelim: l,
      rightDelim: u,
      size: b
    };
  },
  htmlBuilder: aa,
  mathmlBuilder: ia
});
P({
  type: "infix",
  names: ["\\above"],
  props: {
    numArgs: 1,
    argTypes: ["size"],
    infix: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r,
      token: a
    } = n;
    return {
      type: "infix",
      mode: t.mode,
      replaceWith: "\\\\abovefrac",
      size: ne(e[0], "size").value,
      token: a
    };
  }
});
P({
  type: "genfrac",
  names: ["\\\\abovefrac"],
  props: {
    numArgs: 3,
    argTypes: ["math", "size", "math"]
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = Vo(ne(e[1], "infix").size), l = e[2], o = i.number > 0;
    return {
      type: "genfrac",
      mode: t.mode,
      numer: a,
      denom: l,
      continued: !1,
      hasBarLine: o,
      barSize: i,
      leftDelim: null,
      rightDelim: null,
      size: "auto"
    };
  },
  htmlBuilder: aa,
  mathmlBuilder: ia
});
var rs = (n, e) => {
  var t = e.style, r, a;
  n.type === "supsub" ? (r = n.sup ? se(n.sup, e.havingStyle(t.sup()), e) : se(n.sub, e.havingStyle(t.sub()), e), a = ne(n.base, "horizBrace")) : a = ne(n, "horizBrace");
  var i = se(a.base, e.havingBaseStyle(J.DISPLAY)), l = e0.svgSpan(a, e), o;
  if (a.isOver ? (o = F.makeVList({
    positionType: "firstBaseline",
    children: [{
      type: "elem",
      elem: i
    }, {
      type: "kern",
      size: 0.1
    }, {
      type: "elem",
      elem: l
    }]
  }, e), o.children[0].children[0].children[1].classes.push("svg-align")) : (o = F.makeVList({
    positionType: "bottom",
    positionData: i.depth + 0.1 + l.height,
    children: [{
      type: "elem",
      elem: l
    }, {
      type: "kern",
      size: 0.1
    }, {
      type: "elem",
      elem: i
    }]
  }, e), o.children[0].children[0].children[0].classes.push("svg-align")), r) {
    var u = F.makeSpan(["mord", a.isOver ? "mover" : "munder"], [o], e);
    a.isOver ? o = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: u
      }, {
        type: "kern",
        size: 0.2
      }, {
        type: "elem",
        elem: r
      }]
    }, e) : o = F.makeVList({
      positionType: "bottom",
      positionData: u.depth + 0.2 + r.height + r.depth,
      children: [{
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: 0.2
      }, {
        type: "elem",
        elem: u
      }]
    }, e);
  }
  return F.makeSpan(["mord", a.isOver ? "mover" : "munder"], [o], e);
}, cu = (n, e) => {
  var t = e0.mathMLnode(n.label);
  return new q.MathNode(n.isOver ? "mover" : "munder", [pe(n.base, e), t]);
};
P({
  type: "horizBrace",
  names: ["\\overbrace", "\\underbrace"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n;
    return {
      type: "horizBrace",
      mode: t.mode,
      label: r,
      isOver: /^\\over/.test(r),
      base: e[0]
    };
  },
  htmlBuilder: rs,
  mathmlBuilder: cu
});
P({
  type: "href",
  names: ["\\href"],
  props: {
    numArgs: 2,
    argTypes: ["url", "original"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[1], a = ne(e[0], "url").url;
    return t.settings.isTrusted({
      command: "\\href",
      url: a
    }) ? {
      type: "href",
      mode: t.mode,
      href: a,
      body: Ae(r)
    } : t.formatUnsupportedCmd("\\href");
  },
  htmlBuilder: (n, e) => {
    var t = qe(n.body, e, !1);
    return F.makeAnchor(n.href, [], t, e);
  },
  mathmlBuilder: (n, e) => {
    var t = o0(n.body, e);
    return t instanceof Dt || (t = new Dt("mrow", [t])), t.setAttribute("href", n.href), t;
  }
});
P({
  type: "href",
  names: ["\\url"],
  props: {
    numArgs: 1,
    argTypes: ["url"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = ne(e[0], "url").url;
    if (!t.settings.isTrusted({
      command: "\\url",
      url: r
    }))
      return t.formatUnsupportedCmd("\\url");
    for (var a = [], i = 0; i < r.length; i++) {
      var l = r[i];
      l === "~" && (l = "\\textasciitilde"), a.push({
        type: "textord",
        mode: "text",
        text: l
      });
    }
    var o = {
      type: "text",
      mode: t.mode,
      font: "\\texttt",
      body: a
    };
    return {
      type: "href",
      mode: t.mode,
      href: r,
      body: Ae(o)
    };
  }
});
P({
  type: "hbox",
  names: ["\\hbox"],
  props: {
    numArgs: 1,
    argTypes: ["text"],
    allowedInText: !0,
    primitive: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "hbox",
      mode: t.mode,
      body: Ae(e[0])
    };
  },
  htmlBuilder(n, e) {
    var t = qe(n.body, e, !1);
    return F.makeFragment(t);
  },
  mathmlBuilder(n, e) {
    return new q.MathNode("mrow", rt(n.body, e));
  }
});
P({
  type: "html",
  names: ["\\htmlClass", "\\htmlId", "\\htmlStyle", "\\htmlData"],
  props: {
    numArgs: 2,
    argTypes: ["raw", "original"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r,
      token: a
    } = n, i = ne(e[0], "raw").string, l = e[1];
    t.settings.strict && t.settings.reportNonstrict("htmlExtension", "HTML extension is disabled on strict mode");
    var o, u = {};
    switch (r) {
      case "\\htmlClass":
        u.class = i, o = {
          command: "\\htmlClass",
          class: i
        };
        break;
      case "\\htmlId":
        u.id = i, o = {
          command: "\\htmlId",
          id: i
        };
        break;
      case "\\htmlStyle":
        u.style = i, o = {
          command: "\\htmlStyle",
          style: i
        };
        break;
      case "\\htmlData": {
        for (var h = i.split(","), d = 0; d < h.length; d++) {
          var p = h[d].split("=");
          if (p.length !== 2)
            throw new X("Error parsing key-value for \\htmlData");
          u["data-" + p[0].trim()] = p[1].trim();
        }
        o = {
          command: "\\htmlData",
          attributes: u
        };
        break;
      }
      default:
        throw new Error("Unrecognized html command");
    }
    return t.settings.isTrusted(o) ? {
      type: "html",
      mode: t.mode,
      attributes: u,
      body: Ae(l)
    } : t.formatUnsupportedCmd(r);
  },
  htmlBuilder: (n, e) => {
    var t = qe(n.body, e, !1), r = ["enclosing"];
    n.attributes.class && r.push(...n.attributes.class.trim().split(/\s+/));
    var a = F.makeSpan(r, t, e);
    for (var i in n.attributes)
      i !== "class" && n.attributes.hasOwnProperty(i) && a.setAttribute(i, n.attributes[i]);
    return a;
  },
  mathmlBuilder: (n, e) => o0(n.body, e)
});
P({
  type: "htmlmathml",
  names: ["\\html@mathml"],
  props: {
    numArgs: 2,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n;
    return {
      type: "htmlmathml",
      mode: t.mode,
      html: Ae(e[0]),
      mathml: Ae(e[1])
    };
  },
  htmlBuilder: (n, e) => {
    var t = qe(n.html, e, !1);
    return F.makeFragment(t);
  },
  mathmlBuilder: (n, e) => o0(n.mathml, e)
});
var pn = function(e) {
  if (/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(e))
    return {
      number: +e,
      unit: "bp"
    };
  var t = /([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(e);
  if (!t)
    throw new X("Invalid size: '" + e + "' in \\includegraphics");
  var r = {
    number: +(t[1] + t[2]),
    // sign + magnitude, cast to number
    unit: t[3]
  };
  if (!h1(r))
    throw new X("Invalid unit: '" + r.unit + "' in \\includegraphics.");
  return r;
};
P({
  type: "includegraphics",
  names: ["\\includegraphics"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1,
    argTypes: ["raw", "url"],
    allowedInText: !1
  },
  handler: (n, e, t) => {
    var {
      parser: r
    } = n, a = {
      number: 0,
      unit: "em"
    }, i = {
      number: 0.9,
      unit: "em"
    }, l = {
      number: 0,
      unit: "em"
    }, o = "";
    if (t[0])
      for (var u = ne(t[0], "raw").string, h = u.split(","), d = 0; d < h.length; d++) {
        var p = h[d].split("=");
        if (p.length === 2) {
          var b = p[1].trim();
          switch (p[0].trim()) {
            case "alt":
              o = b;
              break;
            case "width":
              a = pn(b);
              break;
            case "height":
              i = pn(b);
              break;
            case "totalheight":
              l = pn(b);
              break;
            default:
              throw new X("Invalid key: '" + p[0] + "' in \\includegraphics.");
          }
        }
      }
    var y = ne(e[0], "url").url;
    return o === "" && (o = y, o = o.replace(/^.*[\\/]/, ""), o = o.substring(0, o.lastIndexOf("."))), r.settings.isTrusted({
      command: "\\includegraphics",
      url: y
    }) ? {
      type: "includegraphics",
      mode: r.mode,
      alt: o,
      width: a,
      height: i,
      totalheight: l,
      src: y
    } : r.formatUnsupportedCmd("\\includegraphics");
  },
  htmlBuilder: (n, e) => {
    var t = ke(n.height, e), r = 0;
    n.totalheight.number > 0 && (r = ke(n.totalheight, e) - t);
    var a = 0;
    n.width.number > 0 && (a = ke(n.width, e));
    var i = {
      height: L(t + r)
    };
    a > 0 && (i.width = L(a)), r > 0 && (i.verticalAlign = L(-r));
    var l = new m1(n.src, n.alt, i);
    return l.height = t, l.depth = r, l;
  },
  mathmlBuilder: (n, e) => {
    var t = new q.MathNode("mglyph", []);
    t.setAttribute("alt", n.alt);
    var r = ke(n.height, e), a = 0;
    if (n.totalheight.number > 0 && (a = ke(n.totalheight, e) - r, t.setAttribute("valign", L(-a))), t.setAttribute("height", L(r + a)), n.width.number > 0) {
      var i = ke(n.width, e);
      t.setAttribute("width", L(i));
    }
    return t.setAttribute("src", n.src), t;
  }
});
P({
  type: "kern",
  names: ["\\kern", "\\mkern", "\\hskip", "\\mskip"],
  props: {
    numArgs: 1,
    argTypes: ["size"],
    primitive: !0,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = ne(e[0], "size");
    if (t.settings.strict) {
      var i = r[1] === "m", l = a.value.unit === "mu";
      i ? (l || t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " supports only mu units, " + ("not " + a.value.unit + " units")), t.mode !== "math" && t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " works only in math mode")) : l && t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " doesn't support mu units");
    }
    return {
      type: "kern",
      mode: t.mode,
      dimension: a.value
    };
  },
  htmlBuilder(n, e) {
    return F.makeGlue(n.dimension, e);
  },
  mathmlBuilder(n, e) {
    var t = ke(n.dimension, e);
    return new q.SpaceNode(t);
  }
});
P({
  type: "lap",
  names: ["\\mathllap", "\\mathrlap", "\\mathclap"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "lap",
      mode: t.mode,
      alignment: r.slice(5),
      body: a
    };
  },
  htmlBuilder: (n, e) => {
    var t;
    n.alignment === "clap" ? (t = F.makeSpan([], [se(n.body, e)]), t = F.makeSpan(["inner"], [t], e)) : t = F.makeSpan(["inner"], [se(n.body, e)]);
    var r = F.makeSpan(["fix"], []), a = F.makeSpan([n.alignment], [t, r], e), i = F.makeSpan(["strut"]);
    return i.style.height = L(a.height + a.depth), a.depth && (i.style.verticalAlign = L(-a.depth)), a.children.unshift(i), a = F.makeSpan(["thinbox"], [a], e), F.makeSpan(["mord", "vbox"], [a], e);
  },
  mathmlBuilder: (n, e) => {
    var t = new q.MathNode("mpadded", [pe(n.body, e)]);
    if (n.alignment !== "rlap") {
      var r = n.alignment === "llap" ? "-1" : "-0.5";
      t.setAttribute("lspace", r + "width");
    }
    return t.setAttribute("width", "0px"), t;
  }
});
P({
  type: "styling",
  names: ["\\(", "$"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !1
  },
  handler(n, e) {
    var {
      funcName: t,
      parser: r
    } = n, a = r.mode;
    r.switchMode("math");
    var i = t === "\\(" ? "\\)" : "$", l = r.parseExpression(!1, i);
    return r.expect(i), r.switchMode(a), {
      type: "styling",
      mode: r.mode,
      style: "text",
      body: l
    };
  }
});
P({
  type: "text",
  // Doesn't matter what this is.
  names: ["\\)", "\\]"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !1
  },
  handler(n, e) {
    throw new X("Mismatched " + n.funcName);
  }
});
var bi = (n, e) => {
  switch (e.style.size) {
    case J.DISPLAY.size:
      return n.display;
    case J.TEXT.size:
      return n.text;
    case J.SCRIPT.size:
      return n.script;
    case J.SCRIPTSCRIPT.size:
      return n.scriptscript;
    default:
      return n.text;
  }
};
P({
  type: "mathchoice",
  names: ["\\mathchoice"],
  props: {
    numArgs: 4,
    primitive: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n;
    return {
      type: "mathchoice",
      mode: t.mode,
      display: Ae(e[0]),
      text: Ae(e[1]),
      script: Ae(e[2]),
      scriptscript: Ae(e[3])
    };
  },
  htmlBuilder: (n, e) => {
    var t = bi(n, e), r = qe(t, e, !1);
    return F.makeFragment(r);
  },
  mathmlBuilder: (n, e) => {
    var t = bi(n, e);
    return o0(t, e);
  }
});
var ns = (n, e, t, r, a, i, l) => {
  n = F.makeSpan([], [n]);
  var o = t && K.isCharacterBox(t), u, h;
  if (e) {
    var d = se(e, r.havingStyle(a.sup()), r);
    h = {
      elem: d,
      kern: Math.max(r.fontMetrics().bigOpSpacing1, r.fontMetrics().bigOpSpacing3 - d.depth)
    };
  }
  if (t) {
    var p = se(t, r.havingStyle(a.sub()), r);
    u = {
      elem: p,
      kern: Math.max(r.fontMetrics().bigOpSpacing2, r.fontMetrics().bigOpSpacing4 - p.height)
    };
  }
  var b;
  if (h && u) {
    var y = r.fontMetrics().bigOpSpacing5 + u.elem.height + u.elem.depth + u.kern + n.depth + l;
    b = F.makeVList({
      positionType: "bottom",
      positionData: y,
      children: [{
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }, {
        type: "elem",
        elem: u.elem,
        marginLeft: L(-i)
      }, {
        type: "kern",
        size: u.kern
      }, {
        type: "elem",
        elem: n
      }, {
        type: "kern",
        size: h.kern
      }, {
        type: "elem",
        elem: h.elem,
        marginLeft: L(i)
      }, {
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }]
    }, r);
  } else if (u) {
    var D = n.height - l;
    b = F.makeVList({
      positionType: "top",
      positionData: D,
      children: [{
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }, {
        type: "elem",
        elem: u.elem,
        marginLeft: L(-i)
      }, {
        type: "kern",
        size: u.kern
      }, {
        type: "elem",
        elem: n
      }]
    }, r);
  } else if (h) {
    var A = n.depth + l;
    b = F.makeVList({
      positionType: "bottom",
      positionData: A,
      children: [{
        type: "elem",
        elem: n
      }, {
        type: "kern",
        size: h.kern
      }, {
        type: "elem",
        elem: h.elem,
        marginLeft: L(i)
      }, {
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }]
    }, r);
  } else
    return n;
  var C = [b];
  if (u && i !== 0 && !o) {
    var T = F.makeSpan(["mspace"], [], r);
    T.style.marginRight = L(i), C.unshift(T);
  }
  return F.makeSpan(["mop", "op-limits"], C, r);
}, as = ["\\smallint"], q0 = (n, e) => {
  var t, r, a = !1, i;
  n.type === "supsub" ? (t = n.sup, r = n.sub, i = ne(n.base, "op"), a = !0) : i = ne(n, "op");
  var l = e.style, o = !1;
  l.size === J.DISPLAY.size && i.symbol && !K.contains(as, i.name) && (o = !0);
  var u;
  if (i.symbol) {
    var h = o ? "Size2-Regular" : "Size1-Regular", d = "";
    if ((i.name === "\\oiint" || i.name === "\\oiiint") && (d = i.name.slice(1), i.name = d === "oiint" ? "\\iint" : "\\iiint"), u = F.makeSymbol(i.name, h, "math", e, ["mop", "op-symbol", o ? "large-op" : "small-op"]), d.length > 0) {
      var p = u.italic, b = F.staticSvg(d + "Size" + (o ? "2" : "1"), e);
      u = F.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: u,
          shift: 0
        }, {
          type: "elem",
          elem: b,
          shift: o ? 0.08 : 0
        }]
      }, e), i.name = "\\" + d, u.classes.unshift("mop"), u.italic = p;
    }
  } else if (i.body) {
    var y = qe(i.body, e, !0);
    y.length === 1 && y[0] instanceof Lt ? (u = y[0], u.classes[0] = "mop") : u = F.makeSpan(["mop"], y, e);
  } else {
    for (var D = [], A = 1; A < i.name.length; A++)
      D.push(F.mathsym(i.name[A], i.mode, e));
    u = F.makeSpan(["mop"], D, e);
  }
  var C = 0, T = 0;
  return (u instanceof Lt || i.name === "\\oiint" || i.name === "\\oiiint") && !i.suppressBaseShift && (C = (u.height - u.depth) / 2 - e.fontMetrics().axisHeight, T = u.italic), a ? ns(u, t, r, e, l, T, C) : (C && (u.style.position = "relative", u.style.top = L(C)), u);
}, nr = (n, e) => {
  var t;
  if (n.symbol)
    t = new Dt("mo", [ot(n.name, n.mode)]), K.contains(as, n.name) && t.setAttribute("largeop", "false");
  else if (n.body)
    t = new Dt("mo", rt(n.body, e));
  else {
    t = new Dt("mi", [new j0(n.name.slice(1))]);
    var r = new Dt("mo", [ot("⁡", "text")]);
    n.parentIsSupSub ? t = new Dt("mrow", [t, r]) : t = Rl([t, r]);
  }
  return t;
}, hu = {
  "∏": "\\prod",
  "∐": "\\coprod",
  "∑": "\\sum",
  "⋀": "\\bigwedge",
  "⋁": "\\bigvee",
  "⋂": "\\bigcap",
  "⋃": "\\bigcup",
  "⨀": "\\bigodot",
  "⨁": "\\bigoplus",
  "⨂": "\\bigotimes",
  "⨄": "\\biguplus",
  "⨆": "\\bigsqcup"
};
P({
  type: "op",
  names: ["\\coprod", "\\bigvee", "\\bigwedge", "\\biguplus", "\\bigcap", "\\bigcup", "\\intop", "\\prod", "\\sum", "\\bigotimes", "\\bigoplus", "\\bigodot", "\\bigsqcup", "\\smallint", "∏", "∐", "∑", "⋀", "⋁", "⋂", "⋃", "⨀", "⨁", "⨂", "⨄", "⨆"],
  props: {
    numArgs: 0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = r;
    return a.length === 1 && (a = hu[a]), {
      type: "op",
      mode: t.mode,
      limits: !0,
      parentIsSupSub: !1,
      symbol: !0,
      name: a
    };
  },
  htmlBuilder: q0,
  mathmlBuilder: nr
});
P({
  type: "op",
  names: ["\\mathop"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "op",
      mode: t.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !1,
      body: Ae(r)
    };
  },
  htmlBuilder: q0,
  mathmlBuilder: nr
});
var mu = {
  "∫": "\\int",
  "∬": "\\iint",
  "∭": "\\iiint",
  "∮": "\\oint",
  "∯": "\\oiint",
  "∰": "\\oiiint"
};
P({
  type: "op",
  names: ["\\arcsin", "\\arccos", "\\arctan", "\\arctg", "\\arcctg", "\\arg", "\\ch", "\\cos", "\\cosec", "\\cosh", "\\cot", "\\cotg", "\\coth", "\\csc", "\\ctg", "\\cth", "\\deg", "\\dim", "\\exp", "\\hom", "\\ker", "\\lg", "\\ln", "\\log", "\\sec", "\\sin", "\\sinh", "\\sh", "\\tan", "\\tanh", "\\tg", "\\th"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    return {
      type: "op",
      mode: e.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !1,
      name: t
    };
  },
  htmlBuilder: q0,
  mathmlBuilder: nr
});
P({
  type: "op",
  names: ["\\det", "\\gcd", "\\inf", "\\lim", "\\max", "\\min", "\\Pr", "\\sup"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    return {
      type: "op",
      mode: e.mode,
      limits: !0,
      parentIsSupSub: !1,
      symbol: !1,
      name: t
    };
  },
  htmlBuilder: q0,
  mathmlBuilder: nr
});
P({
  type: "op",
  names: ["\\int", "\\iint", "\\iiint", "\\oint", "\\oiint", "\\oiiint", "∫", "∬", "∭", "∮", "∯", "∰"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = t;
    return r.length === 1 && (r = mu[r]), {
      type: "op",
      mode: e.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !0,
      name: r
    };
  },
  htmlBuilder: q0,
  mathmlBuilder: nr
});
var is = (n, e) => {
  var t, r, a = !1, i;
  n.type === "supsub" ? (t = n.sup, r = n.sub, i = ne(n.base, "operatorname"), a = !0) : i = ne(n, "operatorname");
  var l;
  if (i.body.length > 0) {
    for (var o = i.body.map((p) => {
      var b = p.text;
      return typeof b == "string" ? {
        type: "textord",
        mode: p.mode,
        text: b
      } : p;
    }), u = qe(o, e.withFont("mathrm"), !0), h = 0; h < u.length; h++) {
      var d = u[h];
      d instanceof Lt && (d.text = d.text.replace(/\u2212/, "-").replace(/\u2217/, "*"));
    }
    l = F.makeSpan(["mop"], u, e);
  } else
    l = F.makeSpan(["mop"], [], e);
  return a ? ns(l, t, r, e, e.style, 0, 0) : l;
}, du = (n, e) => {
  for (var t = rt(n.body, e.withFont("mathrm")), r = !0, a = 0; a < t.length; a++) {
    var i = t[a];
    if (!(i instanceof q.SpaceNode)) if (i instanceof q.MathNode)
      switch (i.type) {
        case "mi":
        case "mn":
        case "ms":
        case "mspace":
        case "mtext":
          break;
        case "mo": {
          var l = i.children[0];
          i.children.length === 1 && l instanceof q.TextNode ? l.text = l.text.replace(/\u2212/, "-").replace(/\u2217/, "*") : r = !1;
          break;
        }
        default:
          r = !1;
      }
    else
      r = !1;
  }
  if (r) {
    var o = t.map((d) => d.toText()).join("");
    t = [new q.TextNode(o)];
  }
  var u = new q.MathNode("mi", t);
  u.setAttribute("mathvariant", "normal");
  var h = new q.MathNode("mo", [ot("⁡", "text")]);
  return n.parentIsSupSub ? new q.MathNode("mrow", [u, h]) : q.newDocumentFragment([u, h]);
};
P({
  type: "operatorname",
  names: ["\\operatorname@", "\\operatornamewithlimits"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "operatorname",
      mode: t.mode,
      body: Ae(a),
      alwaysHandleSupSub: r === "\\operatornamewithlimits",
      limits: !1,
      parentIsSupSub: !1
    };
  },
  htmlBuilder: is,
  mathmlBuilder: du
});
f("\\operatorname", "\\@ifstar\\operatornamewithlimits\\operatorname@");
_0({
  type: "ordgroup",
  htmlBuilder(n, e) {
    return n.semisimple ? F.makeFragment(qe(n.body, e, !1)) : F.makeSpan(["mord"], qe(n.body, e, !0), e);
  },
  mathmlBuilder(n, e) {
    return o0(n.body, e, !0);
  }
});
P({
  type: "overline",
  names: ["\\overline"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "overline",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder(n, e) {
    var t = se(n.body, e.havingCrampedStyle()), r = F.makeLineSpan("overline-line", e), a = e.fontMetrics().defaultRuleThickness, i = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }, {
        type: "kern",
        size: 3 * a
      }, {
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: a
      }]
    }, e);
    return F.makeSpan(["mord", "overline"], [i], e);
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mo", [new q.TextNode("‾")]);
    t.setAttribute("stretchy", "true");
    var r = new q.MathNode("mover", [pe(n.body, e), t]);
    return r.setAttribute("accent", "true"), r;
  }
});
P({
  type: "phantom",
  names: ["\\phantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "phantom",
      mode: t.mode,
      body: Ae(r)
    };
  },
  htmlBuilder: (n, e) => {
    var t = qe(n.body, e.withPhantom(), !1);
    return F.makeFragment(t);
  },
  mathmlBuilder: (n, e) => {
    var t = rt(n.body, e);
    return new q.MathNode("mphantom", t);
  }
});
P({
  type: "hphantom",
  names: ["\\hphantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "hphantom",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder: (n, e) => {
    var t = F.makeSpan([], [se(n.body, e.withPhantom())]);
    if (t.height = 0, t.depth = 0, t.children)
      for (var r = 0; r < t.children.length; r++)
        t.children[r].height = 0, t.children[r].depth = 0;
    return t = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }]
    }, e), F.makeSpan(["mord"], [t], e);
  },
  mathmlBuilder: (n, e) => {
    var t = rt(Ae(n.body), e), r = new q.MathNode("mphantom", t), a = new q.MathNode("mpadded", [r]);
    return a.setAttribute("height", "0px"), a.setAttribute("depth", "0px"), a;
  }
});
P({
  type: "vphantom",
  names: ["\\vphantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "vphantom",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder: (n, e) => {
    var t = F.makeSpan(["inner"], [se(n.body, e.withPhantom())]), r = F.makeSpan(["fix"], []);
    return F.makeSpan(["mord", "rlap"], [t, r], e);
  },
  mathmlBuilder: (n, e) => {
    var t = rt(Ae(n.body), e), r = new q.MathNode("mphantom", t), a = new q.MathNode("mpadded", [r]);
    return a.setAttribute("width", "0px"), a;
  }
});
P({
  type: "raisebox",
  names: ["\\raisebox"],
  props: {
    numArgs: 2,
    argTypes: ["size", "hbox"],
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = ne(e[0], "size").value, a = e[1];
    return {
      type: "raisebox",
      mode: t.mode,
      dy: r,
      body: a
    };
  },
  htmlBuilder(n, e) {
    var t = se(n.body, e), r = ke(n.dy, e);
    return F.makeVList({
      positionType: "shift",
      positionData: -r,
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mpadded", [pe(n.body, e)]), r = n.dy.number + n.dy.unit;
    return t.setAttribute("voffset", r), t;
  }
});
P({
  type: "internal",
  names: ["\\relax"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n) {
    var {
      parser: e
    } = n;
    return {
      type: "internal",
      mode: e.mode
    };
  }
});
P({
  type: "rule",
  names: ["\\rule"],
  props: {
    numArgs: 2,
    numOptionalArgs: 1,
    argTypes: ["size", "size", "size"]
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = t[0], i = ne(e[0], "size"), l = ne(e[1], "size");
    return {
      type: "rule",
      mode: r.mode,
      shift: a && ne(a, "size").value,
      width: i.value,
      height: l.value
    };
  },
  htmlBuilder(n, e) {
    var t = F.makeSpan(["mord", "rule"], [], e), r = ke(n.width, e), a = ke(n.height, e), i = n.shift ? ke(n.shift, e) : 0;
    return t.style.borderRightWidth = L(r), t.style.borderTopWidth = L(a), t.style.bottom = L(i), t.width = r, t.height = a + i, t.depth = -i, t.maxFontSize = a * 1.125 * e.sizeMultiplier, t;
  },
  mathmlBuilder(n, e) {
    var t = ke(n.width, e), r = ke(n.height, e), a = n.shift ? ke(n.shift, e) : 0, i = e.color && e.getColor() || "black", l = new q.MathNode("mspace");
    l.setAttribute("mathbackground", i), l.setAttribute("width", L(t)), l.setAttribute("height", L(r));
    var o = new q.MathNode("mpadded", [l]);
    return a >= 0 ? o.setAttribute("height", L(a)) : (o.setAttribute("height", L(a)), o.setAttribute("depth", L(-a))), o.setAttribute("voffset", L(a)), o;
  }
});
function ls(n, e, t) {
  for (var r = qe(n, e, !1), a = e.sizeMultiplier / t.sizeMultiplier, i = 0; i < r.length; i++) {
    var l = r[i].classes.indexOf("sizing");
    l < 0 ? Array.prototype.push.apply(r[i].classes, e.sizingClasses(t)) : r[i].classes[l + 1] === "reset-size" + e.size && (r[i].classes[l + 1] = "reset-size" + t.size), r[i].height *= a, r[i].depth *= a;
  }
  return F.makeFragment(r);
}
var yi = ["\\tiny", "\\sixptsize", "\\scriptsize", "\\footnotesize", "\\small", "\\normalsize", "\\large", "\\Large", "\\LARGE", "\\huge", "\\Huge"], fu = (n, e) => {
  var t = e.havingSize(n.size);
  return ls(n.body, t, e);
};
P({
  type: "sizing",
  names: yi,
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      breakOnTokenText: t,
      funcName: r,
      parser: a
    } = n, i = a.parseExpression(!1, t);
    return {
      type: "sizing",
      mode: a.mode,
      // Figure out what size to use based on the list of functions above
      size: yi.indexOf(r) + 1,
      body: i
    };
  },
  htmlBuilder: fu,
  mathmlBuilder: (n, e) => {
    var t = e.havingSize(n.size), r = rt(n.body, t), a = new q.MathNode("mstyle", r);
    return a.setAttribute("mathsize", L(t.sizeMultiplier)), a;
  }
});
P({
  type: "smash",
  names: ["\\smash"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1,
    allowedInText: !0
  },
  handler: (n, e, t) => {
    var {
      parser: r
    } = n, a = !1, i = !1, l = t[0] && ne(t[0], "ordgroup");
    if (l)
      for (var o = "", u = 0; u < l.body.length; ++u) {
        var h = l.body[u];
        if (o = h.text, o === "t")
          a = !0;
        else if (o === "b")
          i = !0;
        else {
          a = !1, i = !1;
          break;
        }
      }
    else
      a = !0, i = !0;
    var d = e[0];
    return {
      type: "smash",
      mode: r.mode,
      body: d,
      smashHeight: a,
      smashDepth: i
    };
  },
  htmlBuilder: (n, e) => {
    var t = F.makeSpan([], [se(n.body, e)]);
    if (!n.smashHeight && !n.smashDepth)
      return t;
    if (n.smashHeight && (t.height = 0, t.children))
      for (var r = 0; r < t.children.length; r++)
        t.children[r].height = 0;
    if (n.smashDepth && (t.depth = 0, t.children))
      for (var a = 0; a < t.children.length; a++)
        t.children[a].depth = 0;
    var i = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
    return F.makeSpan(["mord"], [i], e);
  },
  mathmlBuilder: (n, e) => {
    var t = new q.MathNode("mpadded", [pe(n.body, e)]);
    return n.smashHeight && t.setAttribute("height", "0px"), n.smashDepth && t.setAttribute("depth", "0px"), t;
  }
});
P({
  type: "sqrt",
  names: ["\\sqrt"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = t[0], i = e[0];
    return {
      type: "sqrt",
      mode: r.mode,
      body: i,
      index: a
    };
  },
  htmlBuilder(n, e) {
    var t = se(n.body, e.havingCrampedStyle());
    t.height === 0 && (t.height = e.fontMetrics().xHeight), t = F.wrapFragment(t, e);
    var r = e.fontMetrics(), a = r.defaultRuleThickness, i = a;
    e.style.id < J.TEXT.id && (i = e.fontMetrics().xHeight);
    var l = a + i / 4, o = t.height + t.depth + l + a, {
      span: u,
      ruleWidth: h,
      advanceWidth: d
    } = Jt.sqrtImage(o, e), p = u.height - h;
    p > t.height + t.depth + l && (l = (l + p - t.height - t.depth) / 2);
    var b = u.height - t.height - l - h;
    t.style.paddingLeft = L(d);
    var y = F.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t,
        wrapperClasses: ["svg-align"]
      }, {
        type: "kern",
        size: -(t.height + b)
      }, {
        type: "elem",
        elem: u
      }, {
        type: "kern",
        size: h
      }]
    }, e);
    if (n.index) {
      var D = e.havingStyle(J.SCRIPTSCRIPT), A = se(n.index, D, e), C = 0.6 * (y.height - y.depth), T = F.makeVList({
        positionType: "shift",
        positionData: -C,
        children: [{
          type: "elem",
          elem: A
        }]
      }, e), w = F.makeSpan(["root"], [T]);
      return F.makeSpan(["mord", "sqrt"], [w, y], e);
    } else
      return F.makeSpan(["mord", "sqrt"], [y], e);
  },
  mathmlBuilder(n, e) {
    var {
      body: t,
      index: r
    } = n;
    return r ? new q.MathNode("mroot", [pe(t, e), pe(r, e)]) : new q.MathNode("msqrt", [pe(t, e)]);
  }
});
var wi = {
  display: J.DISPLAY,
  text: J.TEXT,
  script: J.SCRIPT,
  scriptscript: J.SCRIPTSCRIPT
};
P({
  type: "styling",
  names: ["\\displaystyle", "\\textstyle", "\\scriptstyle", "\\scriptscriptstyle"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n, e) {
    var {
      breakOnTokenText: t,
      funcName: r,
      parser: a
    } = n, i = a.parseExpression(!0, t), l = r.slice(1, r.length - 5);
    return {
      type: "styling",
      mode: a.mode,
      // Figure out what style to use by pulling out the style from
      // the function name
      style: l,
      body: i
    };
  },
  htmlBuilder(n, e) {
    var t = wi[n.style], r = e.havingStyle(t).withFont("");
    return ls(n.body, r, e);
  },
  mathmlBuilder(n, e) {
    var t = wi[n.style], r = e.havingStyle(t), a = rt(n.body, r), i = new q.MathNode("mstyle", a), l = {
      display: ["0", "true"],
      text: ["0", "false"],
      script: ["1", "false"],
      scriptscript: ["2", "false"]
    }, o = l[n.style];
    return i.setAttribute("scriptlevel", o[0]), i.setAttribute("displaystyle", o[1]), i;
  }
});
var pu = function(e, t) {
  var r = e.base;
  if (r)
    if (r.type === "op") {
      var a = r.limits && (t.style.size === J.DISPLAY.size || r.alwaysHandleSupSub);
      return a ? q0 : null;
    } else if (r.type === "operatorname") {
      var i = r.alwaysHandleSupSub && (t.style.size === J.DISPLAY.size || r.limits);
      return i ? is : null;
    } else {
      if (r.type === "accent")
        return K.isCharacterBox(r.base) ? Qn : null;
      if (r.type === "horizBrace") {
        var l = !e.sub;
        return l === r.isOver ? rs : null;
      } else
        return null;
    }
  else return null;
};
_0({
  type: "supsub",
  htmlBuilder(n, e) {
    var t = pu(n, e);
    if (t)
      return t(n, e);
    var {
      base: r,
      sup: a,
      sub: i
    } = n, l = se(r, e), o, u, h = e.fontMetrics(), d = 0, p = 0, b = r && K.isCharacterBox(r);
    if (a) {
      var y = e.havingStyle(e.style.sup());
      o = se(a, y, e), b || (d = l.height - y.fontMetrics().supDrop * y.sizeMultiplier / e.sizeMultiplier);
    }
    if (i) {
      var D = e.havingStyle(e.style.sub());
      u = se(i, D, e), b || (p = l.depth + D.fontMetrics().subDrop * D.sizeMultiplier / e.sizeMultiplier);
    }
    var A;
    e.style === J.DISPLAY ? A = h.sup1 : e.style.cramped ? A = h.sup3 : A = h.sup2;
    var C = e.sizeMultiplier, T = L(0.5 / h.ptPerEm / C), w = null;
    if (u) {
      var g = n.base && n.base.type === "op" && n.base.name && (n.base.name === "\\oiint" || n.base.name === "\\oiiint");
      (l instanceof Lt || g) && (w = L(-l.italic));
    }
    var S;
    if (o && u) {
      d = Math.max(d, A, o.depth + 0.25 * h.xHeight), p = Math.max(p, h.sub2);
      var E = h.defaultRuleThickness, $ = 4 * E;
      if (d - o.depth - (u.height - p) < $) {
        p = $ - (d - o.depth) + u.height;
        var B = 0.8 * h.xHeight - (d - o.depth);
        B > 0 && (d += B, p -= B);
      }
      var O = [{
        type: "elem",
        elem: u,
        shift: p,
        marginRight: T,
        marginLeft: w
      }, {
        type: "elem",
        elem: o,
        shift: -d,
        marginRight: T
      }];
      S = F.makeVList({
        positionType: "individualShift",
        children: O
      }, e);
    } else if (u) {
      p = Math.max(p, h.sub1, u.height - 0.8 * h.xHeight);
      var M = [{
        type: "elem",
        elem: u,
        marginLeft: w,
        marginRight: T
      }];
      S = F.makeVList({
        positionType: "shift",
        positionData: p,
        children: M
      }, e);
    } else if (o)
      d = Math.max(d, A, o.depth + 0.25 * h.xHeight), S = F.makeVList({
        positionType: "shift",
        positionData: -d,
        children: [{
          type: "elem",
          elem: o,
          marginRight: T
        }]
      }, e);
    else
      throw new Error("supsub must have either sup or sub.");
    var R = $n(l, "right") || "mord";
    return F.makeSpan([R], [l, F.makeSpan(["msupsub"], [S])], e);
  },
  mathmlBuilder(n, e) {
    var t = !1, r, a;
    n.base && n.base.type === "horizBrace" && (a = !!n.sup, a === n.base.isOver && (t = !0, r = n.base.isOver)), n.base && (n.base.type === "op" || n.base.type === "operatorname") && (n.base.parentIsSupSub = !0);
    var i = [pe(n.base, e)];
    n.sub && i.push(pe(n.sub, e)), n.sup && i.push(pe(n.sup, e));
    var l;
    if (t)
      l = r ? "mover" : "munder";
    else if (n.sub)
      if (n.sup) {
        var h = n.base;
        h && h.type === "op" && h.limits && e.style === J.DISPLAY || h && h.type === "operatorname" && h.alwaysHandleSupSub && (e.style === J.DISPLAY || h.limits) ? l = "munderover" : l = "msubsup";
      } else {
        var u = n.base;
        u && u.type === "op" && u.limits && (e.style === J.DISPLAY || u.alwaysHandleSupSub) || u && u.type === "operatorname" && u.alwaysHandleSupSub && (u.limits || e.style === J.DISPLAY) ? l = "munder" : l = "msub";
      }
    else {
      var o = n.base;
      o && o.type === "op" && o.limits && (e.style === J.DISPLAY || o.alwaysHandleSupSub) || o && o.type === "operatorname" && o.alwaysHandleSupSub && (o.limits || e.style === J.DISPLAY) ? l = "mover" : l = "msup";
    }
    return new q.MathNode(l, i);
  }
});
_0({
  type: "atom",
  htmlBuilder(n, e) {
    return F.mathsym(n.text, n.mode, e, ["m" + n.family]);
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mo", [ot(n.text, n.mode)]);
    if (n.family === "bin") {
      var r = Zn(n, e);
      r === "bold-italic" && t.setAttribute("mathvariant", r);
    } else n.family === "punct" ? t.setAttribute("separator", "true") : (n.family === "open" || n.family === "close") && t.setAttribute("stretchy", "false");
    return t;
  }
});
var ss = {
  mi: "italic",
  mn: "normal",
  mtext: "normal"
};
_0({
  type: "mathord",
  htmlBuilder(n, e) {
    return F.makeOrd(n, e, "mathord");
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mi", [ot(n.text, n.mode, e)]), r = Zn(n, e) || "italic";
    return r !== ss[t.type] && t.setAttribute("mathvariant", r), t;
  }
});
_0({
  type: "textord",
  htmlBuilder(n, e) {
    return F.makeOrd(n, e, "textord");
  },
  mathmlBuilder(n, e) {
    var t = ot(n.text, n.mode, e), r = Zn(n, e) || "normal", a;
    return n.mode === "text" ? a = new q.MathNode("mtext", [t]) : /[0-9]/.test(n.text) ? a = new q.MathNode("mn", [t]) : n.text === "\\prime" ? a = new q.MathNode("mo", [t]) : a = new q.MathNode("mi", [t]), r !== ss[a.type] && a.setAttribute("mathvariant", r), a;
  }
});
var gn = {
  "\\nobreak": "nobreak",
  "\\allowbreak": "allowbreak"
}, vn = {
  " ": {},
  "\\ ": {},
  "~": {
    className: "nobreak"
  },
  "\\space": {},
  "\\nobreakspace": {
    className: "nobreak"
  }
};
_0({
  type: "spacing",
  htmlBuilder(n, e) {
    if (vn.hasOwnProperty(n.text)) {
      var t = vn[n.text].className || "";
      if (n.mode === "text") {
        var r = F.makeOrd(n, e, "textord");
        return r.classes.push(t), r;
      } else
        return F.makeSpan(["mspace", t], [F.mathsym(n.text, n.mode, e)], e);
    } else {
      if (gn.hasOwnProperty(n.text))
        return F.makeSpan(["mspace", gn[n.text]], [], e);
      throw new X('Unknown type of space "' + n.text + '"');
    }
  },
  mathmlBuilder(n, e) {
    var t;
    if (vn.hasOwnProperty(n.text))
      t = new q.MathNode("mtext", [new q.TextNode(" ")]);
    else {
      if (gn.hasOwnProperty(n.text))
        return new q.MathNode("mspace");
      throw new X('Unknown type of space "' + n.text + '"');
    }
    return t;
  }
});
var ki = () => {
  var n = new q.MathNode("mtd", []);
  return n.setAttribute("width", "50%"), n;
};
_0({
  type: "tag",
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mtable", [new q.MathNode("mtr", [ki(), new q.MathNode("mtd", [o0(n.body, e)]), ki(), new q.MathNode("mtd", [o0(n.tag, e)])])]);
    return t.setAttribute("width", "100%"), t;
  }
});
var Di = {
  "\\text": void 0,
  "\\textrm": "textrm",
  "\\textsf": "textsf",
  "\\texttt": "texttt",
  "\\textnormal": "textrm"
}, xi = {
  "\\textbf": "textbf",
  "\\textmd": "textmd"
}, gu = {
  "\\textit": "textit",
  "\\textup": "textup"
}, Si = (n, e) => {
  var t = n.font;
  if (t) {
    if (Di[t])
      return e.withTextFontFamily(Di[t]);
    if (xi[t])
      return e.withTextFontWeight(xi[t]);
    if (t === "\\emph")
      return e.fontShape === "textit" ? e.withTextFontShape("textup") : e.withTextFontShape("textit");
  } else return e;
  return e.withTextFontShape(gu[t]);
};
P({
  type: "text",
  names: [
    // Font families
    "\\text",
    "\\textrm",
    "\\textsf",
    "\\texttt",
    "\\textnormal",
    // Font weights
    "\\textbf",
    "\\textmd",
    // Font Shapes
    "\\textit",
    "\\textup",
    "\\emph"
  ],
  props: {
    numArgs: 1,
    argTypes: ["text"],
    allowedInArgument: !0,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "text",
      mode: t.mode,
      body: Ae(a),
      font: r
    };
  },
  htmlBuilder(n, e) {
    var t = Si(n, e), r = qe(n.body, t, !0);
    return F.makeSpan(["mord", "text"], r, t);
  },
  mathmlBuilder(n, e) {
    var t = Si(n, e);
    return o0(n.body, t);
  }
});
P({
  type: "underline",
  names: ["\\underline"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "underline",
      mode: t.mode,
      body: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = se(n.body, e), r = F.makeLineSpan("underline-line", e), a = e.fontMetrics().defaultRuleThickness, i = F.makeVList({
      positionType: "top",
      positionData: t.height,
      children: [{
        type: "kern",
        size: a
      }, {
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: 3 * a
      }, {
        type: "elem",
        elem: t
      }]
    }, e);
    return F.makeSpan(["mord", "underline"], [i], e);
  },
  mathmlBuilder(n, e) {
    var t = new q.MathNode("mo", [new q.TextNode("‾")]);
    t.setAttribute("stretchy", "true");
    var r = new q.MathNode("munder", [pe(n.body, e), t]);
    return r.setAttribute("accentunder", "true"), r;
  }
});
P({
  type: "vcenter",
  names: ["\\vcenter"],
  props: {
    numArgs: 1,
    argTypes: ["original"],
    // In LaTeX, \vcenter can act only on a box.
    allowedInText: !1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "vcenter",
      mode: t.mode,
      body: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = se(n.body, e), r = e.fontMetrics().axisHeight, a = 0.5 * (t.height - r - (t.depth + r));
    return F.makeVList({
      positionType: "shift",
      positionData: a,
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
  },
  mathmlBuilder(n, e) {
    return new q.MathNode("mpadded", [pe(n.body, e)], ["vcenter"]);
  }
});
P({
  type: "verb",
  names: ["\\verb"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n, e, t) {
    throw new X("\\verb ended by end of line instead of matching delimiter");
  },
  htmlBuilder(n, e) {
    for (var t = Ai(n), r = [], a = e.havingStyle(e.style.text()), i = 0; i < t.length; i++) {
      var l = t[i];
      l === "~" && (l = "\\textasciitilde"), r.push(F.makeSymbol(l, "Typewriter-Regular", n.mode, a, ["mord", "texttt"]));
    }
    return F.makeSpan(["mord", "text"].concat(a.sizingClasses(e)), F.tryCombineChars(r), a);
  },
  mathmlBuilder(n, e) {
    var t = new q.TextNode(Ai(n)), r = new q.MathNode("mtext", [t]);
    return r.setAttribute("mathvariant", "monospace"), r;
  }
});
var Ai = (n) => n.body.replace(/ /g, n.star ? "␣" : " "), vu = zl;
f("\\noexpand", function(n) {
  var e = n.popToken();
  return n.isExpandable(e.text) && (e.noexpand = !0, e.treatAsRelax = !0), {
    tokens: [e],
    numArgs: 0
  };
});
f("\\expandafter", function(n) {
  var e = n.popToken();
  return n.expandOnce(!0), {
    tokens: [e],
    numArgs: 0
  };
});
f("\\@firstoftwo", function(n) {
  var e = n.consumeArgs(2);
  return {
    tokens: e[0],
    numArgs: 0
  };
});
f("\\@secondoftwo", function(n) {
  var e = n.consumeArgs(2);
  return {
    tokens: e[1],
    numArgs: 0
  };
});
f("\\@ifnextchar", function(n) {
  var e = n.consumeArgs(3);
  n.consumeSpaces();
  var t = n.future();
  return e[0].length === 1 && e[0][0].text === t.text ? {
    tokens: e[1],
    numArgs: 0
  } : {
    tokens: e[2],
    numArgs: 0
  };
});
f("\\@ifstar", "\\@ifnextchar *{\\@firstoftwo{#1}}");
f("\\TextOrMath", function(n) {
  var e = n.consumeArgs(2);
  return n.mode === "text" ? {
    tokens: e[0],
    numArgs: 0
  } : {
    tokens: e[1],
    numArgs: 0
  };
});
var Fi = {
  0: 0,
  1: 1,
  2: 2,
  3: 3,
  4: 4,
  5: 5,
  6: 6,
  7: 7,
  8: 8,
  9: 9,
  a: 10,
  A: 10,
  b: 11,
  B: 11,
  c: 12,
  C: 12,
  d: 13,
  D: 13,
  e: 14,
  E: 14,
  f: 15,
  F: 15
};
f("\\char", function(n) {
  var e = n.popToken(), t, r = "";
  if (e.text === "'")
    t = 8, e = n.popToken();
  else if (e.text === '"')
    t = 16, e = n.popToken();
  else if (e.text === "`")
    if (e = n.popToken(), e.text[0] === "\\")
      r = e.text.charCodeAt(1);
    else {
      if (e.text === "EOF")
        throw new X("\\char` missing argument");
      r = e.text.charCodeAt(0);
    }
  else
    t = 10;
  if (t) {
    if (r = Fi[e.text], r == null || r >= t)
      throw new X("Invalid base-" + t + " digit " + e.text);
    for (var a; (a = Fi[n.future().text]) != null && a < t; )
      r *= t, r += a, n.popToken();
  }
  return "\\@char{" + r + "}";
});
var la = (n, e, t) => {
  var r = n.consumeArg().tokens;
  if (r.length !== 1)
    throw new X("\\newcommand's first argument must be a macro name");
  var a = r[0].text, i = n.isDefined(a);
  if (i && !e)
    throw new X("\\newcommand{" + a + "} attempting to redefine " + (a + "; use \\renewcommand"));
  if (!i && !t)
    throw new X("\\renewcommand{" + a + "} when command " + a + " does not yet exist; use \\newcommand");
  var l = 0;
  if (r = n.consumeArg().tokens, r.length === 1 && r[0].text === "[") {
    for (var o = "", u = n.expandNextToken(); u.text !== "]" && u.text !== "EOF"; )
      o += u.text, u = n.expandNextToken();
    if (!o.match(/^\s*[0-9]+\s*$/))
      throw new X("Invalid number of arguments: " + o);
    l = parseInt(o), r = n.consumeArg().tokens;
  }
  return n.macros.set(a, {
    tokens: r,
    numArgs: l
  }), "";
};
f("\\newcommand", (n) => la(n, !1, !0));
f("\\renewcommand", (n) => la(n, !0, !1));
f("\\providecommand", (n) => la(n, !0, !0));
f("\\message", (n) => {
  var e = n.consumeArgs(1)[0];
  return console.log(e.reverse().map((t) => t.text).join("")), "";
});
f("\\errmessage", (n) => {
  var e = n.consumeArgs(1)[0];
  return console.error(e.reverse().map((t) => t.text).join("")), "";
});
f("\\show", (n) => {
  var e = n.popToken(), t = e.text;
  return console.log(e, n.macros.get(t), vu[t], Fe.math[t], Fe.text[t]), "";
});
f("\\bgroup", "{");
f("\\egroup", "}");
f("~", "\\nobreakspace");
f("\\lq", "`");
f("\\rq", "'");
f("\\aa", "\\r a");
f("\\AA", "\\r A");
f("\\textcopyright", "\\html@mathml{\\textcircled{c}}{\\char`©}");
f("\\copyright", "\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");
f("\\textregistered", "\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");
f("ℬ", "\\mathscr{B}");
f("ℰ", "\\mathscr{E}");
f("ℱ", "\\mathscr{F}");
f("ℋ", "\\mathscr{H}");
f("ℐ", "\\mathscr{I}");
f("ℒ", "\\mathscr{L}");
f("ℳ", "\\mathscr{M}");
f("ℛ", "\\mathscr{R}");
f("ℭ", "\\mathfrak{C}");
f("ℌ", "\\mathfrak{H}");
f("ℨ", "\\mathfrak{Z}");
f("\\Bbbk", "\\Bbb{k}");
f("·", "\\cdotp");
f("\\llap", "\\mathllap{\\textrm{#1}}");
f("\\rlap", "\\mathrlap{\\textrm{#1}}");
f("\\clap", "\\mathclap{\\textrm{#1}}");
f("\\mathstrut", "\\vphantom{(}");
f("\\underbar", "\\underline{\\text{#1}}");
f("\\not", '\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');
f("\\neq", "\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");
f("\\ne", "\\neq");
f("≠", "\\neq");
f("\\notin", "\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");
f("∉", "\\notin");
f("≘", "\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");
f("≙", "\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");
f("≚", "\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");
f("≛", "\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");
f("≝", "\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");
f("≞", "\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");
f("≟", "\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");
f("⟂", "\\perp");
f("‼", "\\mathclose{!\\mkern-0.8mu!}");
f("∌", "\\notni");
f("⌜", "\\ulcorner");
f("⌝", "\\urcorner");
f("⌞", "\\llcorner");
f("⌟", "\\lrcorner");
f("©", "\\copyright");
f("®", "\\textregistered");
f("️", "\\textregistered");
f("\\ulcorner", '\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');
f("\\urcorner", '\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');
f("\\llcorner", '\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');
f("\\lrcorner", '\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');
f("\\vdots", "\\mathord{\\varvdots\\rule{0pt}{15pt}}");
f("⋮", "\\vdots");
f("\\varGamma", "\\mathit{\\Gamma}");
f("\\varDelta", "\\mathit{\\Delta}");
f("\\varTheta", "\\mathit{\\Theta}");
f("\\varLambda", "\\mathit{\\Lambda}");
f("\\varXi", "\\mathit{\\Xi}");
f("\\varPi", "\\mathit{\\Pi}");
f("\\varSigma", "\\mathit{\\Sigma}");
f("\\varUpsilon", "\\mathit{\\Upsilon}");
f("\\varPhi", "\\mathit{\\Phi}");
f("\\varPsi", "\\mathit{\\Psi}");
f("\\varOmega", "\\mathit{\\Omega}");
f("\\substack", "\\begin{subarray}{c}#1\\end{subarray}");
f("\\colon", "\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");
f("\\boxed", "\\fbox{$\\displaystyle{#1}$}");
f("\\iff", "\\DOTSB\\;\\Longleftrightarrow\\;");
f("\\implies", "\\DOTSB\\;\\Longrightarrow\\;");
f("\\impliedby", "\\DOTSB\\;\\Longleftarrow\\;");
var Ci = {
  ",": "\\dotsc",
  "\\not": "\\dotsb",
  // \keybin@ checks for the following:
  "+": "\\dotsb",
  "=": "\\dotsb",
  "<": "\\dotsb",
  ">": "\\dotsb",
  "-": "\\dotsb",
  "*": "\\dotsb",
  ":": "\\dotsb",
  // Symbols whose definition starts with \DOTSB:
  "\\DOTSB": "\\dotsb",
  "\\coprod": "\\dotsb",
  "\\bigvee": "\\dotsb",
  "\\bigwedge": "\\dotsb",
  "\\biguplus": "\\dotsb",
  "\\bigcap": "\\dotsb",
  "\\bigcup": "\\dotsb",
  "\\prod": "\\dotsb",
  "\\sum": "\\dotsb",
  "\\bigotimes": "\\dotsb",
  "\\bigoplus": "\\dotsb",
  "\\bigodot": "\\dotsb",
  "\\bigsqcup": "\\dotsb",
  "\\And": "\\dotsb",
  "\\longrightarrow": "\\dotsb",
  "\\Longrightarrow": "\\dotsb",
  "\\longleftarrow": "\\dotsb",
  "\\Longleftarrow": "\\dotsb",
  "\\longleftrightarrow": "\\dotsb",
  "\\Longleftrightarrow": "\\dotsb",
  "\\mapsto": "\\dotsb",
  "\\longmapsto": "\\dotsb",
  "\\hookrightarrow": "\\dotsb",
  "\\doteq": "\\dotsb",
  // Symbols whose definition starts with \mathbin:
  "\\mathbin": "\\dotsb",
  // Symbols whose definition starts with \mathrel:
  "\\mathrel": "\\dotsb",
  "\\relbar": "\\dotsb",
  "\\Relbar": "\\dotsb",
  "\\xrightarrow": "\\dotsb",
  "\\xleftarrow": "\\dotsb",
  // Symbols whose definition starts with \DOTSI:
  "\\DOTSI": "\\dotsi",
  "\\int": "\\dotsi",
  "\\oint": "\\dotsi",
  "\\iint": "\\dotsi",
  "\\iiint": "\\dotsi",
  "\\iiiint": "\\dotsi",
  "\\idotsint": "\\dotsi",
  // Symbols whose definition starts with \DOTSX:
  "\\DOTSX": "\\dotsx"
};
f("\\dots", function(n) {
  var e = "\\dotso", t = n.expandAfterFuture().text;
  return t in Ci ? e = Ci[t] : (t.slice(0, 4) === "\\not" || t in Fe.math && K.contains(["bin", "rel"], Fe.math[t].group)) && (e = "\\dotsb"), e;
});
var sa = {
  // \rightdelim@ checks for the following:
  ")": !0,
  "]": !0,
  "\\rbrack": !0,
  "\\}": !0,
  "\\rbrace": !0,
  "\\rangle": !0,
  "\\rceil": !0,
  "\\rfloor": !0,
  "\\rgroup": !0,
  "\\rmoustache": !0,
  "\\right": !0,
  "\\bigr": !0,
  "\\biggr": !0,
  "\\Bigr": !0,
  "\\Biggr": !0,
  // \extra@ also tests for the following:
  $: !0,
  // \extrap@ checks for the following:
  ";": !0,
  ".": !0,
  ",": !0
};
f("\\dotso", function(n) {
  var e = n.future().text;
  return e in sa ? "\\ldots\\," : "\\ldots";
});
f("\\dotsc", function(n) {
  var e = n.future().text;
  return e in sa && e !== "," ? "\\ldots\\," : "\\ldots";
});
f("\\cdots", function(n) {
  var e = n.future().text;
  return e in sa ? "\\@cdots\\," : "\\@cdots";
});
f("\\dotsb", "\\cdots");
f("\\dotsm", "\\cdots");
f("\\dotsi", "\\!\\cdots");
f("\\dotsx", "\\ldots\\,");
f("\\DOTSI", "\\relax");
f("\\DOTSB", "\\relax");
f("\\DOTSX", "\\relax");
f("\\tmspace", "\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");
f("\\,", "\\tmspace+{3mu}{.1667em}");
f("\\thinspace", "\\,");
f("\\>", "\\mskip{4mu}");
f("\\:", "\\tmspace+{4mu}{.2222em}");
f("\\medspace", "\\:");
f("\\;", "\\tmspace+{5mu}{.2777em}");
f("\\thickspace", "\\;");
f("\\!", "\\tmspace-{3mu}{.1667em}");
f("\\negthinspace", "\\!");
f("\\negmedspace", "\\tmspace-{4mu}{.2222em}");
f("\\negthickspace", "\\tmspace-{5mu}{.277em}");
f("\\enspace", "\\kern.5em ");
f("\\enskip", "\\hskip.5em\\relax");
f("\\quad", "\\hskip1em\\relax");
f("\\qquad", "\\hskip2em\\relax");
f("\\tag", "\\@ifstar\\tag@literal\\tag@paren");
f("\\tag@paren", "\\tag@literal{({#1})}");
f("\\tag@literal", (n) => {
  if (n.macros.get("\\df@tag"))
    throw new X("Multiple \\tag");
  return "\\gdef\\df@tag{\\text{#1}}";
});
f("\\bmod", "\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");
f("\\pod", "\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");
f("\\pmod", "\\pod{{\\rm mod}\\mkern6mu#1}");
f("\\mod", "\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");
f("\\newline", "\\\\\\relax");
f("\\TeX", "\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");
var os = L(Kt["Main-Regular"][84][1] - 0.7 * Kt["Main-Regular"][65][1]);
f("\\LaTeX", "\\textrm{\\html@mathml{" + ("L\\kern-.36em\\raisebox{" + os + "}{\\scriptstyle A}") + "\\kern-.15em\\TeX}{LaTeX}}");
f("\\KaTeX", "\\textrm{\\html@mathml{" + ("K\\kern-.17em\\raisebox{" + os + "}{\\scriptstyle A}") + "\\kern-.15em\\TeX}{KaTeX}}");
f("\\hspace", "\\@ifstar\\@hspacer\\@hspace");
f("\\@hspace", "\\hskip #1\\relax");
f("\\@hspacer", "\\rule{0pt}{0pt}\\hskip #1\\relax");
f("\\ordinarycolon", ":");
f("\\vcentcolon", "\\mathrel{\\mathop\\ordinarycolon}");
f("\\dblcolon", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');
f("\\coloneqq", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');
f("\\Coloneqq", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');
f("\\coloneq", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');
f("\\Coloneq", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');
f("\\eqqcolon", '\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');
f("\\Eqqcolon", '\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');
f("\\eqcolon", '\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');
f("\\Eqcolon", '\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');
f("\\colonapprox", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');
f("\\Colonapprox", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');
f("\\colonsim", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');
f("\\Colonsim", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');
f("∷", "\\dblcolon");
f("∹", "\\eqcolon");
f("≔", "\\coloneqq");
f("≕", "\\eqqcolon");
f("⩴", "\\Coloneqq");
f("\\ratio", "\\vcentcolon");
f("\\coloncolon", "\\dblcolon");
f("\\colonequals", "\\coloneqq");
f("\\coloncolonequals", "\\Coloneqq");
f("\\equalscolon", "\\eqqcolon");
f("\\equalscoloncolon", "\\Eqqcolon");
f("\\colonminus", "\\coloneq");
f("\\coloncolonminus", "\\Coloneq");
f("\\minuscolon", "\\eqcolon");
f("\\minuscoloncolon", "\\Eqcolon");
f("\\coloncolonapprox", "\\Colonapprox");
f("\\coloncolonsim", "\\Colonsim");
f("\\simcolon", "\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");
f("\\simcoloncolon", "\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");
f("\\approxcolon", "\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");
f("\\approxcoloncolon", "\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");
f("\\notni", "\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");
f("\\limsup", "\\DOTSB\\operatorname*{lim\\,sup}");
f("\\liminf", "\\DOTSB\\operatorname*{lim\\,inf}");
f("\\injlim", "\\DOTSB\\operatorname*{inj\\,lim}");
f("\\projlim", "\\DOTSB\\operatorname*{proj\\,lim}");
f("\\varlimsup", "\\DOTSB\\operatorname*{\\overline{lim}}");
f("\\varliminf", "\\DOTSB\\operatorname*{\\underline{lim}}");
f("\\varinjlim", "\\DOTSB\\operatorname*{\\underrightarrow{lim}}");
f("\\varprojlim", "\\DOTSB\\operatorname*{\\underleftarrow{lim}}");
f("\\gvertneqq", "\\html@mathml{\\@gvertneqq}{≩}");
f("\\lvertneqq", "\\html@mathml{\\@lvertneqq}{≨}");
f("\\ngeqq", "\\html@mathml{\\@ngeqq}{≱}");
f("\\ngeqslant", "\\html@mathml{\\@ngeqslant}{≱}");
f("\\nleqq", "\\html@mathml{\\@nleqq}{≰}");
f("\\nleqslant", "\\html@mathml{\\@nleqslant}{≰}");
f("\\nshortmid", "\\html@mathml{\\@nshortmid}{∤}");
f("\\nshortparallel", "\\html@mathml{\\@nshortparallel}{∦}");
f("\\nsubseteqq", "\\html@mathml{\\@nsubseteqq}{⊈}");
f("\\nsupseteqq", "\\html@mathml{\\@nsupseteqq}{⊉}");
f("\\varsubsetneq", "\\html@mathml{\\@varsubsetneq}{⊊}");
f("\\varsubsetneqq", "\\html@mathml{\\@varsubsetneqq}{⫋}");
f("\\varsupsetneq", "\\html@mathml{\\@varsupsetneq}{⊋}");
f("\\varsupsetneqq", "\\html@mathml{\\@varsupsetneqq}{⫌}");
f("\\imath", "\\html@mathml{\\@imath}{ı}");
f("\\jmath", "\\html@mathml{\\@jmath}{ȷ}");
f("\\llbracket", "\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");
f("\\rrbracket", "\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");
f("⟦", "\\llbracket");
f("⟧", "\\rrbracket");
f("\\lBrace", "\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");
f("\\rBrace", "\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");
f("⦃", "\\lBrace");
f("⦄", "\\rBrace");
f("\\minuso", "\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");
f("⦵", "\\minuso");
f("\\darr", "\\downarrow");
f("\\dArr", "\\Downarrow");
f("\\Darr", "\\Downarrow");
f("\\lang", "\\langle");
f("\\rang", "\\rangle");
f("\\uarr", "\\uparrow");
f("\\uArr", "\\Uparrow");
f("\\Uarr", "\\Uparrow");
f("\\N", "\\mathbb{N}");
f("\\R", "\\mathbb{R}");
f("\\Z", "\\mathbb{Z}");
f("\\alef", "\\aleph");
f("\\alefsym", "\\aleph");
f("\\Alpha", "\\mathrm{A}");
f("\\Beta", "\\mathrm{B}");
f("\\bull", "\\bullet");
f("\\Chi", "\\mathrm{X}");
f("\\clubs", "\\clubsuit");
f("\\cnums", "\\mathbb{C}");
f("\\Complex", "\\mathbb{C}");
f("\\Dagger", "\\ddagger");
f("\\diamonds", "\\diamondsuit");
f("\\empty", "\\emptyset");
f("\\Epsilon", "\\mathrm{E}");
f("\\Eta", "\\mathrm{H}");
f("\\exist", "\\exists");
f("\\harr", "\\leftrightarrow");
f("\\hArr", "\\Leftrightarrow");
f("\\Harr", "\\Leftrightarrow");
f("\\hearts", "\\heartsuit");
f("\\image", "\\Im");
f("\\infin", "\\infty");
f("\\Iota", "\\mathrm{I}");
f("\\isin", "\\in");
f("\\Kappa", "\\mathrm{K}");
f("\\larr", "\\leftarrow");
f("\\lArr", "\\Leftarrow");
f("\\Larr", "\\Leftarrow");
f("\\lrarr", "\\leftrightarrow");
f("\\lrArr", "\\Leftrightarrow");
f("\\Lrarr", "\\Leftrightarrow");
f("\\Mu", "\\mathrm{M}");
f("\\natnums", "\\mathbb{N}");
f("\\Nu", "\\mathrm{N}");
f("\\Omicron", "\\mathrm{O}");
f("\\plusmn", "\\pm");
f("\\rarr", "\\rightarrow");
f("\\rArr", "\\Rightarrow");
f("\\Rarr", "\\Rightarrow");
f("\\real", "\\Re");
f("\\reals", "\\mathbb{R}");
f("\\Reals", "\\mathbb{R}");
f("\\Rho", "\\mathrm{P}");
f("\\sdot", "\\cdot");
f("\\sect", "\\S");
f("\\spades", "\\spadesuit");
f("\\sub", "\\subset");
f("\\sube", "\\subseteq");
f("\\supe", "\\supseteq");
f("\\Tau", "\\mathrm{T}");
f("\\thetasym", "\\vartheta");
f("\\weierp", "\\wp");
f("\\Zeta", "\\mathrm{Z}");
f("\\argmin", "\\DOTSB\\operatorname*{arg\\,min}");
f("\\argmax", "\\DOTSB\\operatorname*{arg\\,max}");
f("\\plim", "\\DOTSB\\mathop{\\operatorname{plim}}\\limits");
f("\\bra", "\\mathinner{\\langle{#1}|}");
f("\\ket", "\\mathinner{|{#1}\\rangle}");
f("\\braket", "\\mathinner{\\langle{#1}\\rangle}");
f("\\Bra", "\\left\\langle#1\\right|");
f("\\Ket", "\\left|#1\\right\\rangle");
var us = (n) => (e) => {
  var t = e.consumeArg().tokens, r = e.consumeArg().tokens, a = e.consumeArg().tokens, i = e.consumeArg().tokens, l = e.macros.get("|"), o = e.macros.get("\\|");
  e.macros.beginGroup();
  var u = (p) => (b) => {
    n && (b.macros.set("|", l), a.length && b.macros.set("\\|", o));
    var y = p;
    if (!p && a.length) {
      var D = b.future();
      D.text === "|" && (b.popToken(), y = !0);
    }
    return {
      tokens: y ? a : r,
      numArgs: 0
    };
  };
  e.macros.set("|", u(!1)), a.length && e.macros.set("\\|", u(!0));
  var h = e.consumeArg().tokens, d = e.expandTokens([
    ...i,
    ...h,
    ...t
    // reversed
  ]);
  return e.macros.endGroup(), {
    tokens: d.reverse(),
    numArgs: 0
  };
};
f("\\bra@ket", us(!1));
f("\\bra@set", us(!0));
f("\\Braket", "\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");
f("\\Set", "\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");
f("\\set", "\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");
f("\\angln", "{\\angl n}");
f("\\blue", "\\textcolor{##6495ed}{#1}");
f("\\orange", "\\textcolor{##ffa500}{#1}");
f("\\pink", "\\textcolor{##ff00af}{#1}");
f("\\red", "\\textcolor{##df0030}{#1}");
f("\\green", "\\textcolor{##28ae7b}{#1}");
f("\\gray", "\\textcolor{gray}{#1}");
f("\\purple", "\\textcolor{##9d38bd}{#1}");
f("\\blueA", "\\textcolor{##ccfaff}{#1}");
f("\\blueB", "\\textcolor{##80f6ff}{#1}");
f("\\blueC", "\\textcolor{##63d9ea}{#1}");
f("\\blueD", "\\textcolor{##11accd}{#1}");
f("\\blueE", "\\textcolor{##0c7f99}{#1}");
f("\\tealA", "\\textcolor{##94fff5}{#1}");
f("\\tealB", "\\textcolor{##26edd5}{#1}");
f("\\tealC", "\\textcolor{##01d1c1}{#1}");
f("\\tealD", "\\textcolor{##01a995}{#1}");
f("\\tealE", "\\textcolor{##208170}{#1}");
f("\\greenA", "\\textcolor{##b6ffb0}{#1}");
f("\\greenB", "\\textcolor{##8af281}{#1}");
f("\\greenC", "\\textcolor{##74cf70}{#1}");
f("\\greenD", "\\textcolor{##1fab54}{#1}");
f("\\greenE", "\\textcolor{##0d923f}{#1}");
f("\\goldA", "\\textcolor{##ffd0a9}{#1}");
f("\\goldB", "\\textcolor{##ffbb71}{#1}");
f("\\goldC", "\\textcolor{##ff9c39}{#1}");
f("\\goldD", "\\textcolor{##e07d10}{#1}");
f("\\goldE", "\\textcolor{##a75a05}{#1}");
f("\\redA", "\\textcolor{##fca9a9}{#1}");
f("\\redB", "\\textcolor{##ff8482}{#1}");
f("\\redC", "\\textcolor{##f9685d}{#1}");
f("\\redD", "\\textcolor{##e84d39}{#1}");
f("\\redE", "\\textcolor{##bc2612}{#1}");
f("\\maroonA", "\\textcolor{##ffbde0}{#1}");
f("\\maroonB", "\\textcolor{##ff92c6}{#1}");
f("\\maroonC", "\\textcolor{##ed5fa6}{#1}");
f("\\maroonD", "\\textcolor{##ca337c}{#1}");
f("\\maroonE", "\\textcolor{##9e034e}{#1}");
f("\\purpleA", "\\textcolor{##ddd7ff}{#1}");
f("\\purpleB", "\\textcolor{##c6b9fc}{#1}");
f("\\purpleC", "\\textcolor{##aa87ff}{#1}");
f("\\purpleD", "\\textcolor{##7854ab}{#1}");
f("\\purpleE", "\\textcolor{##543b78}{#1}");
f("\\mintA", "\\textcolor{##f5f9e8}{#1}");
f("\\mintB", "\\textcolor{##edf2df}{#1}");
f("\\mintC", "\\textcolor{##e0e5cc}{#1}");
f("\\grayA", "\\textcolor{##f6f7f7}{#1}");
f("\\grayB", "\\textcolor{##f0f1f2}{#1}");
f("\\grayC", "\\textcolor{##e3e5e6}{#1}");
f("\\grayD", "\\textcolor{##d6d8da}{#1}");
f("\\grayE", "\\textcolor{##babec2}{#1}");
f("\\grayF", "\\textcolor{##888d93}{#1}");
f("\\grayG", "\\textcolor{##626569}{#1}");
f("\\grayH", "\\textcolor{##3b3e40}{#1}");
f("\\grayI", "\\textcolor{##21242c}{#1}");
f("\\kaBlue", "\\textcolor{##314453}{#1}");
f("\\kaGreen", "\\textcolor{##71B307}{#1}");
typeof document < "u" && document.compatMode !== "CSS1Compat" && typeof console < "u" && console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype.");
function oa() {
  return {
    async: !1,
    breaks: !1,
    extensions: null,
    gfm: !0,
    hooks: null,
    pedantic: !1,
    renderer: null,
    silent: !1,
    tokenizer: null,
    walkTokens: null
  };
}
let b0 = oa();
function cs(n) {
  b0 = n;
}
const hs = /[&<>"']/, _u = new RegExp(hs.source, "g"), ms = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, bu = new RegExp(ms.source, "g"), yu = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, Ei = (n) => yu[n];
function Je(n, e) {
  if (e) {
    if (hs.test(n))
      return n.replace(_u, Ei);
  } else if (ms.test(n))
    return n.replace(bu, Ei);
  return n;
}
const wu = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig;
function ku(n) {
  return n.replace(wu, (e, t) => (t = t.toLowerCase(), t === "colon" ? ":" : t.charAt(0) === "#" ? t.charAt(1) === "x" ? String.fromCharCode(parseInt(t.substring(2), 16)) : String.fromCharCode(+t.substring(1)) : ""));
}
const Du = /(^|[^\[])\^/g;
function fe(n, e) {
  let t = typeof n == "string" ? n : n.source;
  e = e || "";
  const r = {
    replace: (a, i) => {
      let l = typeof i == "string" ? i : i.source;
      return l = l.replace(Du, "$1"), t = t.replace(a, l), r;
    },
    getRegex: () => new RegExp(t, e)
  };
  return r;
}
function Ti(n) {
  try {
    n = encodeURI(n).replace(/%25/g, "%");
  } catch {
    return null;
  }
  return n;
}
const Z0 = { exec: () => null };
function $i(n, e) {
  const t = n.replace(/\|/g, (i, l, o) => {
    let u = !1, h = l;
    for (; --h >= 0 && o[h] === "\\"; )
      u = !u;
    return u ? "|" : " |";
  }), r = t.split(/ \|/);
  let a = 0;
  if (r[0].trim() || r.shift(), r.length > 0 && !r[r.length - 1].trim() && r.pop(), e)
    if (r.length > e)
      r.splice(e);
    else
      for (; r.length < e; )
        r.push("");
  for (; a < r.length; a++)
    r[a] = r[a].trim().replace(/\\\|/g, "|");
  return r;
}
function br(n, e, t) {
  const r = n.length;
  if (r === 0)
    return "";
  let a = 0;
  for (; a < r; ) {
    const i = n.charAt(r - a - 1);
    if (i === e && !t)
      a++;
    else if (i !== e && t)
      a++;
    else
      break;
  }
  return n.slice(0, r - a);
}
function xu(n, e) {
  if (n.indexOf(e[1]) === -1)
    return -1;
  let t = 0;
  for (let r = 0; r < n.length; r++)
    if (n[r] === "\\")
      r++;
    else if (n[r] === e[0])
      t++;
    else if (n[r] === e[1] && (t--, t < 0))
      return r;
  return -1;
}
function Mi(n, e, t, r) {
  const a = e.href, i = e.title ? Je(e.title) : null, l = n[1].replace(/\\([\[\]])/g, "$1");
  if (n[0].charAt(0) !== "!") {
    r.state.inLink = !0;
    const o = {
      type: "link",
      raw: t,
      href: a,
      title: i,
      text: l,
      tokens: r.inlineTokens(l)
    };
    return r.state.inLink = !1, o;
  }
  return {
    type: "image",
    raw: t,
    href: a,
    title: i,
    text: Je(l)
  };
}
function Su(n, e) {
  const t = n.match(/^(\s+)(?:```)/);
  if (t === null)
    return e;
  const r = t[1];
  return e.split(`
`).map((a) => {
    const i = a.match(/^\s+/);
    if (i === null)
      return a;
    const [l] = i;
    return l.length >= r.length ? a.slice(r.length) : a;
  }).join(`
`);
}
class Lr {
  // set by the lexer
  constructor(e) {
    ve(this, "options");
    ve(this, "rules");
    // set by the lexer
    ve(this, "lexer");
    this.options = e || b0;
  }
  space(e) {
    const t = this.rules.block.newline.exec(e);
    if (t && t[0].length > 0)
      return {
        type: "space",
        raw: t[0]
      };
  }
  code(e) {
    const t = this.rules.block.code.exec(e);
    if (t) {
      const r = t[0].replace(/^ {1,4}/gm, "");
      return {
        type: "code",
        raw: t[0],
        codeBlockStyle: "indented",
        text: this.options.pedantic ? r : br(r, `
`)
      };
    }
  }
  fences(e) {
    const t = this.rules.block.fences.exec(e);
    if (t) {
      const r = t[0], a = Su(r, t[3] || "");
      return {
        type: "code",
        raw: r,
        lang: t[2] ? t[2].trim().replace(this.rules.inline.anyPunctuation, "$1") : t[2],
        text: a
      };
    }
  }
  heading(e) {
    const t = this.rules.block.heading.exec(e);
    if (t) {
      let r = t[2].trim();
      if (/#$/.test(r)) {
        const a = br(r, "#");
        (this.options.pedantic || !a || / $/.test(a)) && (r = a.trim());
      }
      return {
        type: "heading",
        raw: t[0],
        depth: t[1].length,
        text: r,
        tokens: this.lexer.inline(r)
      };
    }
  }
  hr(e) {
    const t = this.rules.block.hr.exec(e);
    if (t)
      return {
        type: "hr",
        raw: t[0]
      };
  }
  blockquote(e) {
    const t = this.rules.block.blockquote.exec(e);
    if (t) {
      let r = t[0].replace(/\n {0,3}((?:=+|-+) *)(?=\n|$)/g, `
    $1`);
      r = br(r.replace(/^ *>[ \t]?/gm, ""), `
`);
      const a = this.lexer.state.top;
      this.lexer.state.top = !0;
      const i = this.lexer.blockTokens(r);
      return this.lexer.state.top = a, {
        type: "blockquote",
        raw: t[0],
        tokens: i,
        text: r
      };
    }
  }
  list(e) {
    let t = this.rules.block.list.exec(e);
    if (t) {
      let r = t[1].trim();
      const a = r.length > 1, i = {
        type: "list",
        raw: "",
        ordered: a,
        start: a ? +r.slice(0, -1) : "",
        loose: !1,
        items: []
      };
      r = a ? `\\d{1,9}\\${r.slice(-1)}` : `\\${r}`, this.options.pedantic && (r = a ? r : "[*+-]");
      const l = new RegExp(`^( {0,3}${r})((?:[	 ][^\\n]*)?(?:\\n|$))`);
      let o = "", u = "", h = !1;
      for (; e; ) {
        let d = !1;
        if (!(t = l.exec(e)) || this.rules.block.hr.test(e))
          break;
        o = t[0], e = e.substring(o.length);
        let p = t[2].split(`
`, 1)[0].replace(/^\t+/, (T) => " ".repeat(3 * T.length)), b = e.split(`
`, 1)[0], y = 0;
        this.options.pedantic ? (y = 2, u = p.trimStart()) : (y = t[2].search(/[^ ]/), y = y > 4 ? 1 : y, u = p.slice(y), y += t[1].length);
        let D = !1;
        if (!p && /^ *$/.test(b) && (o += b + `
`, e = e.substring(b.length + 1), d = !0), !d) {
          const T = new RegExp(`^ {0,${Math.min(3, y - 1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`), w = new RegExp(`^ {0,${Math.min(3, y - 1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`), g = new RegExp(`^ {0,${Math.min(3, y - 1)}}(?:\`\`\`|~~~)`), S = new RegExp(`^ {0,${Math.min(3, y - 1)}}#`);
          for (; e; ) {
            const E = e.split(`
`, 1)[0];
            if (b = E, this.options.pedantic && (b = b.replace(/^ {1,4}(?=( {4})*[^ ])/g, "  ")), g.test(b) || S.test(b) || T.test(b) || w.test(e))
              break;
            if (b.search(/[^ ]/) >= y || !b.trim())
              u += `
` + b.slice(y);
            else {
              if (D || p.search(/[^ ]/) >= 4 || g.test(p) || S.test(p) || w.test(p))
                break;
              u += `
` + b;
            }
            !D && !b.trim() && (D = !0), o += E + `
`, e = e.substring(E.length + 1), p = b.slice(y);
          }
        }
        i.loose || (h ? i.loose = !0 : /\n *\n *$/.test(o) && (h = !0));
        let A = null, C;
        this.options.gfm && (A = /^\[[ xX]\] /.exec(u), A && (C = A[0] !== "[ ] ", u = u.replace(/^\[[ xX]\] +/, ""))), i.items.push({
          type: "list_item",
          raw: o,
          task: !!A,
          checked: C,
          loose: !1,
          text: u,
          tokens: []
        }), i.raw += o;
      }
      i.items[i.items.length - 1].raw = o.trimEnd(), i.items[i.items.length - 1].text = u.trimEnd(), i.raw = i.raw.trimEnd();
      for (let d = 0; d < i.items.length; d++)
        if (this.lexer.state.top = !1, i.items[d].tokens = this.lexer.blockTokens(i.items[d].text, []), !i.loose) {
          const p = i.items[d].tokens.filter((y) => y.type === "space"), b = p.length > 0 && p.some((y) => /\n.*\n/.test(y.raw));
          i.loose = b;
        }
      if (i.loose)
        for (let d = 0; d < i.items.length; d++)
          i.items[d].loose = !0;
      return i;
    }
  }
  html(e) {
    const t = this.rules.block.html.exec(e);
    if (t)
      return {
        type: "html",
        block: !0,
        raw: t[0],
        pre: t[1] === "pre" || t[1] === "script" || t[1] === "style",
        text: t[0]
      };
  }
  def(e) {
    const t = this.rules.block.def.exec(e);
    if (t) {
      const r = t[1].toLowerCase().replace(/\s+/g, " "), a = t[2] ? t[2].replace(/^<(.*)>$/, "$1").replace(this.rules.inline.anyPunctuation, "$1") : "", i = t[3] ? t[3].substring(1, t[3].length - 1).replace(this.rules.inline.anyPunctuation, "$1") : t[3];
      return {
        type: "def",
        tag: r,
        raw: t[0],
        href: a,
        title: i
      };
    }
  }
  table(e) {
    const t = this.rules.block.table.exec(e);
    if (!t || !/[:|]/.test(t[2]))
      return;
    const r = $i(t[1]), a = t[2].replace(/^\||\| *$/g, "").split("|"), i = t[3] && t[3].trim() ? t[3].replace(/\n[ \t]*$/, "").split(`
`) : [], l = {
      type: "table",
      raw: t[0],
      header: [],
      align: [],
      rows: []
    };
    if (r.length === a.length) {
      for (const o of a)
        /^ *-+: *$/.test(o) ? l.align.push("right") : /^ *:-+: *$/.test(o) ? l.align.push("center") : /^ *:-+ *$/.test(o) ? l.align.push("left") : l.align.push(null);
      for (const o of r)
        l.header.push({
          text: o,
          tokens: this.lexer.inline(o)
        });
      for (const o of i)
        l.rows.push($i(o, l.header.length).map((u) => ({
          text: u,
          tokens: this.lexer.inline(u)
        })));
      return l;
    }
  }
  lheading(e) {
    const t = this.rules.block.lheading.exec(e);
    if (t)
      return {
        type: "heading",
        raw: t[0],
        depth: t[2].charAt(0) === "=" ? 1 : 2,
        text: t[1],
        tokens: this.lexer.inline(t[1])
      };
  }
  paragraph(e) {
    const t = this.rules.block.paragraph.exec(e);
    if (t) {
      const r = t[1].charAt(t[1].length - 1) === `
` ? t[1].slice(0, -1) : t[1];
      return {
        type: "paragraph",
        raw: t[0],
        text: r,
        tokens: this.lexer.inline(r)
      };
    }
  }
  text(e) {
    const t = this.rules.block.text.exec(e);
    if (t)
      return {
        type: "text",
        raw: t[0],
        text: t[0],
        tokens: this.lexer.inline(t[0])
      };
  }
  escape(e) {
    const t = this.rules.inline.escape.exec(e);
    if (t)
      return {
        type: "escape",
        raw: t[0],
        text: Je(t[1])
      };
  }
  tag(e) {
    const t = this.rules.inline.tag.exec(e);
    if (t)
      return !this.lexer.state.inLink && /^<a /i.test(t[0]) ? this.lexer.state.inLink = !0 : this.lexer.state.inLink && /^<\/a>/i.test(t[0]) && (this.lexer.state.inLink = !1), !this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(t[0]) ? this.lexer.state.inRawBlock = !0 : this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(t[0]) && (this.lexer.state.inRawBlock = !1), {
        type: "html",
        raw: t[0],
        inLink: this.lexer.state.inLink,
        inRawBlock: this.lexer.state.inRawBlock,
        block: !1,
        text: t[0]
      };
  }
  link(e) {
    const t = this.rules.inline.link.exec(e);
    if (t) {
      const r = t[2].trim();
      if (!this.options.pedantic && /^</.test(r)) {
        if (!/>$/.test(r))
          return;
        const l = br(r.slice(0, -1), "\\");
        if ((r.length - l.length) % 2 === 0)
          return;
      } else {
        const l = xu(t[2], "()");
        if (l > -1) {
          const u = (t[0].indexOf("!") === 0 ? 5 : 4) + t[1].length + l;
          t[2] = t[2].substring(0, l), t[0] = t[0].substring(0, u).trim(), t[3] = "";
        }
      }
      let a = t[2], i = "";
      if (this.options.pedantic) {
        const l = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(a);
        l && (a = l[1], i = l[3]);
      } else
        i = t[3] ? t[3].slice(1, -1) : "";
      return a = a.trim(), /^</.test(a) && (this.options.pedantic && !/>$/.test(r) ? a = a.slice(1) : a = a.slice(1, -1)), Mi(t, {
        href: a && a.replace(this.rules.inline.anyPunctuation, "$1"),
        title: i && i.replace(this.rules.inline.anyPunctuation, "$1")
      }, t[0], this.lexer);
    }
  }
  reflink(e, t) {
    let r;
    if ((r = this.rules.inline.reflink.exec(e)) || (r = this.rules.inline.nolink.exec(e))) {
      const a = (r[2] || r[1]).replace(/\s+/g, " "), i = t[a.toLowerCase()];
      if (!i) {
        const l = r[0].charAt(0);
        return {
          type: "text",
          raw: l,
          text: l
        };
      }
      return Mi(r, i, r[0], this.lexer);
    }
  }
  emStrong(e, t, r = "") {
    let a = this.rules.inline.emStrongLDelim.exec(e);
    if (!a || a[3] && r.match(/[\p{L}\p{N}]/u))
      return;
    if (!(a[1] || a[2] || "") || !r || this.rules.inline.punctuation.exec(r)) {
      const l = [...a[0]].length - 1;
      let o, u, h = l, d = 0;
      const p = a[0][0] === "*" ? this.rules.inline.emStrongRDelimAst : this.rules.inline.emStrongRDelimUnd;
      for (p.lastIndex = 0, t = t.slice(-1 * e.length + l); (a = p.exec(t)) != null; ) {
        if (o = a[1] || a[2] || a[3] || a[4] || a[5] || a[6], !o)
          continue;
        if (u = [...o].length, a[3] || a[4]) {
          h += u;
          continue;
        } else if ((a[5] || a[6]) && l % 3 && !((l + u) % 3)) {
          d += u;
          continue;
        }
        if (h -= u, h > 0)
          continue;
        u = Math.min(u, u + h + d);
        const b = [...a[0]][0].length, y = e.slice(0, l + a.index + b + u);
        if (Math.min(l, u) % 2) {
          const A = y.slice(1, -1);
          return {
            type: "em",
            raw: y,
            text: A,
            tokens: this.lexer.inlineTokens(A)
          };
        }
        const D = y.slice(2, -2);
        return {
          type: "strong",
          raw: y,
          text: D,
          tokens: this.lexer.inlineTokens(D)
        };
      }
    }
  }
  codespan(e) {
    const t = this.rules.inline.code.exec(e);
    if (t) {
      let r = t[2].replace(/\n/g, " ");
      const a = /[^ ]/.test(r), i = /^ /.test(r) && / $/.test(r);
      return a && i && (r = r.substring(1, r.length - 1)), r = Je(r, !0), {
        type: "codespan",
        raw: t[0],
        text: r
      };
    }
  }
  br(e) {
    const t = this.rules.inline.br.exec(e);
    if (t)
      return {
        type: "br",
        raw: t[0]
      };
  }
  del(e) {
    const t = this.rules.inline.del.exec(e);
    if (t)
      return {
        type: "del",
        raw: t[0],
        text: t[2],
        tokens: this.lexer.inlineTokens(t[2])
      };
  }
  autolink(e) {
    const t = this.rules.inline.autolink.exec(e);
    if (t) {
      let r, a;
      return t[2] === "@" ? (r = Je(t[1]), a = "mailto:" + r) : (r = Je(t[1]), a = r), {
        type: "link",
        raw: t[0],
        text: r,
        href: a,
        tokens: [
          {
            type: "text",
            raw: r,
            text: r
          }
        ]
      };
    }
  }
  url(e) {
    var r;
    let t;
    if (t = this.rules.inline.url.exec(e)) {
      let a, i;
      if (t[2] === "@")
        a = Je(t[0]), i = "mailto:" + a;
      else {
        let l;
        do
          l = t[0], t[0] = ((r = this.rules.inline._backpedal.exec(t[0])) == null ? void 0 : r[0]) ?? "";
        while (l !== t[0]);
        a = Je(t[0]), t[1] === "www." ? i = "http://" + t[0] : i = t[0];
      }
      return {
        type: "link",
        raw: t[0],
        text: a,
        href: i,
        tokens: [
          {
            type: "text",
            raw: a,
            text: a
          }
        ]
      };
    }
  }
  inlineText(e) {
    const t = this.rules.inline.text.exec(e);
    if (t) {
      let r;
      return this.lexer.state.inRawBlock ? r = t[0] : r = Je(t[0]), {
        type: "text",
        raw: t[0],
        text: r
      };
    }
  }
}
const Au = /^(?: *(?:\n|$))+/, Fu = /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/, Cu = /^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/, ar = /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/, Eu = /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/, ds = /(?:[*+-]|\d{1,9}[.)])/, fs = fe(/^(?!bull |blockCode|fences|blockquote|heading|html)((?:.|\n(?!\s*?\n|bull |blockCode|fences|blockquote|heading|html))+?)\n {0,3}(=+|-+) *(?:\n+|$)/).replace(/bull/g, ds).replace(/blockCode/g, / {4}/).replace(/fences/g, / {0,3}(?:`{3,}|~{3,})/).replace(/blockquote/g, / {0,3}>/).replace(/heading/g, / {0,3}#{1,6}/).replace(/html/g, / {0,3}<[^\n>]+>\n/).getRegex(), ua = /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/, Tu = /^[^\n]+/, ca = /(?!\s*\])(?:\\.|[^\[\]\\])+/, $u = fe(/^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/).replace("label", ca).replace("title", /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/).getRegex(), Mu = fe(/^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/).replace(/bull/g, ds).getRegex(), Qr = "address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|search|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul", ha = /<!--(?:-?>|[\s\S]*?(?:-->|$))/, zu = fe("^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))", "i").replace("comment", ha).replace("tag", Qr).replace("attribute", / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(), ps = fe(ua).replace("hr", ar).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("|table", "").replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Qr).getRegex(), Bu = fe(/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/).replace("paragraph", ps).getRegex(), ma = {
  blockquote: Bu,
  code: Fu,
  def: $u,
  fences: Cu,
  heading: Eu,
  hr: ar,
  html: zu,
  lheading: fs,
  list: Mu,
  newline: Au,
  paragraph: ps,
  table: Z0,
  text: Tu
}, zi = fe("^ *([^\\n ].*)\\n {0,3}((?:\\| *)?:?-+:? *(?:\\| *:?-+:? *)*(?:\\| *)?)(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)").replace("hr", ar).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("blockquote", " {0,3}>").replace("code", " {4}[^\\n]").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Qr).getRegex(), Ru = {
  ...ma,
  table: zi,
  paragraph: fe(ua).replace("hr", ar).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("table", zi).replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Qr).getRegex()
}, qu = {
  ...ma,
  html: fe(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment", ha).replace(/tag/g, "(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),
  def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,
  heading: /^(#{1,6})(.*)(?:\n+|$)/,
  fences: Z0,
  // fences not supported
  lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/,
  paragraph: fe(ua).replace("hr", ar).replace("heading", ` *#{1,6} *[^
]`).replace("lheading", fs).replace("|table", "").replace("blockquote", " {0,3}>").replace("|fences", "").replace("|list", "").replace("|html", "").replace("|tag", "").getRegex()
}, gs = /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/, Nu = /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/, vs = /^( {2,}|\\)\n(?!\s*$)/, Iu = /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/, ir = "\\p{P}\\p{S}", Lu = fe(/^((?![*_])[\spunctuation])/, "u").replace(/punctuation/g, ir).getRegex(), Ou = /\[[^[\]]*?\]\([^\(\)]*?\)|`[^`]*?`|<[^<>]*?>/g, Pu = fe(/^(?:\*+(?:((?!\*)[punct])|[^\s*]))|^_+(?:((?!_)[punct])|([^\s_]))/, "u").replace(/punct/g, ir).getRegex(), Hu = fe("^[^_*]*?__[^_*]*?\\*[^_*]*?(?=__)|[^*]+(?=[^*])|(?!\\*)[punct](\\*+)(?=[\\s]|$)|[^punct\\s](\\*+)(?!\\*)(?=[punct\\s]|$)|(?!\\*)[punct\\s](\\*+)(?=[^punct\\s])|[\\s](\\*+)(?!\\*)(?=[punct])|(?!\\*)[punct](\\*+)(?!\\*)(?=[punct])|[^punct\\s](\\*+)(?=[^punct\\s])", "gu").replace(/punct/g, ir).getRegex(), Uu = fe("^[^_*]*?\\*\\*[^_*]*?_[^_*]*?(?=\\*\\*)|[^_]+(?=[^_])|(?!_)[punct](_+)(?=[\\s]|$)|[^punct\\s](_+)(?!_)(?=[punct\\s]|$)|(?!_)[punct\\s](_+)(?=[^punct\\s])|[\\s](_+)(?!_)(?=[punct])|(?!_)[punct](_+)(?!_)(?=[punct])", "gu").replace(/punct/g, ir).getRegex(), Vu = fe(/\\([punct])/, "gu").replace(/punct/g, ir).getRegex(), Gu = fe(/^<(scheme:[^\s\x00-\x1f<>]*|email)>/).replace("scheme", /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/).replace("email", /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/).getRegex(), Yu = fe(ha).replace("(?:-->|$)", "-->").getRegex(), Wu = fe("^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>").replace("comment", Yu).replace("attribute", /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/).getRegex(), Or = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/, ju = fe(/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/).replace("label", Or).replace("href", /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/).replace("title", /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/).getRegex(), _s = fe(/^!?\[(label)\]\[(ref)\]/).replace("label", Or).replace("ref", ca).getRegex(), bs = fe(/^!?\[(ref)\](?:\[\])?/).replace("ref", ca).getRegex(), Xu = fe("reflink|nolink(?!\\()", "g").replace("reflink", _s).replace("nolink", bs).getRegex(), da = {
  _backpedal: Z0,
  // only used for GFM url
  anyPunctuation: Vu,
  autolink: Gu,
  blockSkip: Ou,
  br: vs,
  code: Nu,
  del: Z0,
  emStrongLDelim: Pu,
  emStrongRDelimAst: Hu,
  emStrongRDelimUnd: Uu,
  escape: gs,
  link: ju,
  nolink: bs,
  punctuation: Lu,
  reflink: _s,
  reflinkSearch: Xu,
  tag: Wu,
  text: Iu,
  url: Z0
}, Zu = {
  ...da,
  link: fe(/^!?\[(label)\]\((.*?)\)/).replace("label", Or).getRegex(),
  reflink: fe(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label", Or).getRegex()
}, Bn = {
  ...da,
  escape: fe(gs).replace("])", "~|])").getRegex(),
  url: fe(/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/, "i").replace("email", /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/).getRegex(),
  _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/,
  del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,
  text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/
}, Ku = {
  ...Bn,
  br: fe(vs).replace("{2,}", "*").getRegex(),
  text: fe(Bn.text).replace("\\b_", "\\b_| {2,}\\n").replace(/\{2,\}/g, "*").getRegex()
}, yr = {
  normal: ma,
  gfm: Ru,
  pedantic: qu
}, O0 = {
  normal: da,
  gfm: Bn,
  breaks: Ku,
  pedantic: Zu
};
class zt {
  constructor(e) {
    ve(this, "tokens");
    ve(this, "options");
    ve(this, "state");
    ve(this, "tokenizer");
    ve(this, "inlineQueue");
    this.tokens = [], this.tokens.links = /* @__PURE__ */ Object.create(null), this.options = e || b0, this.options.tokenizer = this.options.tokenizer || new Lr(), this.tokenizer = this.options.tokenizer, this.tokenizer.options = this.options, this.tokenizer.lexer = this, this.inlineQueue = [], this.state = {
      inLink: !1,
      inRawBlock: !1,
      top: !0
    };
    const t = {
      block: yr.normal,
      inline: O0.normal
    };
    this.options.pedantic ? (t.block = yr.pedantic, t.inline = O0.pedantic) : this.options.gfm && (t.block = yr.gfm, this.options.breaks ? t.inline = O0.breaks : t.inline = O0.gfm), this.tokenizer.rules = t;
  }
  /**
   * Expose Rules
   */
  static get rules() {
    return {
      block: yr,
      inline: O0
    };
  }
  /**
   * Static Lex Method
   */
  static lex(e, t) {
    return new zt(t).lex(e);
  }
  /**
   * Static Lex Inline Method
   */
  static lexInline(e, t) {
    return new zt(t).inlineTokens(e);
  }
  /**
   * Preprocessing
   */
  lex(e) {
    e = e.replace(/\r\n|\r/g, `
`), this.blockTokens(e, this.tokens);
    for (let t = 0; t < this.inlineQueue.length; t++) {
      const r = this.inlineQueue[t];
      this.inlineTokens(r.src, r.tokens);
    }
    return this.inlineQueue = [], this.tokens;
  }
  blockTokens(e, t = []) {
    this.options.pedantic ? e = e.replace(/\t/g, "    ").replace(/^ +$/gm, "") : e = e.replace(/^( *)(\t+)/gm, (o, u, h) => u + "    ".repeat(h.length));
    let r, a, i, l;
    for (; e; )
      if (!(this.options.extensions && this.options.extensions.block && this.options.extensions.block.some((o) => (r = o.call({ lexer: this }, e, t)) ? (e = e.substring(r.raw.length), t.push(r), !0) : !1))) {
        if (r = this.tokenizer.space(e)) {
          e = e.substring(r.raw.length), r.raw.length === 1 && t.length > 0 ? t[t.length - 1].raw += `
` : t.push(r);
          continue;
        }
        if (r = this.tokenizer.code(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && (a.type === "paragraph" || a.type === "text") ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.fences(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.heading(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.hr(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.blockquote(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.list(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.html(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.def(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && (a.type === "paragraph" || a.type === "text") ? (a.raw += `
` + r.raw, a.text += `
` + r.raw, this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : this.tokens.links[r.tag] || (this.tokens.links[r.tag] = {
            href: r.href,
            title: r.title
          });
          continue;
        }
        if (r = this.tokenizer.table(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.lheading(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (i = e, this.options.extensions && this.options.extensions.startBlock) {
          let o = 1 / 0;
          const u = e.slice(1);
          let h;
          this.options.extensions.startBlock.forEach((d) => {
            h = d.call({ lexer: this }, u), typeof h == "number" && h >= 0 && (o = Math.min(o, h));
          }), o < 1 / 0 && o >= 0 && (i = e.substring(0, o + 1));
        }
        if (this.state.top && (r = this.tokenizer.paragraph(i))) {
          a = t[t.length - 1], l && a.type === "paragraph" ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r), l = i.length !== e.length, e = e.substring(r.raw.length);
          continue;
        }
        if (r = this.tokenizer.text(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && a.type === "text" ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r);
          continue;
        }
        if (e) {
          const o = "Infinite loop on byte: " + e.charCodeAt(0);
          if (this.options.silent) {
            console.error(o);
            break;
          } else
            throw new Error(o);
        }
      }
    return this.state.top = !0, t;
  }
  inline(e, t = []) {
    return this.inlineQueue.push({ src: e, tokens: t }), t;
  }
  /**
   * Lexing/Compiling
   */
  inlineTokens(e, t = []) {
    let r, a, i, l = e, o, u, h;
    if (this.tokens.links) {
      const d = Object.keys(this.tokens.links);
      if (d.length > 0)
        for (; (o = this.tokenizer.rules.inline.reflinkSearch.exec(l)) != null; )
          d.includes(o[0].slice(o[0].lastIndexOf("[") + 1, -1)) && (l = l.slice(0, o.index) + "[" + "a".repeat(o[0].length - 2) + "]" + l.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex));
    }
    for (; (o = this.tokenizer.rules.inline.blockSkip.exec(l)) != null; )
      l = l.slice(0, o.index) + "[" + "a".repeat(o[0].length - 2) + "]" + l.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
    for (; (o = this.tokenizer.rules.inline.anyPunctuation.exec(l)) != null; )
      l = l.slice(0, o.index) + "++" + l.slice(this.tokenizer.rules.inline.anyPunctuation.lastIndex);
    for (; e; )
      if (u || (h = ""), u = !1, !(this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some((d) => (r = d.call({ lexer: this }, e, t)) ? (e = e.substring(r.raw.length), t.push(r), !0) : !1))) {
        if (r = this.tokenizer.escape(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.tag(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && r.type === "text" && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.link(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.reflink(e, this.tokens.links)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && r.type === "text" && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.emStrong(e, l, h)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.codespan(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.br(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.del(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.autolink(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (!this.state.inLink && (r = this.tokenizer.url(e))) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (i = e, this.options.extensions && this.options.extensions.startInline) {
          let d = 1 / 0;
          const p = e.slice(1);
          let b;
          this.options.extensions.startInline.forEach((y) => {
            b = y.call({ lexer: this }, p), typeof b == "number" && b >= 0 && (d = Math.min(d, b));
          }), d < 1 / 0 && d >= 0 && (i = e.substring(0, d + 1));
        }
        if (r = this.tokenizer.inlineText(i)) {
          e = e.substring(r.raw.length), r.raw.slice(-1) !== "_" && (h = r.raw.slice(-1)), u = !0, a = t[t.length - 1], a && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (e) {
          const d = "Infinite loop on byte: " + e.charCodeAt(0);
          if (this.options.silent) {
            console.error(d);
            break;
          } else
            throw new Error(d);
        }
      }
    return t;
  }
}
class Pr {
  constructor(e) {
    ve(this, "options");
    this.options = e || b0;
  }
  code(e, t, r) {
    var i;
    const a = (i = (t || "").match(/^\S*/)) == null ? void 0 : i[0];
    return e = e.replace(/\n$/, "") + `
`, a ? '<pre><code class="language-' + Je(a) + '">' + (r ? e : Je(e, !0)) + `</code></pre>
` : "<pre><code>" + (r ? e : Je(e, !0)) + `</code></pre>
`;
  }
  blockquote(e) {
    return `<blockquote>
${e}</blockquote>
`;
  }
  html(e, t) {
    return e;
  }
  heading(e, t, r) {
    return `<h${t}>${e}</h${t}>
`;
  }
  hr() {
    return `<hr>
`;
  }
  list(e, t, r) {
    const a = t ? "ol" : "ul", i = t && r !== 1 ? ' start="' + r + '"' : "";
    return "<" + a + i + `>
` + e + "</" + a + `>
`;
  }
  listitem(e, t, r) {
    return `<li>${e}</li>
`;
  }
  checkbox(e) {
    return "<input " + (e ? 'checked="" ' : "") + 'disabled="" type="checkbox">';
  }
  paragraph(e) {
    return `<p>${e}</p>
`;
  }
  table(e, t) {
    return t && (t = `<tbody>${t}</tbody>`), `<table>
<thead>
` + e + `</thead>
` + t + `</table>
`;
  }
  tablerow(e) {
    return `<tr>
${e}</tr>
`;
  }
  tablecell(e, t) {
    const r = t.header ? "th" : "td";
    return (t.align ? `<${r} align="${t.align}">` : `<${r}>`) + e + `</${r}>
`;
  }
  /**
   * span level renderer
   */
  strong(e) {
    return `<strong>${e}</strong>`;
  }
  em(e) {
    return `<em>${e}</em>`;
  }
  codespan(e) {
    return `<code>${e}</code>`;
  }
  br() {
    return "<br>";
  }
  del(e) {
    return `<del>${e}</del>`;
  }
  link(e, t, r) {
    const a = Ti(e);
    if (a === null)
      return r;
    e = a;
    let i = '<a href="' + e + '"';
    return t && (i += ' title="' + t + '"'), i += ">" + r + "</a>", i;
  }
  image(e, t, r) {
    const a = Ti(e);
    if (a === null)
      return r;
    e = a;
    let i = `<img src="${e}" alt="${r}"`;
    return t && (i += ` title="${t}"`), i += ">", i;
  }
  text(e) {
    return e;
  }
}
class fa {
  // no need for block level renderers
  strong(e) {
    return e;
  }
  em(e) {
    return e;
  }
  codespan(e) {
    return e;
  }
  del(e) {
    return e;
  }
  html(e) {
    return e;
  }
  text(e) {
    return e;
  }
  link(e, t, r) {
    return "" + r;
  }
  image(e, t, r) {
    return "" + r;
  }
  br() {
    return "";
  }
}
class Bt {
  constructor(e) {
    ve(this, "options");
    ve(this, "renderer");
    ve(this, "textRenderer");
    this.options = e || b0, this.options.renderer = this.options.renderer || new Pr(), this.renderer = this.options.renderer, this.renderer.options = this.options, this.textRenderer = new fa();
  }
  /**
   * Static Parse Method
   */
  static parse(e, t) {
    return new Bt(t).parse(e);
  }
  /**
   * Static Parse Inline Method
   */
  static parseInline(e, t) {
    return new Bt(t).parseInline(e);
  }
  /**
   * Parse Loop
   */
  parse(e, t = !0) {
    let r = "";
    for (let a = 0; a < e.length; a++) {
      const i = e[a];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const l = i, o = this.options.extensions.renderers[l.type].call({ parser: this }, l);
        if (o !== !1 || !["space", "hr", "heading", "code", "table", "blockquote", "list", "html", "paragraph", "text"].includes(l.type)) {
          r += o || "";
          continue;
        }
      }
      switch (i.type) {
        case "space":
          continue;
        case "hr": {
          r += this.renderer.hr();
          continue;
        }
        case "heading": {
          const l = i;
          r += this.renderer.heading(this.parseInline(l.tokens), l.depth, ku(this.parseInline(l.tokens, this.textRenderer)));
          continue;
        }
        case "code": {
          const l = i;
          r += this.renderer.code(l.text, l.lang, !!l.escaped);
          continue;
        }
        case "table": {
          const l = i;
          let o = "", u = "";
          for (let d = 0; d < l.header.length; d++)
            u += this.renderer.tablecell(this.parseInline(l.header[d].tokens), { header: !0, align: l.align[d] });
          o += this.renderer.tablerow(u);
          let h = "";
          for (let d = 0; d < l.rows.length; d++) {
            const p = l.rows[d];
            u = "";
            for (let b = 0; b < p.length; b++)
              u += this.renderer.tablecell(this.parseInline(p[b].tokens), { header: !1, align: l.align[b] });
            h += this.renderer.tablerow(u);
          }
          r += this.renderer.table(o, h);
          continue;
        }
        case "blockquote": {
          const l = i, o = this.parse(l.tokens);
          r += this.renderer.blockquote(o);
          continue;
        }
        case "list": {
          const l = i, o = l.ordered, u = l.start, h = l.loose;
          let d = "";
          for (let p = 0; p < l.items.length; p++) {
            const b = l.items[p], y = b.checked, D = b.task;
            let A = "";
            if (b.task) {
              const C = this.renderer.checkbox(!!y);
              h ? b.tokens.length > 0 && b.tokens[0].type === "paragraph" ? (b.tokens[0].text = C + " " + b.tokens[0].text, b.tokens[0].tokens && b.tokens[0].tokens.length > 0 && b.tokens[0].tokens[0].type === "text" && (b.tokens[0].tokens[0].text = C + " " + b.tokens[0].tokens[0].text)) : b.tokens.unshift({
                type: "text",
                text: C + " "
              }) : A += C + " ";
            }
            A += this.parse(b.tokens, h), d += this.renderer.listitem(A, D, !!y);
          }
          r += this.renderer.list(d, o, u);
          continue;
        }
        case "html": {
          const l = i;
          r += this.renderer.html(l.text, l.block);
          continue;
        }
        case "paragraph": {
          const l = i;
          r += this.renderer.paragraph(this.parseInline(l.tokens));
          continue;
        }
        case "text": {
          let l = i, o = l.tokens ? this.parseInline(l.tokens) : l.text;
          for (; a + 1 < e.length && e[a + 1].type === "text"; )
            l = e[++a], o += `
` + (l.tokens ? this.parseInline(l.tokens) : l.text);
          r += t ? this.renderer.paragraph(o) : o;
          continue;
        }
        default: {
          const l = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(l), "";
          throw new Error(l);
        }
      }
    }
    return r;
  }
  /**
   * Parse Inline Tokens
   */
  parseInline(e, t) {
    t = t || this.renderer;
    let r = "";
    for (let a = 0; a < e.length; a++) {
      const i = e[a];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const l = this.options.extensions.renderers[i.type].call({ parser: this }, i);
        if (l !== !1 || !["escape", "html", "link", "image", "strong", "em", "codespan", "br", "del", "text"].includes(i.type)) {
          r += l || "";
          continue;
        }
      }
      switch (i.type) {
        case "escape": {
          const l = i;
          r += t.text(l.text);
          break;
        }
        case "html": {
          const l = i;
          r += t.html(l.text);
          break;
        }
        case "link": {
          const l = i;
          r += t.link(l.href, l.title, this.parseInline(l.tokens, t));
          break;
        }
        case "image": {
          const l = i;
          r += t.image(l.href, l.title, l.text);
          break;
        }
        case "strong": {
          const l = i;
          r += t.strong(this.parseInline(l.tokens, t));
          break;
        }
        case "em": {
          const l = i;
          r += t.em(this.parseInline(l.tokens, t));
          break;
        }
        case "codespan": {
          const l = i;
          r += t.codespan(l.text);
          break;
        }
        case "br": {
          r += t.br();
          break;
        }
        case "del": {
          const l = i;
          r += t.del(this.parseInline(l.tokens, t));
          break;
        }
        case "text": {
          const l = i;
          r += t.text(l.text);
          break;
        }
        default: {
          const l = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(l), "";
          throw new Error(l);
        }
      }
    }
    return r;
  }
}
class K0 {
  constructor(e) {
    ve(this, "options");
    this.options = e || b0;
  }
  /**
   * Process markdown before marked
   */
  preprocess(e) {
    return e;
  }
  /**
   * Process HTML after marked is finished
   */
  postprocess(e) {
    return e;
  }
  /**
   * Process all tokens before walk tokens
   */
  processAllTokens(e) {
    return e;
  }
}
ve(K0, "passThroughHooks", /* @__PURE__ */ new Set([
  "preprocess",
  "postprocess",
  "processAllTokens"
]));
var v0, Rn, ys;
class Qu {
  constructor(...e) {
    La(this, v0);
    ve(this, "defaults", oa());
    ve(this, "options", this.setOptions);
    ve(this, "parse", hr(this, v0, Rn).call(this, zt.lex, Bt.parse));
    ve(this, "parseInline", hr(this, v0, Rn).call(this, zt.lexInline, Bt.parseInline));
    ve(this, "Parser", Bt);
    ve(this, "Renderer", Pr);
    ve(this, "TextRenderer", fa);
    ve(this, "Lexer", zt);
    ve(this, "Tokenizer", Lr);
    ve(this, "Hooks", K0);
    this.use(...e);
  }
  /**
   * Run callback for every token
   */
  walkTokens(e, t) {
    var a, i;
    let r = [];
    for (const l of e)
      switch (r = r.concat(t.call(this, l)), l.type) {
        case "table": {
          const o = l;
          for (const u of o.header)
            r = r.concat(this.walkTokens(u.tokens, t));
          for (const u of o.rows)
            for (const h of u)
              r = r.concat(this.walkTokens(h.tokens, t));
          break;
        }
        case "list": {
          const o = l;
          r = r.concat(this.walkTokens(o.items, t));
          break;
        }
        default: {
          const o = l;
          (i = (a = this.defaults.extensions) == null ? void 0 : a.childTokens) != null && i[o.type] ? this.defaults.extensions.childTokens[o.type].forEach((u) => {
            const h = o[u].flat(1 / 0);
            r = r.concat(this.walkTokens(h, t));
          }) : o.tokens && (r = r.concat(this.walkTokens(o.tokens, t)));
        }
      }
    return r;
  }
  use(...e) {
    const t = this.defaults.extensions || { renderers: {}, childTokens: {} };
    return e.forEach((r) => {
      const a = { ...r };
      if (a.async = this.defaults.async || a.async || !1, r.extensions && (r.extensions.forEach((i) => {
        if (!i.name)
          throw new Error("extension name required");
        if ("renderer" in i) {
          const l = t.renderers[i.name];
          l ? t.renderers[i.name] = function(...o) {
            let u = i.renderer.apply(this, o);
            return u === !1 && (u = l.apply(this, o)), u;
          } : t.renderers[i.name] = i.renderer;
        }
        if ("tokenizer" in i) {
          if (!i.level || i.level !== "block" && i.level !== "inline")
            throw new Error("extension level must be 'block' or 'inline'");
          const l = t[i.level];
          l ? l.unshift(i.tokenizer) : t[i.level] = [i.tokenizer], i.start && (i.level === "block" ? t.startBlock ? t.startBlock.push(i.start) : t.startBlock = [i.start] : i.level === "inline" && (t.startInline ? t.startInline.push(i.start) : t.startInline = [i.start]));
        }
        "childTokens" in i && i.childTokens && (t.childTokens[i.name] = i.childTokens);
      }), a.extensions = t), r.renderer) {
        const i = this.defaults.renderer || new Pr(this.defaults);
        for (const l in r.renderer) {
          if (!(l in i))
            throw new Error(`renderer '${l}' does not exist`);
          if (l === "options")
            continue;
          const o = l, u = r.renderer[o], h = i[o];
          i[o] = (...d) => {
            let p = u.apply(i, d);
            return p === !1 && (p = h.apply(i, d)), p || "";
          };
        }
        a.renderer = i;
      }
      if (r.tokenizer) {
        const i = this.defaults.tokenizer || new Lr(this.defaults);
        for (const l in r.tokenizer) {
          if (!(l in i))
            throw new Error(`tokenizer '${l}' does not exist`);
          if (["options", "rules", "lexer"].includes(l))
            continue;
          const o = l, u = r.tokenizer[o], h = i[o];
          i[o] = (...d) => {
            let p = u.apply(i, d);
            return p === !1 && (p = h.apply(i, d)), p;
          };
        }
        a.tokenizer = i;
      }
      if (r.hooks) {
        const i = this.defaults.hooks || new K0();
        for (const l in r.hooks) {
          if (!(l in i))
            throw new Error(`hook '${l}' does not exist`);
          if (l === "options")
            continue;
          const o = l, u = r.hooks[o], h = i[o];
          K0.passThroughHooks.has(l) ? i[o] = (d) => {
            if (this.defaults.async)
              return Promise.resolve(u.call(i, d)).then((b) => h.call(i, b));
            const p = u.call(i, d);
            return h.call(i, p);
          } : i[o] = (...d) => {
            let p = u.apply(i, d);
            return p === !1 && (p = h.apply(i, d)), p;
          };
        }
        a.hooks = i;
      }
      if (r.walkTokens) {
        const i = this.defaults.walkTokens, l = r.walkTokens;
        a.walkTokens = function(o) {
          let u = [];
          return u.push(l.call(this, o)), i && (u = u.concat(i.call(this, o))), u;
        };
      }
      this.defaults = { ...this.defaults, ...a };
    }), this;
  }
  setOptions(e) {
    return this.defaults = { ...this.defaults, ...e }, this;
  }
  lexer(e, t) {
    return zt.lex(e, t ?? this.defaults);
  }
  parser(e, t) {
    return Bt.parse(e, t ?? this.defaults);
  }
}
v0 = new WeakSet(), Rn = function(e, t) {
  return (r, a) => {
    const i = { ...a }, l = { ...this.defaults, ...i };
    this.defaults.async === !0 && i.async === !1 && (l.silent || console.warn("marked(): The async option was set to true by an extension. The async: false option sent to parse will be ignored."), l.async = !0);
    const o = hr(this, v0, ys).call(this, !!l.silent, !!l.async);
    if (typeof r > "u" || r === null)
      return o(new Error("marked(): input parameter is undefined or null"));
    if (typeof r != "string")
      return o(new Error("marked(): input parameter is of type " + Object.prototype.toString.call(r) + ", string expected"));
    if (l.hooks && (l.hooks.options = l), l.async)
      return Promise.resolve(l.hooks ? l.hooks.preprocess(r) : r).then((u) => e(u, l)).then((u) => l.hooks ? l.hooks.processAllTokens(u) : u).then((u) => l.walkTokens ? Promise.all(this.walkTokens(u, l.walkTokens)).then(() => u) : u).then((u) => t(u, l)).then((u) => l.hooks ? l.hooks.postprocess(u) : u).catch(o);
    try {
      l.hooks && (r = l.hooks.preprocess(r));
      let u = e(r, l);
      l.hooks && (u = l.hooks.processAllTokens(u)), l.walkTokens && this.walkTokens(u, l.walkTokens);
      let h = t(u, l);
      return l.hooks && (h = l.hooks.postprocess(h)), h;
    } catch (u) {
      return o(u);
    }
  };
}, ys = function(e, t) {
  return (r) => {
    if (r.message += `
Please report this to https://github.com/markedjs/marked.`, e) {
      const a = "<p>An error occurred:</p><pre>" + Je(r.message + "", !0) + "</pre>";
      return t ? Promise.resolve(a) : a;
    }
    if (t)
      return Promise.reject(r);
    throw r;
  };
};
const g0 = new Qu();
function de(n, e) {
  return g0.parse(n, e);
}
de.options = de.setOptions = function(n) {
  return g0.setOptions(n), de.defaults = g0.defaults, cs(de.defaults), de;
};
de.getDefaults = oa;
de.defaults = b0;
de.use = function(...n) {
  return g0.use(...n), de.defaults = g0.defaults, cs(de.defaults), de;
};
de.walkTokens = function(n, e) {
  return g0.walkTokens(n, e);
};
de.parseInline = g0.parseInline;
de.Parser = Bt;
de.parser = Bt.parse;
de.Renderer = Pr;
de.TextRenderer = fa;
de.Lexer = zt;
de.lexer = zt.lex;
de.Tokenizer = Lr;
de.Hooks = K0;
de.parse = de;
de.options;
de.setOptions;
de.use;
de.walkTokens;
de.parseInline;
Bt.parse;
zt.lex;
const Ju = /[\0-\x1F!-,\.\/:-@\[-\^`\{-\xA9\xAB-\xB4\xB6-\xB9\xBB-\xBF\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0378\u0379\u037E\u0380-\u0385\u0387\u038B\u038D\u03A2\u03F6\u0482\u0530\u0557\u0558\u055A-\u055F\u0589-\u0590\u05BE\u05C0\u05C3\u05C6\u05C8-\u05CF\u05EB-\u05EE\u05F3-\u060F\u061B-\u061F\u066A-\u066D\u06D4\u06DD\u06DE\u06E9\u06FD\u06FE\u0700-\u070F\u074B\u074C\u07B2-\u07BF\u07F6-\u07F9\u07FB\u07FC\u07FE\u07FF\u082E-\u083F\u085C-\u085F\u086B-\u089F\u08B5\u08C8-\u08D2\u08E2\u0964\u0965\u0970\u0984\u098D\u098E\u0991\u0992\u09A9\u09B1\u09B3-\u09B5\u09BA\u09BB\u09C5\u09C6\u09C9\u09CA\u09CF-\u09D6\u09D8-\u09DB\u09DE\u09E4\u09E5\u09F2-\u09FB\u09FD\u09FF\u0A00\u0A04\u0A0B-\u0A0E\u0A11\u0A12\u0A29\u0A31\u0A34\u0A37\u0A3A\u0A3B\u0A3D\u0A43-\u0A46\u0A49\u0A4A\u0A4E-\u0A50\u0A52-\u0A58\u0A5D\u0A5F-\u0A65\u0A76-\u0A80\u0A84\u0A8E\u0A92\u0AA9\u0AB1\u0AB4\u0ABA\u0ABB\u0AC6\u0ACA\u0ACE\u0ACF\u0AD1-\u0ADF\u0AE4\u0AE5\u0AF0-\u0AF8\u0B00\u0B04\u0B0D\u0B0E\u0B11\u0B12\u0B29\u0B31\u0B34\u0B3A\u0B3B\u0B45\u0B46\u0B49\u0B4A\u0B4E-\u0B54\u0B58-\u0B5B\u0B5E\u0B64\u0B65\u0B70\u0B72-\u0B81\u0B84\u0B8B-\u0B8D\u0B91\u0B96-\u0B98\u0B9B\u0B9D\u0BA0-\u0BA2\u0BA5-\u0BA7\u0BAB-\u0BAD\u0BBA-\u0BBD\u0BC3-\u0BC5\u0BC9\u0BCE\u0BCF\u0BD1-\u0BD6\u0BD8-\u0BE5\u0BF0-\u0BFF\u0C0D\u0C11\u0C29\u0C3A-\u0C3C\u0C45\u0C49\u0C4E-\u0C54\u0C57\u0C5B-\u0C5F\u0C64\u0C65\u0C70-\u0C7F\u0C84\u0C8D\u0C91\u0CA9\u0CB4\u0CBA\u0CBB\u0CC5\u0CC9\u0CCE-\u0CD4\u0CD7-\u0CDD\u0CDF\u0CE4\u0CE5\u0CF0\u0CF3-\u0CFF\u0D0D\u0D11\u0D45\u0D49\u0D4F-\u0D53\u0D58-\u0D5E\u0D64\u0D65\u0D70-\u0D79\u0D80\u0D84\u0D97-\u0D99\u0DB2\u0DBC\u0DBE\u0DBF\u0DC7-\u0DC9\u0DCB-\u0DCE\u0DD5\u0DD7\u0DE0-\u0DE5\u0DF0\u0DF1\u0DF4-\u0E00\u0E3B-\u0E3F\u0E4F\u0E5A-\u0E80\u0E83\u0E85\u0E8B\u0EA4\u0EA6\u0EBE\u0EBF\u0EC5\u0EC7\u0ECE\u0ECF\u0EDA\u0EDB\u0EE0-\u0EFF\u0F01-\u0F17\u0F1A-\u0F1F\u0F2A-\u0F34\u0F36\u0F38\u0F3A-\u0F3D\u0F48\u0F6D-\u0F70\u0F85\u0F98\u0FBD-\u0FC5\u0FC7-\u0FFF\u104A-\u104F\u109E\u109F\u10C6\u10C8-\u10CC\u10CE\u10CF\u10FB\u1249\u124E\u124F\u1257\u1259\u125E\u125F\u1289\u128E\u128F\u12B1\u12B6\u12B7\u12BF\u12C1\u12C6\u12C7\u12D7\u1311\u1316\u1317\u135B\u135C\u1360-\u137F\u1390-\u139F\u13F6\u13F7\u13FE-\u1400\u166D\u166E\u1680\u169B-\u169F\u16EB-\u16ED\u16F9-\u16FF\u170D\u1715-\u171F\u1735-\u173F\u1754-\u175F\u176D\u1771\u1774-\u177F\u17D4-\u17D6\u17D8-\u17DB\u17DE\u17DF\u17EA-\u180A\u180E\u180F\u181A-\u181F\u1879-\u187F\u18AB-\u18AF\u18F6-\u18FF\u191F\u192C-\u192F\u193C-\u1945\u196E\u196F\u1975-\u197F\u19AC-\u19AF\u19CA-\u19CF\u19DA-\u19FF\u1A1C-\u1A1F\u1A5F\u1A7D\u1A7E\u1A8A-\u1A8F\u1A9A-\u1AA6\u1AA8-\u1AAF\u1AC1-\u1AFF\u1B4C-\u1B4F\u1B5A-\u1B6A\u1B74-\u1B7F\u1BF4-\u1BFF\u1C38-\u1C3F\u1C4A-\u1C4C\u1C7E\u1C7F\u1C89-\u1C8F\u1CBB\u1CBC\u1CC0-\u1CCF\u1CD3\u1CFB-\u1CFF\u1DFA\u1F16\u1F17\u1F1E\u1F1F\u1F46\u1F47\u1F4E\u1F4F\u1F58\u1F5A\u1F5C\u1F5E\u1F7E\u1F7F\u1FB5\u1FBD\u1FBF-\u1FC1\u1FC5\u1FCD-\u1FCF\u1FD4\u1FD5\u1FDC-\u1FDF\u1FED-\u1FF1\u1FF5\u1FFD-\u203E\u2041-\u2053\u2055-\u2070\u2072-\u207E\u2080-\u208F\u209D-\u20CF\u20F1-\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F-\u215F\u2189-\u24B5\u24EA-\u2BFF\u2C2F\u2C5F\u2CE5-\u2CEA\u2CF4-\u2CFF\u2D26\u2D28-\u2D2C\u2D2E\u2D2F\u2D68-\u2D6E\u2D70-\u2D7E\u2D97-\u2D9F\u2DA7\u2DAF\u2DB7\u2DBF\u2DC7\u2DCF\u2DD7\u2DDF\u2E00-\u2E2E\u2E30-\u3004\u3008-\u3020\u3030\u3036\u3037\u303D-\u3040\u3097\u3098\u309B\u309C\u30A0\u30FB\u3100-\u3104\u3130\u318F-\u319F\u31C0-\u31EF\u3200-\u33FF\u4DC0-\u4DFF\u9FFD-\u9FFF\uA48D-\uA4CF\uA4FE\uA4FF\uA60D-\uA60F\uA62C-\uA63F\uA673\uA67E\uA6F2-\uA716\uA720\uA721\uA789\uA78A\uA7C0\uA7C1\uA7CB-\uA7F4\uA828-\uA82B\uA82D-\uA83F\uA874-\uA87F\uA8C6-\uA8CF\uA8DA-\uA8DF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA954-\uA95F\uA97D-\uA97F\uA9C1-\uA9CE\uA9DA-\uA9DF\uA9FF\uAA37-\uAA3F\uAA4E\uAA4F\uAA5A-\uAA5F\uAA77-\uAA79\uAAC3-\uAADA\uAADE\uAADF\uAAF0\uAAF1\uAAF7-\uAB00\uAB07\uAB08\uAB0F\uAB10\uAB17-\uAB1F\uAB27\uAB2F\uAB5B\uAB6A-\uAB6F\uABEB\uABEE\uABEF\uABFA-\uABFF\uD7A4-\uD7AF\uD7C7-\uD7CA\uD7FC-\uD7FF\uE000-\uF8FF\uFA6E\uFA6F\uFADA-\uFAFF\uFB07-\uFB12\uFB18-\uFB1C\uFB29\uFB37\uFB3D\uFB3F\uFB42\uFB45\uFBB2-\uFBD2\uFD3E-\uFD4F\uFD90\uFD91\uFDC8-\uFDEF\uFDFC-\uFDFF\uFE10-\uFE1F\uFE30-\uFE32\uFE35-\uFE4C\uFE50-\uFE6F\uFE75\uFEFD-\uFF0F\uFF1A-\uFF20\uFF3B-\uFF3E\uFF40\uFF5B-\uFF65\uFFBF-\uFFC1\uFFC8\uFFC9\uFFD0\uFFD1\uFFD8\uFFD9\uFFDD-\uFFFF]|\uD800[\uDC0C\uDC27\uDC3B\uDC3E\uDC4E\uDC4F\uDC5E-\uDC7F\uDCFB-\uDD3F\uDD75-\uDDFC\uDDFE-\uDE7F\uDE9D-\uDE9F\uDED1-\uDEDF\uDEE1-\uDEFF\uDF20-\uDF2C\uDF4B-\uDF4F\uDF7B-\uDF7F\uDF9E\uDF9F\uDFC4-\uDFC7\uDFD0\uDFD6-\uDFFF]|\uD801[\uDC9E\uDC9F\uDCAA-\uDCAF\uDCD4-\uDCD7\uDCFC-\uDCFF\uDD28-\uDD2F\uDD64-\uDDFF\uDF37-\uDF3F\uDF56-\uDF5F\uDF68-\uDFFF]|\uD802[\uDC06\uDC07\uDC09\uDC36\uDC39-\uDC3B\uDC3D\uDC3E\uDC56-\uDC5F\uDC77-\uDC7F\uDC9F-\uDCDF\uDCF3\uDCF6-\uDCFF\uDD16-\uDD1F\uDD3A-\uDD7F\uDDB8-\uDDBD\uDDC0-\uDDFF\uDE04\uDE07-\uDE0B\uDE14\uDE18\uDE36\uDE37\uDE3B-\uDE3E\uDE40-\uDE5F\uDE7D-\uDE7F\uDE9D-\uDEBF\uDEC8\uDEE7-\uDEFF\uDF36-\uDF3F\uDF56-\uDF5F\uDF73-\uDF7F\uDF92-\uDFFF]|\uD803[\uDC49-\uDC7F\uDCB3-\uDCBF\uDCF3-\uDCFF\uDD28-\uDD2F\uDD3A-\uDE7F\uDEAA\uDEAD-\uDEAF\uDEB2-\uDEFF\uDF1D-\uDF26\uDF28-\uDF2F\uDF51-\uDFAF\uDFC5-\uDFDF\uDFF7-\uDFFF]|\uD804[\uDC47-\uDC65\uDC70-\uDC7E\uDCBB-\uDCCF\uDCE9-\uDCEF\uDCFA-\uDCFF\uDD35\uDD40-\uDD43\uDD48-\uDD4F\uDD74\uDD75\uDD77-\uDD7F\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDFF\uDE12\uDE38-\uDE3D\uDE3F-\uDE7F\uDE87\uDE89\uDE8E\uDE9E\uDEA9-\uDEAF\uDEEB-\uDEEF\uDEFA-\uDEFF\uDF04\uDF0D\uDF0E\uDF11\uDF12\uDF29\uDF31\uDF34\uDF3A\uDF45\uDF46\uDF49\uDF4A\uDF4E\uDF4F\uDF51-\uDF56\uDF58-\uDF5C\uDF64\uDF65\uDF6D-\uDF6F\uDF75-\uDFFF]|\uD805[\uDC4B-\uDC4F\uDC5A-\uDC5D\uDC62-\uDC7F\uDCC6\uDCC8-\uDCCF\uDCDA-\uDD7F\uDDB6\uDDB7\uDDC1-\uDDD7\uDDDE-\uDDFF\uDE41-\uDE43\uDE45-\uDE4F\uDE5A-\uDE7F\uDEB9-\uDEBF\uDECA-\uDEFF\uDF1B\uDF1C\uDF2C-\uDF2F\uDF3A-\uDFFF]|\uD806[\uDC3B-\uDC9F\uDCEA-\uDCFE\uDD07\uDD08\uDD0A\uDD0B\uDD14\uDD17\uDD36\uDD39\uDD3A\uDD44-\uDD4F\uDD5A-\uDD9F\uDDA8\uDDA9\uDDD8\uDDD9\uDDE2\uDDE5-\uDDFF\uDE3F-\uDE46\uDE48-\uDE4F\uDE9A-\uDE9C\uDE9E-\uDEBF\uDEF9-\uDFFF]|\uD807[\uDC09\uDC37\uDC41-\uDC4F\uDC5A-\uDC71\uDC90\uDC91\uDCA8\uDCB7-\uDCFF\uDD07\uDD0A\uDD37-\uDD39\uDD3B\uDD3E\uDD48-\uDD4F\uDD5A-\uDD5F\uDD66\uDD69\uDD8F\uDD92\uDD99-\uDD9F\uDDAA-\uDEDF\uDEF7-\uDFAF\uDFB1-\uDFFF]|\uD808[\uDF9A-\uDFFF]|\uD809[\uDC6F-\uDC7F\uDD44-\uDFFF]|[\uD80A\uD80B\uD80E-\uD810\uD812-\uD819\uD824-\uD82B\uD82D\uD82E\uD830-\uD833\uD837\uD839\uD83D\uD83F\uD87B-\uD87D\uD87F\uD885-\uDB3F\uDB41-\uDBFF][\uDC00-\uDFFF]|\uD80D[\uDC2F-\uDFFF]|\uD811[\uDE47-\uDFFF]|\uD81A[\uDE39-\uDE3F\uDE5F\uDE6A-\uDECF\uDEEE\uDEEF\uDEF5-\uDEFF\uDF37-\uDF3F\uDF44-\uDF4F\uDF5A-\uDF62\uDF78-\uDF7C\uDF90-\uDFFF]|\uD81B[\uDC00-\uDE3F\uDE80-\uDEFF\uDF4B-\uDF4E\uDF88-\uDF8E\uDFA0-\uDFDF\uDFE2\uDFE5-\uDFEF\uDFF2-\uDFFF]|\uD821[\uDFF8-\uDFFF]|\uD823[\uDCD6-\uDCFF\uDD09-\uDFFF]|\uD82C[\uDD1F-\uDD4F\uDD53-\uDD63\uDD68-\uDD6F\uDEFC-\uDFFF]|\uD82F[\uDC6B-\uDC6F\uDC7D-\uDC7F\uDC89-\uDC8F\uDC9A-\uDC9C\uDC9F-\uDFFF]|\uD834[\uDC00-\uDD64\uDD6A-\uDD6C\uDD73-\uDD7A\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDE41\uDE45-\uDFFF]|\uD835[\uDC55\uDC9D\uDCA0\uDCA1\uDCA3\uDCA4\uDCA7\uDCA8\uDCAD\uDCBA\uDCBC\uDCC4\uDD06\uDD0B\uDD0C\uDD15\uDD1D\uDD3A\uDD3F\uDD45\uDD47-\uDD49\uDD51\uDEA6\uDEA7\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3\uDFCC\uDFCD]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85-\uDE9A\uDEA0\uDEB0-\uDFFF]|\uD838[\uDC07\uDC19\uDC1A\uDC22\uDC25\uDC2B-\uDCFF\uDD2D-\uDD2F\uDD3E\uDD3F\uDD4A-\uDD4D\uDD4F-\uDEBF\uDEFA-\uDFFF]|\uD83A[\uDCC5-\uDCCF\uDCD7-\uDCFF\uDD4C-\uDD4F\uDD5A-\uDFFF]|\uD83B[\uDC00-\uDDFF\uDE04\uDE20\uDE23\uDE25\uDE26\uDE28\uDE33\uDE38\uDE3A\uDE3C-\uDE41\uDE43-\uDE46\uDE48\uDE4A\uDE4C\uDE50\uDE53\uDE55\uDE56\uDE58\uDE5A\uDE5C\uDE5E\uDE60\uDE63\uDE65\uDE66\uDE6B\uDE73\uDE78\uDE7D\uDE7F\uDE8A\uDE9C-\uDEA0\uDEA4\uDEAA\uDEBC-\uDFFF]|\uD83C[\uDC00-\uDD2F\uDD4A-\uDD4F\uDD6A-\uDD6F\uDD8A-\uDFFF]|\uD83E[\uDC00-\uDFEF\uDFFA-\uDFFF]|\uD869[\uDEDE-\uDEFF]|\uD86D[\uDF35-\uDF3F]|\uD86E[\uDC1E\uDC1F]|\uD873[\uDEA2-\uDEAF]|\uD87A[\uDFE1-\uDFFF]|\uD87E[\uDE1E-\uDFFF]|\uD884[\uDF4B-\uDFFF]|\uDB40[\uDC00-\uDCFF\uDDF0-\uDFFF]/g, e4 = Object.hasOwnProperty;
class ws {
  /**
   * Create a new slug class.
   */
  constructor() {
    this.occurrences, this.reset();
  }
  /**
   * Generate a unique slug.
  *
  * Tracks previously generated slugs: repeated calls with the same value
  * will result in different slugs.
  * Use the `slug` function to get same slugs.
   *
   * @param  {string} value
   *   String of text to slugify
   * @param  {boolean} [maintainCase=false]
   *   Keep the current case, otherwise make all lowercase
   * @return {string}
   *   A unique slug string
   */
  slug(e, t) {
    const r = this;
    let a = t4(e, t === !0);
    const i = a;
    for (; e4.call(r.occurrences, a); )
      r.occurrences[i]++, a = i + "-" + r.occurrences[i];
    return r.occurrences[a] = 0, a;
  }
  /**
   * Reset - Forget all previous slugs
   *
   * @return void
   */
  reset() {
    this.occurrences = /* @__PURE__ */ Object.create(null);
  }
}
function t4(n, e) {
  return typeof n != "string" ? "" : (e || (n = n.toLowerCase()), n.replace(Ju, "").replace(/ /g, "-"));
}
new ws();
var Bi = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {}, r4 = { exports: {} };
(function(n) {
  var e = typeof window < "u" ? window : typeof WorkerGlobalScope < "u" && self instanceof WorkerGlobalScope ? self : {};
  /**
   * Prism: Lightweight, robust, elegant syntax highlighting
   *
   * @license MIT <https://opensource.org/licenses/MIT>
   * @author Lea Verou <https://lea.verou.me>
   * @namespace
   * @public
   */
  var t = function(r) {
    var a = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i, i = 0, l = {}, o = {
      /**
       * By default, Prism will attempt to highlight all code elements (by calling {@link Prism.highlightAll}) on the
       * current page after the page finished loading. This might be a problem if e.g. you wanted to asynchronously load
       * additional languages or plugins yourself.
       *
       * By setting this value to `true`, Prism will not automatically highlight all code elements on the page.
       *
       * You obviously have to change this value before the automatic highlighting started. To do this, you can add an
       * empty Prism object into the global scope before loading the Prism script like this:
       *
       * ```js
       * window.Prism = window.Prism || {};
       * Prism.manual = true;
       * // add a new <script> to load Prism's script
       * ```
       *
       * @default false
       * @type {boolean}
       * @memberof Prism
       * @public
       */
      manual: r.Prism && r.Prism.manual,
      /**
       * By default, if Prism is in a web worker, it assumes that it is in a worker it created itself, so it uses
       * `addEventListener` to communicate with its parent instance. However, if you're using Prism manually in your
       * own worker, you don't want it to do this.
       *
       * By setting this value to `true`, Prism will not add its own listeners to the worker.
       *
       * You obviously have to change this value before Prism executes. To do this, you can add an
       * empty Prism object into the global scope before loading the Prism script like this:
       *
       * ```js
       * window.Prism = window.Prism || {};
       * Prism.disableWorkerMessageHandler = true;
       * // Load Prism's script
       * ```
       *
       * @default false
       * @type {boolean}
       * @memberof Prism
       * @public
       */
      disableWorkerMessageHandler: r.Prism && r.Prism.disableWorkerMessageHandler,
      /**
       * A namespace for utility methods.
       *
       * All function in this namespace that are not explicitly marked as _public_ are for __internal use only__ and may
       * change or disappear at any time.
       *
       * @namespace
       * @memberof Prism
       */
      util: {
        encode: function w(g) {
          return g instanceof u ? new u(g.type, w(g.content), g.alias) : Array.isArray(g) ? g.map(w) : g.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/\u00a0/g, " ");
        },
        /**
         * Returns the name of the type of the given value.
         *
         * @param {any} o
         * @returns {string}
         * @example
         * type(null)      === 'Null'
         * type(undefined) === 'Undefined'
         * type(123)       === 'Number'
         * type('foo')     === 'String'
         * type(true)      === 'Boolean'
         * type([1, 2])    === 'Array'
         * type({})        === 'Object'
         * type(String)    === 'Function'
         * type(/abc+/)    === 'RegExp'
         */
        type: function(w) {
          return Object.prototype.toString.call(w).slice(8, -1);
        },
        /**
         * Returns a unique number for the given object. Later calls will still return the same number.
         *
         * @param {Object} obj
         * @returns {number}
         */
        objId: function(w) {
          return w.__id || Object.defineProperty(w, "__id", { value: ++i }), w.__id;
        },
        /**
         * Creates a deep clone of the given object.
         *
         * The main intended use of this function is to clone language definitions.
         *
         * @param {T} o
         * @param {Record<number, any>} [visited]
         * @returns {T}
         * @template T
         */
        clone: function w(g, S) {
          S = S || {};
          var E, $;
          switch (o.util.type(g)) {
            case "Object":
              if ($ = o.util.objId(g), S[$])
                return S[$];
              E = /** @type {Record<string, any>} */
              {}, S[$] = E;
              for (var B in g)
                g.hasOwnProperty(B) && (E[B] = w(g[B], S));
              return (
                /** @type {any} */
                E
              );
            case "Array":
              return $ = o.util.objId(g), S[$] ? S[$] : (E = [], S[$] = E, /** @type {Array} */
              /** @type {any} */
              g.forEach(function(O, M) {
                E[M] = w(O, S);
              }), /** @type {any} */
              E);
            default:
              return g;
          }
        },
        /**
         * Returns the Prism language of the given element set by a `language-xxxx` or `lang-xxxx` class.
         *
         * If no language is set for the element or the element is `null` or `undefined`, `none` will be returned.
         *
         * @param {Element} element
         * @returns {string}
         */
        getLanguage: function(w) {
          for (; w; ) {
            var g = a.exec(w.className);
            if (g)
              return g[1].toLowerCase();
            w = w.parentElement;
          }
          return "none";
        },
        /**
         * Sets the Prism `language-xxxx` class of the given element.
         *
         * @param {Element} element
         * @param {string} language
         * @returns {void}
         */
        setLanguage: function(w, g) {
          w.className = w.className.replace(RegExp(a, "gi"), ""), w.classList.add("language-" + g);
        },
        /**
         * Returns the script element that is currently executing.
         *
         * This does __not__ work for line script element.
         *
         * @returns {HTMLScriptElement | null}
         */
        currentScript: function() {
          if (typeof document > "u")
            return null;
          if ("currentScript" in document)
            return (
              /** @type {any} */
              document.currentScript
            );
          try {
            throw new Error();
          } catch (E) {
            var w = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(E.stack) || [])[1];
            if (w) {
              var g = document.getElementsByTagName("script");
              for (var S in g)
                if (g[S].src == w)
                  return g[S];
            }
            return null;
          }
        },
        /**
         * Returns whether a given class is active for `element`.
         *
         * The class can be activated if `element` or one of its ancestors has the given class and it can be deactivated
         * if `element` or one of its ancestors has the negated version of the given class. The _negated version_ of the
         * given class is just the given class with a `no-` prefix.
         *
         * Whether the class is active is determined by the closest ancestor of `element` (where `element` itself is
         * closest ancestor) that has the given class or the negated version of it. If neither `element` nor any of its
         * ancestors have the given class or the negated version of it, then the default activation will be returned.
         *
         * In the paradoxical situation where the closest ancestor contains __both__ the given class and the negated
         * version of it, the class is considered active.
         *
         * @param {Element} element
         * @param {string} className
         * @param {boolean} [defaultActivation=false]
         * @returns {boolean}
         */
        isActive: function(w, g, S) {
          for (var E = "no-" + g; w; ) {
            var $ = w.classList;
            if ($.contains(g))
              return !0;
            if ($.contains(E))
              return !1;
            w = w.parentElement;
          }
          return !!S;
        }
      },
      /**
       * This namespace contains all currently loaded languages and the some helper functions to create and modify languages.
       *
       * @namespace
       * @memberof Prism
       * @public
       */
      languages: {
        /**
         * The grammar for plain, unformatted text.
         */
        plain: l,
        plaintext: l,
        text: l,
        txt: l,
        /**
         * Creates a deep copy of the language with the given id and appends the given tokens.
         *
         * If a token in `redef` also appears in the copied language, then the existing token in the copied language
         * will be overwritten at its original position.
         *
         * ## Best practices
         *
         * Since the position of overwriting tokens (token in `redef` that overwrite tokens in the copied language)
         * doesn't matter, they can technically be in any order. However, this can be confusing to others that trying to
         * understand the language definition because, normally, the order of tokens matters in Prism grammars.
         *
         * Therefore, it is encouraged to order overwriting tokens according to the positions of the overwritten tokens.
         * Furthermore, all non-overwriting tokens should be placed after the overwriting ones.
         *
         * @param {string} id The id of the language to extend. This has to be a key in `Prism.languages`.
         * @param {Grammar} redef The new tokens to append.
         * @returns {Grammar} The new language created.
         * @public
         * @example
         * Prism.languages['css-with-colors'] = Prism.languages.extend('css', {
         *     // Prism.languages.css already has a 'comment' token, so this token will overwrite CSS' 'comment' token
         *     // at its original position
         *     'comment': { ... },
         *     // CSS doesn't have a 'color' token, so this token will be appended
         *     'color': /\b(?:red|green|blue)\b/
         * });
         */
        extend: function(w, g) {
          var S = o.util.clone(o.languages[w]);
          for (var E in g)
            S[E] = g[E];
          return S;
        },
        /**
         * Inserts tokens _before_ another token in a language definition or any other grammar.
         *
         * ## Usage
         *
         * This helper method makes it easy to modify existing languages. For example, the CSS language definition
         * not only defines CSS highlighting for CSS documents, but also needs to define highlighting for CSS embedded
         * in HTML through `<style>` elements. To do this, it needs to modify `Prism.languages.markup` and add the
         * appropriate tokens. However, `Prism.languages.markup` is a regular JavaScript object literal, so if you do
         * this:
         *
         * ```js
         * Prism.languages.markup.style = {
         *     // token
         * };
         * ```
         *
         * then the `style` token will be added (and processed) at the end. `insertBefore` allows you to insert tokens
         * before existing tokens. For the CSS example above, you would use it like this:
         *
         * ```js
         * Prism.languages.insertBefore('markup', 'cdata', {
         *     'style': {
         *         // token
         *     }
         * });
         * ```
         *
         * ## Special cases
         *
         * If the grammars of `inside` and `insert` have tokens with the same name, the tokens in `inside`'s grammar
         * will be ignored.
         *
         * This behavior can be used to insert tokens after `before`:
         *
         * ```js
         * Prism.languages.insertBefore('markup', 'comment', {
         *     'comment': Prism.languages.markup.comment,
         *     // tokens after 'comment'
         * });
         * ```
         *
         * ## Limitations
         *
         * The main problem `insertBefore` has to solve is iteration order. Since ES2015, the iteration order for object
         * properties is guaranteed to be the insertion order (except for integer keys) but some browsers behave
         * differently when keys are deleted and re-inserted. So `insertBefore` can't be implemented by temporarily
         * deleting properties which is necessary to insert at arbitrary positions.
         *
         * To solve this problem, `insertBefore` doesn't actually insert the given tokens into the target object.
         * Instead, it will create a new object and replace all references to the target object with the new one. This
         * can be done without temporarily deleting properties, so the iteration order is well-defined.
         *
         * However, only references that can be reached from `Prism.languages` or `insert` will be replaced. I.e. if
         * you hold the target object in a variable, then the value of the variable will not change.
         *
         * ```js
         * var oldMarkup = Prism.languages.markup;
         * var newMarkup = Prism.languages.insertBefore('markup', 'comment', { ... });
         *
         * assert(oldMarkup !== Prism.languages.markup);
         * assert(newMarkup === Prism.languages.markup);
         * ```
         *
         * @param {string} inside The property of `root` (e.g. a language id in `Prism.languages`) that contains the
         * object to be modified.
         * @param {string} before The key to insert before.
         * @param {Grammar} insert An object containing the key-value pairs to be inserted.
         * @param {Object<string, any>} [root] The object containing `inside`, i.e. the object that contains the
         * object to be modified.
         *
         * Defaults to `Prism.languages`.
         * @returns {Grammar} The new grammar object.
         * @public
         */
        insertBefore: function(w, g, S, E) {
          E = E || /** @type {any} */
          o.languages;
          var $ = E[w], B = {};
          for (var O in $)
            if ($.hasOwnProperty(O)) {
              if (O == g)
                for (var M in S)
                  S.hasOwnProperty(M) && (B[M] = S[M]);
              S.hasOwnProperty(O) || (B[O] = $[O]);
            }
          var R = E[w];
          return E[w] = B, o.languages.DFS(o.languages, function(W, Q) {
            Q === R && W != w && (this[W] = B);
          }), B;
        },
        // Traverse a language definition with Depth First Search
        DFS: function w(g, S, E, $) {
          $ = $ || {};
          var B = o.util.objId;
          for (var O in g)
            if (g.hasOwnProperty(O)) {
              S.call(g, O, g[O], E || O);
              var M = g[O], R = o.util.type(M);
              R === "Object" && !$[B(M)] ? ($[B(M)] = !0, w(M, S, null, $)) : R === "Array" && !$[B(M)] && ($[B(M)] = !0, w(M, S, O, $));
            }
        }
      },
      plugins: {},
      /**
       * This is the most high-level function in Prism’s API.
       * It fetches all the elements that have a `.language-xxxx` class and then calls {@link Prism.highlightElement} on
       * each one of them.
       *
       * This is equivalent to `Prism.highlightAllUnder(document, async, callback)`.
       *
       * @param {boolean} [async=false] Same as in {@link Prism.highlightAllUnder}.
       * @param {HighlightCallback} [callback] Same as in {@link Prism.highlightAllUnder}.
       * @memberof Prism
       * @public
       */
      highlightAll: function(w, g) {
        o.highlightAllUnder(document, w, g);
      },
      /**
       * Fetches all the descendants of `container` that have a `.language-xxxx` class and then calls
       * {@link Prism.highlightElement} on each one of them.
       *
       * The following hooks will be run:
       * 1. `before-highlightall`
       * 2. `before-all-elements-highlight`
       * 3. All hooks of {@link Prism.highlightElement} for each element.
       *
       * @param {ParentNode} container The root element, whose descendants that have a `.language-xxxx` class will be highlighted.
       * @param {boolean} [async=false] Whether each element is to be highlighted asynchronously using Web Workers.
       * @param {HighlightCallback} [callback] An optional callback to be invoked on each element after its highlighting is done.
       * @memberof Prism
       * @public
       */
      highlightAllUnder: function(w, g, S) {
        var E = {
          callback: S,
          container: w,
          selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'
        };
        o.hooks.run("before-highlightall", E), E.elements = Array.prototype.slice.apply(E.container.querySelectorAll(E.selector)), o.hooks.run("before-all-elements-highlight", E);
        for (var $ = 0, B; B = E.elements[$++]; )
          o.highlightElement(B, g === !0, E.callback);
      },
      /**
       * Highlights the code inside a single element.
       *
       * The following hooks will be run:
       * 1. `before-sanity-check`
       * 2. `before-highlight`
       * 3. All hooks of {@link Prism.highlight}. These hooks will be run by an asynchronous worker if `async` is `true`.
       * 4. `before-insert`
       * 5. `after-highlight`
       * 6. `complete`
       *
       * Some the above hooks will be skipped if the element doesn't contain any text or there is no grammar loaded for
       * the element's language.
       *
       * @param {Element} element The element containing the code.
       * It must have a class of `language-xxxx` to be processed, where `xxxx` is a valid language identifier.
       * @param {boolean} [async=false] Whether the element is to be highlighted asynchronously using Web Workers
       * to improve performance and avoid blocking the UI when highlighting very large chunks of code. This option is
       * [disabled by default](https://prismjs.com/faq.html#why-is-asynchronous-highlighting-disabled-by-default).
       *
       * Note: All language definitions required to highlight the code must be included in the main `prism.js` file for
       * asynchronous highlighting to work. You can build your own bundle on the
       * [Download page](https://prismjs.com/download.html).
       * @param {HighlightCallback} [callback] An optional callback to be invoked after the highlighting is done.
       * Mostly useful when `async` is `true`, since in that case, the highlighting is done asynchronously.
       * @memberof Prism
       * @public
       */
      highlightElement: function(w, g, S) {
        var E = o.util.getLanguage(w), $ = o.languages[E];
        o.util.setLanguage(w, E);
        var B = w.parentElement;
        B && B.nodeName.toLowerCase() === "pre" && o.util.setLanguage(B, E);
        var O = w.textContent, M = {
          element: w,
          language: E,
          grammar: $,
          code: O
        };
        function R(Q) {
          M.highlightedCode = Q, o.hooks.run("before-insert", M), M.element.innerHTML = M.highlightedCode, o.hooks.run("after-highlight", M), o.hooks.run("complete", M), S && S.call(M.element);
        }
        if (o.hooks.run("before-sanity-check", M), B = M.element.parentElement, B && B.nodeName.toLowerCase() === "pre" && !B.hasAttribute("tabindex") && B.setAttribute("tabindex", "0"), !M.code) {
          o.hooks.run("complete", M), S && S.call(M.element);
          return;
        }
        if (o.hooks.run("before-highlight", M), !M.grammar) {
          R(o.util.encode(M.code));
          return;
        }
        if (g && r.Worker) {
          var W = new Worker(o.filename);
          W.onmessage = function(Q) {
            R(Q.data);
          }, W.postMessage(JSON.stringify({
            language: M.language,
            code: M.code,
            immediateClose: !0
          }));
        } else
          R(o.highlight(M.code, M.grammar, M.language));
      },
      /**
       * Low-level function, only use if you know what you’re doing. It accepts a string of text as input
       * and the language definitions to use, and returns a string with the HTML produced.
       *
       * The following hooks will be run:
       * 1. `before-tokenize`
       * 2. `after-tokenize`
       * 3. `wrap`: On each {@link Token}.
       *
       * @param {string} text A string with the code to be highlighted.
       * @param {Grammar} grammar An object containing the tokens to use.
       *
       * Usually a language definition like `Prism.languages.markup`.
       * @param {string} language The name of the language definition passed to `grammar`.
       * @returns {string} The highlighted HTML.
       * @memberof Prism
       * @public
       * @example
       * Prism.highlight('var foo = true;', Prism.languages.javascript, 'javascript');
       */
      highlight: function(w, g, S) {
        var E = {
          code: w,
          grammar: g,
          language: S
        };
        if (o.hooks.run("before-tokenize", E), !E.grammar)
          throw new Error('The language "' + E.language + '" has no grammar.');
        return E.tokens = o.tokenize(E.code, E.grammar), o.hooks.run("after-tokenize", E), u.stringify(o.util.encode(E.tokens), E.language);
      },
      /**
       * This is the heart of Prism, and the most low-level function you can use. It accepts a string of text as input
       * and the language definitions to use, and returns an array with the tokenized code.
       *
       * When the language definition includes nested tokens, the function is called recursively on each of these tokens.
       *
       * This method could be useful in other contexts as well, as a very crude parser.
       *
       * @param {string} text A string with the code to be highlighted.
       * @param {Grammar} grammar An object containing the tokens to use.
       *
       * Usually a language definition like `Prism.languages.markup`.
       * @returns {TokenStream} An array of strings and tokens, a token stream.
       * @memberof Prism
       * @public
       * @example
       * let code = `var foo = 0;`;
       * let tokens = Prism.tokenize(code, Prism.languages.javascript);
       * tokens.forEach(token => {
       *     if (token instanceof Prism.Token && token.type === 'number') {
       *         console.log(`Found numeric literal: ${token.content}`);
       *     }
       * });
       */
      tokenize: function(w, g) {
        var S = g.rest;
        if (S) {
          for (var E in S)
            g[E] = S[E];
          delete g.rest;
        }
        var $ = new p();
        return b($, $.head, w), d(w, $, g, $.head, 0), D($);
      },
      /**
       * @namespace
       * @memberof Prism
       * @public
       */
      hooks: {
        all: {},
        /**
         * Adds the given callback to the list of callbacks for the given hook.
         *
         * The callback will be invoked when the hook it is registered for is run.
         * Hooks are usually directly run by a highlight function but you can also run hooks yourself.
         *
         * One callback function can be registered to multiple hooks and the same hook multiple times.
         *
         * @param {string} name The name of the hook.
         * @param {HookCallback} callback The callback function which is given environment variables.
         * @public
         */
        add: function(w, g) {
          var S = o.hooks.all;
          S[w] = S[w] || [], S[w].push(g);
        },
        /**
         * Runs a hook invoking all registered callbacks with the given environment variables.
         *
         * Callbacks will be invoked synchronously and in the order in which they were registered.
         *
         * @param {string} name The name of the hook.
         * @param {Object<string, any>} env The environment variables of the hook passed to all callbacks registered.
         * @public
         */
        run: function(w, g) {
          var S = o.hooks.all[w];
          if (!(!S || !S.length))
            for (var E = 0, $; $ = S[E++]; )
              $(g);
        }
      },
      Token: u
    };
    r.Prism = o;
    function u(w, g, S, E) {
      this.type = w, this.content = g, this.alias = S, this.length = (E || "").length | 0;
    }
    u.stringify = function w(g, S) {
      if (typeof g == "string")
        return g;
      if (Array.isArray(g)) {
        var E = "";
        return g.forEach(function(R) {
          E += w(R, S);
        }), E;
      }
      var $ = {
        type: g.type,
        content: w(g.content, S),
        tag: "span",
        classes: ["token", g.type],
        attributes: {},
        language: S
      }, B = g.alias;
      B && (Array.isArray(B) ? Array.prototype.push.apply($.classes, B) : $.classes.push(B)), o.hooks.run("wrap", $);
      var O = "";
      for (var M in $.attributes)
        O += " " + M + '="' + ($.attributes[M] || "").replace(/"/g, "&quot;") + '"';
      return "<" + $.tag + ' class="' + $.classes.join(" ") + '"' + O + ">" + $.content + "</" + $.tag + ">";
    };
    function h(w, g, S, E) {
      w.lastIndex = g;
      var $ = w.exec(S);
      if ($ && E && $[1]) {
        var B = $[1].length;
        $.index += B, $[0] = $[0].slice(B);
      }
      return $;
    }
    function d(w, g, S, E, $, B) {
      for (var O in S)
        if (!(!S.hasOwnProperty(O) || !S[O])) {
          var M = S[O];
          M = Array.isArray(M) ? M : [M];
          for (var R = 0; R < M.length; ++R) {
            if (B && B.cause == O + "," + R)
              return;
            var W = M[R], Q = W.inside, G = !!W.lookbehind, U = !!W.greedy, ae = W.alias;
            if (U && !W.pattern.global) {
              var ce = W.pattern.toString().match(/[imsuy]*$/)[0];
              W.pattern = RegExp(W.pattern.source, ce + "g");
            }
            for (var $e = W.pattern || W, ue = E.next, ge = $; ue !== g.tail && !(B && ge >= B.reach); ge += ue.value.length, ue = ue.next) {
              var _e = ue.value;
              if (g.length > w.length)
                return;
              if (!(_e instanceof u)) {
                var re = 1, he;
                if (U) {
                  if (he = h($e, ge, w, G), !he || he.index >= w.length)
                    break;
                  var Xe = he.index, me = he.index + he[0].length, Me = ge;
                  for (Me += ue.value.length; Xe >= Me; )
                    ue = ue.next, Me += ue.value.length;
                  if (Me -= ue.value.length, ge = Me, ue.value instanceof u)
                    continue;
                  for (var I = ue; I !== g.tail && (Me < me || typeof I.value == "string"); I = I.next)
                    re++, Me += I.value.length;
                  re--, _e = w.slice(ge, Me), he.index -= ge;
                } else if (he = h($e, 0, _e, G), !he)
                  continue;
                var Xe = he.index, Ie = he[0], Ze = _e.slice(0, Xe), mt = _e.slice(Xe + Ie.length), dt = ge + _e.length;
                B && dt > B.reach && (B.reach = dt);
                var Ut = ue.prev;
                Ze && (Ut = b(g, Ut, Ze), ge += Ze.length), y(g, Ut, re);
                var At = new u(O, Q ? o.tokenize(Ie, Q) : Ie, ae, Ie);
                if (ue = b(g, Ut, At), mt && b(g, ue, mt), re > 1) {
                  var Vt = {
                    cause: O + "," + R,
                    reach: dt
                  };
                  d(w, g, S, ue.prev, ge, Vt), B && Vt.reach > B.reach && (B.reach = Vt.reach);
                }
              }
            }
          }
        }
    }
    function p() {
      var w = { value: null, prev: null, next: null }, g = { value: null, prev: w, next: null };
      w.next = g, this.head = w, this.tail = g, this.length = 0;
    }
    function b(w, g, S) {
      var E = g.next, $ = { value: S, prev: g, next: E };
      return g.next = $, E.prev = $, w.length++, $;
    }
    function y(w, g, S) {
      for (var E = g.next, $ = 0; $ < S && E !== w.tail; $++)
        E = E.next;
      g.next = E, E.prev = g, w.length -= $;
    }
    function D(w) {
      for (var g = [], S = w.head.next; S !== w.tail; )
        g.push(S.value), S = S.next;
      return g;
    }
    if (!r.document)
      return r.addEventListener && (o.disableWorkerMessageHandler || r.addEventListener("message", function(w) {
        var g = JSON.parse(w.data), S = g.language, E = g.code, $ = g.immediateClose;
        r.postMessage(o.highlight(E, o.languages[S], S)), $ && r.close();
      }, !1)), o;
    var A = o.util.currentScript();
    A && (o.filename = A.src, A.hasAttribute("data-manual") && (o.manual = !0));
    function C() {
      o.manual || o.highlightAll();
    }
    if (!o.manual) {
      var T = document.readyState;
      T === "loading" || T === "interactive" && A && A.defer ? document.addEventListener("DOMContentLoaded", C) : window.requestAnimationFrame ? window.requestAnimationFrame(C) : window.setTimeout(C, 16);
    }
    return o;
  }(e);
  n.exports && (n.exports = t), typeof Bi < "u" && (Bi.Prism = t), t.languages.markup = {
    comment: {
      pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
      greedy: !0
    },
    prolog: {
      pattern: /<\?[\s\S]+?\?>/,
      greedy: !0
    },
    doctype: {
      // https://www.w3.org/TR/xml/#NT-doctypedecl
      pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
      greedy: !0,
      inside: {
        "internal-subset": {
          pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/,
          lookbehind: !0,
          greedy: !0,
          inside: null
          // see below
        },
        string: {
          pattern: /"[^"]*"|'[^']*'/,
          greedy: !0
        },
        punctuation: /^<!|>$|[[\]]/,
        "doctype-tag": /^DOCTYPE/i,
        name: /[^\s<>'"]+/
      }
    },
    cdata: {
      pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
      greedy: !0
    },
    tag: {
      pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
      greedy: !0,
      inside: {
        tag: {
          pattern: /^<\/?[^\s>\/]+/,
          inside: {
            punctuation: /^<\/?/,
            namespace: /^[^\s>\/:]+:/
          }
        },
        "special-attr": [],
        "attr-value": {
          pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
          inside: {
            punctuation: [
              {
                pattern: /^=/,
                alias: "attr-equals"
              },
              {
                pattern: /^(\s*)["']|["']$/,
                lookbehind: !0
              }
            ]
          }
        },
        punctuation: /\/?>/,
        "attr-name": {
          pattern: /[^\s>\/]+/,
          inside: {
            namespace: /^[^\s>\/:]+:/
          }
        }
      }
    },
    entity: [
      {
        pattern: /&[\da-z]{1,8};/i,
        alias: "named-entity"
      },
      /&#x?[\da-f]{1,8};/i
    ]
  }, t.languages.markup.tag.inside["attr-value"].inside.entity = t.languages.markup.entity, t.languages.markup.doctype.inside["internal-subset"].inside = t.languages.markup, t.hooks.add("wrap", function(r) {
    r.type === "entity" && (r.attributes.title = r.content.replace(/&amp;/, "&"));
  }), Object.defineProperty(t.languages.markup.tag, "addInlined", {
    /**
     * Adds an inlined language to markup.
     *
     * An example of an inlined language is CSS with `<style>` tags.
     *
     * @param {string} tagName The name of the tag that contains the inlined language. This name will be treated as
     * case insensitive.
     * @param {string} lang The language key.
     * @example
     * addInlined('style', 'css');
     */
    value: function(a, i) {
      var l = {};
      l["language-" + i] = {
        pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
        lookbehind: !0,
        inside: t.languages[i]
      }, l.cdata = /^<!\[CDATA\[|\]\]>$/i;
      var o = {
        "included-cdata": {
          pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
          inside: l
        }
      };
      o["language-" + i] = {
        pattern: /[\s\S]+/,
        inside: t.languages[i]
      };
      var u = {};
      u[a] = {
        pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function() {
          return a;
        }), "i"),
        lookbehind: !0,
        greedy: !0,
        inside: o
      }, t.languages.insertBefore("markup", "cdata", u);
    }
  }), Object.defineProperty(t.languages.markup.tag, "addAttribute", {
    /**
     * Adds an pattern to highlight languages embedded in HTML attributes.
     *
     * An example of an inlined language is CSS with `style` attributes.
     *
     * @param {string} attrName The name of the tag that contains the inlined language. This name will be treated as
     * case insensitive.
     * @param {string} lang The language key.
     * @example
     * addAttribute('style', 'css');
     */
    value: function(r, a) {
      t.languages.markup.tag.inside["special-attr"].push({
        pattern: RegExp(
          /(^|["'\s])/.source + "(?:" + r + ")" + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
          "i"
        ),
        lookbehind: !0,
        inside: {
          "attr-name": /^[^\s=]+/,
          "attr-value": {
            pattern: /=[\s\S]+/,
            inside: {
              value: {
                pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
                lookbehind: !0,
                alias: [a, "language-" + a],
                inside: t.languages[a]
              },
              punctuation: [
                {
                  pattern: /^=/,
                  alias: "attr-equals"
                },
                /"|'/
              ]
            }
          }
        }
      });
    }
  }), t.languages.html = t.languages.markup, t.languages.mathml = t.languages.markup, t.languages.svg = t.languages.markup, t.languages.xml = t.languages.extend("markup", {}), t.languages.ssml = t.languages.xml, t.languages.atom = t.languages.xml, t.languages.rss = t.languages.xml, function(r) {
    var a = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
    r.languages.css = {
      comment: /\/\*[\s\S]*?\*\//,
      atrule: {
        pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + a.source + ")*?" + /(?:;|(?=\s*\{))/.source),
        inside: {
          rule: /^@[\w-]+/,
          "selector-function-argument": {
            pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
            lookbehind: !0,
            alias: "selector"
          },
          keyword: {
            pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
            lookbehind: !0
          }
          // See rest below
        }
      },
      url: {
        // https://drafts.csswg.org/css-values-3/#urls
        pattern: RegExp("\\burl\\((?:" + a.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"),
        greedy: !0,
        inside: {
          function: /^url/i,
          punctuation: /^\(|\)$/,
          string: {
            pattern: RegExp("^" + a.source + "$"),
            alias: "url"
          }
        }
      },
      selector: {
        pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + a.source + ")*(?=\\s*\\{)"),
        lookbehind: !0
      },
      string: {
        pattern: a,
        greedy: !0
      },
      property: {
        pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
        lookbehind: !0
      },
      important: /!important\b/i,
      function: {
        pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
        lookbehind: !0
      },
      punctuation: /[(){};:,]/
    }, r.languages.css.atrule.inside.rest = r.languages.css;
    var i = r.languages.markup;
    i && (i.tag.addInlined("style", "css"), i.tag.addAttribute("style", "css"));
  }(t), t.languages.clike = {
    comment: [
      {
        pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
        lookbehind: !0,
        greedy: !0
      },
      {
        pattern: /(^|[^\\:])\/\/.*/,
        lookbehind: !0,
        greedy: !0
      }
    ],
    string: {
      pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
      greedy: !0
    },
    "class-name": {
      pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
      lookbehind: !0,
      inside: {
        punctuation: /[.\\]/
      }
    },
    keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
    boolean: /\b(?:false|true)\b/,
    function: /\b\w+(?=\()/,
    number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
    operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
    punctuation: /[{}[\];(),.:]/
  }, t.languages.javascript = t.languages.extend("clike", {
    "class-name": [
      t.languages.clike["class-name"],
      {
        pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
        lookbehind: !0
      }
    ],
    keyword: [
      {
        pattern: /((?:^|\})\s*)catch\b/,
        lookbehind: !0
      },
      {
        pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
        lookbehind: !0
      }
    ],
    // Allow for all non-ASCII characters (See http://stackoverflow.com/a/2008444)
    function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
    number: {
      pattern: RegExp(
        /(^|[^\w$])/.source + "(?:" + // constant
        (/NaN|Infinity/.source + "|" + // binary integer
        /0[bB][01]+(?:_[01]+)*n?/.source + "|" + // octal integer
        /0[oO][0-7]+(?:_[0-7]+)*n?/.source + "|" + // hexadecimal integer
        /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source + "|" + // decimal bigint
        /\d+(?:_\d+)*n/.source + "|" + // decimal number (integer or float) but no bigint
        /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source) + ")" + /(?![\w$])/.source
      ),
      lookbehind: !0
    },
    operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/
  }), t.languages.javascript["class-name"][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/, t.languages.insertBefore("javascript", "keyword", {
    regex: {
      pattern: RegExp(
        // lookbehind
        // eslint-disable-next-line regexp/no-dupe-characters-character-class
        /((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source + // Regex pattern:
        // There are 2 regex patterns here. The RegExp set notation proposal added support for nested character
        // classes if the `v` flag is present. Unfortunately, nested CCs are both context-free and incompatible
        // with the only syntax, so we have to define 2 different regex patterns.
        /\//.source + "(?:" + /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source + "|" + // `v` flag syntax. This supports 3 levels of nested character classes.
        /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source + ")" + // lookahead
        /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source
      ),
      lookbehind: !0,
      greedy: !0,
      inside: {
        "regex-source": {
          pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
          lookbehind: !0,
          alias: "language-regex",
          inside: t.languages.regex
        },
        "regex-delimiter": /^\/|\/$/,
        "regex-flags": /^[a-z]+$/
      }
    },
    // This must be declared before keyword because we use "function" inside the look-forward
    "function-variable": {
      pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
      alias: "function"
    },
    parameter: [
      {
        pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
        lookbehind: !0,
        inside: t.languages.javascript
      }
    ],
    constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/
  }), t.languages.insertBefore("javascript", "string", {
    hashbang: {
      pattern: /^#!.*/,
      greedy: !0,
      alias: "comment"
    },
    "template-string": {
      pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
      greedy: !0,
      inside: {
        "template-punctuation": {
          pattern: /^`|`$/,
          alias: "string"
        },
        interpolation: {
          pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
          lookbehind: !0,
          inside: {
            "interpolation-punctuation": {
              pattern: /^\$\{|\}$/,
              alias: "punctuation"
            },
            rest: t.languages.javascript
          }
        },
        string: /[\s\S]+/
      }
    },
    "string-property": {
      pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
      lookbehind: !0,
      greedy: !0,
      alias: "property"
    }
  }), t.languages.insertBefore("javascript", "operator", {
    "literal-property": {
      pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
      lookbehind: !0,
      alias: "property"
    }
  }), t.languages.markup && (t.languages.markup.tag.addInlined("script", "javascript"), t.languages.markup.tag.addAttribute(
    /on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,
    "javascript"
  )), t.languages.js = t.languages.javascript, function() {
    if (typeof t > "u" || typeof document > "u")
      return;
    Element.prototype.matches || (Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector);
    var r = "Loading…", a = function(A, C) {
      return "✖ Error " + A + " while fetching file: " + C;
    }, i = "✖ Error: File does not exist or is empty", l = {
      js: "javascript",
      py: "python",
      rb: "ruby",
      ps1: "powershell",
      psm1: "powershell",
      sh: "bash",
      bat: "batch",
      h: "c",
      tex: "latex"
    }, o = "data-src-status", u = "loading", h = "loaded", d = "failed", p = "pre[data-src]:not([" + o + '="' + h + '"]):not([' + o + '="' + u + '"])';
    function b(A, C, T) {
      var w = new XMLHttpRequest();
      w.open("GET", A, !0), w.onreadystatechange = function() {
        w.readyState == 4 && (w.status < 400 && w.responseText ? C(w.responseText) : w.status >= 400 ? T(a(w.status, w.statusText)) : T(i));
      }, w.send(null);
    }
    function y(A) {
      var C = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(A || "");
      if (C) {
        var T = Number(C[1]), w = C[2], g = C[3];
        return w ? g ? [T, Number(g)] : [T, void 0] : [T, T];
      }
    }
    t.hooks.add("before-highlightall", function(A) {
      A.selector += ", " + p;
    }), t.hooks.add("before-sanity-check", function(A) {
      var C = (
        /** @type {HTMLPreElement} */
        A.element
      );
      if (C.matches(p)) {
        A.code = "", C.setAttribute(o, u);
        var T = C.appendChild(document.createElement("CODE"));
        T.textContent = r;
        var w = C.getAttribute("data-src"), g = A.language;
        if (g === "none") {
          var S = (/\.(\w+)$/.exec(w) || [, "none"])[1];
          g = l[S] || S;
        }
        t.util.setLanguage(T, g), t.util.setLanguage(C, g);
        var E = t.plugins.autoloader;
        E && E.loadLanguages(g), b(
          w,
          function($) {
            C.setAttribute(o, h);
            var B = y(C.getAttribute("data-range"));
            if (B) {
              var O = $.split(/\r\n?|\n/g), M = B[0], R = B[1] == null ? O.length : B[1];
              M < 0 && (M += O.length), M = Math.max(0, Math.min(M - 1, O.length)), R < 0 && (R += O.length), R = Math.max(0, Math.min(R, O.length)), $ = O.slice(M, R).join(`
`), C.hasAttribute("data-start") || C.setAttribute("data-start", String(M + 1));
            }
            T.textContent = $, t.highlightElement(T);
          },
          function($) {
            C.setAttribute(o, d), T.textContent = $;
          }
        );
      }
    }), t.plugins.fileHighlight = {
      /**
       * Executes the File Highlight plugin for all matching `pre` elements under the given container.
       *
       * Note: Elements which are already loaded or currently loading will not be touched by this method.
       *
       * @param {ParentNode} [container=document]
       */
      highlight: function(C) {
        for (var T = (C || document).querySelectorAll(p), w = 0, g; g = T[w++]; )
          t.highlightElement(g);
      }
    };
    var D = !1;
    t.fileHighlight = function() {
      D || (console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."), D = !0), t.plugins.fileHighlight.highlight.apply(this, arguments);
    };
  }();
})(r4);
Prism.languages.python = {
  comment: {
    pattern: /(^|[^\\])#.*/,
    lookbehind: !0,
    greedy: !0
  },
  "string-interpolation": {
    pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,
    greedy: !0,
    inside: {
      interpolation: {
        // "{" <expression> <optional "!s", "!r", or "!a"> <optional ":" format specifier> "}"
        pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,
        lookbehind: !0,
        inside: {
          "format-spec": {
            pattern: /(:)[^:(){}]+(?=\}$)/,
            lookbehind: !0
          },
          "conversion-option": {
            pattern: /![sra](?=[:}]$)/,
            alias: "punctuation"
          },
          rest: null
        }
      },
      string: /[\s\S]+/
    }
  },
  "triple-quoted-string": {
    pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,
    greedy: !0,
    alias: "string"
  },
  string: {
    pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,
    greedy: !0
  },
  function: {
    pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,
    lookbehind: !0
  },
  "class-name": {
    pattern: /(\bclass\s+)\w+/i,
    lookbehind: !0
  },
  decorator: {
    pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m,
    lookbehind: !0,
    alias: ["annotation", "punctuation"],
    inside: {
      punctuation: /\./
    }
  },
  keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,
  builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,
  boolean: /\b(?:False|None|True)\b/,
  number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,
  operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,
  punctuation: /[{}[\];(),.:]/
};
Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest = Prism.languages.python;
Prism.languages.py = Prism.languages.python;
(function(n) {
  var e = /\\(?:[^a-z()[\]]|[a-z*]+)/i, t = {
    "equation-command": {
      pattern: e,
      alias: "regex"
    }
  };
  n.languages.latex = {
    comment: /%.*/,
    // the verbatim environment prints whitespace to the document
    cdata: {
      pattern: /(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
      lookbehind: !0
    },
    /*
     * equations can be between $$ $$ or $ $ or \( \) or \[ \]
     * (all are multiline)
     */
    equation: [
      {
        pattern: /\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,
        inside: t,
        alias: "string"
      },
      {
        pattern: /(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
        lookbehind: !0,
        inside: t,
        alias: "string"
      }
    ],
    /*
     * arguments which are keywords or references are highlighted
     * as keywords
     */
    keyword: {
      pattern: /(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    url: {
      pattern: /(\\url\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    /*
     * section or chapter headlines are highlighted as bold so that
     * they stand out more
     */
    headline: {
      pattern: /(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0,
      alias: "class-name"
    },
    function: {
      pattern: e,
      alias: "selector"
    },
    punctuation: /[[\]{}&]/
  }, n.languages.tex = n.languages.latex, n.languages.context = n.languages.latex;
})(Prism);
(function(n) {
  var e = "\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b", t = {
    pattern: /(^(["']?)\w+\2)[ \t]+\S.*/,
    lookbehind: !0,
    alias: "punctuation",
    // this looks reasonably well in all themes
    inside: null
    // see below
  }, r = {
    bash: t,
    environment: {
      pattern: RegExp("\\$" + e),
      alias: "constant"
    },
    variable: [
      // [0]: Arithmetic Environment
      {
        pattern: /\$?\(\([\s\S]+?\)\)/,
        greedy: !0,
        inside: {
          // If there is a $ sign at the beginning highlight $(( and )) as variable
          variable: [
            {
              pattern: /(^\$\(\([\s\S]+)\)\)/,
              lookbehind: !0
            },
            /^\$\(\(/
          ],
          number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,
          // Operators according to https://www.gnu.org/software/bash/manual/bashref.html#Shell-Arithmetic
          operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,
          // If there is no $ sign at the beginning highlight (( and )) as punctuation
          punctuation: /\(\(?|\)\)?|,|;/
        }
      },
      // [1]: Command Substitution
      {
        pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,
        greedy: !0,
        inside: {
          variable: /^\$\(|^`|\)$|`$/
        }
      },
      // [2]: Brace expansion
      {
        pattern: /\$\{[^}]+\}/,
        greedy: !0,
        inside: {
          operator: /:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,
          punctuation: /[\[\]]/,
          environment: {
            pattern: RegExp("(\\{)" + e),
            lookbehind: !0,
            alias: "constant"
          }
        }
      },
      /\$(?:\w+|[#?*!@$])/
    ],
    // Escape sequences from echo and printf's manuals, and escaped quotes.
    entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/
  };
  n.languages.bash = {
    shebang: {
      pattern: /^#!\s*\/.*/,
      alias: "important"
    },
    comment: {
      pattern: /(^|[^"{\\$])#.*/,
      lookbehind: !0
    },
    "function-name": [
      // a) function foo {
      // b) foo() {
      // c) function foo() {
      // but not “foo {”
      {
        // a) and c)
        pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,
        lookbehind: !0,
        alias: "function"
      },
      {
        // b)
        pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/,
        alias: "function"
      }
    ],
    // Highlight variable names as variables in for and select beginnings.
    "for-or-select": {
      pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/,
      alias: "variable",
      lookbehind: !0
    },
    // Highlight variable names as variables in the left-hand part
    // of assignments (“=” and “+=”).
    "assign-left": {
      pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,
      inside: {
        environment: {
          pattern: RegExp("(^|[\\s;|&]|[<>]\\()" + e),
          lookbehind: !0,
          alias: "constant"
        }
      },
      alias: "variable",
      lookbehind: !0
    },
    // Highlight parameter names as variables
    parameter: {
      pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,
      alias: "variable",
      lookbehind: !0
    },
    string: [
      // Support for Here-documents https://en.wikipedia.org/wiki/Here_document
      {
        pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,
        lookbehind: !0,
        greedy: !0,
        inside: r
      },
      // Here-document with quotes around the tag
      // → No expansion (so no “inside”).
      {
        pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,
        lookbehind: !0,
        greedy: !0,
        inside: {
          bash: t
        }
      },
      // “Normal” string
      {
        // https://www.gnu.org/software/bash/manual/html_node/Double-Quotes.html
        pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,
        lookbehind: !0,
        greedy: !0,
        inside: r
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/Single-Quotes.html
        pattern: /(^|[^$\\])'[^']*'/,
        lookbehind: !0,
        greedy: !0
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/ANSI_002dC-Quoting.html
        pattern: /\$'(?:[^'\\]|\\[\s\S])*'/,
        greedy: !0,
        inside: {
          entity: r.entity
        }
      }
    ],
    environment: {
      pattern: RegExp("\\$?" + e),
      alias: "constant"
    },
    variable: r.variable,
    function: {
      pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    keyword: {
      pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    // https://www.gnu.org/software/bash/manual/html_node/Shell-Builtin-Commands.html
    builtin: {
      pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,
      lookbehind: !0,
      // Alias added to make those easier to distinguish from strings.
      alias: "class-name"
    },
    boolean: {
      pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    "file-descriptor": {
      pattern: /\B&\d\b/,
      alias: "important"
    },
    operator: {
      // Lots of redirections here, but not just that.
      pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,
      inside: {
        "file-descriptor": {
          pattern: /^\d/,
          alias: "important"
        }
      }
    },
    punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,
    number: {
      pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,
      lookbehind: !0
    }
  }, t.inside = n.languages.bash;
  for (var a = [
    "comment",
    "function-name",
    "for-or-select",
    "assign-left",
    "parameter",
    "string",
    "environment",
    "function",
    "keyword",
    "builtin",
    "boolean",
    "file-descriptor",
    "operator",
    "punctuation",
    "number"
  ], i = r.variable[1].inside, l = 0; l < a.length; l++)
    i[a[l]] = n.languages.bash[a[l]];
  n.languages.sh = n.languages.bash, n.languages.shell = n.languages.bash;
})(Prism);
new ws();
const n4 = (n) => {
  const e = {};
  for (let t = 0, r = n.length; t < r; t++) {
    const a = n[t];
    for (const i in a)
      e[i] ? e[i] = e[i].concat(a[i]) : e[i] = a[i];
  }
  return e;
}, a4 = [
  "abbr",
  "accept",
  "accept-charset",
  "accesskey",
  "action",
  "align",
  "alink",
  "allow",
  "allowfullscreen",
  "alt",
  "anchor",
  "archive",
  "as",
  "async",
  "autocapitalize",
  "autocomplete",
  "autocorrect",
  "autofocus",
  "autopictureinpicture",
  "autoplay",
  "axis",
  "background",
  "behavior",
  "bgcolor",
  "border",
  "bordercolor",
  "capture",
  "cellpadding",
  "cellspacing",
  "challenge",
  "char",
  "charoff",
  "charset",
  "checked",
  "cite",
  "class",
  "classid",
  "clear",
  "code",
  "codebase",
  "codetype",
  "color",
  "cols",
  "colspan",
  "compact",
  "content",
  "contenteditable",
  "controls",
  "controlslist",
  "conversiondestination",
  "coords",
  "crossorigin",
  "csp",
  "data",
  "datetime",
  "declare",
  "decoding",
  "default",
  "defer",
  "dir",
  "direction",
  "dirname",
  "disabled",
  "disablepictureinpicture",
  "disableremoteplayback",
  "disallowdocumentaccess",
  "download",
  "draggable",
  "elementtiming",
  "enctype",
  "end",
  "enterkeyhint",
  "event",
  "exportparts",
  "face",
  "for",
  "form",
  "formaction",
  "formenctype",
  "formmethod",
  "formnovalidate",
  "formtarget",
  "frame",
  "frameborder",
  "headers",
  "height",
  "hidden",
  "high",
  "href",
  "hreflang",
  "hreftranslate",
  "hspace",
  "http-equiv",
  "id",
  "imagesizes",
  "imagesrcset",
  "importance",
  "impressiondata",
  "impressionexpiry",
  "incremental",
  "inert",
  "inputmode",
  "integrity",
  "invisible",
  "ismap",
  "keytype",
  "kind",
  "label",
  "lang",
  "language",
  "latencyhint",
  "leftmargin",
  "link",
  "list",
  "loading",
  "longdesc",
  "loop",
  "low",
  "lowsrc",
  "manifest",
  "marginheight",
  "marginwidth",
  "max",
  "maxlength",
  "mayscript",
  "media",
  "method",
  "min",
  "minlength",
  "multiple",
  "muted",
  "name",
  "nohref",
  "nomodule",
  "nonce",
  "noresize",
  "noshade",
  "novalidate",
  "nowrap",
  "object",
  "open",
  "optimum",
  "part",
  "pattern",
  "ping",
  "placeholder",
  "playsinline",
  "policy",
  "poster",
  "preload",
  "pseudo",
  "readonly",
  "referrerpolicy",
  "rel",
  "reportingorigin",
  "required",
  "resources",
  "rev",
  "reversed",
  "role",
  "rows",
  "rowspan",
  "rules",
  "sandbox",
  "scheme",
  "scope",
  "scopes",
  "scrollamount",
  "scrolldelay",
  "scrolling",
  "select",
  "selected",
  "shadowroot",
  "shadowrootdelegatesfocus",
  "shape",
  "size",
  "sizes",
  "slot",
  "span",
  "spellcheck",
  "src",
  "srclang",
  "srcset",
  "standby",
  "start",
  "step",
  "style",
  "summary",
  "tabindex",
  "target",
  "text",
  "title",
  "topmargin",
  "translate",
  "truespeed",
  "trusttoken",
  "type",
  "usemap",
  "valign",
  "value",
  "valuetype",
  "version",
  "virtualkeyboardpolicy",
  "vlink",
  "vspace",
  "webkitdirectory",
  "width",
  "wrap"
], i4 = [
  "accent-height",
  "accumulate",
  "additive",
  "alignment-baseline",
  "ascent",
  "attributename",
  "attributetype",
  "azimuth",
  "basefrequency",
  "baseline-shift",
  "begin",
  "bias",
  "by",
  "class",
  "clip",
  "clippathunits",
  "clip-path",
  "clip-rule",
  "color",
  "color-interpolation",
  "color-interpolation-filters",
  "color-profile",
  "color-rendering",
  "cx",
  "cy",
  "d",
  "dx",
  "dy",
  "diffuseconstant",
  "direction",
  "display",
  "divisor",
  "dominant-baseline",
  "dur",
  "edgemode",
  "elevation",
  "end",
  "fill",
  "fill-opacity",
  "fill-rule",
  "filter",
  "filterunits",
  "flood-color",
  "flood-opacity",
  "font-family",
  "font-size",
  "font-size-adjust",
  "font-stretch",
  "font-style",
  "font-variant",
  "font-weight",
  "fx",
  "fy",
  "g1",
  "g2",
  "glyph-name",
  "glyphref",
  "gradientunits",
  "gradienttransform",
  "height",
  "href",
  "id",
  "image-rendering",
  "in",
  "in2",
  "k",
  "k1",
  "k2",
  "k3",
  "k4",
  "kerning",
  "keypoints",
  "keysplines",
  "keytimes",
  "lang",
  "lengthadjust",
  "letter-spacing",
  "kernelmatrix",
  "kernelunitlength",
  "lighting-color",
  "local",
  "marker-end",
  "marker-mid",
  "marker-start",
  "markerheight",
  "markerunits",
  "markerwidth",
  "maskcontentunits",
  "maskunits",
  "max",
  "mask",
  "media",
  "method",
  "mode",
  "min",
  "name",
  "numoctaves",
  "offset",
  "operator",
  "opacity",
  "order",
  "orient",
  "orientation",
  "origin",
  "overflow",
  "paint-order",
  "path",
  "pathlength",
  "patterncontentunits",
  "patterntransform",
  "patternunits",
  "points",
  "preservealpha",
  "preserveaspectratio",
  "primitiveunits",
  "r",
  "rx",
  "ry",
  "radius",
  "refx",
  "refy",
  "repeatcount",
  "repeatdur",
  "restart",
  "result",
  "rotate",
  "scale",
  "seed",
  "shape-rendering",
  "specularconstant",
  "specularexponent",
  "spreadmethod",
  "startoffset",
  "stddeviation",
  "stitchtiles",
  "stop-color",
  "stop-opacity",
  "stroke-dasharray",
  "stroke-dashoffset",
  "stroke-linecap",
  "stroke-linejoin",
  "stroke-miterlimit",
  "stroke-opacity",
  "stroke",
  "stroke-width",
  "style",
  "surfacescale",
  "systemlanguage",
  "tabindex",
  "targetx",
  "targety",
  "transform",
  "transform-origin",
  "text-anchor",
  "text-decoration",
  "text-rendering",
  "textlength",
  "type",
  "u1",
  "u2",
  "unicode",
  "values",
  "viewbox",
  "visibility",
  "version",
  "vert-adv-y",
  "vert-origin-x",
  "vert-origin-y",
  "width",
  "word-spacing",
  "wrap",
  "writing-mode",
  "xchannelselector",
  "ychannelselector",
  "x",
  "x1",
  "x2",
  "xmlns",
  "y",
  "y1",
  "y2",
  "z",
  "zoomandpan"
], l4 = [
  "accent",
  "accentunder",
  "align",
  "bevelled",
  "close",
  "columnsalign",
  "columnlines",
  "columnspan",
  "denomalign",
  "depth",
  "dir",
  "display",
  "displaystyle",
  "encoding",
  "fence",
  "frame",
  "height",
  "href",
  "id",
  "largeop",
  "length",
  "linethickness",
  "lspace",
  "lquote",
  "mathbackground",
  "mathcolor",
  "mathsize",
  "mathvariant",
  "maxsize",
  "minsize",
  "movablelimits",
  "notation",
  "numalign",
  "open",
  "rowalign",
  "rowlines",
  "rowspacing",
  "rowspan",
  "rspace",
  "rquote",
  "scriptlevel",
  "scriptminsize",
  "scriptsizemultiplier",
  "selection",
  "separator",
  "separators",
  "stretchy",
  "subscriptshift",
  "supscriptshift",
  "symmetric",
  "voffset",
  "width",
  "xmlns"
];
n4([
  Object.fromEntries(a4.map((n) => [n, ["*"]])),
  Object.fromEntries(i4.map((n) => [n, ["svg:*"]])),
  Object.fromEntries(l4.map((n) => [n, ["math:*"]]))
]);
const {
  HtmlTagHydration: Ic,
  SvelteComponent: Lc,
  attr: Oc,
  binding_callbacks: Pc,
  children: Hc,
  claim_element: Uc,
  claim_html_tag: Vc,
  detach: Gc,
  element: Yc,
  init: Wc,
  insert_hydration: jc,
  noop: Xc,
  safe_not_equal: Zc,
  toggle_class: Kc
} = window.__gradio__svelte__internal, { afterUpdate: Qc } = window.__gradio__svelte__internal, {
  SvelteComponent: Jc,
  attr: e2,
  children: t2,
  claim_component: r2,
  claim_element: n2,
  create_component: a2,
  destroy_component: i2,
  detach: l2,
  element: s2,
  init: o2,
  insert_hydration: u2,
  mount_component: c2,
  safe_not_equal: h2,
  transition_in: m2,
  transition_out: d2
} = window.__gradio__svelte__internal, {
  SvelteComponent: f2,
  attr: p2,
  check_outros: g2,
  children: v2,
  claim_component: _2,
  claim_element: b2,
  claim_space: y2,
  create_component: w2,
  create_slot: k2,
  destroy_component: D2,
  detach: x2,
  element: S2,
  empty: A2,
  get_all_dirty_from_scope: F2,
  get_slot_changes: C2,
  group_outros: E2,
  init: T2,
  insert_hydration: $2,
  mount_component: M2,
  safe_not_equal: z2,
  space: B2,
  toggle_class: R2,
  transition_in: q2,
  transition_out: N2,
  update_slot_base: I2
} = window.__gradio__svelte__internal, {
  SvelteComponent: L2,
  append_hydration: O2,
  attr: P2,
  children: H2,
  claim_component: U2,
  claim_element: V2,
  claim_space: G2,
  claim_text: Y2,
  create_component: W2,
  destroy_component: j2,
  detach: X2,
  element: Z2,
  init: K2,
  insert_hydration: Q2,
  mount_component: J2,
  safe_not_equal: eh,
  set_data: th,
  space: rh,
  text: nh,
  toggle_class: ah,
  transition_in: ih,
  transition_out: lh
} = window.__gradio__svelte__internal, {
  SvelteComponent: s4,
  append_hydration: Mr,
  attr: Zt,
  bubble: o4,
  check_outros: u4,
  children: qn,
  claim_component: c4,
  claim_element: Nn,
  claim_space: Ri,
  claim_text: h4,
  construct_svelte_component: qi,
  create_component: Ni,
  create_slot: m4,
  destroy_component: Ii,
  detach: Q0,
  element: In,
  get_all_dirty_from_scope: d4,
  get_slot_changes: f4,
  group_outros: p4,
  init: g4,
  insert_hydration: ks,
  listen: v4,
  mount_component: Li,
  safe_not_equal: _4,
  set_data: b4,
  set_style: wr,
  space: Oi,
  text: y4,
  toggle_class: We,
  transition_in: _n,
  transition_out: bn,
  update_slot_base: w4
} = window.__gradio__svelte__internal;
function Pi(n) {
  let e, t;
  return {
    c() {
      e = In("span"), t = y4(
        /*label*/
        n[1]
      ), this.h();
    },
    l(r) {
      e = Nn(r, "SPAN", { class: !0 });
      var a = qn(e);
      t = h4(
        a,
        /*label*/
        n[1]
      ), a.forEach(Q0), this.h();
    },
    h() {
      Zt(e, "class", "svelte-vk34kx");
    },
    m(r, a) {
      ks(r, e, a), Mr(e, t);
    },
    p(r, a) {
      a & /*label*/
      2 && b4(
        t,
        /*label*/
        r[1]
      );
    },
    d(r) {
      r && Q0(e);
    }
  };
}
function k4(n) {
  let e, t, r, a, i, l, o, u, h = (
    /*show_label*/
    n[2] && Pi(n)
  );
  var d = (
    /*Icon*/
    n[0]
  );
  function p(D, A) {
    return {};
  }
  d && (a = qi(d, p()));
  const b = (
    /*#slots*/
    n[14].default
  ), y = m4(
    b,
    n,
    /*$$scope*/
    n[13],
    null
  );
  return {
    c() {
      e = In("button"), h && h.c(), t = Oi(), r = In("div"), a && Ni(a.$$.fragment), i = Oi(), y && y.c(), this.h();
    },
    l(D) {
      e = Nn(D, "BUTTON", {
        "aria-label": !0,
        "aria-haspopup": !0,
        title: !0,
        class: !0
      });
      var A = qn(e);
      h && h.l(A), t = Ri(A), r = Nn(A, "DIV", { class: !0 });
      var C = qn(r);
      a && c4(a.$$.fragment, C), i = Ri(C), y && y.l(C), C.forEach(Q0), A.forEach(Q0), this.h();
    },
    h() {
      Zt(r, "class", "svelte-vk34kx"), We(
        r,
        "small",
        /*size*/
        n[4] === "small"
      ), We(
        r,
        "large",
        /*size*/
        n[4] === "large"
      ), We(
        r,
        "medium",
        /*size*/
        n[4] === "medium"
      ), e.disabled = /*disabled*/
      n[7], Zt(
        e,
        "aria-label",
        /*label*/
        n[1]
      ), Zt(
        e,
        "aria-haspopup",
        /*hasPopup*/
        n[8]
      ), Zt(
        e,
        "title",
        /*label*/
        n[1]
      ), Zt(e, "class", "svelte-vk34kx"), We(
        e,
        "pending",
        /*pending*/
        n[3]
      ), We(
        e,
        "padded",
        /*padded*/
        n[5]
      ), We(
        e,
        "highlight",
        /*highlight*/
        n[6]
      ), We(
        e,
        "transparent",
        /*transparent*/
        n[9]
      ), wr(e, "color", !/*disabled*/
      n[7] && /*_color*/
      n[11] ? (
        /*_color*/
        n[11]
      ) : "var(--block-label-text-color)"), wr(e, "--bg-color", /*disabled*/
      n[7] ? "auto" : (
        /*background*/
        n[10]
      ));
    },
    m(D, A) {
      ks(D, e, A), h && h.m(e, null), Mr(e, t), Mr(e, r), a && Li(a, r, null), Mr(r, i), y && y.m(r, null), l = !0, o || (u = v4(
        e,
        "click",
        /*click_handler*/
        n[15]
      ), o = !0);
    },
    p(D, [A]) {
      if (/*show_label*/
      D[2] ? h ? h.p(D, A) : (h = Pi(D), h.c(), h.m(e, t)) : h && (h.d(1), h = null), A & /*Icon*/
      1 && d !== (d = /*Icon*/
      D[0])) {
        if (a) {
          p4();
          const C = a;
          bn(C.$$.fragment, 1, 0, () => {
            Ii(C, 1);
          }), u4();
        }
        d ? (a = qi(d, p()), Ni(a.$$.fragment), _n(a.$$.fragment, 1), Li(a, r, i)) : a = null;
      }
      y && y.p && (!l || A & /*$$scope*/
      8192) && w4(
        y,
        b,
        D,
        /*$$scope*/
        D[13],
        l ? f4(
          b,
          /*$$scope*/
          D[13],
          A,
          null
        ) : d4(
          /*$$scope*/
          D[13]
        ),
        null
      ), (!l || A & /*size*/
      16) && We(
        r,
        "small",
        /*size*/
        D[4] === "small"
      ), (!l || A & /*size*/
      16) && We(
        r,
        "large",
        /*size*/
        D[4] === "large"
      ), (!l || A & /*size*/
      16) && We(
        r,
        "medium",
        /*size*/
        D[4] === "medium"
      ), (!l || A & /*disabled*/
      128) && (e.disabled = /*disabled*/
      D[7]), (!l || A & /*label*/
      2) && Zt(
        e,
        "aria-label",
        /*label*/
        D[1]
      ), (!l || A & /*hasPopup*/
      256) && Zt(
        e,
        "aria-haspopup",
        /*hasPopup*/
        D[8]
      ), (!l || A & /*label*/
      2) && Zt(
        e,
        "title",
        /*label*/
        D[1]
      ), (!l || A & /*pending*/
      8) && We(
        e,
        "pending",
        /*pending*/
        D[3]
      ), (!l || A & /*padded*/
      32) && We(
        e,
        "padded",
        /*padded*/
        D[5]
      ), (!l || A & /*highlight*/
      64) && We(
        e,
        "highlight",
        /*highlight*/
        D[6]
      ), (!l || A & /*transparent*/
      512) && We(
        e,
        "transparent",
        /*transparent*/
        D[9]
      ), A & /*disabled, _color*/
      2176 && wr(e, "color", !/*disabled*/
      D[7] && /*_color*/
      D[11] ? (
        /*_color*/
        D[11]
      ) : "var(--block-label-text-color)"), A & /*disabled, background*/
      1152 && wr(e, "--bg-color", /*disabled*/
      D[7] ? "auto" : (
        /*background*/
        D[10]
      ));
    },
    i(D) {
      l || (a && _n(a.$$.fragment, D), _n(y, D), l = !0);
    },
    o(D) {
      a && bn(a.$$.fragment, D), bn(y, D), l = !1;
    },
    d(D) {
      D && Q0(e), h && h.d(), a && Ii(a), y && y.d(D), o = !1, u();
    }
  };
}
function D4(n, e, t) {
  let r, { $$slots: a = {}, $$scope: i } = e, { Icon: l } = e, { label: o = "" } = e, { show_label: u = !1 } = e, { pending: h = !1 } = e, { size: d = "small" } = e, { padded: p = !0 } = e, { highlight: b = !1 } = e, { disabled: y = !1 } = e, { hasPopup: D = !1 } = e, { color: A = "var(--block-label-text-color)" } = e, { transparent: C = !1 } = e, { background: T = "var(--block-background-fill)" } = e;
  function w(g) {
    o4.call(this, n, g);
  }
  return n.$$set = (g) => {
    "Icon" in g && t(0, l = g.Icon), "label" in g && t(1, o = g.label), "show_label" in g && t(2, u = g.show_label), "pending" in g && t(3, h = g.pending), "size" in g && t(4, d = g.size), "padded" in g && t(5, p = g.padded), "highlight" in g && t(6, b = g.highlight), "disabled" in g && t(7, y = g.disabled), "hasPopup" in g && t(8, D = g.hasPopup), "color" in g && t(12, A = g.color), "transparent" in g && t(9, C = g.transparent), "background" in g && t(10, T = g.background), "$$scope" in g && t(13, i = g.$$scope);
  }, n.$$.update = () => {
    n.$$.dirty & /*highlight, color*/
    4160 && t(11, r = b ? "var(--color-accent)" : A);
  }, [
    l,
    o,
    u,
    h,
    d,
    p,
    b,
    y,
    D,
    C,
    T,
    r,
    A,
    i,
    a,
    w
  ];
}
class x4 extends s4 {
  constructor(e) {
    super(), g4(this, e, D4, k4, _4, {
      Icon: 0,
      label: 1,
      show_label: 2,
      pending: 3,
      size: 4,
      padded: 5,
      highlight: 6,
      disabled: 7,
      hasPopup: 8,
      color: 12,
      transparent: 9,
      background: 10
    });
  }
}
const {
  SvelteComponent: sh,
  append_hydration: oh,
  attr: uh,
  binding_callbacks: ch,
  children: hh,
  claim_element: mh,
  create_slot: dh,
  detach: fh,
  element: ph,
  get_all_dirty_from_scope: gh,
  get_slot_changes: vh,
  init: _h,
  insert_hydration: bh,
  safe_not_equal: yh,
  toggle_class: wh,
  transition_in: kh,
  transition_out: Dh,
  update_slot_base: xh
} = window.__gradio__svelte__internal, {
  SvelteComponent: Sh,
  append_hydration: Ah,
  attr: Fh,
  children: Ch,
  claim_svg_element: Eh,
  detach: Th,
  init: $h,
  insert_hydration: Mh,
  noop: zh,
  safe_not_equal: Bh,
  svg_element: Rh
} = window.__gradio__svelte__internal, {
  SvelteComponent: qh,
  append_hydration: Nh,
  attr: Ih,
  children: Lh,
  claim_svg_element: Oh,
  detach: Ph,
  init: Hh,
  insert_hydration: Uh,
  noop: Vh,
  safe_not_equal: Gh,
  svg_element: Yh
} = window.__gradio__svelte__internal, {
  SvelteComponent: Wh,
  append_hydration: jh,
  attr: Xh,
  children: Zh,
  claim_svg_element: Kh,
  detach: Qh,
  init: Jh,
  insert_hydration: em,
  noop: tm,
  safe_not_equal: rm,
  svg_element: nm
} = window.__gradio__svelte__internal, {
  SvelteComponent: am,
  append_hydration: im,
  attr: lm,
  children: sm,
  claim_svg_element: om,
  detach: um,
  init: cm,
  insert_hydration: hm,
  noop: mm,
  safe_not_equal: dm,
  svg_element: fm
} = window.__gradio__svelte__internal, {
  SvelteComponent: pm,
  append_hydration: gm,
  attr: vm,
  children: _m,
  claim_svg_element: bm,
  detach: ym,
  init: wm,
  insert_hydration: km,
  noop: Dm,
  safe_not_equal: xm,
  svg_element: Sm
} = window.__gradio__svelte__internal, {
  SvelteComponent: Am,
  append_hydration: Fm,
  attr: Cm,
  children: Em,
  claim_svg_element: Tm,
  detach: $m,
  init: Mm,
  insert_hydration: zm,
  noop: Bm,
  safe_not_equal: Rm,
  svg_element: qm
} = window.__gradio__svelte__internal, {
  SvelteComponent: Nm,
  append_hydration: Im,
  attr: Lm,
  children: Om,
  claim_svg_element: Pm,
  detach: Hm,
  init: Um,
  insert_hydration: Vm,
  noop: Gm,
  safe_not_equal: Ym,
  svg_element: Wm
} = window.__gradio__svelte__internal, {
  SvelteComponent: jm,
  append_hydration: Xm,
  attr: Zm,
  children: Km,
  claim_svg_element: Qm,
  detach: Jm,
  init: e5,
  insert_hydration: t5,
  noop: r5,
  safe_not_equal: n5,
  svg_element: a5
} = window.__gradio__svelte__internal, {
  SvelteComponent: i5,
  append_hydration: l5,
  attr: s5,
  children: o5,
  claim_svg_element: u5,
  detach: c5,
  init: h5,
  insert_hydration: m5,
  noop: d5,
  safe_not_equal: f5,
  svg_element: p5
} = window.__gradio__svelte__internal, {
  SvelteComponent: g5,
  append_hydration: v5,
  attr: _5,
  children: b5,
  claim_svg_element: y5,
  detach: w5,
  init: k5,
  insert_hydration: D5,
  noop: x5,
  safe_not_equal: S5,
  svg_element: A5
} = window.__gradio__svelte__internal, {
  SvelteComponent: S4,
  append_hydration: yn,
  attr: _t,
  children: kr,
  claim_svg_element: Dr,
  detach: P0,
  init: A4,
  insert_hydration: F4,
  noop: wn,
  safe_not_equal: C4,
  set_style: $t,
  svg_element: xr
} = window.__gradio__svelte__internal;
function E4(n) {
  let e, t, r, a;
  return {
    c() {
      e = xr("svg"), t = xr("g"), r = xr("path"), a = xr("path"), this.h();
    },
    l(i) {
      e = Dr(i, "svg", {
        width: !0,
        height: !0,
        viewBox: !0,
        version: !0,
        xmlns: !0,
        "xmlns:xlink": !0,
        "xml:space": !0,
        stroke: !0,
        style: !0
      });
      var l = kr(e);
      t = Dr(l, "g", { transform: !0 });
      var o = kr(t);
      r = Dr(o, "path", { d: !0, style: !0 }), kr(r).forEach(P0), o.forEach(P0), a = Dr(l, "path", { d: !0, style: !0 }), kr(a).forEach(P0), l.forEach(P0), this.h();
    },
    h() {
      _t(r, "d", "M18,6L6.087,17.913"), $t(r, "fill", "none"), $t(r, "fill-rule", "nonzero"), $t(r, "stroke-width", "2px"), _t(t, "transform", "matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"), _t(a, "d", "M4.364,4.364L19.636,19.636"), $t(a, "fill", "none"), $t(a, "fill-rule", "nonzero"), $t(a, "stroke-width", "2px"), _t(e, "width", "100%"), _t(e, "height", "100%"), _t(e, "viewBox", "0 0 24 24"), _t(e, "version", "1.1"), _t(e, "xmlns", "http://www.w3.org/2000/svg"), _t(e, "xmlns:xlink", "http://www.w3.org/1999/xlink"), _t(e, "xml:space", "preserve"), _t(e, "stroke", "currentColor"), $t(e, "fill-rule", "evenodd"), $t(e, "clip-rule", "evenodd"), $t(e, "stroke-linecap", "round"), $t(e, "stroke-linejoin", "round");
    },
    m(i, l) {
      F4(i, e, l), yn(e, t), yn(t, r), yn(e, a);
    },
    p: wn,
    i: wn,
    o: wn,
    d(i) {
      i && P0(e);
    }
  };
}
class T4 extends S4 {
  constructor(e) {
    super(), A4(this, e, null, E4, C4, {});
  }
}
const {
  SvelteComponent: F5,
  append_hydration: C5,
  attr: E5,
  children: T5,
  claim_svg_element: $5,
  detach: M5,
  init: z5,
  insert_hydration: B5,
  noop: R5,
  safe_not_equal: q5,
  svg_element: N5
} = window.__gradio__svelte__internal, {
  SvelteComponent: I5,
  append_hydration: L5,
  attr: O5,
  children: P5,
  claim_svg_element: H5,
  detach: U5,
  init: V5,
  insert_hydration: G5,
  noop: Y5,
  safe_not_equal: W5,
  svg_element: j5
} = window.__gradio__svelte__internal, {
  SvelteComponent: X5,
  append_hydration: Z5,
  attr: K5,
  children: Q5,
  claim_svg_element: J5,
  detach: ed,
  init: td,
  insert_hydration: rd,
  noop: nd,
  safe_not_equal: ad,
  svg_element: id
} = window.__gradio__svelte__internal, {
  SvelteComponent: ld,
  append_hydration: sd,
  attr: od,
  children: ud,
  claim_svg_element: cd,
  detach: hd,
  init: md,
  insert_hydration: dd,
  noop: fd,
  safe_not_equal: pd,
  svg_element: gd
} = window.__gradio__svelte__internal, {
  SvelteComponent: vd,
  append_hydration: _d,
  attr: bd,
  children: yd,
  claim_svg_element: wd,
  detach: kd,
  init: Dd,
  insert_hydration: xd,
  noop: Sd,
  safe_not_equal: Ad,
  svg_element: Fd
} = window.__gradio__svelte__internal, {
  SvelteComponent: Cd,
  append_hydration: Ed,
  attr: Td,
  children: $d,
  claim_svg_element: Md,
  detach: zd,
  init: Bd,
  insert_hydration: Rd,
  noop: qd,
  safe_not_equal: Nd,
  svg_element: Id
} = window.__gradio__svelte__internal, {
  SvelteComponent: Ld,
  append_hydration: Od,
  attr: Pd,
  children: Hd,
  claim_svg_element: Ud,
  detach: Vd,
  init: Gd,
  insert_hydration: Yd,
  noop: Wd,
  safe_not_equal: jd,
  svg_element: Xd
} = window.__gradio__svelte__internal, {
  SvelteComponent: Zd,
  append_hydration: Kd,
  attr: Qd,
  children: Jd,
  claim_svg_element: e3,
  detach: t3,
  init: r3,
  insert_hydration: n3,
  noop: a3,
  safe_not_equal: i3,
  svg_element: l3
} = window.__gradio__svelte__internal, {
  SvelteComponent: s3,
  append_hydration: o3,
  attr: u3,
  children: c3,
  claim_svg_element: h3,
  detach: m3,
  init: d3,
  insert_hydration: f3,
  noop: p3,
  safe_not_equal: g3,
  svg_element: v3
} = window.__gradio__svelte__internal, {
  SvelteComponent: _3,
  append_hydration: b3,
  attr: y3,
  children: w3,
  claim_svg_element: k3,
  detach: D3,
  init: x3,
  insert_hydration: S3,
  noop: A3,
  safe_not_equal: F3,
  svg_element: C3
} = window.__gradio__svelte__internal, {
  SvelteComponent: E3,
  append_hydration: T3,
  attr: $3,
  children: M3,
  claim_svg_element: z3,
  detach: B3,
  init: R3,
  insert_hydration: q3,
  noop: N3,
  safe_not_equal: I3,
  svg_element: L3
} = window.__gradio__svelte__internal, {
  SvelteComponent: O3,
  append_hydration: P3,
  attr: H3,
  children: U3,
  claim_svg_element: V3,
  detach: G3,
  init: Y3,
  insert_hydration: W3,
  noop: j3,
  safe_not_equal: X3,
  svg_element: Z3
} = window.__gradio__svelte__internal, {
  SvelteComponent: K3,
  append_hydration: Q3,
  attr: J3,
  children: e6,
  claim_svg_element: t6,
  detach: r6,
  init: n6,
  insert_hydration: a6,
  noop: i6,
  safe_not_equal: l6,
  svg_element: s6
} = window.__gradio__svelte__internal, {
  SvelteComponent: o6,
  append_hydration: u6,
  attr: c6,
  children: h6,
  claim_svg_element: m6,
  detach: d6,
  init: f6,
  insert_hydration: p6,
  noop: g6,
  safe_not_equal: v6,
  svg_element: _6
} = window.__gradio__svelte__internal, {
  SvelteComponent: b6,
  append_hydration: y6,
  attr: w6,
  children: k6,
  claim_svg_element: D6,
  detach: x6,
  init: S6,
  insert_hydration: A6,
  noop: F6,
  safe_not_equal: C6,
  svg_element: E6
} = window.__gradio__svelte__internal, {
  SvelteComponent: T6,
  append_hydration: $6,
  attr: M6,
  children: z6,
  claim_svg_element: B6,
  detach: R6,
  init: q6,
  insert_hydration: N6,
  noop: I6,
  safe_not_equal: L6,
  svg_element: O6
} = window.__gradio__svelte__internal, {
  SvelteComponent: P6,
  append_hydration: H6,
  attr: U6,
  children: V6,
  claim_svg_element: G6,
  detach: Y6,
  init: W6,
  insert_hydration: j6,
  noop: X6,
  safe_not_equal: Z6,
  svg_element: K6
} = window.__gradio__svelte__internal, {
  SvelteComponent: Q6,
  append_hydration: J6,
  attr: e7,
  children: t7,
  claim_svg_element: r7,
  detach: n7,
  init: a7,
  insert_hydration: i7,
  noop: l7,
  safe_not_equal: s7,
  svg_element: o7
} = window.__gradio__svelte__internal, {
  SvelteComponent: u7,
  append_hydration: c7,
  attr: h7,
  children: m7,
  claim_svg_element: d7,
  detach: f7,
  init: p7,
  insert_hydration: g7,
  noop: v7,
  safe_not_equal: _7,
  svg_element: b7
} = window.__gradio__svelte__internal, {
  SvelteComponent: y7,
  append_hydration: w7,
  attr: k7,
  children: D7,
  claim_svg_element: x7,
  detach: S7,
  init: A7,
  insert_hydration: F7,
  noop: C7,
  safe_not_equal: E7,
  svg_element: T7
} = window.__gradio__svelte__internal, {
  SvelteComponent: $7,
  append_hydration: M7,
  attr: z7,
  children: B7,
  claim_svg_element: R7,
  detach: q7,
  init: N7,
  insert_hydration: I7,
  noop: L7,
  safe_not_equal: O7,
  svg_element: P7
} = window.__gradio__svelte__internal, {
  SvelteComponent: H7,
  append_hydration: U7,
  attr: V7,
  children: G7,
  claim_svg_element: Y7,
  detach: W7,
  init: j7,
  insert_hydration: X7,
  noop: Z7,
  safe_not_equal: K7,
  svg_element: Q7
} = window.__gradio__svelte__internal, {
  SvelteComponent: J7,
  append_hydration: ef,
  attr: tf,
  children: rf,
  claim_svg_element: nf,
  detach: af,
  init: lf,
  insert_hydration: sf,
  noop: of,
  safe_not_equal: uf,
  svg_element: cf
} = window.__gradio__svelte__internal, {
  SvelteComponent: hf,
  append_hydration: mf,
  attr: df,
  children: ff,
  claim_svg_element: pf,
  detach: gf,
  init: vf,
  insert_hydration: _f,
  noop: bf,
  safe_not_equal: yf,
  svg_element: wf
} = window.__gradio__svelte__internal, {
  SvelteComponent: kf,
  append_hydration: Df,
  attr: xf,
  children: Sf,
  claim_svg_element: Af,
  detach: Ff,
  init: Cf,
  insert_hydration: Ef,
  noop: Tf,
  safe_not_equal: $f,
  svg_element: Mf
} = window.__gradio__svelte__internal, {
  SvelteComponent: zf,
  append_hydration: Bf,
  attr: Rf,
  children: qf,
  claim_svg_element: Nf,
  detach: If,
  init: Lf,
  insert_hydration: Of,
  noop: Pf,
  safe_not_equal: Hf,
  svg_element: Uf
} = window.__gradio__svelte__internal, {
  SvelteComponent: Vf,
  append_hydration: Gf,
  attr: Yf,
  children: Wf,
  claim_svg_element: jf,
  detach: Xf,
  init: Zf,
  insert_hydration: Kf,
  noop: Qf,
  safe_not_equal: Jf,
  svg_element: e8
} = window.__gradio__svelte__internal, {
  SvelteComponent: t8,
  append_hydration: r8,
  attr: n8,
  children: a8,
  claim_svg_element: i8,
  detach: l8,
  init: s8,
  insert_hydration: o8,
  noop: u8,
  safe_not_equal: c8,
  svg_element: h8
} = window.__gradio__svelte__internal, {
  SvelteComponent: m8,
  append_hydration: d8,
  attr: f8,
  children: p8,
  claim_svg_element: g8,
  detach: v8,
  init: _8,
  insert_hydration: b8,
  noop: y8,
  safe_not_equal: w8,
  svg_element: k8
} = window.__gradio__svelte__internal, {
  SvelteComponent: D8,
  append_hydration: x8,
  attr: S8,
  children: A8,
  claim_svg_element: F8,
  detach: C8,
  init: E8,
  insert_hydration: T8,
  noop: $8,
  safe_not_equal: M8,
  set_style: z8,
  svg_element: B8
} = window.__gradio__svelte__internal, {
  SvelteComponent: R8,
  append_hydration: q8,
  attr: N8,
  children: I8,
  claim_svg_element: L8,
  detach: O8,
  init: P8,
  insert_hydration: H8,
  noop: U8,
  safe_not_equal: V8,
  svg_element: G8
} = window.__gradio__svelte__internal, {
  SvelteComponent: Y8,
  append_hydration: W8,
  attr: j8,
  children: X8,
  claim_svg_element: Z8,
  detach: K8,
  init: Q8,
  insert_hydration: J8,
  noop: ep,
  safe_not_equal: tp,
  svg_element: rp
} = window.__gradio__svelte__internal, {
  SvelteComponent: np,
  append_hydration: ap,
  attr: ip,
  children: lp,
  claim_svg_element: sp,
  detach: op,
  init: up,
  insert_hydration: cp,
  noop: hp,
  safe_not_equal: mp,
  svg_element: dp
} = window.__gradio__svelte__internal, {
  SvelteComponent: fp,
  append_hydration: pp,
  attr: gp,
  children: vp,
  claim_svg_element: _p,
  detach: bp,
  init: yp,
  insert_hydration: wp,
  noop: kp,
  safe_not_equal: Dp,
  svg_element: xp
} = window.__gradio__svelte__internal, {
  SvelteComponent: Sp,
  append_hydration: Ap,
  attr: Fp,
  children: Cp,
  claim_svg_element: Ep,
  detach: Tp,
  init: $p,
  insert_hydration: Mp,
  noop: zp,
  safe_not_equal: Bp,
  svg_element: Rp
} = window.__gradio__svelte__internal, {
  SvelteComponent: qp,
  append_hydration: Np,
  attr: Ip,
  children: Lp,
  claim_svg_element: Op,
  detach: Pp,
  init: Hp,
  insert_hydration: Up,
  noop: Vp,
  safe_not_equal: Gp,
  svg_element: Yp
} = window.__gradio__svelte__internal, {
  SvelteComponent: Wp,
  append_hydration: jp,
  attr: Xp,
  children: Zp,
  claim_svg_element: Kp,
  detach: Qp,
  init: Jp,
  insert_hydration: e9,
  noop: t9,
  safe_not_equal: r9,
  svg_element: n9
} = window.__gradio__svelte__internal, {
  SvelteComponent: a9,
  append_hydration: i9,
  attr: l9,
  children: s9,
  claim_svg_element: o9,
  detach: u9,
  init: c9,
  insert_hydration: h9,
  noop: m9,
  safe_not_equal: d9,
  svg_element: f9
} = window.__gradio__svelte__internal, {
  SvelteComponent: p9,
  append_hydration: g9,
  attr: v9,
  children: _9,
  claim_svg_element: b9,
  claim_text: y9,
  detach: w9,
  init: k9,
  insert_hydration: D9,
  noop: x9,
  safe_not_equal: S9,
  svg_element: A9,
  text: F9
} = window.__gradio__svelte__internal, {
  SvelteComponent: C9,
  append_hydration: E9,
  attr: T9,
  children: $9,
  claim_svg_element: M9,
  detach: z9,
  init: B9,
  insert_hydration: R9,
  noop: q9,
  safe_not_equal: N9,
  svg_element: I9
} = window.__gradio__svelte__internal, {
  SvelteComponent: L9,
  append_hydration: O9,
  attr: P9,
  children: H9,
  claim_svg_element: U9,
  detach: V9,
  init: G9,
  insert_hydration: Y9,
  noop: W9,
  safe_not_equal: j9,
  svg_element: X9
} = window.__gradio__svelte__internal, {
  SvelteComponent: Z9,
  append_hydration: K9,
  attr: Q9,
  children: J9,
  claim_svg_element: eg,
  detach: tg,
  init: rg,
  insert_hydration: ng,
  noop: ag,
  safe_not_equal: ig,
  svg_element: lg
} = window.__gradio__svelte__internal, {
  SvelteComponent: sg,
  append_hydration: og,
  attr: ug,
  children: cg,
  claim_svg_element: hg,
  detach: mg,
  init: dg,
  insert_hydration: fg,
  noop: pg,
  safe_not_equal: gg,
  svg_element: vg
} = window.__gradio__svelte__internal, {
  SvelteComponent: _g,
  append_hydration: bg,
  attr: yg,
  children: wg,
  claim_svg_element: kg,
  detach: Dg,
  init: xg,
  insert_hydration: Sg,
  noop: Ag,
  safe_not_equal: Fg,
  svg_element: Cg
} = window.__gradio__svelte__internal, {
  SvelteComponent: Eg,
  append_hydration: Tg,
  attr: $g,
  children: Mg,
  claim_svg_element: zg,
  claim_text: Bg,
  detach: Rg,
  init: qg,
  insert_hydration: Ng,
  noop: Ig,
  safe_not_equal: Lg,
  svg_element: Og,
  text: Pg
} = window.__gradio__svelte__internal, {
  SvelteComponent: Hg,
  append_hydration: Ug,
  attr: Vg,
  children: Gg,
  claim_svg_element: Yg,
  claim_text: Wg,
  detach: jg,
  init: Xg,
  insert_hydration: Zg,
  noop: Kg,
  safe_not_equal: Qg,
  svg_element: Jg,
  text: ev
} = window.__gradio__svelte__internal, {
  SvelteComponent: tv,
  append_hydration: rv,
  attr: nv,
  children: av,
  claim_svg_element: iv,
  claim_text: lv,
  detach: sv,
  init: ov,
  insert_hydration: uv,
  noop: cv,
  safe_not_equal: hv,
  svg_element: mv,
  text: dv
} = window.__gradio__svelte__internal, {
  SvelteComponent: fv,
  append_hydration: pv,
  attr: gv,
  children: vv,
  claim_svg_element: _v,
  detach: bv,
  init: yv,
  insert_hydration: wv,
  noop: kv,
  safe_not_equal: Dv,
  svg_element: xv
} = window.__gradio__svelte__internal, {
  SvelteComponent: Sv,
  append_hydration: Av,
  attr: Fv,
  children: Cv,
  claim_svg_element: Ev,
  detach: Tv,
  init: $v,
  insert_hydration: Mv,
  noop: zv,
  safe_not_equal: Bv,
  svg_element: Rv
} = window.__gradio__svelte__internal, {
  SvelteComponent: qv,
  append_hydration: Nv,
  attr: Iv,
  children: Lv,
  claim_svg_element: Ov,
  detach: Pv,
  init: Hv,
  insert_hydration: Uv,
  noop: Vv,
  safe_not_equal: Gv,
  svg_element: Yv
} = window.__gradio__svelte__internal, {
  SvelteComponent: Wv,
  append_hydration: jv,
  attr: Xv,
  children: Zv,
  claim_svg_element: Kv,
  detach: Qv,
  init: Jv,
  insert_hydration: e_,
  noop: t_,
  safe_not_equal: r_,
  svg_element: n_
} = window.__gradio__svelte__internal, {
  SvelteComponent: a_,
  append_hydration: i_,
  attr: l_,
  children: s_,
  claim_svg_element: o_,
  detach: u_,
  init: c_,
  insert_hydration: h_,
  noop: m_,
  safe_not_equal: d_,
  svg_element: f_
} = window.__gradio__svelte__internal, $4 = [
  { color: "red", primary: 600, secondary: 100 },
  { color: "green", primary: 600, secondary: 100 },
  { color: "blue", primary: 600, secondary: 100 },
  { color: "yellow", primary: 500, secondary: 100 },
  { color: "purple", primary: 600, secondary: 100 },
  { color: "teal", primary: 600, secondary: 100 },
  { color: "orange", primary: 600, secondary: 100 },
  { color: "cyan", primary: 600, secondary: 100 },
  { color: "lime", primary: 500, secondary: 100 },
  { color: "pink", primary: 600, secondary: 100 }
], Hi = {
  inherit: "inherit",
  current: "currentColor",
  transparent: "transparent",
  black: "#000",
  white: "#fff",
  slate: {
    50: "#f8fafc",
    100: "#f1f5f9",
    200: "#e2e8f0",
    300: "#cbd5e1",
    400: "#94a3b8",
    500: "#64748b",
    600: "#475569",
    700: "#334155",
    800: "#1e293b",
    900: "#0f172a",
    950: "#020617"
  },
  gray: {
    50: "#f9fafb",
    100: "#f3f4f6",
    200: "#e5e7eb",
    300: "#d1d5db",
    400: "#9ca3af",
    500: "#6b7280",
    600: "#4b5563",
    700: "#374151",
    800: "#1f2937",
    900: "#111827",
    950: "#030712"
  },
  zinc: {
    50: "#fafafa",
    100: "#f4f4f5",
    200: "#e4e4e7",
    300: "#d4d4d8",
    400: "#a1a1aa",
    500: "#71717a",
    600: "#52525b",
    700: "#3f3f46",
    800: "#27272a",
    900: "#18181b",
    950: "#09090b"
  },
  neutral: {
    50: "#fafafa",
    100: "#f5f5f5",
    200: "#e5e5e5",
    300: "#d4d4d4",
    400: "#a3a3a3",
    500: "#737373",
    600: "#525252",
    700: "#404040",
    800: "#262626",
    900: "#171717",
    950: "#0a0a0a"
  },
  stone: {
    50: "#fafaf9",
    100: "#f5f5f4",
    200: "#e7e5e4",
    300: "#d6d3d1",
    400: "#a8a29e",
    500: "#78716c",
    600: "#57534e",
    700: "#44403c",
    800: "#292524",
    900: "#1c1917",
    950: "#0c0a09"
  },
  red: {
    50: "#fef2f2",
    100: "#fee2e2",
    200: "#fecaca",
    300: "#fca5a5",
    400: "#f87171",
    500: "#ef4444",
    600: "#dc2626",
    700: "#b91c1c",
    800: "#991b1b",
    900: "#7f1d1d",
    950: "#450a0a"
  },
  orange: {
    50: "#fff7ed",
    100: "#ffedd5",
    200: "#fed7aa",
    300: "#fdba74",
    400: "#fb923c",
    500: "#f97316",
    600: "#ea580c",
    700: "#c2410c",
    800: "#9a3412",
    900: "#7c2d12",
    950: "#431407"
  },
  amber: {
    50: "#fffbeb",
    100: "#fef3c7",
    200: "#fde68a",
    300: "#fcd34d",
    400: "#fbbf24",
    500: "#f59e0b",
    600: "#d97706",
    700: "#b45309",
    800: "#92400e",
    900: "#78350f",
    950: "#451a03"
  },
  yellow: {
    50: "#fefce8",
    100: "#fef9c3",
    200: "#fef08a",
    300: "#fde047",
    400: "#facc15",
    500: "#eab308",
    600: "#ca8a04",
    700: "#a16207",
    800: "#854d0e",
    900: "#713f12",
    950: "#422006"
  },
  lime: {
    50: "#f7fee7",
    100: "#ecfccb",
    200: "#d9f99d",
    300: "#bef264",
    400: "#a3e635",
    500: "#84cc16",
    600: "#65a30d",
    700: "#4d7c0f",
    800: "#3f6212",
    900: "#365314",
    950: "#1a2e05"
  },
  green: {
    50: "#f0fdf4",
    100: "#dcfce7",
    200: "#bbf7d0",
    300: "#86efac",
    400: "#4ade80",
    500: "#22c55e",
    600: "#16a34a",
    700: "#15803d",
    800: "#166534",
    900: "#14532d",
    950: "#052e16"
  },
  emerald: {
    50: "#ecfdf5",
    100: "#d1fae5",
    200: "#a7f3d0",
    300: "#6ee7b7",
    400: "#34d399",
    500: "#10b981",
    600: "#059669",
    700: "#047857",
    800: "#065f46",
    900: "#064e3b",
    950: "#022c22"
  },
  teal: {
    50: "#f0fdfa",
    100: "#ccfbf1",
    200: "#99f6e4",
    300: "#5eead4",
    400: "#2dd4bf",
    500: "#14b8a6",
    600: "#0d9488",
    700: "#0f766e",
    800: "#115e59",
    900: "#134e4a",
    950: "#042f2e"
  },
  cyan: {
    50: "#ecfeff",
    100: "#cffafe",
    200: "#a5f3fc",
    300: "#67e8f9",
    400: "#22d3ee",
    500: "#06b6d4",
    600: "#0891b2",
    700: "#0e7490",
    800: "#155e75",
    900: "#164e63",
    950: "#083344"
  },
  sky: {
    50: "#f0f9ff",
    100: "#e0f2fe",
    200: "#bae6fd",
    300: "#7dd3fc",
    400: "#38bdf8",
    500: "#0ea5e9",
    600: "#0284c7",
    700: "#0369a1",
    800: "#075985",
    900: "#0c4a6e",
    950: "#082f49"
  },
  blue: {
    50: "#eff6ff",
    100: "#dbeafe",
    200: "#bfdbfe",
    300: "#93c5fd",
    400: "#60a5fa",
    500: "#3b82f6",
    600: "#2563eb",
    700: "#1d4ed8",
    800: "#1e40af",
    900: "#1e3a8a",
    950: "#172554"
  },
  indigo: {
    50: "#eef2ff",
    100: "#e0e7ff",
    200: "#c7d2fe",
    300: "#a5b4fc",
    400: "#818cf8",
    500: "#6366f1",
    600: "#4f46e5",
    700: "#4338ca",
    800: "#3730a3",
    900: "#312e81",
    950: "#1e1b4b"
  },
  violet: {
    50: "#f5f3ff",
    100: "#ede9fe",
    200: "#ddd6fe",
    300: "#c4b5fd",
    400: "#a78bfa",
    500: "#8b5cf6",
    600: "#7c3aed",
    700: "#6d28d9",
    800: "#5b21b6",
    900: "#4c1d95",
    950: "#2e1065"
  },
  purple: {
    50: "#faf5ff",
    100: "#f3e8ff",
    200: "#e9d5ff",
    300: "#d8b4fe",
    400: "#c084fc",
    500: "#a855f7",
    600: "#9333ea",
    700: "#7e22ce",
    800: "#6b21a8",
    900: "#581c87",
    950: "#3b0764"
  },
  fuchsia: {
    50: "#fdf4ff",
    100: "#fae8ff",
    200: "#f5d0fe",
    300: "#f0abfc",
    400: "#e879f9",
    500: "#d946ef",
    600: "#c026d3",
    700: "#a21caf",
    800: "#86198f",
    900: "#701a75",
    950: "#4a044e"
  },
  pink: {
    50: "#fdf2f8",
    100: "#fce7f3",
    200: "#fbcfe8",
    300: "#f9a8d4",
    400: "#f472b6",
    500: "#ec4899",
    600: "#db2777",
    700: "#be185d",
    800: "#9d174d",
    900: "#831843",
    950: "#500724"
  },
  rose: {
    50: "#fff1f2",
    100: "#ffe4e6",
    200: "#fecdd3",
    300: "#fda4af",
    400: "#fb7185",
    500: "#f43f5e",
    600: "#e11d48",
    700: "#be123c",
    800: "#9f1239",
    900: "#881337",
    950: "#4c0519"
  }
};
$4.reduce(
  (n, { color: e, primary: t, secondary: r }) => ({
    ...n,
    [e]: {
      primary: Hi[e][t],
      secondary: Hi[e][r]
    }
  }),
  {}
);
const {
  SvelteComponent: p_,
  claim_component: g_,
  create_component: v_,
  destroy_component: __,
  init: b_,
  mount_component: y_,
  safe_not_equal: w_,
  transition_in: k_,
  transition_out: D_
} = window.__gradio__svelte__internal, { createEventDispatcher: x_ } = window.__gradio__svelte__internal, {
  SvelteComponent: S_,
  append_hydration: A_,
  attr: F_,
  check_outros: C_,
  children: E_,
  claim_component: T_,
  claim_element: $_,
  claim_space: M_,
  claim_text: z_,
  create_component: B_,
  destroy_component: R_,
  detach: q_,
  element: N_,
  empty: I_,
  group_outros: L_,
  init: O_,
  insert_hydration: P_,
  mount_component: H_,
  safe_not_equal: U_,
  set_data: V_,
  space: G_,
  text: Y_,
  toggle_class: W_,
  transition_in: j_,
  transition_out: X_
} = window.__gradio__svelte__internal, {
  SvelteComponent: Z_,
  attr: K_,
  children: Q_,
  claim_element: J_,
  create_slot: eb,
  detach: tb,
  element: rb,
  get_all_dirty_from_scope: nb,
  get_slot_changes: ab,
  init: ib,
  insert_hydration: lb,
  safe_not_equal: sb,
  toggle_class: ob,
  transition_in: ub,
  transition_out: cb,
  update_slot_base: hb
} = window.__gradio__svelte__internal, {
  SvelteComponent: mb,
  append_hydration: db,
  attr: fb,
  check_outros: pb,
  children: gb,
  claim_component: vb,
  claim_element: _b,
  claim_space: bb,
  create_component: yb,
  destroy_component: wb,
  detach: kb,
  element: Db,
  empty: xb,
  group_outros: Sb,
  init: Ab,
  insert_hydration: Fb,
  listen: Cb,
  mount_component: Eb,
  safe_not_equal: Tb,
  space: $b,
  toggle_class: Mb,
  transition_in: zb,
  transition_out: Bb
} = window.__gradio__svelte__internal, {
  SvelteComponent: Rb,
  attr: qb,
  children: Nb,
  claim_element: Ib,
  create_slot: Lb,
  detach: Ob,
  element: Pb,
  get_all_dirty_from_scope: Hb,
  get_slot_changes: Ub,
  init: Vb,
  insert_hydration: Gb,
  null_to_empty: Yb,
  safe_not_equal: Wb,
  transition_in: jb,
  transition_out: Xb,
  update_slot_base: Zb
} = window.__gradio__svelte__internal, {
  SvelteComponent: M4,
  append_hydration: d0,
  attr: St,
  binding_callbacks: Ui,
  check_outros: Ln,
  children: Rt,
  claim_component: Ds,
  claim_element: qt,
  claim_space: lt,
  claim_text: De,
  create_component: xs,
  create_slot: Ss,
  destroy_component: As,
  destroy_each: Fs,
  detach: j,
  element: Nt,
  empty: ut,
  ensure_array_like: Hr,
  get_all_dirty_from_scope: Cs,
  get_slot_changes: Es,
  group_outros: On,
  init: z4,
  insert_hydration: te,
  mount_component: Ts,
  noop: Pn,
  safe_not_equal: B4,
  set_data: ct,
  set_style: i0,
  space: st,
  text: xe,
  toggle_class: at,
  transition_in: xt,
  transition_out: It,
  update_slot_base: $s
} = window.__gradio__svelte__internal, { tick: R4 } = window.__gradio__svelte__internal, { onDestroy: q4 } = window.__gradio__svelte__internal, { createEventDispatcher: N4 } = window.__gradio__svelte__internal, I4 = (n) => ({}), Vi = (n) => ({}), L4 = (n) => ({}), Gi = (n) => ({});
function Yi(n, e, t) {
  const r = n.slice();
  return r[40] = e[t], r[42] = t, r;
}
function Wi(n, e, t) {
  const r = n.slice();
  return r[40] = e[t], r;
}
function O4(n) {
  let e, t, r, a, i = (
    /*i18n*/
    n[1]("common.error") + ""
  ), l, o, u;
  t = new x4({
    props: {
      Icon: T4,
      label: (
        /*i18n*/
        n[1]("common.clear")
      ),
      disabled: !1
    }
  }), t.$on(
    "click",
    /*click_handler*/
    n[32]
  );
  const h = (
    /*#slots*/
    n[30].error
  ), d = Ss(
    h,
    n,
    /*$$scope*/
    n[29],
    Vi
  );
  return {
    c() {
      e = Nt("div"), xs(t.$$.fragment), r = st(), a = Nt("span"), l = xe(i), o = st(), d && d.c(), this.h();
    },
    l(p) {
      e = qt(p, "DIV", { class: !0 });
      var b = Rt(e);
      Ds(t.$$.fragment, b), b.forEach(j), r = lt(p), a = qt(p, "SPAN", { class: !0 });
      var y = Rt(a);
      l = De(y, i), y.forEach(j), o = lt(p), d && d.l(p), this.h();
    },
    h() {
      St(e, "class", "clear-status svelte-17v219f"), St(a, "class", "error svelte-17v219f");
    },
    m(p, b) {
      te(p, e, b), Ts(t, e, null), te(p, r, b), te(p, a, b), d0(a, l), te(p, o, b), d && d.m(p, b), u = !0;
    },
    p(p, b) {
      const y = {};
      b[0] & /*i18n*/
      2 && (y.label = /*i18n*/
      p[1]("common.clear")), t.$set(y), (!u || b[0] & /*i18n*/
      2) && i !== (i = /*i18n*/
      p[1]("common.error") + "") && ct(l, i), d && d.p && (!u || b[0] & /*$$scope*/
      536870912) && $s(
        d,
        h,
        p,
        /*$$scope*/
        p[29],
        u ? Es(
          h,
          /*$$scope*/
          p[29],
          b,
          I4
        ) : Cs(
          /*$$scope*/
          p[29]
        ),
        Vi
      );
    },
    i(p) {
      u || (xt(t.$$.fragment, p), xt(d, p), u = !0);
    },
    o(p) {
      It(t.$$.fragment, p), It(d, p), u = !1;
    },
    d(p) {
      p && (j(e), j(r), j(a), j(o)), As(t), d && d.d(p);
    }
  };
}
function P4(n) {
  let e, t, r, a, i, l, o, u, h, d = (
    /*variant*/
    n[8] === "default" && /*show_eta_bar*/
    n[18] && /*show_progress*/
    n[6] === "full" && ji(n)
  );
  function p(g, S) {
    if (
      /*progress*/
      g[7]
    ) return V4;
    if (
      /*queue_position*/
      g[2] !== null && /*queue_size*/
      g[3] !== void 0 && /*queue_position*/
      g[2] >= 0
    ) return U4;
    if (
      /*queue_position*/
      g[2] === 0
    ) return H4;
  }
  let b = p(n), y = b && b(n), D = (
    /*timer*/
    n[5] && Ki(n)
  );
  const A = [j4, W4], C = [];
  function T(g, S) {
    return (
      /*last_progress_level*/
      g[15] != null ? 0 : (
        /*show_progress*/
        g[6] === "full" ? 1 : -1
      )
    );
  }
  ~(i = T(n)) && (l = C[i] = A[i](n));
  let w = !/*timer*/
  n[5] && al(n);
  return {
    c() {
      d && d.c(), e = st(), t = Nt("div"), y && y.c(), r = st(), D && D.c(), a = st(), l && l.c(), o = st(), w && w.c(), u = ut(), this.h();
    },
    l(g) {
      d && d.l(g), e = lt(g), t = qt(g, "DIV", { class: !0 });
      var S = Rt(t);
      y && y.l(S), r = lt(S), D && D.l(S), S.forEach(j), a = lt(g), l && l.l(g), o = lt(g), w && w.l(g), u = ut(), this.h();
    },
    h() {
      St(t, "class", "progress-text svelte-17v219f"), at(
        t,
        "meta-text-center",
        /*variant*/
        n[8] === "center"
      ), at(
        t,
        "meta-text",
        /*variant*/
        n[8] === "default"
      );
    },
    m(g, S) {
      d && d.m(g, S), te(g, e, S), te(g, t, S), y && y.m(t, null), d0(t, r), D && D.m(t, null), te(g, a, S), ~i && C[i].m(g, S), te(g, o, S), w && w.m(g, S), te(g, u, S), h = !0;
    },
    p(g, S) {
      /*variant*/
      g[8] === "default" && /*show_eta_bar*/
      g[18] && /*show_progress*/
      g[6] === "full" ? d ? d.p(g, S) : (d = ji(g), d.c(), d.m(e.parentNode, e)) : d && (d.d(1), d = null), b === (b = p(g)) && y ? y.p(g, S) : (y && y.d(1), y = b && b(g), y && (y.c(), y.m(t, r))), /*timer*/
      g[5] ? D ? D.p(g, S) : (D = Ki(g), D.c(), D.m(t, null)) : D && (D.d(1), D = null), (!h || S[0] & /*variant*/
      256) && at(
        t,
        "meta-text-center",
        /*variant*/
        g[8] === "center"
      ), (!h || S[0] & /*variant*/
      256) && at(
        t,
        "meta-text",
        /*variant*/
        g[8] === "default"
      );
      let E = i;
      i = T(g), i === E ? ~i && C[i].p(g, S) : (l && (On(), It(C[E], 1, 1, () => {
        C[E] = null;
      }), Ln()), ~i ? (l = C[i], l ? l.p(g, S) : (l = C[i] = A[i](g), l.c()), xt(l, 1), l.m(o.parentNode, o)) : l = null), /*timer*/
      g[5] ? w && (On(), It(w, 1, 1, () => {
        w = null;
      }), Ln()) : w ? (w.p(g, S), S[0] & /*timer*/
      32 && xt(w, 1)) : (w = al(g), w.c(), xt(w, 1), w.m(u.parentNode, u));
    },
    i(g) {
      h || (xt(l), xt(w), h = !0);
    },
    o(g) {
      It(l), It(w), h = !1;
    },
    d(g) {
      g && (j(e), j(t), j(a), j(o), j(u)), d && d.d(g), y && y.d(), D && D.d(), ~i && C[i].d(g), w && w.d(g);
    }
  };
}
function ji(n) {
  let e, t = `translateX(${/*eta_level*/
  (n[17] || 0) * 100 - 100}%)`;
  return {
    c() {
      e = Nt("div"), this.h();
    },
    l(r) {
      e = qt(r, "DIV", { class: !0 }), Rt(e).forEach(j), this.h();
    },
    h() {
      St(e, "class", "eta-bar svelte-17v219f"), i0(e, "transform", t);
    },
    m(r, a) {
      te(r, e, a);
    },
    p(r, a) {
      a[0] & /*eta_level*/
      131072 && t !== (t = `translateX(${/*eta_level*/
      (r[17] || 0) * 100 - 100}%)`) && i0(e, "transform", t);
    },
    d(r) {
      r && j(e);
    }
  };
}
function H4(n) {
  let e;
  return {
    c() {
      e = xe("processing |");
    },
    l(t) {
      e = De(t, "processing |");
    },
    m(t, r) {
      te(t, e, r);
    },
    p: Pn,
    d(t) {
      t && j(e);
    }
  };
}
function U4(n) {
  let e, t = (
    /*queue_position*/
    n[2] + 1 + ""
  ), r, a, i, l;
  return {
    c() {
      e = xe("queue: "), r = xe(t), a = xe("/"), i = xe(
        /*queue_size*/
        n[3]
      ), l = xe(" |");
    },
    l(o) {
      e = De(o, "queue: "), r = De(o, t), a = De(o, "/"), i = De(
        o,
        /*queue_size*/
        n[3]
      ), l = De(o, " |");
    },
    m(o, u) {
      te(o, e, u), te(o, r, u), te(o, a, u), te(o, i, u), te(o, l, u);
    },
    p(o, u) {
      u[0] & /*queue_position*/
      4 && t !== (t = /*queue_position*/
      o[2] + 1 + "") && ct(r, t), u[0] & /*queue_size*/
      8 && ct(
        i,
        /*queue_size*/
        o[3]
      );
    },
    d(o) {
      o && (j(e), j(r), j(a), j(i), j(l));
    }
  };
}
function V4(n) {
  let e, t = Hr(
    /*progress*/
    n[7]
  ), r = [];
  for (let a = 0; a < t.length; a += 1)
    r[a] = Zi(Wi(n, t, a));
  return {
    c() {
      for (let a = 0; a < r.length; a += 1)
        r[a].c();
      e = ut();
    },
    l(a) {
      for (let i = 0; i < r.length; i += 1)
        r[i].l(a);
      e = ut();
    },
    m(a, i) {
      for (let l = 0; l < r.length; l += 1)
        r[l] && r[l].m(a, i);
      te(a, e, i);
    },
    p(a, i) {
      if (i[0] & /*progress*/
      128) {
        t = Hr(
          /*progress*/
          a[7]
        );
        let l;
        for (l = 0; l < t.length; l += 1) {
          const o = Wi(a, t, l);
          r[l] ? r[l].p(o, i) : (r[l] = Zi(o), r[l].c(), r[l].m(e.parentNode, e));
        }
        for (; l < r.length; l += 1)
          r[l].d(1);
        r.length = t.length;
      }
    },
    d(a) {
      a && j(e), Fs(r, a);
    }
  };
}
function Xi(n) {
  let e, t = (
    /*p*/
    n[40].unit + ""
  ), r, a, i = " ", l;
  function o(d, p) {
    return (
      /*p*/
      d[40].length != null ? Y4 : G4
    );
  }
  let u = o(n), h = u(n);
  return {
    c() {
      h.c(), e = st(), r = xe(t), a = xe(" | "), l = xe(i);
    },
    l(d) {
      h.l(d), e = lt(d), r = De(d, t), a = De(d, " | "), l = De(d, i);
    },
    m(d, p) {
      h.m(d, p), te(d, e, p), te(d, r, p), te(d, a, p), te(d, l, p);
    },
    p(d, p) {
      u === (u = o(d)) && h ? h.p(d, p) : (h.d(1), h = u(d), h && (h.c(), h.m(e.parentNode, e))), p[0] & /*progress*/
      128 && t !== (t = /*p*/
      d[40].unit + "") && ct(r, t);
    },
    d(d) {
      d && (j(e), j(r), j(a), j(l)), h.d(d);
    }
  };
}
function G4(n) {
  let e = T0(
    /*p*/
    n[40].index || 0
  ) + "", t;
  return {
    c() {
      t = xe(e);
    },
    l(r) {
      t = De(r, e);
    },
    m(r, a) {
      te(r, t, a);
    },
    p(r, a) {
      a[0] & /*progress*/
      128 && e !== (e = T0(
        /*p*/
        r[40].index || 0
      ) + "") && ct(t, e);
    },
    d(r) {
      r && j(t);
    }
  };
}
function Y4(n) {
  let e = T0(
    /*p*/
    n[40].index || 0
  ) + "", t, r, a = T0(
    /*p*/
    n[40].length
  ) + "", i;
  return {
    c() {
      t = xe(e), r = xe("/"), i = xe(a);
    },
    l(l) {
      t = De(l, e), r = De(l, "/"), i = De(l, a);
    },
    m(l, o) {
      te(l, t, o), te(l, r, o), te(l, i, o);
    },
    p(l, o) {
      o[0] & /*progress*/
      128 && e !== (e = T0(
        /*p*/
        l[40].index || 0
      ) + "") && ct(t, e), o[0] & /*progress*/
      128 && a !== (a = T0(
        /*p*/
        l[40].length
      ) + "") && ct(i, a);
    },
    d(l) {
      l && (j(t), j(r), j(i));
    }
  };
}
function Zi(n) {
  let e, t = (
    /*p*/
    n[40].index != null && Xi(n)
  );
  return {
    c() {
      t && t.c(), e = ut();
    },
    l(r) {
      t && t.l(r), e = ut();
    },
    m(r, a) {
      t && t.m(r, a), te(r, e, a);
    },
    p(r, a) {
      /*p*/
      r[40].index != null ? t ? t.p(r, a) : (t = Xi(r), t.c(), t.m(e.parentNode, e)) : t && (t.d(1), t = null);
    },
    d(r) {
      r && j(e), t && t.d(r);
    }
  };
}
function Ki(n) {
  let e, t = (
    /*eta*/
    n[0] ? `/${/*formatted_eta*/
    n[19]}` : ""
  ), r, a;
  return {
    c() {
      e = xe(
        /*formatted_timer*/
        n[20]
      ), r = xe(t), a = xe("s");
    },
    l(i) {
      e = De(
        i,
        /*formatted_timer*/
        n[20]
      ), r = De(i, t), a = De(i, "s");
    },
    m(i, l) {
      te(i, e, l), te(i, r, l), te(i, a, l);
    },
    p(i, l) {
      l[0] & /*formatted_timer*/
      1048576 && ct(
        e,
        /*formatted_timer*/
        i[20]
      ), l[0] & /*eta, formatted_eta*/
      524289 && t !== (t = /*eta*/
      i[0] ? `/${/*formatted_eta*/
      i[19]}` : "") && ct(r, t);
    },
    d(i) {
      i && (j(e), j(r), j(a));
    }
  };
}
function W4(n) {
  let e, t;
  return e = new _o({
    props: { margin: (
      /*variant*/
      n[8] === "default"
    ) }
  }), {
    c() {
      xs(e.$$.fragment);
    },
    l(r) {
      Ds(e.$$.fragment, r);
    },
    m(r, a) {
      Ts(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a[0] & /*variant*/
      256 && (i.margin = /*variant*/
      r[8] === "default"), e.$set(i);
    },
    i(r) {
      t || (xt(e.$$.fragment, r), t = !0);
    },
    o(r) {
      It(e.$$.fragment, r), t = !1;
    },
    d(r) {
      As(e, r);
    }
  };
}
function j4(n) {
  let e, t, r, a, i, l = `${/*last_progress_level*/
  n[15] * 100}%`, o = (
    /*progress*/
    n[7] != null && Qi(n)
  );
  return {
    c() {
      e = Nt("div"), t = Nt("div"), o && o.c(), r = st(), a = Nt("div"), i = Nt("div"), this.h();
    },
    l(u) {
      e = qt(u, "DIV", { class: !0 });
      var h = Rt(e);
      t = qt(h, "DIV", { class: !0 });
      var d = Rt(t);
      o && o.l(d), d.forEach(j), r = lt(h), a = qt(h, "DIV", { class: !0 });
      var p = Rt(a);
      i = qt(p, "DIV", { class: !0 }), Rt(i).forEach(j), p.forEach(j), h.forEach(j), this.h();
    },
    h() {
      St(t, "class", "progress-level-inner svelte-17v219f"), St(i, "class", "progress-bar svelte-17v219f"), i0(i, "width", l), St(a, "class", "progress-bar-wrap svelte-17v219f"), St(e, "class", "progress-level svelte-17v219f");
    },
    m(u, h) {
      te(u, e, h), d0(e, t), o && o.m(t, null), d0(e, r), d0(e, a), d0(a, i), n[31](i);
    },
    p(u, h) {
      /*progress*/
      u[7] != null ? o ? o.p(u, h) : (o = Qi(u), o.c(), o.m(t, null)) : o && (o.d(1), o = null), h[0] & /*last_progress_level*/
      32768 && l !== (l = `${/*last_progress_level*/
      u[15] * 100}%`) && i0(i, "width", l);
    },
    i: Pn,
    o: Pn,
    d(u) {
      u && j(e), o && o.d(), n[31](null);
    }
  };
}
function Qi(n) {
  let e, t = Hr(
    /*progress*/
    n[7]
  ), r = [];
  for (let a = 0; a < t.length; a += 1)
    r[a] = nl(Yi(n, t, a));
  return {
    c() {
      for (let a = 0; a < r.length; a += 1)
        r[a].c();
      e = ut();
    },
    l(a) {
      for (let i = 0; i < r.length; i += 1)
        r[i].l(a);
      e = ut();
    },
    m(a, i) {
      for (let l = 0; l < r.length; l += 1)
        r[l] && r[l].m(a, i);
      te(a, e, i);
    },
    p(a, i) {
      if (i[0] & /*progress_level, progress*/
      16512) {
        t = Hr(
          /*progress*/
          a[7]
        );
        let l;
        for (l = 0; l < t.length; l += 1) {
          const o = Yi(a, t, l);
          r[l] ? r[l].p(o, i) : (r[l] = nl(o), r[l].c(), r[l].m(e.parentNode, e));
        }
        for (; l < r.length; l += 1)
          r[l].d(1);
        r.length = t.length;
      }
    },
    d(a) {
      a && j(e), Fs(r, a);
    }
  };
}
function Ji(n) {
  let e, t, r, a, i = (
    /*i*/
    n[42] !== 0 && X4()
  ), l = (
    /*p*/
    n[40].desc != null && el(n)
  ), o = (
    /*p*/
    n[40].desc != null && /*progress_level*/
    n[14] && /*progress_level*/
    n[14][
      /*i*/
      n[42]
    ] != null && tl()
  ), u = (
    /*progress_level*/
    n[14] != null && rl(n)
  );
  return {
    c() {
      i && i.c(), e = st(), l && l.c(), t = st(), o && o.c(), r = st(), u && u.c(), a = ut();
    },
    l(h) {
      i && i.l(h), e = lt(h), l && l.l(h), t = lt(h), o && o.l(h), r = lt(h), u && u.l(h), a = ut();
    },
    m(h, d) {
      i && i.m(h, d), te(h, e, d), l && l.m(h, d), te(h, t, d), o && o.m(h, d), te(h, r, d), u && u.m(h, d), te(h, a, d);
    },
    p(h, d) {
      /*p*/
      h[40].desc != null ? l ? l.p(h, d) : (l = el(h), l.c(), l.m(t.parentNode, t)) : l && (l.d(1), l = null), /*p*/
      h[40].desc != null && /*progress_level*/
      h[14] && /*progress_level*/
      h[14][
        /*i*/
        h[42]
      ] != null ? o || (o = tl(), o.c(), o.m(r.parentNode, r)) : o && (o.d(1), o = null), /*progress_level*/
      h[14] != null ? u ? u.p(h, d) : (u = rl(h), u.c(), u.m(a.parentNode, a)) : u && (u.d(1), u = null);
    },
    d(h) {
      h && (j(e), j(t), j(r), j(a)), i && i.d(h), l && l.d(h), o && o.d(h), u && u.d(h);
    }
  };
}
function X4(n) {
  let e;
  return {
    c() {
      e = xe(" /");
    },
    l(t) {
      e = De(t, " /");
    },
    m(t, r) {
      te(t, e, r);
    },
    d(t) {
      t && j(e);
    }
  };
}
function el(n) {
  let e = (
    /*p*/
    n[40].desc + ""
  ), t;
  return {
    c() {
      t = xe(e);
    },
    l(r) {
      t = De(r, e);
    },
    m(r, a) {
      te(r, t, a);
    },
    p(r, a) {
      a[0] & /*progress*/
      128 && e !== (e = /*p*/
      r[40].desc + "") && ct(t, e);
    },
    d(r) {
      r && j(t);
    }
  };
}
function tl(n) {
  let e;
  return {
    c() {
      e = xe("-");
    },
    l(t) {
      e = De(t, "-");
    },
    m(t, r) {
      te(t, e, r);
    },
    d(t) {
      t && j(e);
    }
  };
}
function rl(n) {
  let e = (100 * /*progress_level*/
  (n[14][
    /*i*/
    n[42]
  ] || 0)).toFixed(1) + "", t, r;
  return {
    c() {
      t = xe(e), r = xe("%");
    },
    l(a) {
      t = De(a, e), r = De(a, "%");
    },
    m(a, i) {
      te(a, t, i), te(a, r, i);
    },
    p(a, i) {
      i[0] & /*progress_level*/
      16384 && e !== (e = (100 * /*progress_level*/
      (a[14][
        /*i*/
        a[42]
      ] || 0)).toFixed(1) + "") && ct(t, e);
    },
    d(a) {
      a && (j(t), j(r));
    }
  };
}
function nl(n) {
  let e, t = (
    /*p*/
    (n[40].desc != null || /*progress_level*/
    n[14] && /*progress_level*/
    n[14][
      /*i*/
      n[42]
    ] != null) && Ji(n)
  );
  return {
    c() {
      t && t.c(), e = ut();
    },
    l(r) {
      t && t.l(r), e = ut();
    },
    m(r, a) {
      t && t.m(r, a), te(r, e, a);
    },
    p(r, a) {
      /*p*/
      r[40].desc != null || /*progress_level*/
      r[14] && /*progress_level*/
      r[14][
        /*i*/
        r[42]
      ] != null ? t ? t.p(r, a) : (t = Ji(r), t.c(), t.m(e.parentNode, e)) : t && (t.d(1), t = null);
    },
    d(r) {
      r && j(e), t && t.d(r);
    }
  };
}
function al(n) {
  let e, t, r, a;
  const i = (
    /*#slots*/
    n[30]["additional-loading-text"]
  ), l = Ss(
    i,
    n,
    /*$$scope*/
    n[29],
    Gi
  );
  return {
    c() {
      e = Nt("p"), t = xe(
        /*loading_text*/
        n[9]
      ), r = st(), l && l.c(), this.h();
    },
    l(o) {
      e = qt(o, "P", { class: !0 });
      var u = Rt(e);
      t = De(
        u,
        /*loading_text*/
        n[9]
      ), u.forEach(j), r = lt(o), l && l.l(o), this.h();
    },
    h() {
      St(e, "class", "loading svelte-17v219f");
    },
    m(o, u) {
      te(o, e, u), d0(e, t), te(o, r, u), l && l.m(o, u), a = !0;
    },
    p(o, u) {
      (!a || u[0] & /*loading_text*/
      512) && ct(
        t,
        /*loading_text*/
        o[9]
      ), l && l.p && (!a || u[0] & /*$$scope*/
      536870912) && $s(
        l,
        i,
        o,
        /*$$scope*/
        o[29],
        a ? Es(
          i,
          /*$$scope*/
          o[29],
          u,
          L4
        ) : Cs(
          /*$$scope*/
          o[29]
        ),
        Gi
      );
    },
    i(o) {
      a || (xt(l, o), a = !0);
    },
    o(o) {
      It(l, o), a = !1;
    },
    d(o) {
      o && (j(e), j(r)), l && l.d(o);
    }
  };
}
function Z4(n) {
  let e, t, r, a, i;
  const l = [P4, O4], o = [];
  function u(h, d) {
    return (
      /*status*/
      h[4] === "pending" ? 0 : (
        /*status*/
        h[4] === "error" ? 1 : -1
      )
    );
  }
  return ~(t = u(n)) && (r = o[t] = l[t](n)), {
    c() {
      e = Nt("div"), r && r.c(), this.h();
    },
    l(h) {
      e = qt(h, "DIV", { class: !0 });
      var d = Rt(e);
      r && r.l(d), d.forEach(j), this.h();
    },
    h() {
      St(e, "class", a = "wrap " + /*variant*/
      n[8] + " " + /*show_progress*/
      n[6] + " svelte-17v219f"), at(e, "hide", !/*status*/
      n[4] || /*status*/
      n[4] === "complete" || /*show_progress*/
      n[6] === "hidden" || /*status*/
      n[4] == "streaming"), at(
        e,
        "translucent",
        /*variant*/
        n[8] === "center" && /*status*/
        (n[4] === "pending" || /*status*/
        n[4] === "error") || /*translucent*/
        n[11] || /*show_progress*/
        n[6] === "minimal"
      ), at(
        e,
        "generating",
        /*status*/
        n[4] === "generating" && /*show_progress*/
        n[6] === "full"
      ), at(
        e,
        "border",
        /*border*/
        n[12]
      ), i0(
        e,
        "position",
        /*absolute*/
        n[10] ? "absolute" : "static"
      ), i0(
        e,
        "padding",
        /*absolute*/
        n[10] ? "0" : "var(--size-8) 0"
      );
    },
    m(h, d) {
      te(h, e, d), ~t && o[t].m(e, null), n[33](e), i = !0;
    },
    p(h, d) {
      let p = t;
      t = u(h), t === p ? ~t && o[t].p(h, d) : (r && (On(), It(o[p], 1, 1, () => {
        o[p] = null;
      }), Ln()), ~t ? (r = o[t], r ? r.p(h, d) : (r = o[t] = l[t](h), r.c()), xt(r, 1), r.m(e, null)) : r = null), (!i || d[0] & /*variant, show_progress*/
      320 && a !== (a = "wrap " + /*variant*/
      h[8] + " " + /*show_progress*/
      h[6] + " svelte-17v219f")) && St(e, "class", a), (!i || d[0] & /*variant, show_progress, status, show_progress*/
      336) && at(e, "hide", !/*status*/
      h[4] || /*status*/
      h[4] === "complete" || /*show_progress*/
      h[6] === "hidden" || /*status*/
      h[4] == "streaming"), (!i || d[0] & /*variant, show_progress, variant, status, translucent, show_progress*/
      2384) && at(
        e,
        "translucent",
        /*variant*/
        h[8] === "center" && /*status*/
        (h[4] === "pending" || /*status*/
        h[4] === "error") || /*translucent*/
        h[11] || /*show_progress*/
        h[6] === "minimal"
      ), (!i || d[0] & /*variant, show_progress, status, show_progress*/
      336) && at(
        e,
        "generating",
        /*status*/
        h[4] === "generating" && /*show_progress*/
        h[6] === "full"
      ), (!i || d[0] & /*variant, show_progress, border*/
      4416) && at(
        e,
        "border",
        /*border*/
        h[12]
      ), d[0] & /*absolute*/
      1024 && i0(
        e,
        "position",
        /*absolute*/
        h[10] ? "absolute" : "static"
      ), d[0] & /*absolute*/
      1024 && i0(
        e,
        "padding",
        /*absolute*/
        h[10] ? "0" : "var(--size-8) 0"
      );
    },
    i(h) {
      i || (xt(r), i = !0);
    },
    o(h) {
      It(r), i = !1;
    },
    d(h) {
      h && j(e), ~t && o[t].d(), n[33](null);
    }
  };
}
let Sr = [], kn = !1;
const K4 = typeof window < "u", Ms = K4 ? window.requestAnimationFrame : (n) => {
};
async function Q4(n, e = !0) {
  if (!(window.__gradio_mode__ === "website" || window.__gradio_mode__ !== "app" && e !== !0)) {
    if (Sr.push(n), !kn) kn = !0;
    else return;
    await R4(), Ms(() => {
      let t = [0, 0];
      for (let r = 0; r < Sr.length; r++) {
        const i = Sr[r].getBoundingClientRect();
        (r === 0 || i.top + window.scrollY <= t[0]) && (t[0] = i.top + window.scrollY, t[1] = r);
      }
      window.scrollTo({ top: t[0] - 20, behavior: "smooth" }), kn = !1, Sr = [];
    });
  }
}
function J4(n, e, t) {
  let r, { $$slots: a = {}, $$scope: i } = e;
  const l = N4();
  let { i18n: o } = e, { eta: u = null } = e, { queue_position: h } = e, { queue_size: d } = e, { status: p } = e, { scroll_to_output: b = !1 } = e, { timer: y = !0 } = e, { show_progress: D = "full" } = e, { message: A = null } = e, { progress: C = null } = e, { variant: T = "default" } = e, { loading_text: w = "Loading..." } = e, { absolute: g = !0 } = e, { translucent: S = !1 } = e, { border: E = !1 } = e, { autoscroll: $ } = e, B, O = !1, M = 0, R = 0, W = null, Q = null, G = 0, U = null, ae, ce = null, $e = !0;
  const ue = () => {
    t(0, u = t(27, W = t(19, re = null))), t(25, M = performance.now()), t(26, R = 0), O = !0, ge();
  };
  function ge() {
    Ms(() => {
      t(26, R = (performance.now() - M) / 1e3), O && ge();
    });
  }
  function _e() {
    t(26, R = 0), t(0, u = t(27, W = t(19, re = null))), O && (O = !1);
  }
  q4(() => {
    O && _e();
  });
  let re = null;
  function he(I) {
    Ui[I ? "unshift" : "push"](() => {
      ce = I, t(16, ce), t(7, C), t(14, U), t(15, ae);
    });
  }
  const me = () => {
    l("clear_status");
  };
  function Me(I) {
    Ui[I ? "unshift" : "push"](() => {
      B = I, t(13, B);
    });
  }
  return n.$$set = (I) => {
    "i18n" in I && t(1, o = I.i18n), "eta" in I && t(0, u = I.eta), "queue_position" in I && t(2, h = I.queue_position), "queue_size" in I && t(3, d = I.queue_size), "status" in I && t(4, p = I.status), "scroll_to_output" in I && t(22, b = I.scroll_to_output), "timer" in I && t(5, y = I.timer), "show_progress" in I && t(6, D = I.show_progress), "message" in I && t(23, A = I.message), "progress" in I && t(7, C = I.progress), "variant" in I && t(8, T = I.variant), "loading_text" in I && t(9, w = I.loading_text), "absolute" in I && t(10, g = I.absolute), "translucent" in I && t(11, S = I.translucent), "border" in I && t(12, E = I.border), "autoscroll" in I && t(24, $ = I.autoscroll), "$$scope" in I && t(29, i = I.$$scope);
  }, n.$$.update = () => {
    n.$$.dirty[0] & /*eta, old_eta, timer_start, eta_from_start*/
    436207617 && (u === null && t(0, u = W), u != null && W !== u && (t(28, Q = (performance.now() - M) / 1e3 + u), t(19, re = Q.toFixed(1)), t(27, W = u))), n.$$.dirty[0] & /*eta_from_start, timer_diff*/
    335544320 && t(17, G = Q === null || Q <= 0 || !R ? null : Math.min(R / Q, 1)), n.$$.dirty[0] & /*progress*/
    128 && C != null && t(18, $e = !1), n.$$.dirty[0] & /*progress, progress_level, progress_bar, last_progress_level*/
    114816 && (C != null ? t(14, U = C.map((I) => {
      if (I.index != null && I.length != null)
        return I.index / I.length;
      if (I.progress != null)
        return I.progress;
    })) : t(14, U = null), U ? (t(15, ae = U[U.length - 1]), ce && (ae === 0 ? t(16, ce.style.transition = "0", ce) : t(16, ce.style.transition = "150ms", ce))) : t(15, ae = void 0)), n.$$.dirty[0] & /*status*/
    16 && (p === "pending" ? ue() : _e()), n.$$.dirty[0] & /*el, scroll_to_output, status, autoscroll*/
    20979728 && B && b && (p === "pending" || p === "complete") && Q4(B, $), n.$$.dirty[0] & /*status, message*/
    8388624, n.$$.dirty[0] & /*timer_diff*/
    67108864 && t(20, r = R.toFixed(1));
  }, [
    u,
    o,
    h,
    d,
    p,
    y,
    D,
    C,
    T,
    w,
    g,
    S,
    E,
    B,
    U,
    ae,
    ce,
    G,
    $e,
    re,
    r,
    l,
    b,
    A,
    $,
    M,
    R,
    W,
    Q,
    i,
    a,
    he,
    me,
    Me
  ];
}
class ec extends M4 {
  constructor(e) {
    super(), z4(
      this,
      e,
      J4,
      Z4,
      B4,
      {
        i18n: 1,
        eta: 0,
        queue_position: 2,
        queue_size: 3,
        status: 4,
        scroll_to_output: 22,
        timer: 5,
        show_progress: 6,
        message: 23,
        progress: 7,
        variant: 8,
        loading_text: 9,
        absolute: 10,
        translucent: 11,
        border: 12,
        autoscroll: 24
      },
      null,
      [-1, -1]
    );
  }
}
/*! @license DOMPurify 3.2.0 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.2.0/LICENSE */
const {
  entries: zs,
  setPrototypeOf: il,
  isFrozen: tc,
  getPrototypeOf: rc,
  getOwnPropertyDescriptor: nc
} = Object;
let {
  freeze: Ue,
  seal: ht,
  create: Bs
} = Object, {
  apply: Hn,
  construct: Un
} = typeof Reflect < "u" && Reflect;
Ue || (Ue = function(e) {
  return e;
});
ht || (ht = function(e) {
  return e;
});
Hn || (Hn = function(e, t, r) {
  return e.apply(t, r);
});
Un || (Un = function(e, t) {
  return new e(...t);
});
const Ar = et(Array.prototype.forEach), ll = et(Array.prototype.pop), H0 = et(Array.prototype.push), zr = et(String.prototype.toLowerCase), Dn = et(String.prototype.toString), sl = et(String.prototype.match), U0 = et(String.prototype.replace), ac = et(String.prototype.indexOf), ic = et(String.prototype.trim), wt = et(Object.prototype.hasOwnProperty), Pe = et(RegExp.prototype.test), V0 = lc(TypeError);
function et(n) {
  return function(e) {
    for (var t = arguments.length, r = new Array(t > 1 ? t - 1 : 0), a = 1; a < t; a++)
      r[a - 1] = arguments[a];
    return Hn(n, e, r);
  };
}
function lc(n) {
  return function() {
    for (var e = arguments.length, t = new Array(e), r = 0; r < e; r++)
      t[r] = arguments[r];
    return Un(n, t);
  };
}
function ie(n, e) {
  let t = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : zr;
  il && il(n, null);
  let r = e.length;
  for (; r--; ) {
    let a = e[r];
    if (typeof a == "string") {
      const i = t(a);
      i !== a && (tc(e) || (e[r] = i), a = i);
    }
    n[a] = !0;
  }
  return n;
}
function sc(n) {
  for (let e = 0; e < n.length; e++)
    wt(n, e) || (n[e] = null);
  return n;
}
function m0(n) {
  const e = Bs(null);
  for (const [t, r] of zs(n))
    wt(n, t) && (Array.isArray(r) ? e[t] = sc(r) : r && typeof r == "object" && r.constructor === Object ? e[t] = m0(r) : e[t] = r);
  return e;
}
function G0(n, e) {
  for (; n !== null; ) {
    const r = nc(n, e);
    if (r) {
      if (r.get)
        return et(r.get);
      if (typeof r.value == "function")
        return et(r.value);
    }
    n = rc(n);
  }
  function t() {
    return null;
  }
  return t;
}
const ol = Ue(["a", "abbr", "acronym", "address", "area", "article", "aside", "audio", "b", "bdi", "bdo", "big", "blink", "blockquote", "body", "br", "button", "canvas", "caption", "center", "cite", "code", "col", "colgroup", "content", "data", "datalist", "dd", "decorator", "del", "details", "dfn", "dialog", "dir", "div", "dl", "dt", "element", "em", "fieldset", "figcaption", "figure", "font", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "i", "img", "input", "ins", "kbd", "label", "legend", "li", "main", "map", "mark", "marquee", "menu", "menuitem", "meter", "nav", "nobr", "ol", "optgroup", "option", "output", "p", "picture", "pre", "progress", "q", "rp", "rt", "ruby", "s", "samp", "section", "select", "shadow", "small", "source", "spacer", "span", "strike", "strong", "style", "sub", "summary", "sup", "table", "tbody", "td", "template", "textarea", "tfoot", "th", "thead", "time", "tr", "track", "tt", "u", "ul", "var", "video", "wbr"]), xn = Ue(["svg", "a", "altglyph", "altglyphdef", "altglyphitem", "animatecolor", "animatemotion", "animatetransform", "circle", "clippath", "defs", "desc", "ellipse", "filter", "font", "g", "glyph", "glyphref", "hkern", "image", "line", "lineargradient", "marker", "mask", "metadata", "mpath", "path", "pattern", "polygon", "polyline", "radialgradient", "rect", "stop", "style", "switch", "symbol", "text", "textpath", "title", "tref", "tspan", "view", "vkern"]), Sn = Ue(["feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feDropShadow", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence"]), oc = Ue(["animate", "color-profile", "cursor", "discard", "font-face", "font-face-format", "font-face-name", "font-face-src", "font-face-uri", "foreignobject", "hatch", "hatchpath", "mesh", "meshgradient", "meshpatch", "meshrow", "missing-glyph", "script", "set", "solidcolor", "unknown", "use"]), An = Ue(["math", "menclose", "merror", "mfenced", "mfrac", "mglyph", "mi", "mlabeledtr", "mmultiscripts", "mn", "mo", "mover", "mpadded", "mphantom", "mroot", "mrow", "ms", "mspace", "msqrt", "mstyle", "msub", "msup", "msubsup", "mtable", "mtd", "mtext", "mtr", "munder", "munderover", "mprescripts"]), uc = Ue(["maction", "maligngroup", "malignmark", "mlongdiv", "mscarries", "mscarry", "msgroup", "mstack", "msline", "msrow", "semantics", "annotation", "annotation-xml", "mprescripts", "none"]), ul = Ue(["#text"]), cl = Ue(["accept", "action", "align", "alt", "autocapitalize", "autocomplete", "autopictureinpicture", "autoplay", "background", "bgcolor", "border", "capture", "cellpadding", "cellspacing", "checked", "cite", "class", "clear", "color", "cols", "colspan", "controls", "controlslist", "coords", "crossorigin", "datetime", "decoding", "default", "dir", "disabled", "disablepictureinpicture", "disableremoteplayback", "download", "draggable", "enctype", "enterkeyhint", "face", "for", "headers", "height", "hidden", "high", "href", "hreflang", "id", "inputmode", "integrity", "ismap", "kind", "label", "lang", "list", "loading", "loop", "low", "max", "maxlength", "media", "method", "min", "minlength", "multiple", "muted", "name", "nonce", "noshade", "novalidate", "nowrap", "open", "optimum", "pattern", "placeholder", "playsinline", "popover", "popovertarget", "popovertargetaction", "poster", "preload", "pubdate", "radiogroup", "readonly", "rel", "required", "rev", "reversed", "role", "rows", "rowspan", "spellcheck", "scope", "selected", "shape", "size", "sizes", "span", "srclang", "start", "src", "srcset", "step", "style", "summary", "tabindex", "title", "translate", "type", "usemap", "valign", "value", "width", "wrap", "xmlns", "slot"]), Fn = Ue(["accent-height", "accumulate", "additive", "alignment-baseline", "amplitude", "ascent", "attributename", "attributetype", "azimuth", "basefrequency", "baseline-shift", "begin", "bias", "by", "class", "clip", "clippathunits", "clip-path", "clip-rule", "color", "color-interpolation", "color-interpolation-filters", "color-profile", "color-rendering", "cx", "cy", "d", "dx", "dy", "diffuseconstant", "direction", "display", "divisor", "dur", "edgemode", "elevation", "end", "exponent", "fill", "fill-opacity", "fill-rule", "filter", "filterunits", "flood-color", "flood-opacity", "font-family", "font-size", "font-size-adjust", "font-stretch", "font-style", "font-variant", "font-weight", "fx", "fy", "g1", "g2", "glyph-name", "glyphref", "gradientunits", "gradienttransform", "height", "href", "id", "image-rendering", "in", "in2", "intercept", "k", "k1", "k2", "k3", "k4", "kerning", "keypoints", "keysplines", "keytimes", "lang", "lengthadjust", "letter-spacing", "kernelmatrix", "kernelunitlength", "lighting-color", "local", "marker-end", "marker-mid", "marker-start", "markerheight", "markerunits", "markerwidth", "maskcontentunits", "maskunits", "max", "mask", "media", "method", "mode", "min", "name", "numoctaves", "offset", "operator", "opacity", "order", "orient", "orientation", "origin", "overflow", "paint-order", "path", "pathlength", "patterncontentunits", "patterntransform", "patternunits", "points", "preservealpha", "preserveaspectratio", "primitiveunits", "r", "rx", "ry", "radius", "refx", "refy", "repeatcount", "repeatdur", "restart", "result", "rotate", "scale", "seed", "shape-rendering", "slope", "specularconstant", "specularexponent", "spreadmethod", "startoffset", "stddeviation", "stitchtiles", "stop-color", "stop-opacity", "stroke-dasharray", "stroke-dashoffset", "stroke-linecap", "stroke-linejoin", "stroke-miterlimit", "stroke-opacity", "stroke", "stroke-width", "style", "surfacescale", "systemlanguage", "tabindex", "tablevalues", "targetx", "targety", "transform", "transform-origin", "text-anchor", "text-decoration", "text-rendering", "textlength", "type", "u1", "u2", "unicode", "values", "viewbox", "visibility", "version", "vert-adv-y", "vert-origin-x", "vert-origin-y", "width", "word-spacing", "wrap", "writing-mode", "xchannelselector", "ychannelselector", "x", "x1", "x2", "xmlns", "y", "y1", "y2", "z", "zoomandpan"]), hl = Ue(["accent", "accentunder", "align", "bevelled", "close", "columnsalign", "columnlines", "columnspan", "denomalign", "depth", "dir", "display", "displaystyle", "encoding", "fence", "frame", "height", "href", "id", "largeop", "length", "linethickness", "lspace", "lquote", "mathbackground", "mathcolor", "mathsize", "mathvariant", "maxsize", "minsize", "movablelimits", "notation", "numalign", "open", "rowalign", "rowlines", "rowspacing", "rowspan", "rspace", "rquote", "scriptlevel", "scriptminsize", "scriptsizemultiplier", "selection", "separator", "separators", "stretchy", "subscriptshift", "supscriptshift", "symmetric", "voffset", "width", "xmlns"]), Fr = Ue(["xlink:href", "xml:id", "xlink:title", "xml:space", "xmlns:xlink"]), cc = ht(/\{\{[\w\W]*|[\w\W]*\}\}/gm), hc = ht(/<%[\w\W]*|[\w\W]*%>/gm), mc = ht(/\${[\w\W]*}/gm), dc = ht(/^data-[\-\w.\u00B7-\uFFFF]/), fc = ht(/^aria-[\-\w]+$/), Rs = ht(
  /^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i
  // eslint-disable-line no-useless-escape
), pc = ht(/^(?:\w+script|data):/i), gc = ht(
  /[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g
  // eslint-disable-line no-control-regex
), qs = ht(/^html$/i), vc = ht(/^[a-z][.\w]*(-[.\w]+)+$/i);
var ml = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  ARIA_ATTR: fc,
  ATTR_WHITESPACE: gc,
  CUSTOM_ELEMENT: vc,
  DATA_ATTR: dc,
  DOCTYPE_NAME: qs,
  ERB_EXPR: hc,
  IS_ALLOWED_URI: Rs,
  IS_SCRIPT_OR_DATA: pc,
  MUSTACHE_EXPR: cc,
  TMPLIT_EXPR: mc
});
const Y0 = {
  element: 1,
  text: 3,
  // Deprecated
  progressingInstruction: 7,
  comment: 8,
  document: 9
}, _c = function() {
  return typeof window > "u" ? null : window;
}, bc = function(e, t) {
  if (typeof e != "object" || typeof e.createPolicy != "function")
    return null;
  let r = null;
  const a = "data-tt-policy-suffix";
  t && t.hasAttribute(a) && (r = t.getAttribute(a));
  const i = "dompurify" + (r ? "#" + r : "");
  try {
    return e.createPolicy(i, {
      createHTML(l) {
        return l;
      },
      createScriptURL(l) {
        return l;
      }
    });
  } catch {
    return console.warn("TrustedTypes policy " + i + " could not be created."), null;
  }
};
function Ns() {
  let n = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : _c();
  const e = (Y) => Ns(Y);
  if (e.version = "3.2.0", e.removed = [], !n || !n.document || n.document.nodeType !== Y0.document)
    return e.isSupported = !1, e;
  let {
    document: t
  } = n;
  const r = t, a = r.currentScript, {
    DocumentFragment: i,
    HTMLTemplateElement: l,
    Node: o,
    Element: u,
    NodeFilter: h,
    NamedNodeMap: d = n.NamedNodeMap || n.MozNamedAttrMap,
    HTMLFormElement: p,
    DOMParser: b,
    trustedTypes: y
  } = n, D = u.prototype, A = G0(D, "cloneNode"), C = G0(D, "remove"), T = G0(D, "nextSibling"), w = G0(D, "childNodes"), g = G0(D, "parentNode");
  if (typeof l == "function") {
    const Y = t.createElement("template");
    Y.content && Y.content.ownerDocument && (t = Y.content.ownerDocument);
  }
  let S, E = "";
  const {
    implementation: $,
    createNodeIterator: B,
    createDocumentFragment: O,
    getElementsByTagName: M
  } = t, {
    importNode: R
  } = r;
  let W = {};
  e.isSupported = typeof zs == "function" && typeof g == "function" && $ && $.createHTMLDocument !== void 0;
  const {
    MUSTACHE_EXPR: Q,
    ERB_EXPR: G,
    TMPLIT_EXPR: U,
    DATA_ATTR: ae,
    ARIA_ATTR: ce,
    IS_SCRIPT_OR_DATA: $e,
    ATTR_WHITESPACE: ue,
    CUSTOM_ELEMENT: ge
  } = ml;
  let {
    IS_ALLOWED_URI: _e
  } = ml, re = null;
  const he = ie({}, [...ol, ...xn, ...Sn, ...An, ...ul]);
  let me = null;
  const Me = ie({}, [...cl, ...Fn, ...hl, ...Fr]);
  let I = Object.seal(Bs(null, {
    tagNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    attributeNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    allowCustomizedBuiltInElements: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: !1
    }
  })), Xe = null, Ie = null, Ze = !0, mt = !0, dt = !1, Ut = !0, At = !1, Vt = !0, ft = !1, y0 = !1, w0 = !1, Ft = !1, Gt = !1, Yt = !1, ba = !0, ya = !1;
  const Ls = "user-content-";
  let Jr = !0, N0 = !1, k0 = {}, D0 = null;
  const wa = ie({}, ["annotation-xml", "audio", "colgroup", "desc", "foreignobject", "head", "iframe", "math", "mi", "mn", "mo", "ms", "mtext", "noembed", "noframes", "noscript", "plaintext", "script", "style", "svg", "template", "thead", "title", "video", "xmp"]);
  let ka = null;
  const Da = ie({}, ["audio", "video", "img", "source", "image", "track"]);
  let en = null;
  const xa = ie({}, ["alt", "class", "for", "id", "label", "name", "pattern", "placeholder", "role", "summary", "title", "value", "style", "xmlns"]), lr = "http://www.w3.org/1998/Math/MathML", sr = "http://www.w3.org/2000/svg", Wt = "http://www.w3.org/1999/xhtml";
  let x0 = Wt, tn = !1, rn = null;
  const Os = ie({}, [lr, sr, Wt], Dn);
  let or = ie({}, ["mi", "mo", "mn", "ms", "mtext"]), ur = ie({}, ["annotation-xml"]);
  const Ps = ie({}, ["title", "style", "font", "a", "script"]);
  let I0 = null;
  const Hs = ["application/xhtml+xml", "text/html"], Us = "text/html";
  let Ee = null, S0 = null;
  const Vs = t.createElement("form"), Sa = function(x) {
    return x instanceof RegExp || x instanceof Function;
  }, nn = function() {
    let x = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    if (!(S0 && S0 === x)) {
      if ((!x || typeof x != "object") && (x = {}), x = m0(x), I0 = // eslint-disable-next-line unicorn/prefer-includes
      Hs.indexOf(x.PARSER_MEDIA_TYPE) === -1 ? Us : x.PARSER_MEDIA_TYPE, Ee = I0 === "application/xhtml+xml" ? Dn : zr, re = wt(x, "ALLOWED_TAGS") ? ie({}, x.ALLOWED_TAGS, Ee) : he, me = wt(x, "ALLOWED_ATTR") ? ie({}, x.ALLOWED_ATTR, Ee) : Me, rn = wt(x, "ALLOWED_NAMESPACES") ? ie({}, x.ALLOWED_NAMESPACES, Dn) : Os, en = wt(x, "ADD_URI_SAFE_ATTR") ? ie(m0(xa), x.ADD_URI_SAFE_ATTR, Ee) : xa, ka = wt(x, "ADD_DATA_URI_TAGS") ? ie(m0(Da), x.ADD_DATA_URI_TAGS, Ee) : Da, D0 = wt(x, "FORBID_CONTENTS") ? ie({}, x.FORBID_CONTENTS, Ee) : wa, Xe = wt(x, "FORBID_TAGS") ? ie({}, x.FORBID_TAGS, Ee) : {}, Ie = wt(x, "FORBID_ATTR") ? ie({}, x.FORBID_ATTR, Ee) : {}, k0 = wt(x, "USE_PROFILES") ? x.USE_PROFILES : !1, Ze = x.ALLOW_ARIA_ATTR !== !1, mt = x.ALLOW_DATA_ATTR !== !1, dt = x.ALLOW_UNKNOWN_PROTOCOLS || !1, Ut = x.ALLOW_SELF_CLOSE_IN_ATTR !== !1, At = x.SAFE_FOR_TEMPLATES || !1, Vt = x.SAFE_FOR_XML !== !1, ft = x.WHOLE_DOCUMENT || !1, Ft = x.RETURN_DOM || !1, Gt = x.RETURN_DOM_FRAGMENT || !1, Yt = x.RETURN_TRUSTED_TYPE || !1, w0 = x.FORCE_BODY || !1, ba = x.SANITIZE_DOM !== !1, ya = x.SANITIZE_NAMED_PROPS || !1, Jr = x.KEEP_CONTENT !== !1, N0 = x.IN_PLACE || !1, _e = x.ALLOWED_URI_REGEXP || Rs, x0 = x.NAMESPACE || Wt, or = x.MATHML_TEXT_INTEGRATION_POINTS || or, ur = x.HTML_INTEGRATION_POINTS || ur, I = x.CUSTOM_ELEMENT_HANDLING || {}, x.CUSTOM_ELEMENT_HANDLING && Sa(x.CUSTOM_ELEMENT_HANDLING.tagNameCheck) && (I.tagNameCheck = x.CUSTOM_ELEMENT_HANDLING.tagNameCheck), x.CUSTOM_ELEMENT_HANDLING && Sa(x.CUSTOM_ELEMENT_HANDLING.attributeNameCheck) && (I.attributeNameCheck = x.CUSTOM_ELEMENT_HANDLING.attributeNameCheck), x.CUSTOM_ELEMENT_HANDLING && typeof x.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements == "boolean" && (I.allowCustomizedBuiltInElements = x.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements), At && (mt = !1), Gt && (Ft = !0), k0 && (re = ie({}, ul), me = [], k0.html === !0 && (ie(re, ol), ie(me, cl)), k0.svg === !0 && (ie(re, xn), ie(me, Fn), ie(me, Fr)), k0.svgFilters === !0 && (ie(re, Sn), ie(me, Fn), ie(me, Fr)), k0.mathMl === !0 && (ie(re, An), ie(me, hl), ie(me, Fr))), x.ADD_TAGS && (re === he && (re = m0(re)), ie(re, x.ADD_TAGS, Ee)), x.ADD_ATTR && (me === Me && (me = m0(me)), ie(me, x.ADD_ATTR, Ee)), x.ADD_URI_SAFE_ATTR && ie(en, x.ADD_URI_SAFE_ATTR, Ee), x.FORBID_CONTENTS && (D0 === wa && (D0 = m0(D0)), ie(D0, x.FORBID_CONTENTS, Ee)), Jr && (re["#text"] = !0), ft && ie(re, ["html", "head", "body"]), re.table && (ie(re, ["tbody"]), delete Xe.tbody), x.TRUSTED_TYPES_POLICY) {
        if (typeof x.TRUSTED_TYPES_POLICY.createHTML != "function")
          throw V0('TRUSTED_TYPES_POLICY configuration option must provide a "createHTML" hook.');
        if (typeof x.TRUSTED_TYPES_POLICY.createScriptURL != "function")
          throw V0('TRUSTED_TYPES_POLICY configuration option must provide a "createScriptURL" hook.');
        S = x.TRUSTED_TYPES_POLICY, E = S.createHTML("");
      } else
        S === void 0 && (S = bc(y, a)), S !== null && typeof E == "string" && (E = S.createHTML(""));
      Ue && Ue(x), S0 = x;
    }
  }, Aa = ie({}, [...xn, ...Sn, ...oc]), Fa = ie({}, [...An, ...uc]), Gs = function(x) {
    let N = g(x);
    (!N || !N.tagName) && (N = {
      namespaceURI: x0,
      tagName: "template"
    });
    const V = zr(x.tagName), be = zr(N.tagName);
    return rn[x.namespaceURI] ? x.namespaceURI === sr ? N.namespaceURI === Wt ? V === "svg" : N.namespaceURI === lr ? V === "svg" && (be === "annotation-xml" || or[be]) : !!Aa[V] : x.namespaceURI === lr ? N.namespaceURI === Wt ? V === "math" : N.namespaceURI === sr ? V === "math" && ur[be] : !!Fa[V] : x.namespaceURI === Wt ? N.namespaceURI === sr && !ur[be] || N.namespaceURI === lr && !or[be] ? !1 : !Fa[V] && (Ps[V] || !Aa[V]) : !!(I0 === "application/xhtml+xml" && rn[x.namespaceURI]) : !1;
  }, Ct = function(x) {
    H0(e.removed, {
      element: x
    });
    try {
      g(x).removeChild(x);
    } catch {
      C(x);
    }
  }, cr = function(x, N) {
    try {
      H0(e.removed, {
        attribute: N.getAttributeNode(x),
        from: N
      });
    } catch {
      H0(e.removed, {
        attribute: null,
        from: N
      });
    }
    if (N.removeAttribute(x), x === "is" && !me[x])
      if (Ft || Gt)
        try {
          Ct(N);
        } catch {
        }
      else
        try {
          N.setAttribute(x, "");
        } catch {
        }
  }, Ca = function(x) {
    let N = null, V = null;
    if (w0)
      x = "<remove></remove>" + x;
    else {
      const ze = sl(x, /^[\r\n\t ]+/);
      V = ze && ze[0];
    }
    I0 === "application/xhtml+xml" && x0 === Wt && (x = '<html xmlns="http://www.w3.org/1999/xhtml"><head></head><body>' + x + "</body></html>");
    const be = S ? S.createHTML(x) : x;
    if (x0 === Wt)
      try {
        N = new b().parseFromString(be, I0);
      } catch {
      }
    if (!N || !N.documentElement) {
      N = $.createDocument(x0, "template", null);
      try {
        N.documentElement.innerHTML = tn ? E : be;
      } catch {
      }
    }
    const Ne = N.body || N.documentElement;
    return x && V && Ne.insertBefore(t.createTextNode(V), Ne.childNodes[0] || null), x0 === Wt ? M.call(N, ft ? "html" : "body")[0] : ft ? N.documentElement : Ne;
  }, Ea = function(x) {
    return B.call(
      x.ownerDocument || x,
      x,
      // eslint-disable-next-line no-bitwise
      h.SHOW_ELEMENT | h.SHOW_COMMENT | h.SHOW_TEXT | h.SHOW_PROCESSING_INSTRUCTION | h.SHOW_CDATA_SECTION,
      null
    );
  }, Ta = function(x) {
    return x instanceof p && (typeof x.nodeName != "string" || typeof x.textContent != "string" || typeof x.removeChild != "function" || !(x.attributes instanceof d) || typeof x.removeAttribute != "function" || typeof x.setAttribute != "function" || typeof x.namespaceURI != "string" || typeof x.insertBefore != "function" || typeof x.hasChildNodes != "function");
  }, $a = function(x) {
    return typeof o == "function" && x instanceof o;
  };
  function jt(Y, x, N) {
    W[Y] && Ar(W[Y], (V) => {
      V.call(e, x, N, S0);
    });
  }
  const Ma = function(x) {
    let N = null;
    if (jt("beforeSanitizeElements", x, null), Ta(x))
      return Ct(x), !0;
    const V = Ee(x.nodeName);
    if (jt("uponSanitizeElement", x, {
      tagName: V,
      allowedTags: re
    }), x.hasChildNodes() && !$a(x.firstElementChild) && Pe(/<[/\w]/g, x.innerHTML) && Pe(/<[/\w]/g, x.textContent) || x.nodeType === Y0.progressingInstruction || Vt && x.nodeType === Y0.comment && Pe(/<[/\w]/g, x.data))
      return Ct(x), !0;
    if (!re[V] || Xe[V]) {
      if (!Xe[V] && Ba(V) && (I.tagNameCheck instanceof RegExp && Pe(I.tagNameCheck, V) || I.tagNameCheck instanceof Function && I.tagNameCheck(V)))
        return !1;
      if (Jr && !D0[V]) {
        const be = g(x) || x.parentNode, Ne = w(x) || x.childNodes;
        if (Ne && be) {
          const ze = Ne.length;
          for (let Ge = ze - 1; Ge >= 0; --Ge) {
            const Et = A(Ne[Ge], !0);
            Et.__removalCount = (x.__removalCount || 0) + 1, be.insertBefore(Et, T(x));
          }
        }
      }
      return Ct(x), !0;
    }
    return x instanceof u && !Gs(x) || (V === "noscript" || V === "noembed" || V === "noframes") && Pe(/<\/no(script|embed|frames)/i, x.innerHTML) ? (Ct(x), !0) : (At && x.nodeType === Y0.text && (N = x.textContent, Ar([Q, G, U], (be) => {
      N = U0(N, be, " ");
    }), x.textContent !== N && (H0(e.removed, {
      element: x.cloneNode()
    }), x.textContent = N)), jt("afterSanitizeElements", x, null), !1);
  }, za = function(x, N, V) {
    if (ba && (N === "id" || N === "name") && (V in t || V in Vs))
      return !1;
    if (!(mt && !Ie[N] && Pe(ae, N))) {
      if (!(Ze && Pe(ce, N))) {
        if (!me[N] || Ie[N]) {
          if (
            // First condition does a very basic check if a) it's basically a valid custom element tagname AND
            // b) if the tagName passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            // and c) if the attribute name passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.attributeNameCheck
            !(Ba(x) && (I.tagNameCheck instanceof RegExp && Pe(I.tagNameCheck, x) || I.tagNameCheck instanceof Function && I.tagNameCheck(x)) && (I.attributeNameCheck instanceof RegExp && Pe(I.attributeNameCheck, N) || I.attributeNameCheck instanceof Function && I.attributeNameCheck(N)) || // Alternative, second condition checks if it's an `is`-attribute, AND
            // the value passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            N === "is" && I.allowCustomizedBuiltInElements && (I.tagNameCheck instanceof RegExp && Pe(I.tagNameCheck, V) || I.tagNameCheck instanceof Function && I.tagNameCheck(V)))
          ) return !1;
        } else if (!en[N]) {
          if (!Pe(_e, U0(V, ue, ""))) {
            if (!((N === "src" || N === "xlink:href" || N === "href") && x !== "script" && ac(V, "data:") === 0 && ka[x])) {
              if (!(dt && !Pe($e, U0(V, ue, "")))) {
                if (V)
                  return !1;
              }
            }
          }
        }
      }
    }
    return !0;
  }, Ba = function(x) {
    return x !== "annotation-xml" && sl(x, ge);
  }, Ra = function(x) {
    jt("beforeSanitizeAttributes", x, null);
    const {
      attributes: N
    } = x;
    if (!N)
      return;
    const V = {
      attrName: "",
      attrValue: "",
      keepAttr: !0,
      allowedAttributes: me,
      forceKeepAttr: void 0
    };
    let be = N.length;
    for (; be--; ) {
      const Ne = N[be], {
        name: ze,
        namespaceURI: Ge,
        value: Et
      } = Ne, L0 = Ee(ze);
      let Le = ze === "value" ? Et : ic(Et);
      if (V.attrName = L0, V.attrValue = Le, V.keepAttr = !0, V.forceKeepAttr = void 0, jt("uponSanitizeAttribute", x, V), Le = V.attrValue, ya && (L0 === "id" || L0 === "name") && (cr(ze, x), Le = Ls + Le), Vt && Pe(/((--!?|])>)|<\/(style|title)/i, Le)) {
        cr(ze, x);
        continue;
      }
      if (V.forceKeepAttr || (cr(ze, x), !V.keepAttr))
        continue;
      if (!Ut && Pe(/\/>/i, Le)) {
        cr(ze, x);
        continue;
      }
      At && Ar([Q, G, U], (Na) => {
        Le = U0(Le, Na, " ");
      });
      const qa = Ee(x.nodeName);
      if (za(qa, L0, Le)) {
        if (S && typeof y == "object" && typeof y.getAttributeType == "function" && !Ge)
          switch (y.getAttributeType(qa, L0)) {
            case "TrustedHTML": {
              Le = S.createHTML(Le);
              break;
            }
            case "TrustedScriptURL": {
              Le = S.createScriptURL(Le);
              break;
            }
          }
        try {
          Ge ? x.setAttributeNS(Ge, ze, Le) : x.setAttribute(ze, Le), Ta(x) ? Ct(x) : ll(e.removed);
        } catch {
        }
      }
    }
    jt("afterSanitizeAttributes", x, null);
  }, Ys = function Y(x) {
    let N = null;
    const V = Ea(x);
    for (jt("beforeSanitizeShadowDOM", x, null); N = V.nextNode(); )
      jt("uponSanitizeShadowNode", N, null), !Ma(N) && (N.content instanceof i && Y(N.content), Ra(N));
    jt("afterSanitizeShadowDOM", x, null);
  };
  return e.sanitize = function(Y) {
    let x = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, N = null, V = null, be = null, Ne = null;
    if (tn = !Y, tn && (Y = "<!-->"), typeof Y != "string" && !$a(Y))
      if (typeof Y.toString == "function") {
        if (Y = Y.toString(), typeof Y != "string")
          throw V0("dirty is not a string, aborting");
      } else
        throw V0("toString is not a function");
    if (!e.isSupported)
      return Y;
    if (y0 || nn(x), e.removed = [], typeof Y == "string" && (N0 = !1), N0) {
      if (Y.nodeName) {
        const Et = Ee(Y.nodeName);
        if (!re[Et] || Xe[Et])
          throw V0("root node is forbidden and cannot be sanitized in-place");
      }
    } else if (Y instanceof o)
      N = Ca("<!---->"), V = N.ownerDocument.importNode(Y, !0), V.nodeType === Y0.element && V.nodeName === "BODY" || V.nodeName === "HTML" ? N = V : N.appendChild(V);
    else {
      if (!Ft && !At && !ft && // eslint-disable-next-line unicorn/prefer-includes
      Y.indexOf("<") === -1)
        return S && Yt ? S.createHTML(Y) : Y;
      if (N = Ca(Y), !N)
        return Ft ? null : Yt ? E : "";
    }
    N && w0 && Ct(N.firstChild);
    const ze = Ea(N0 ? Y : N);
    for (; be = ze.nextNode(); )
      Ma(be) || (be.content instanceof i && Ys(be.content), Ra(be));
    if (N0)
      return Y;
    if (Ft) {
      if (Gt)
        for (Ne = O.call(N.ownerDocument); N.firstChild; )
          Ne.appendChild(N.firstChild);
      else
        Ne = N;
      return (me.shadowroot || me.shadowrootmode) && (Ne = R.call(r, Ne, !0)), Ne;
    }
    let Ge = ft ? N.outerHTML : N.innerHTML;
    return ft && re["!doctype"] && N.ownerDocument && N.ownerDocument.doctype && N.ownerDocument.doctype.name && Pe(qs, N.ownerDocument.doctype.name) && (Ge = "<!DOCTYPE " + N.ownerDocument.doctype.name + `>
` + Ge), At && Ar([Q, G, U], (Et) => {
      Ge = U0(Ge, Et, " ");
    }), S && Yt ? S.createHTML(Ge) : Ge;
  }, e.setConfig = function() {
    let Y = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    nn(Y), y0 = !0;
  }, e.clearConfig = function() {
    S0 = null, y0 = !1;
  }, e.isValidAttribute = function(Y, x, N) {
    S0 || nn({});
    const V = Ee(Y), be = Ee(x);
    return za(V, be, N);
  }, e.addHook = function(Y, x) {
    typeof x == "function" && (W[Y] = W[Y] || [], H0(W[Y], x));
  }, e.removeHook = function(Y) {
    if (W[Y])
      return ll(W[Y]);
  }, e.removeHooks = function(Y) {
    W[Y] && (W[Y] = []);
  }, e.removeAllHooks = function() {
    W = {};
  }, e;
}
Ns();
const {
  HtmlTagHydration: Kb,
  SvelteComponent: Qb,
  add_render_callback: Jb,
  append_hydration: ey,
  attr: ty,
  bubble: ry,
  check_outros: ny,
  children: ay,
  claim_component: iy,
  claim_element: ly,
  claim_html_tag: sy,
  claim_space: oy,
  claim_text: uy,
  create_component: cy,
  create_in_transition: hy,
  create_out_transition: my,
  destroy_component: dy,
  detach: fy,
  element: py,
  get_svelte_dataset: gy,
  group_outros: vy,
  init: _y,
  insert_hydration: by,
  listen: yy,
  mount_component: wy,
  run_all: ky,
  safe_not_equal: Dy,
  set_data: xy,
  space: Sy,
  stop_propagation: Ay,
  text: Fy,
  toggle_class: Cy,
  transition_in: Ey,
  transition_out: Ty
} = window.__gradio__svelte__internal, { createEventDispatcher: $y, onMount: My } = window.__gradio__svelte__internal, {
  SvelteComponent: zy,
  append_hydration: By,
  attr: Ry,
  bubble: qy,
  check_outros: Ny,
  children: Iy,
  claim_component: Ly,
  claim_element: Oy,
  claim_space: Py,
  create_animation: Hy,
  create_component: Uy,
  destroy_component: Vy,
  detach: Gy,
  element: Yy,
  ensure_array_like: Wy,
  fix_and_outro_and_destroy_block: jy,
  fix_position: Xy,
  group_outros: Zy,
  init: Ky,
  insert_hydration: Qy,
  mount_component: Jy,
  noop: ew,
  safe_not_equal: tw,
  set_style: rw,
  space: nw,
  transition_in: aw,
  transition_out: iw,
  update_keyed_each: lw
} = window.__gradio__svelte__internal, {
  SvelteComponent: sw,
  attr: ow,
  children: uw,
  claim_element: cw,
  detach: hw,
  element: mw,
  empty: dw,
  init: fw,
  insert_hydration: pw,
  noop: gw,
  safe_not_equal: vw,
  set_style: _w
} = window.__gradio__svelte__internal, {
  SvelteComponent: yc,
  append_hydration: Re,
  assign: wc,
  attr: oe,
  check_outros: dl,
  children: Qe,
  claim_component: pa,
  claim_element: bt,
  claim_space: C0,
  claim_svg_element: Ur,
  claim_text: kc,
  create_component: ga,
  destroy_component: va,
  detach: Te,
  element: yt,
  get_spread_object: Dc,
  get_spread_update: xc,
  get_svelte_dataset: fl,
  group_outros: pl,
  init: Sc,
  insert_hydration: tr,
  listen: Cr,
  mount_component: _a,
  noop: Ac,
  prevent_default: Fc,
  run_all: Cc,
  safe_not_equal: Is,
  set_data: Ec,
  space: E0,
  svg_element: Vr,
  text: Tc,
  toggle_class: Er,
  transition_in: a0,
  transition_out: f0
} = window.__gradio__svelte__internal, { onMount: $c } = window.__gradio__svelte__internal;
function gl(n) {
  let e, t;
  const r = [
    { autoscroll: (
      /*gradio*/
      n[6].autoscroll
    ) },
    { i18n: (
      /*gradio*/
      n[6].i18n
    ) },
    /*loading_status*/
    n[4],
    { variant: "center" }
  ];
  let a = {};
  for (let i = 0; i < r.length; i += 1)
    a = wc(a, r[i]);
  return e = new ec({ props: a }), {
    c() {
      ga(e.$$.fragment);
    },
    l(i) {
      pa(e.$$.fragment, i);
    },
    m(i, l) {
      _a(e, i, l), t = !0;
    },
    p(i, l) {
      const o = l & /*gradio, loading_status*/
      80 ? xc(r, [
        l & /*gradio*/
        64 && { autoscroll: (
          /*gradio*/
          i[6].autoscroll
        ) },
        l & /*gradio*/
        64 && { i18n: (
          /*gradio*/
          i[6].i18n
        ) },
        l & /*loading_status*/
        16 && Dc(
          /*loading_status*/
          i[4]
        ),
        r[3]
      ]) : {};
      e.$set(o);
    },
    i(i) {
      t || (a0(e.$$.fragment, i), t = !0);
    },
    o(i) {
      f0(e.$$.fragment, i), t = !1;
    },
    d(i) {
      va(e, i);
    }
  };
}
function Mc(n) {
  let e, t;
  return {
    c() {
      e = Vr("svg"), t = Vr("path"), this.h();
    },
    l(r) {
      e = Ur(r, "svg", {
        xmlns: !0,
        fill: !0,
        viewBox: !0,
        "stroke-width": !0,
        stroke: !0,
        class: !0
      });
      var a = Qe(e);
      t = Ur(a, "path", {
        "stroke-linecap": !0,
        "stroke-linejoin": !0,
        d: !0
      }), Qe(t).forEach(Te), a.forEach(Te), this.h();
    },
    h() {
      oe(t, "stroke-linecap", "round"), oe(t, "stroke-linejoin", "round"), oe(t, "d", "M3.75 3.75v4.5m0-4.5h4.5m-4.5 0L9 9M3.75 20.25v-4.5m0 4.5h4.5m-4.5 0L9 15M20.25 3.75h-4.5m4.5 0v4.5m0-4.5L15 9m5.25 11.25h-4.5m4.5 0v-4.5m0 4.5L15 15"), oe(e, "xmlns", "http://www.w3.org/2000/svg"), oe(e, "fill", "none"), oe(e, "viewBox", "0 0 24 24"), oe(e, "stroke-width", "1.5"), oe(e, "stroke", "currentColor"), oe(e, "class", "size-5");
    },
    m(r, a) {
      tr(r, e, a), Re(e, t);
    },
    d(r) {
      r && Te(e);
    }
  };
}
function zc(n) {
  let e, t;
  return {
    c() {
      e = Vr("svg"), t = Vr("path"), this.h();
    },
    l(r) {
      e = Ur(r, "svg", {
        xmlns: !0,
        fill: !0,
        viewBox: !0,
        "stroke-width": !0,
        stroke: !0,
        class: !0
      });
      var a = Qe(e);
      t = Ur(a, "path", {
        "stroke-linecap": !0,
        "stroke-linejoin": !0,
        d: !0
      }), Qe(t).forEach(Te), a.forEach(Te), this.h();
    },
    h() {
      oe(t, "stroke-linecap", "round"), oe(t, "stroke-linejoin", "round"), oe(t, "d", "M9 9V4.5M9 9H4.5M9 9 3.75 3.75M9 15v4.5M9 15H4.5M9 15l-5.25 5.25M15 9h4.5M15 9V4.5M15 9l5.25-5.25M15 15h4.5M15 15v4.5m0-4.5 5.25 5.25"), oe(e, "xmlns", "http://www.w3.org/2000/svg"), oe(e, "fill", "none"), oe(e, "viewBox", "0 0 24 24"), oe(e, "stroke-width", "1.5"), oe(e, "stroke", "currentColor"), oe(e, "class", "size-5");
    },
    m(r, a) {
      tr(r, e, a), Re(e, t);
    },
    d(r) {
      r && Te(e);
    }
  };
}
function vl(n) {
  var a;
  let e, t, r;
  return t = new ao({
    props: {
      min_height: (
        /*loading_status*/
        n[4] && /*loading_status*/
        ((a = n[4]) == null ? void 0 : a.status) !== "complete"
      ),
      value: (
        /*sandboxUrl*/
        n[7]
      ),
      elem_classes: (
        /*elem_classes*/
        n[3]
      ),
      visible: (
        /*visible*/
        n[5]
      )
    }
  }), t.$on(
    "change",
    /*change_handler*/
    n[17]
  ), {
    c() {
      e = yt("div"), ga(t.$$.fragment), this.h();
    },
    l(i) {
      e = bt(i, "DIV", { class: !0 });
      var l = Qe(e);
      pa(t.$$.fragment, l), l.forEach(Te), this.h();
    },
    h() {
      oe(e, "class", "h-full p-10 bg-slate-600 backdrop-blur");
    },
    m(i, l) {
      tr(i, e, l), _a(t, e, null), r = !0;
    },
    p(i, l) {
      var u;
      const o = {};
      l & /*loading_status*/
      16 && (o.min_height = /*loading_status*/
      i[4] && /*loading_status*/
      ((u = i[4]) == null ? void 0 : u.status) !== "complete"), l & /*sandboxUrl*/
      128 && (o.value = /*sandboxUrl*/
      i[7]), l & /*elem_classes*/
      8 && (o.elem_classes = /*elem_classes*/
      i[3]), l & /*visible*/
      32 && (o.visible = /*visible*/
      i[5]), t.$set(o);
    },
    i(i) {
      r || (a0(t.$$.fragment, i), r = !0);
    },
    o(i) {
      f0(t.$$.fragment, i), r = !1;
    },
    d(i) {
      i && Te(e), va(t);
    }
  };
}
function Bc(n) {
  let e, t, r, a, i, l, o, u, h, d = '<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" stroke-width="1.5" class="size-5"><path stroke-linecap="round" stroke-linejoin="round" d="M9 12h3.75M9 15h3.75M9 18h3.75m3 .75H18a2.25 2.25 0 0 0 2.25-2.25V6.108c0-1.135-.845-2.098-1.976-2.192a48.424 48.424 0 0 0-1.123-.08m-5.801 0c-.065.21-.1.433-.1.664 0 .414.336.75.75.75h4.5a.75.75 0 0 0 .75-.75 2.25 2.25 0 0 0-.1-.664m-5.8 0A2.251 2.251 0 0 1 13.5 2.25H15c1.012 0 1.867.668 2.15 1.586m-5.8 0c-.376.023-.75.05-1.124.08C9.095 4.01 8.25 4.973 8.25 6.108V8.25m0 0H4.875c-.621 0-1.125.504-1.125 1.125v11.25c0 .621.504 1.125 1.125 1.125h9.75c.621 0 1.125-.504 1.125-1.125V9.375c0-.621-.504-1.125-1.125-1.125H8.25ZM6.75 12h.008v.008H6.75V12Zm0 3h.008v.008H6.75V15Zm0 3h.008v.008H6.75V18Z"></path></svg>', p, b, y, D, A = '<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="size-5"><path stroke-linecap="round" stroke-linejoin="round" d="M16.023 9.348h4.992v-.001M2.985 19.644v-4.992m0 0h4.992m-4.993 0 3.181 3.183a8.25 8.25 0 0 0 13.803-3.7M4.031 9.865a8.25 8.25 0 0 1 13.803-3.7l3.181 3.182m0-4.991v4.99"></path></svg>', C, T, w = (
    /*iframeKey*/
    n[8]
  ), g, S, E, $, B, O, M = (
    /*loading_status*/
    n[4] && gl(n)
  );
  function R(U, ae) {
    return (
      /*isFullScreen*/
      U[9] ? zc : Mc
    );
  }
  let W = R(n), Q = W(n), G = vl(n);
  return {
    c() {
      M && M.c(), e = E0(), t = yt("div"), r = yt("div"), a = yt("div"), i = yt("span"), l = Tc(
        /*sandboxUrl*/
        n[7]
      ), o = E0(), u = yt("div"), h = yt("button"), h.innerHTML = d, p = E0(), b = yt("button"), Q.c(), y = E0(), D = yt("button"), D.innerHTML = A, C = E0(), T = yt("div"), G.c(), g = E0(), S = yt("div"), this.h();
    },
    l(U) {
      M && M.l(U), e = C0(U), t = bt(U, "DIV", { class: !0 });
      var ae = Qe(t);
      r = bt(ae, "DIV", { class: !0 });
      var ce = Qe(r);
      a = bt(ce, "DIV", { class: !0 });
      var $e = Qe(a);
      i = bt($e, "SPAN", { class: !0 });
      var ue = Qe(i);
      l = kc(
        ue,
        /*sandboxUrl*/
        n[7]
      ), ue.forEach(Te), $e.forEach(Te), o = C0(ce), u = bt(ce, "DIV", {});
      var ge = Qe(u);
      h = bt(ge, "BUTTON", { class: !0, "data-svelte-h": !0 }), fl(h) !== "svelte-1hhnc8c" && (h.innerHTML = d), p = C0(ge), b = bt(ge, "BUTTON", { class: !0 });
      var _e = Qe(b);
      Q.l(_e), _e.forEach(Te), y = C0(ge), D = bt(ge, "BUTTON", { class: !0, "data-svelte-h": !0 }), fl(D) !== "svelte-tkjltc" && (D.innerHTML = A), ge.forEach(Te), ce.forEach(Te), C = C0(ae), T = bt(ae, "DIV", { class: !0, style: !0 });
      var re = Qe(T);
      G.l(re), g = C0(re), S = bt(re, "DIV", {
        id: !0,
        class: !0,
        "aria-hidden": !0
      }), Qe(S).forEach(Te), re.forEach(Te), ae.forEach(Te), this.h();
    },
    h() {
      var U;
      oe(i, "class", "text-white bg-gray-700 px-3 py-1 rounded-r-md flex-1"), oe(a, "class", "bg-gray-800 p-2 rounded-t-md flex items-center mr-10"), oe(h, "class", "px-2 py-1 bg-green-500 text-white rounded cursor-pointer ml-2"), oe(b, "class", "px-2 py-1 bg-red-500 text-white rounded cursor-pointer"), oe(D, "class", "px-2 py-1 bg-blue-500 text-white rounded cursor-pointer"), oe(r, "class", "flex items-center justify-between bg-black border border-gray-300 rounded px-2 py-1 font-mono w-full"), oe(S, "id", "resizer"), oe(S, "class", "w-[15px] h-[15px] bg-gray-500 absolute right-0 bottom-0 cursor-[se-resize]"), oe(S, "aria-hidden", "true"), oe(T, "class", "relative w-full"), oe(T, "style", E = /*isFullScreen*/
      n[9] ? "height: 100%; width: 100%" : `height: ${/*height*/
      n[1]}px; width: ${/*width*/
      n[0]}px;`), Er(
        T,
        "pending",
        /*loading_status*/
        ((U = n[4]) == null ? void 0 : U.status) === "pending"
      ), oe(t, "class", "svelte-1t198jr"), Er(
        t,
        "full-screen",
        /*isFullScreen*/
        n[9]
      );
    },
    m(U, ae) {
      M && M.m(U, ae), tr(U, e, ae), tr(U, t, ae), Re(t, r), Re(r, a), Re(a, i), Re(i, l), Re(r, o), Re(r, u), Re(u, h), Re(u, p), Re(u, b), Q.m(b, null), Re(u, y), Re(u, D), Re(t, C), Re(t, T), G.m(T, null), Re(T, g), Re(T, S), $ = !0, B || (O = [
        Cr(
          h,
          "click",
          /*click_handler*/
          n[16]
        ),
        Cr(
          b,
          "click",
          /*toggleFullScreen*/
          n[12]
        ),
        Cr(
          D,
          "click",
          /*refreshHTML*/
          n[10]
        ),
        Cr(S, "mousedown", Fc(
          /*onClickResize*/
          n[11]
        ))
      ], B = !0);
    },
    p(U, ae) {
      var ce;
      /*loading_status*/
      U[4] ? M ? (M.p(U, ae), ae & /*loading_status*/
      16 && a0(M, 1)) : (M = gl(U), M.c(), a0(M, 1), M.m(e.parentNode, e)) : M && (pl(), f0(M, 1, 1, () => {
        M = null;
      }), dl()), (!$ || ae & /*sandboxUrl*/
      128) && Ec(
        l,
        /*sandboxUrl*/
        U[7]
      ), W !== (W = R(U)) && (Q.d(1), Q = W(U), Q && (Q.c(), Q.m(b, null))), ae & /*iframeKey*/
      256 && Is(w, w = /*iframeKey*/
      U[8]) ? (pl(), f0(G, 1, 1, Ac), dl(), G = vl(U), G.c(), a0(G, 1), G.m(T, g)) : G.p(U, ae), (!$ || ae & /*isFullScreen, height, width*/
      515 && E !== (E = /*isFullScreen*/
      U[9] ? "height: 100%; width: 100%" : `height: ${/*height*/
      U[1]}px; width: ${/*width*/
      U[0]}px;`)) && oe(T, "style", E), (!$ || ae & /*loading_status*/
      16) && Er(
        T,
        "pending",
        /*loading_status*/
        ((ce = U[4]) == null ? void 0 : ce.status) === "pending"
      ), (!$ || ae & /*isFullScreen*/
      512) && Er(
        t,
        "full-screen",
        /*isFullScreen*/
        U[9]
      );
    },
    i(U) {
      $ || (a0(M), a0(G), $ = !0);
    },
    o(U) {
      f0(M), f0(G), $ = !1;
    },
    d(U) {
      U && (Te(e), Te(t)), M && M.d(U), Q.d(), G.d(U), B = !1, Cc(O);
    }
  };
}
function Rc(n) {
  let e, t;
  return e = new Ro({
    props: {
      visible: (
        /*visible*/
        n[5]
      ),
      elem_id: (
        /*elem_id*/
        n[2]
      ),
      elem_classes: (
        /*elem_classes*/
        n[3]
      ),
      container: !1,
      $$slots: { default: [Bc] },
      $$scope: { ctx: n }
    }
  }), {
    c() {
      ga(e.$$.fragment);
    },
    l(r) {
      pa(e.$$.fragment, r);
    },
    m(r, a) {
      _a(e, r, a), t = !0;
    },
    p(r, [a]) {
      const i = {};
      a & /*visible*/
      32 && (i.visible = /*visible*/
      r[5]), a & /*elem_id*/
      4 && (i.elem_id = /*elem_id*/
      r[2]), a & /*elem_classes*/
      8 && (i.elem_classes = /*elem_classes*/
      r[3]), a & /*$$scope, isFullScreen, height, width, loading_status, iframeKey, sandboxUrl, elem_classes, visible, gradio*/
      67109883 && (i.$$scope = { dirty: a, ctx: r }), e.$set(i);
    },
    i(r) {
      t || (a0(e.$$.fragment, r), t = !0);
    },
    o(r) {
      f0(e.$$.fragment, r), t = !1;
    },
    d(r) {
      va(e, r);
    }
  };
}
function qc(n, e, t) {
  let { value: r = "" } = e, { elem_id: a = "" } = e, { elem_classes: i = [] } = e, { min_width: l = void 0 } = e, { loading_status: o } = e, { label: u } = e, { visible: h = !0 } = e, { gradio: d } = e, [p, b] = JSON.parse(r), y = 0;
  function D() {
    t(8, y += 1);
  }
  let { width: A = Math.max(l ?? 0, 800) } = e, { height: C = 600 } = e, T = !1, w, g, S, E;
  function $(G) {
    T = !0, w = G.clientY, g = G.clientX, S = C, E = A, window.addEventListener("mousemove", O);
  }
  function B() {
    T = !1, window.removeEventListener("mousemove", O);
  }
  function O(G) {
    T && (G.buttons === 0 ? B() : (t(1, C = Math.max(100, S + (G.clientY - w))), t(0, A = Math.max(l ?? 100, E + (G.clientX - g)))));
  }
  let M = !1;
  function R() {
    t(9, M = !M), M ? document.documentElement.requestFullscreen() : document.exitFullscreen();
  }
  $c(() => {
    document.addEventListener("fullscreenchange", () => {
      document.fullscreenElement || t(9, M = !1);
    });
  });
  const W = () => navigator.clipboard.writeText(p), Q = () => d.dispatch("change");
  return n.$$set = (G) => {
    "value" in G && t(13, r = G.value), "elem_id" in G && t(2, a = G.elem_id), "elem_classes" in G && t(3, i = G.elem_classes), "min_width" in G && t(14, l = G.min_width), "loading_status" in G && t(4, o = G.loading_status), "label" in G && t(15, u = G.label), "visible" in G && t(5, h = G.visible), "gradio" in G && t(6, d = G.gradio), "width" in G && t(0, A = G.width), "height" in G && t(1, C = G.height);
  }, n.$$.update = () => {
    n.$$.dirty & /*label, gradio*/
    32832 && d.dispatch("change"), n.$$.dirty & /*value*/
    8192 && t(7, [p, b] = JSON.parse(r), p);
  }, [
    A,
    C,
    a,
    i,
    o,
    h,
    d,
    p,
    y,
    M,
    D,
    $,
    R,
    r,
    l,
    u,
    W,
    Q
  ];
}
class bw extends yc {
  constructor(e) {
    super(), Sc(this, e, qc, Rc, Is, {
      value: 13,
      elem_id: 2,
      elem_classes: 3,
      min_width: 14,
      loading_status: 4,
      label: 15,
      visible: 5,
      gradio: 6,
      width: 0,
      height: 1
    });
  }
}
export {
  bw as default
};
